import re
import sys
import os

# create dict from validation_error_text_map in vk_validation_error_messages.h
vuid_dict = {
    'kVUIDUndefined' : 'VALIDATION_ERROR_UNDEFINED',
    '"VUID-VkAcquireNextImageInfoKHR-commonparent"' : 'VALIDATION_ERROR_00000009',
    '"VUID-VkAcquireNextImageInfoKHR-semaphore-01288"' : 'VALIDATION_ERROR_00000a10',
    '"VUID-VkAcquireNextImageInfoKHR-fence-01289"' : 'VALIDATION_ERROR_00000a12',
    '"VUID-VkAcquireNextImageInfoKHR-deviceMask-01290"' : 'VALIDATION_ERROR_00000a14',
    '"VUID-VkAcquireNextImageInfoKHR-deviceMask-01291"' : 'VALIDATION_ERROR_00000a16',
    '"VUID-VkAcquireNextImageInfoKHR-swapchain-01675"' : 'VALIDATION_ERROR_00000d16',
    '"VUID-VkAcquireNextImageInfoKHR-semaphore-01781"' : 'VALIDATION_ERROR_00000dea',
    '"VUID-VkAcquireNextImageInfoKHR-semaphore-01782"' : 'VALIDATION_ERROR_00000dec',
    '"VUID-VkAcquireNextImageInfoKHR-semaphore-01804"' : 'VALIDATION_ERROR_00000e18',
    '"VUID-VkAcquireNextImageInfoKHR-fence-parameter"' : 'VALIDATION_ERROR_00008801',
    '"VUID-VkAcquireNextImageInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_0001c40d',
    '"VUID-VkAcquireNextImageInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0002b00b',
    '"VUID-VkAcquireNextImageInfoKHR-semaphore-parameter"' : 'VALIDATION_ERROR_0002b801',
    '"VUID-VkAcquireNextImageInfoKHR-swapchain-parameter"' : 'VALIDATION_ERROR_0002f001',
    '"VUID-VkAllocationCallbacks-pfnAllocation-00632"' : 'VALIDATION_ERROR_002004f0',
    '"VUID-VkAllocationCallbacks-pfnReallocation-00633"' : 'VALIDATION_ERROR_002004f2',
    '"VUID-VkAllocationCallbacks-pfnFree-00634"' : 'VALIDATION_ERROR_002004f4',
    '"VUID-VkAllocationCallbacks-pfnInternalAllocation-00635"' : 'VALIDATION_ERROR_002004f6',
    '"VUID-VkAndroidSurfaceCreateInfoKHR-window-01248"' : 'VALIDATION_ERROR_004009c0',
    '"VUID-VkAndroidSurfaceCreateInfoKHR-flags-zerobitmask"' : 'VALIDATION_ERROR_00409005',
    '"VUID-VkAndroidSurfaceCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_0041c40d',
    '"VUID-VkAndroidSurfaceCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0042b00b',
    '"VUID-VkApplicationInfo-pApplicationName-parameter"' : 'VALIDATION_ERROR_0060f001',
    '"VUID-VkApplicationInfo-pEngineName-parameter"' : 'VALIDATION_ERROR_00615c01',
    '"VUID-VkApplicationInfo-pNext-pNext"' : 'VALIDATION_ERROR_0061c40d',
    '"VUID-VkApplicationInfo-sType-sType"' : 'VALIDATION_ERROR_0062b00b',
    '"VUID-VkAttachmentDescription-finalLayout-00843"' : 'VALIDATION_ERROR_00800696',
    '"VUID-VkAttachmentDescription-finalLayout-parameter"' : 'VALIDATION_ERROR_00808e01',
    '"VUID-VkAttachmentDescription-flags-parameter"' : 'VALIDATION_ERROR_00809001',
    '"VUID-VkAttachmentDescription-format-parameter"' : 'VALIDATION_ERROR_00809201',
    '"VUID-VkAttachmentDescription-initialLayout-parameter"' : 'VALIDATION_ERROR_0080b801',
    '"VUID-VkAttachmentDescription-loadOp-parameter"' : 'VALIDATION_ERROR_0080c201',
    '"VUID-VkAttachmentDescription-samples-parameter"' : 'VALIDATION_ERROR_0082b401',
    '"VUID-VkAttachmentDescription-stencilLoadOp-parameter"' : 'VALIDATION_ERROR_0082e001',
    '"VUID-VkAttachmentDescription-stencilStoreOp-parameter"' : 'VALIDATION_ERROR_0082e201',
    '"VUID-VkAttachmentDescription-storeOp-parameter"' : 'VALIDATION_ERROR_0082e401',
    '"VUID-VkAttachmentReference-layout-00857"' : 'VALIDATION_ERROR_00a006b2',
    '"VUID-VkAttachmentReference-layout-parameter"' : 'VALIDATION_ERROR_00a0be01',
    '"VUID-VkBindBufferMemoryInfo-commonparent"' : 'VALIDATION_ERROR_00c00009',
    '"VUID-VkBindBufferMemoryInfo-buffer-01593"' : 'VALIDATION_ERROR_00c00c72',
    '"VUID-VkBindBufferMemoryInfo-buffer-01594"' : 'VALIDATION_ERROR_00c00c74',
    '"VUID-VkBindBufferMemoryInfo-memoryOffset-01595"' : 'VALIDATION_ERROR_00c00c76',
    '"VUID-VkBindBufferMemoryInfo-buffer-01596"' : 'VALIDATION_ERROR_00c00c78',
    '"VUID-VkBindBufferMemoryInfo-buffer-01597"' : 'VALIDATION_ERROR_00c00c7a',
    '"VUID-VkBindBufferMemoryInfo-buffer-01598"' : 'VALIDATION_ERROR_00c00c7c',
    '"VUID-VkBindBufferMemoryInfo-memory-01599"' : 'VALIDATION_ERROR_00c00c7e',
    '"VUID-VkBindBufferMemoryInfo-memoryOffset-01600"' : 'VALIDATION_ERROR_00c00c80',
    '"VUID-VkBindBufferMemoryInfo-size-01601"' : 'VALIDATION_ERROR_00c00c82',
    '"VUID-VkBindBufferMemoryInfo-buffer-01602"' : 'VALIDATION_ERROR_00c00c84',
    '"VUID-VkBindBufferMemoryInfo-buffer-01603"' : 'VALIDATION_ERROR_00c00c86',
    '"VUID-VkBindBufferMemoryInfo-buffer-01604"' : 'VALIDATION_ERROR_00c00c88',
    '"VUID-VkBindBufferMemoryInfo-pNext-01605"' : 'VALIDATION_ERROR_00c00c8a',
    '"VUID-VkBindBufferMemoryInfo-memory-01900"' : 'VALIDATION_ERROR_00c00ed8',
    '"VUID-VkBindBufferMemoryInfo-buffer-parameter"' : 'VALIDATION_ERROR_00c01a01',
    '"VUID-VkBindBufferMemoryInfo-memory-parameter"' : 'VALIDATION_ERROR_00c0c601',
    '"VUID-VkBindBufferMemoryInfo-pNext-pNext"' : 'VALIDATION_ERROR_00c1c40d',
    '"VUID-VkBindBufferMemoryInfo-sType-sType"' : 'VALIDATION_ERROR_00c2b00b',
    '"VUID-VkBindImageMemoryInfo-commonparent"' : 'VALIDATION_ERROR_00e00009',
    '"VUID-VkBindImageMemoryInfo-image-01609"' : 'VALIDATION_ERROR_00e00c92',
    '"VUID-VkBindImageMemoryInfo-image-01610"' : 'VALIDATION_ERROR_00e00c94',
    '"VUID-VkBindImageMemoryInfo-memoryOffset-01611"' : 'VALIDATION_ERROR_00e00c96',
    '"VUID-VkBindImageMemoryInfo-memory-01612"' : 'VALIDATION_ERROR_00e00c98',
    '"VUID-VkBindImageMemoryInfo-memoryOffset-01613"' : 'VALIDATION_ERROR_00e00c9a',
    '"VUID-VkBindImageMemoryInfo-memory-01614"' : 'VALIDATION_ERROR_00e00c9c',
    '"VUID-VkBindImageMemoryInfo-pNext-01615"' : 'VALIDATION_ERROR_00e00c9e',
    '"VUID-VkBindImageMemoryInfo-pNext-01616"' : 'VALIDATION_ERROR_00e00ca0',
    '"VUID-VkBindImageMemoryInfo-pNext-01617"' : 'VALIDATION_ERROR_00e00ca2',
    '"VUID-VkBindImageMemoryInfo-pNext-01618"' : 'VALIDATION_ERROR_00e00ca4',
    '"VUID-VkBindImageMemoryInfo-pNext-01619"' : 'VALIDATION_ERROR_00e00ca6',
    '"VUID-VkBindImageMemoryInfo-pNext-01620"' : 'VALIDATION_ERROR_00e00ca8',
    '"VUID-VkBindImageMemoryInfo-pNext-01621"' : 'VALIDATION_ERROR_00e00caa',
    '"VUID-VkBindImageMemoryInfo-image-01622"' : 'VALIDATION_ERROR_00e00cac',
    '"VUID-VkBindImageMemoryInfo-image-01623"' : 'VALIDATION_ERROR_00e00cae',
    '"VUID-VkBindImageMemoryInfo-image-01624"' : 'VALIDATION_ERROR_00e00cb0',
    '"VUID-VkBindImageMemoryInfo-memory-01625"' : 'VALIDATION_ERROR_00e00cb2',
    '"VUID-VkBindImageMemoryInfo-pNext-01626"' : 'VALIDATION_ERROR_00e00cb4',
    '"VUID-VkBindImageMemoryInfo-pNext-01627"' : 'VALIDATION_ERROR_00e00cb6',
    '"VUID-VkBindImageMemoryInfo-pNext-01628"' : 'VALIDATION_ERROR_00e00cb8',
    '"VUID-VkBindImageMemoryInfo-pNext-01629"' : 'VALIDATION_ERROR_00e00cba',
    '"VUID-VkBindImageMemoryInfo-image-01630"' : 'VALIDATION_ERROR_00e00cbc',
    '"VUID-VkBindImageMemoryInfo-pNext-01631"' : 'VALIDATION_ERROR_00e00cbe',
    '"VUID-VkBindImageMemoryInfo-pNext-01632"' : 'VALIDATION_ERROR_00e00cc0',
    '"VUID-VkBindImageMemoryInfo-memory-01903"' : 'VALIDATION_ERROR_00e00ede',
    '"VUID-VkBindImageMemoryInfo-image-parameter"' : 'VALIDATION_ERROR_00e0a001',
    '"VUID-VkBindImageMemoryInfo-pNext-pNext"' : 'VALIDATION_ERROR_00e1c40d',
    '"VUID-VkBindImageMemoryInfo-sType-sType"' : 'VALIDATION_ERROR_00e2b00b',
    '"VUID-VkBindImageMemoryInfo-sType-unique"' : 'VALIDATION_ERROR_00e2b00f',
    '"VUID-VkBindImageMemorySwapchainInfoKHR-imageIndex-01644"' : 'VALIDATION_ERROR_01000cd8',
    '"VUID-VkBindImageMemorySwapchainInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0102b00b',
    '"VUID-VkBindImageMemorySwapchainInfoKHR-swapchain-parameter"' : 'VALIDATION_ERROR_0102f001',
    '"VUID-VkBindSparseInfo-commonparent"' : 'VALIDATION_ERROR_01200009',
    '"VUID-VkBindSparseInfo-pBufferBinds-parameter"' : 'VALIDATION_ERROR_01210201',
    '"VUID-VkBindSparseInfo-pImageBinds-parameter"' : 'VALIDATION_ERROR_01218001',
    '"VUID-VkBindSparseInfo-pImageOpaqueBinds-parameter"' : 'VALIDATION_ERROR_01218c01',
    '"VUID-VkBindSparseInfo-pNext-pNext"' : 'VALIDATION_ERROR_0121c40d',
    '"VUID-VkBindSparseInfo-pSignalSemaphores-parameter"' : 'VALIDATION_ERROR_01223401',
    '"VUID-VkBindSparseInfo-pWaitSemaphores-parameter"' : 'VALIDATION_ERROR_01227601',
    '"VUID-VkBindSparseInfo-sType-sType"' : 'VALIDATION_ERROR_0122b00b',
    '"VUID-VkBufferCreateInfo-size-00912"' : 'VALIDATION_ERROR_01400720',
    '"VUID-VkBufferCreateInfo-sharingMode-00913"' : 'VALIDATION_ERROR_01400722',
    '"VUID-VkBufferCreateInfo-sharingMode-00914"' : 'VALIDATION_ERROR_01400724',
    '"VUID-VkBufferCreateInfo-flags-00915"' : 'VALIDATION_ERROR_01400726',
    '"VUID-VkBufferCreateInfo-flags-00916"' : 'VALIDATION_ERROR_01400728',
    '"VUID-VkBufferCreateInfo-flags-00917"' : 'VALIDATION_ERROR_0140072a',
    '"VUID-VkBufferCreateInfo-flags-00918"' : 'VALIDATION_ERROR_0140072c',
    '"VUID-VkBufferCreateInfo-pNext-00920"' : 'VALIDATION_ERROR_01400730',
    '"VUID-VkBufferCreateInfo-sharingMode-01391"' : 'VALIDATION_ERROR_01400ade',
    '"VUID-VkBufferCreateInfo-sharingMode-01419"' : 'VALIDATION_ERROR_01400b16',
    '"VUID-VkBufferCreateInfo-pNext-01571"' : 'VALIDATION_ERROR_01400c46',
    '"VUID-VkBufferCreateInfo-flags-01887"' : 'VALIDATION_ERROR_01400ebe',
    '"VUID-VkBufferCreateInfo-None-01888"' : 'VALIDATION_ERROR_01400ec0',
    '"VUID-VkBufferCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_01409001',
    '"VUID-VkBufferCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0141c40d',
    '"VUID-VkBufferCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0142b00b',
    '"VUID-VkBufferCreateInfo-sType-unique"' : 'VALIDATION_ERROR_0142b00f',
    '"VUID-VkBufferCreateInfo-sharingMode-parameter"' : 'VALIDATION_ERROR_0142c001',
    '"VUID-VkBufferCreateInfo-usage-parameter"' : 'VALIDATION_ERROR_01430601',
    '"VUID-VkBufferCreateInfo-usage-requiredbitmask"' : 'VALIDATION_ERROR_01430603',
    '"VUID-VkBufferImageCopy-bufferOffset-00193"' : 'VALIDATION_ERROR_01600182',
    '"VUID-VkBufferImageCopy-bufferOffset-00194"' : 'VALIDATION_ERROR_01600184',
    '"VUID-VkBufferImageCopy-bufferRowLength-00195"' : 'VALIDATION_ERROR_01600186',
    '"VUID-VkBufferImageCopy-bufferImageHeight-00196"' : 'VALIDATION_ERROR_01600188',
    '"VUID-VkBufferImageCopy-imageOffset-00197"' : 'VALIDATION_ERROR_0160018a',
    '"VUID-VkBufferImageCopy-imageOffset-00198"' : 'VALIDATION_ERROR_0160018c',
    '"VUID-VkBufferImageCopy-srcImage-00199"' : 'VALIDATION_ERROR_0160018e',
    '"VUID-VkBufferImageCopy-imageOffset-00200"' : 'VALIDATION_ERROR_01600190',
    '"VUID-VkBufferImageCopy-srcImage-00201"' : 'VALIDATION_ERROR_01600192',
    '"VUID-VkBufferImageCopy-bufferRowLength-00203"' : 'VALIDATION_ERROR_01600196',
    '"VUID-VkBufferImageCopy-bufferImageHeight-00204"' : 'VALIDATION_ERROR_01600198',
    '"VUID-VkBufferImageCopy-imageOffset-00205"' : 'VALIDATION_ERROR_0160019a',
    '"VUID-VkBufferImageCopy-bufferOffset-00206"' : 'VALIDATION_ERROR_0160019c',
    '"VUID-VkBufferImageCopy-imageExtent-00207"' : 'VALIDATION_ERROR_0160019e',
    '"VUID-VkBufferImageCopy-imageExtent-00208"' : 'VALIDATION_ERROR_016001a0',
    '"VUID-VkBufferImageCopy-imageExtent-00209"' : 'VALIDATION_ERROR_016001a2',
    '"VUID-VkBufferImageCopy-aspectMask-00211"' : 'VALIDATION_ERROR_016001a6',
    '"VUID-VkBufferImageCopy-aspectMask-00212"' : 'VALIDATION_ERROR_016001a8',
    '"VUID-VkBufferImageCopy-baseArrayLayer-00213"' : 'VALIDATION_ERROR_016001aa',
    '"VUID-VkBufferImageCopy-None-00214"' : 'VALIDATION_ERROR_016001ac',
    '"VUID-VkBufferImageCopy-bufferOffset-01558"' : 'VALIDATION_ERROR_01600c2c',
    '"VUID-VkBufferImageCopy-bufferOffset-01559"' : 'VALIDATION_ERROR_01600c2e',
    '"VUID-VkBufferImageCopy-aspectMask-01560"' : 'VALIDATION_ERROR_01600c30',
    '"VUID-VkBufferImageCopy-None-01735"' : 'VALIDATION_ERROR_01600d8e',
    '"VUID-VkBufferImageCopy-None-01736"' : 'VALIDATION_ERROR_01600d90',
    '"VUID-VkBufferImageCopy-None-01737"' : 'VALIDATION_ERROR_01600d92',
    '"VUID-VkBufferImageCopy-None-01738"' : 'VALIDATION_ERROR_01600d94',
    '"VUID-VkBufferImageCopy-None-01739"' : 'VALIDATION_ERROR_01600d96',
    '"VUID-VkBufferImageCopy-None-01740"' : 'VALIDATION_ERROR_01600d98',
    '"VUID-VkBufferImageCopy-None-01741"' : 'VALIDATION_ERROR_01600d9a',
    '"VUID-VkBufferImageCopy-imageSubresource-parameter"' : 'VALIDATION_ERROR_0160aa01',
    '"VUID-VkBufferMemoryBarrier-offset-01187"' : 'VALIDATION_ERROR_01800946',
    '"VUID-VkBufferMemoryBarrier-size-01188"' : 'VALIDATION_ERROR_01800948',
    '"VUID-VkBufferMemoryBarrier-size-01189"' : 'VALIDATION_ERROR_0180094a',
    '"VUID-VkBufferMemoryBarrier-buffer-01190"' : 'VALIDATION_ERROR_0180094c',
    '"VUID-VkBufferMemoryBarrier-buffer-01191"' : 'VALIDATION_ERROR_0180094e',
    '"VUID-VkBufferMemoryBarrier-buffer-01192"' : 'VALIDATION_ERROR_01800950',
    '"VUID-VkBufferMemoryBarrier-buffer-01193"' : 'VALIDATION_ERROR_01800952',
    '"VUID-VkBufferMemoryBarrier-buffer-01196"' : 'VALIDATION_ERROR_01800958',
    '"VUID-VkBufferMemoryBarrier-buffer-01763"' : 'VALIDATION_ERROR_01800dc6',
    '"VUID-VkBufferMemoryBarrier-buffer-01764"' : 'VALIDATION_ERROR_01800dc8',
    '"VUID-VkBufferMemoryBarrier-buffer-01765"' : 'VALIDATION_ERROR_01800dca',
    '"VUID-VkBufferMemoryBarrier-buffer-01931"' : 'VALIDATION_ERROR_01800f16',
    '"VUID-VkBufferMemoryBarrier-buffer-parameter"' : 'VALIDATION_ERROR_01801a01',
    '"VUID-VkBufferMemoryBarrier-dstAccessMask-parameter"' : 'VALIDATION_ERROR_01806801',
    '"VUID-VkBufferMemoryBarrier-pNext-pNext"' : 'VALIDATION_ERROR_0181c40d',
    '"VUID-VkBufferMemoryBarrier-sType-sType"' : 'VALIDATION_ERROR_0182b00b',
    '"VUID-VkBufferMemoryBarrier-srcAccessMask-parameter"' : 'VALIDATION_ERROR_0182c401',
    '"VUID-VkBufferViewCreateInfo-offset-00925"' : 'VALIDATION_ERROR_01a0073a',
    '"VUID-VkBufferViewCreateInfo-offset-00926"' : 'VALIDATION_ERROR_01a0073c',
    '"VUID-VkBufferViewCreateInfo-range-00928"' : 'VALIDATION_ERROR_01a00740',
    '"VUID-VkBufferViewCreateInfo-range-00929"' : 'VALIDATION_ERROR_01a00742',
    '"VUID-VkBufferViewCreateInfo-range-00930"' : 'VALIDATION_ERROR_01a00744',
    '"VUID-VkBufferViewCreateInfo-offset-00931"' : 'VALIDATION_ERROR_01a00746',
    '"VUID-VkBufferViewCreateInfo-buffer-00932"' : 'VALIDATION_ERROR_01a00748',
    '"VUID-VkBufferViewCreateInfo-buffer-00933"' : 'VALIDATION_ERROR_01a0074a',
    '"VUID-VkBufferViewCreateInfo-buffer-00934"' : 'VALIDATION_ERROR_01a0074c',
    '"VUID-VkBufferViewCreateInfo-buffer-00935"' : 'VALIDATION_ERROR_01a0074e',
    '"VUID-VkBufferViewCreateInfo-buffer-parameter"' : 'VALIDATION_ERROR_01a01a01',
    '"VUID-VkBufferViewCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_01a09005',
    '"VUID-VkBufferViewCreateInfo-format-parameter"' : 'VALIDATION_ERROR_01a09201',
    '"VUID-VkBufferViewCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_01a1c40d',
    '"VUID-VkBufferViewCreateInfo-sType-sType"' : 'VALIDATION_ERROR_01a2b00b',
    '"VUID-VkClearAttachment-aspectMask-00019"' : 'VALIDATION_ERROR_01c00026',
    '"VUID-VkClearAttachment-aspectMask-00020"' : 'VALIDATION_ERROR_01c00028',
    '"VUID-VkClearAttachment-clearValue-00021"' : 'VALIDATION_ERROR_01c0002a',
    '"VUID-VkClearAttachment-aspectMask-parameter"' : 'VALIDATION_ERROR_01c00c01',
    '"VUID-VkClearAttachment-aspectMask-requiredbitmask"' : 'VALIDATION_ERROR_01c00c03',
    '"VUID-VkClearAttachment-commandBuffer-01809"' : 'VALIDATION_ERROR_01c00e22',
    '"VUID-VkClearAttachment-commandBuffer-01810"' : 'VALIDATION_ERROR_01c00e24',
    '"VUID-VkClearDepthStencilValue-depth-00022"' : 'VALIDATION_ERROR_01e0002c',
    '"VUID-VkClearValue-depthStencil-00023"' : 'VALIDATION_ERROR_0200002e',
    '"VUID-VkCmdProcessCommandsInfoNVX-commonparent"' : 'VALIDATION_ERROR_02200009',
    '"VUID-VkCmdProcessCommandsInfoNVX-objectTable-01331"' : 'VALIDATION_ERROR_02200a66',
    '"VUID-VkCmdProcessCommandsInfoNVX-indirectCommandsTokenCount-01332"' : 'VALIDATION_ERROR_02200a68',
    '"VUID-VkCmdProcessCommandsInfoNVX-tokenType-01333"' : 'VALIDATION_ERROR_02200a6a',
    '"VUID-VkCmdProcessCommandsInfoNVX-targetCommandBuffer-01334"' : 'VALIDATION_ERROR_02200a6c',
    '"VUID-VkCmdProcessCommandsInfoNVX-targetCommandBuffer-01335"' : 'VALIDATION_ERROR_02200a6e',
    '"VUID-VkCmdProcessCommandsInfoNVX-targetCommandBuffer-01336"' : 'VALIDATION_ERROR_02200a70',
    '"VUID-VkCmdProcessCommandsInfoNVX-targetCommandBuffer-01337"' : 'VALIDATION_ERROR_02200a72',
    '"VUID-VkCmdProcessCommandsInfoNVX-sequencesCountBuffer-01338"' : 'VALIDATION_ERROR_02200a74',
    '"VUID-VkCmdProcessCommandsInfoNVX-sequencesCountBuffer-01339"' : 'VALIDATION_ERROR_02200a76',
    '"VUID-VkCmdProcessCommandsInfoNVX-sequencesIndexBuffer-01340"' : 'VALIDATION_ERROR_02200a78',
    '"VUID-VkCmdProcessCommandsInfoNVX-sequencesIndexBuffer-01341"' : 'VALIDATION_ERROR_02200a7a',
    '"VUID-VkCmdProcessCommandsInfoNVX-indirectCommandsLayout-parameter"' : 'VALIDATION_ERROR_0220b401',
    '"VUID-VkCmdProcessCommandsInfoNVX-indirectCommandsTokenCount-arraylength"' : 'VALIDATION_ERROR_0220b61b',
    '"VUID-VkCmdProcessCommandsInfoNVX-objectTable-parameter"' : 'VALIDATION_ERROR_0220d801',
    '"VUID-VkCmdProcessCommandsInfoNVX-pIndirectCommandsTokens-parameter"' : 'VALIDATION_ERROR_02219401',
    '"VUID-VkCmdProcessCommandsInfoNVX-pNext-pNext"' : 'VALIDATION_ERROR_0221c40d',
    '"VUID-VkCmdProcessCommandsInfoNVX-sType-sType"' : 'VALIDATION_ERROR_0222b00b',
    '"VUID-VkCmdProcessCommandsInfoNVX-sequencesCountBuffer-parameter"' : 'VALIDATION_ERROR_0222ba01',
    '"VUID-VkCmdProcessCommandsInfoNVX-sequencesIndexBuffer-parameter"' : 'VALIDATION_ERROR_0222bc01',
    '"VUID-VkCmdProcessCommandsInfoNVX-targetCommandBuffer-parameter"' : 'VALIDATION_ERROR_0222f601',
    '"VUID-VkCmdReserveSpaceForCommandsInfoNVX-commonparent"' : 'VALIDATION_ERROR_02400009',
    '"VUID-VkCmdReserveSpaceForCommandsInfoNVX-indirectCommandsLayout-parameter"' : 'VALIDATION_ERROR_0240b401',
    '"VUID-VkCmdReserveSpaceForCommandsInfoNVX-objectTable-parameter"' : 'VALIDATION_ERROR_0240d801',
    '"VUID-VkCmdReserveSpaceForCommandsInfoNVX-pNext-pNext"' : 'VALIDATION_ERROR_0241c40d',
    '"VUID-VkCmdReserveSpaceForCommandsInfoNVX-sType-sType"' : 'VALIDATION_ERROR_0242b00b',
    '"VUID-VkCommandBufferAllocateInfo-commandBufferCount-00044"' : 'VALIDATION_ERROR_02600058',
    '"VUID-VkCommandBufferAllocateInfo-commandPool-parameter"' : 'VALIDATION_ERROR_02602801',
    '"VUID-VkCommandBufferAllocateInfo-level-parameter"' : 'VALIDATION_ERROR_0260c001',
    '"VUID-VkCommandBufferAllocateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0261c40d',
    '"VUID-VkCommandBufferAllocateInfo-sType-sType"' : 'VALIDATION_ERROR_0262b00b',
    '"VUID-VkCommandBufferBeginInfo-flags-00053"' : 'VALIDATION_ERROR_0280006a',
    '"VUID-VkCommandBufferBeginInfo-flags-00054"' : 'VALIDATION_ERROR_0280006c',
    '"VUID-VkCommandBufferBeginInfo-flags-00055"' : 'VALIDATION_ERROR_0280006e',
    '"VUID-VkCommandBufferBeginInfo-flags-parameter"' : 'VALIDATION_ERROR_02809001',
    '"VUID-VkCommandBufferBeginInfo-pNext-pNext"' : 'VALIDATION_ERROR_0281c40d',
    '"VUID-VkCommandBufferBeginInfo-sType-sType"' : 'VALIDATION_ERROR_0282b00b',
    '"VUID-VkCommandBufferInheritanceInfo-commonparent"' : 'VALIDATION_ERROR_02a00009',
    '"VUID-VkCommandBufferInheritanceInfo-occlusionQueryEnable-00056"' : 'VALIDATION_ERROR_02a00070',
    '"VUID-VkCommandBufferInheritanceInfo-queryFlags-00057"' : 'VALIDATION_ERROR_02a00072',
    '"VUID-VkCommandBufferInheritanceInfo-pipelineStatistics-00058"' : 'VALIDATION_ERROR_02a00074',
    '"VUID-VkCommandBufferInheritanceInfo-pNext-pNext"' : 'VALIDATION_ERROR_02a1c40d',
    '"VUID-VkCommandBufferInheritanceInfo-sType-sType"' : 'VALIDATION_ERROR_02a2b00b',
    '"VUID-VkCommandPoolCreateInfo-queueFamilyIndex-00039"' : 'VALIDATION_ERROR_02c0004e',
    '"VUID-VkCommandPoolCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_02c09001',
    '"VUID-VkCommandPoolCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_02c1c40d',
    '"VUID-VkCommandPoolCreateInfo-sType-sType"' : 'VALIDATION_ERROR_02c2b00b',
    '"VUID-VkComponentMapping-a-parameter"' : 'VALIDATION_ERROR_02e00001',
    '"VUID-VkComponentMapping-b-parameter"' : 'VALIDATION_ERROR_02e01001',
    '"VUID-VkComponentMapping-g-parameter"' : 'VALIDATION_ERROR_02e09a01',
    '"VUID-VkComponentMapping-r-parameter"' : 'VALIDATION_ERROR_02e2a201',
    '"VUID-VkComputePipelineCreateInfo-commonparent"' : 'VALIDATION_ERROR_03000009',
    '"VUID-VkComputePipelineCreateInfo-flags-00697"' : 'VALIDATION_ERROR_03000572',
    '"VUID-VkComputePipelineCreateInfo-flags-00698"' : 'VALIDATION_ERROR_03000574',
    '"VUID-VkComputePipelineCreateInfo-flags-00699"' : 'VALIDATION_ERROR_03000576',
    '"VUID-VkComputePipelineCreateInfo-flags-00700"' : 'VALIDATION_ERROR_03000578',
    '"VUID-VkComputePipelineCreateInfo-stage-00701"' : 'VALIDATION_ERROR_0300057a',
    '"VUID-VkComputePipelineCreateInfo-stage-00702"' : 'VALIDATION_ERROR_0300057c',
    '"VUID-VkComputePipelineCreateInfo-layout-00703"' : 'VALIDATION_ERROR_0300057e',
    '"VUID-VkComputePipelineCreateInfo-layout-01687"' : 'VALIDATION_ERROR_03000d2e',
    '"VUID-VkComputePipelineCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_03009001',
    '"VUID-VkComputePipelineCreateInfo-layout-parameter"' : 'VALIDATION_ERROR_0300be01',
    '"VUID-VkComputePipelineCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0301c40d',
    '"VUID-VkComputePipelineCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0302b00b',
    '"VUID-VkComputePipelineCreateInfo-stage-parameter"' : 'VALIDATION_ERROR_0302d801',
    '"VUID-VkCopyDescriptorSet-commonparent"' : 'VALIDATION_ERROR_03200009',
    '"VUID-VkCopyDescriptorSet-srcBinding-00345"' : 'VALIDATION_ERROR_032002b2',
    '"VUID-VkCopyDescriptorSet-srcArrayElement-00346"' : 'VALIDATION_ERROR_032002b4',
    '"VUID-VkCopyDescriptorSet-dstBinding-00347"' : 'VALIDATION_ERROR_032002b6',
    '"VUID-VkCopyDescriptorSet-dstArrayElement-00348"' : 'VALIDATION_ERROR_032002b8',
    '"VUID-VkCopyDescriptorSet-srcSet-00349"' : 'VALIDATION_ERROR_032002ba',
    '"VUID-VkCopyDescriptorSet-srcSet-01918"' : 'VALIDATION_ERROR_03200efc',
    '"VUID-VkCopyDescriptorSet-srcSet-01919"' : 'VALIDATION_ERROR_03200efe',
    '"VUID-VkCopyDescriptorSet-srcSet-01920"' : 'VALIDATION_ERROR_03200f00',
    '"VUID-VkCopyDescriptorSet-srcSet-01921"' : 'VALIDATION_ERROR_03200f02',
    '"VUID-VkCopyDescriptorSet-dstSet-parameter"' : 'VALIDATION_ERROR_03207601',
    '"VUID-VkCopyDescriptorSet-pNext-pNext"' : 'VALIDATION_ERROR_0321c40d',
    '"VUID-VkCopyDescriptorSet-sType-sType"' : 'VALIDATION_ERROR_0322b00b',
    '"VUID-VkCopyDescriptorSet-srcSet-parameter"' : 'VALIDATION_ERROR_0322d201',
    '"VUID-VkD3D12FenceSubmitInfoKHR-waitSemaphoreValuesCount-00079"' : 'VALIDATION_ERROR_0340009e',
    '"VUID-VkD3D12FenceSubmitInfoKHR-signalSemaphoreValuesCount-00080"' : 'VALIDATION_ERROR_034000a0',
    '"VUID-VkD3D12FenceSubmitInfoKHR-pSignalSemaphoreValues-parameter"' : 'VALIDATION_ERROR_03423201',
    '"VUID-VkD3D12FenceSubmitInfoKHR-pWaitSemaphoreValues-parameter"' : 'VALIDATION_ERROR_03427401',
    '"VUID-VkD3D12FenceSubmitInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0342b00b',
    '"VUID-VkDebugMarkerMarkerInfoEXT-pMarkerName-parameter"' : 'VALIDATION_ERROR_0361a801',
    '"VUID-VkDebugMarkerMarkerInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_0361c40d',
    '"VUID-VkDebugMarkerMarkerInfoEXT-sType-sType"' : 'VALIDATION_ERROR_0362b00b',
    '"VUID-VkDebugMarkerObjectNameInfoEXT-objectType-01490"' : 'VALIDATION_ERROR_03800ba4',
    '"VUID-VkDebugMarkerObjectNameInfoEXT-object-01491"' : 'VALIDATION_ERROR_03800ba6',
    '"VUID-VkDebugMarkerObjectNameInfoEXT-object-01492"' : 'VALIDATION_ERROR_03800ba8',
    '"VUID-VkDebugMarkerObjectNameInfoEXT-objectType-parameter"' : 'VALIDATION_ERROR_0380da01',
    '"VUID-VkDebugMarkerObjectNameInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_0381c40d',
    '"VUID-VkDebugMarkerObjectNameInfoEXT-pObjectName-parameter"' : 'VALIDATION_ERROR_0381ce01',
    '"VUID-VkDebugMarkerObjectNameInfoEXT-sType-sType"' : 'VALIDATION_ERROR_0382b00b',
    '"VUID-VkDebugMarkerObjectTagInfoEXT-objectType-01493"' : 'VALIDATION_ERROR_03a00baa',
    '"VUID-VkDebugMarkerObjectTagInfoEXT-object-01494"' : 'VALIDATION_ERROR_03a00bac',
    '"VUID-VkDebugMarkerObjectTagInfoEXT-object-01495"' : 'VALIDATION_ERROR_03a00bae',
    '"VUID-VkDebugMarkerObjectTagInfoEXT-objectType-parameter"' : 'VALIDATION_ERROR_03a0da01',
    '"VUID-VkDebugMarkerObjectTagInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_03a1c40d',
    '"VUID-VkDebugMarkerObjectTagInfoEXT-pTag-parameter"' : 'VALIDATION_ERROR_03a25a01',
    '"VUID-VkDebugMarkerObjectTagInfoEXT-sType-sType"' : 'VALIDATION_ERROR_03a2b00b',
    '"VUID-VkDebugMarkerObjectTagInfoEXT-tagSize-arraylength"' : 'VALIDATION_ERROR_03a2f41b',
    '"VUID-VkDebugReportCallbackCreateInfoEXT-pfnCallback-01385"' : 'VALIDATION_ERROR_03c00ad2',
    '"VUID-VkDebugReportCallbackCreateInfoEXT-flags-parameter"' : 'VALIDATION_ERROR_03c09001',
    '"VUID-VkDebugReportCallbackCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_03c2b00b',
    '"VUID-VkDedicatedAllocationBufferCreateInfoNV-sType-sType"' : 'VALIDATION_ERROR_03e2b00b',
    '"VUID-VkDedicatedAllocationImageCreateInfoNV-dedicatedAllocation-00994"' : 'VALIDATION_ERROR_040007c4',
    '"VUID-VkDedicatedAllocationImageCreateInfoNV-sType-sType"' : 'VALIDATION_ERROR_0402b00b',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-commonparent"' : 'VALIDATION_ERROR_04200009',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-image-00649"' : 'VALIDATION_ERROR_04200512',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-image-00650"' : 'VALIDATION_ERROR_04200514',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-buffer-00651"' : 'VALIDATION_ERROR_04200516',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-image-00652"' : 'VALIDATION_ERROR_04200518',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-buffer-00653"' : 'VALIDATION_ERROR_0420051a',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-image-00654"' : 'VALIDATION_ERROR_0420051c',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-buffer-00655"' : 'VALIDATION_ERROR_0420051e',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-buffer-parameter"' : 'VALIDATION_ERROR_04201a01',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-image-parameter"' : 'VALIDATION_ERROR_0420a001',
    '"VUID-VkDedicatedAllocationMemoryAllocateInfoNV-sType-sType"' : 'VALIDATION_ERROR_0422b00b',
    '"VUID-VkDescriptorBufferInfo-offset-00340"' : 'VALIDATION_ERROR_044002a8',
    '"VUID-VkDescriptorBufferInfo-range-00341"' : 'VALIDATION_ERROR_044002aa',
    '"VUID-VkDescriptorBufferInfo-range-00342"' : 'VALIDATION_ERROR_044002ac',
    '"VUID-VkDescriptorBufferInfo-buffer-parameter"' : 'VALIDATION_ERROR_04401a01',
    '"VUID-VkDescriptorImageInfo-commonparent"' : 'VALIDATION_ERROR_04600009',
    '"VUID-VkDescriptorImageInfo-imageView-00343"' : 'VALIDATION_ERROR_046002ae',
    '"VUID-VkDescriptorImageInfo-imageLayout-00344"' : 'VALIDATION_ERROR_046002b0',
    '"VUID-VkDescriptorImageInfo-sampler-01563"' : 'VALIDATION_ERROR_04600c36',
    '"VUID-VkDescriptorImageInfo-sampler-01564"' : 'VALIDATION_ERROR_04600c38',
    '"VUID-VkDescriptorPoolCreateInfo-maxSets-00301"' : 'VALIDATION_ERROR_0480025a',
    '"VUID-VkDescriptorPoolCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_04809001',
    '"VUID-VkDescriptorPoolCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0481c40d',
    '"VUID-VkDescriptorPoolCreateInfo-pPoolSizes-parameter"' : 'VALIDATION_ERROR_0481e401',
    '"VUID-VkDescriptorPoolCreateInfo-poolSizeCount-arraylength"' : 'VALIDATION_ERROR_0482881b',
    '"VUID-VkDescriptorPoolCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0482b00b',
    '"VUID-VkDescriptorPoolSize-descriptorCount-00302"' : 'VALIDATION_ERROR_04a0025c',
    '"VUID-VkDescriptorPoolSize-type-parameter"' : 'VALIDATION_ERROR_04a30401',
    '"VUID-VkDescriptorSetAllocateInfo-commonparent"' : 'VALIDATION_ERROR_04c00009',
    '"VUID-VkDescriptorSetAllocateInfo-descriptorSetCount-00306"' : 'VALIDATION_ERROR_04c00264',
    '"VUID-VkDescriptorSetAllocateInfo-descriptorPool-00307"' : 'VALIDATION_ERROR_04c00266',
    '"VUID-VkDescriptorSetAllocateInfo-pSetLayouts-00308"' : 'VALIDATION_ERROR_04c00268',
    '"VUID-VkDescriptorSetAllocateInfo-pSetLayouts-03044"' : 'VALIDATION_ERROR_04c017c8',
    '"VUID-VkDescriptorSetAllocateInfo-descriptorPool-parameter"' : 'VALIDATION_ERROR_04c04601',
    '"VUID-VkDescriptorSetAllocateInfo-descriptorSetCount-arraylength"' : 'VALIDATION_ERROR_04c04a1b',
    '"VUID-VkDescriptorSetAllocateInfo-pNext-pNext"' : 'VALIDATION_ERROR_04c1c40d',
    '"VUID-VkDescriptorSetAllocateInfo-pSetLayouts-parameter"' : 'VALIDATION_ERROR_04c22c01',
    '"VUID-VkDescriptorSetAllocateInfo-sType-sType"' : 'VALIDATION_ERROR_04c2b00b',
    '"VUID-VkDescriptorSetLayoutBinding-descriptorType-00282"' : 'VALIDATION_ERROR_04e00234',
    '"VUID-VkDescriptorSetLayoutBinding-descriptorCount-00283"' : 'VALIDATION_ERROR_04e00236',
    '"VUID-VkDescriptorSetLayoutBinding-descriptorType-01510"' : 'VALIDATION_ERROR_04e00bcc',
    '"VUID-VkDescriptorSetLayoutBinding-descriptorType-parameter"' : 'VALIDATION_ERROR_04e04e01',
    '"VUID-VkDescriptorSetLayoutCreateInfo-binding-00279"' : 'VALIDATION_ERROR_0500022e',
    '"VUID-VkDescriptorSetLayoutCreateInfo-flags-00280"' : 'VALIDATION_ERROR_05000230',
    '"VUID-VkDescriptorSetLayoutCreateInfo-flags-00281"' : 'VALIDATION_ERROR_05000232',
    '"VUID-VkDescriptorSetLayoutCreateInfo-flags-03000"' : 'VALIDATION_ERROR_05001770',
    '"VUID-VkDescriptorSetLayoutCreateInfo-descriptorType-03001"' : 'VALIDATION_ERROR_05001772',
    '"VUID-VkDescriptorSetLayoutCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_05009001',
    '"VUID-VkDescriptorSetLayoutCreateInfo-pBindings-parameter"' : 'VALIDATION_ERROR_0500fc01',
    '"VUID-VkDescriptorSetLayoutCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0501c40d',
    '"VUID-VkDescriptorSetLayoutCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0502b00b',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-commonparent"' : 'VALIDATION_ERROR_05200009',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-templateType-00350"' : 'VALIDATION_ERROR_052002bc',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-templateType-00351"' : 'VALIDATION_ERROR_052002be',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-templateType-00352"' : 'VALIDATION_ERROR_052002c0',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-templateType-00353"' : 'VALIDATION_ERROR_052002c2',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-descriptorSetLayout-parameter"' : 'VALIDATION_ERROR_05204c01',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-descriptorUpdateEntryCount-arraylength"' : 'VALIDATION_ERROR_0520501b',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_05209005',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-pDescriptorUpdateEntries-parameter"' : 'VALIDATION_ERROR_05213201',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0521c40d',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0522b00b',
    '"VUID-VkDescriptorUpdateTemplateCreateInfo-templateType-parameter"' : 'VALIDATION_ERROR_0522f801',
    '"VUID-VkDescriptorUpdateTemplateEntry-dstBinding-00354"' : 'VALIDATION_ERROR_054002c4',
    '"VUID-VkDescriptorUpdateTemplateEntry-dstArrayElement-00355"' : 'VALIDATION_ERROR_054002c6',
    '"VUID-VkDescriptorUpdateTemplateEntry-descriptorType-parameter"' : 'VALIDATION_ERROR_05404e01',
    '"VUID-VkDeviceCreateInfo-queueFamilyIndex-00372"' : 'VALIDATION_ERROR_056002e8',
    '"VUID-VkDeviceCreateInfo-pNext-00373"' : 'VALIDATION_ERROR_056002ea',
    '"VUID-VkDeviceCreateInfo-ppEnabledExtensionNames-00374"' : 'VALIDATION_ERROR_056002ec',
    '"VUID-VkDeviceCreateInfo-ppEnabledExtensionNames-01840"' : 'VALIDATION_ERROR_05600e60',
    '"VUID-VkDeviceCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_05609005',
    '"VUID-VkDeviceCreateInfo-pEnabledFeatures-parameter"' : 'VALIDATION_ERROR_05615a01',
    '"VUID-VkDeviceCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0561c40d',
    '"VUID-VkDeviceCreateInfo-pQueueCreateInfos-parameter"' : 'VALIDATION_ERROR_0561fe01',
    '"VUID-VkDeviceCreateInfo-ppEnabledExtensionNames-parameter"' : 'VALIDATION_ERROR_05628e01',
    '"VUID-VkDeviceCreateInfo-ppEnabledLayerNames-parameter"' : 'VALIDATION_ERROR_05629001',
    '"VUID-VkDeviceCreateInfo-queueCreateInfoCount-arraylength"' : 'VALIDATION_ERROR_0562a01b',
    '"VUID-VkDeviceCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0562b00b',
    '"VUID-VkDeviceCreateInfo-sType-unique"' : 'VALIDATION_ERROR_0562b00f',
    '"VUID-VkDeviceEventInfoEXT-deviceEvent-parameter"' : 'VALIDATION_ERROR_05805801',
    '"VUID-VkDeviceEventInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_0581c40d',
    '"VUID-VkDeviceEventInfoEXT-sType-sType"' : 'VALIDATION_ERROR_0582b00b',
    '"VUID-VkDeviceGeneratedCommandsFeaturesNVX-pNext-pNext"' : 'VALIDATION_ERROR_05a1c40d',
    '"VUID-VkDeviceGeneratedCommandsFeaturesNVX-sType-sType"' : 'VALIDATION_ERROR_05a2b00b',
    '"VUID-VkDeviceGeneratedCommandsLimitsNVX-pNext-pNext"' : 'VALIDATION_ERROR_05c1c40d',
    '"VUID-VkDeviceGeneratedCommandsLimitsNVX-sType-sType"' : 'VALIDATION_ERROR_05c2b00b',
    '"VUID-VkDeviceGroupBindSparseInfo-resourceDeviceIndex-01118"' : 'VALIDATION_ERROR_05e008bc',
    '"VUID-VkDeviceGroupBindSparseInfo-memoryDeviceIndex-01119"' : 'VALIDATION_ERROR_05e008be',
    '"VUID-VkDeviceGroupBindSparseInfo-sType-sType"' : 'VALIDATION_ERROR_05e2b00b',
    '"VUID-VkDeviceGroupCommandBufferBeginInfo-deviceMask-00106"' : 'VALIDATION_ERROR_060000d4',
    '"VUID-VkDeviceGroupCommandBufferBeginInfo-deviceMask-00107"' : 'VALIDATION_ERROR_060000d6',
    '"VUID-VkDeviceGroupCommandBufferBeginInfo-sType-sType"' : 'VALIDATION_ERROR_0602b00b',
    '"VUID-VkDeviceGroupDeviceCreateInfo-pPhysicalDevices-00375"' : 'VALIDATION_ERROR_062002ee',
    '"VUID-VkDeviceGroupDeviceCreateInfo-pPhysicalDevices-00376"' : 'VALIDATION_ERROR_062002f0',
    '"VUID-VkDeviceGroupDeviceCreateInfo-physicalDeviceCount-00377"' : 'VALIDATION_ERROR_062002f2',
    '"VUID-VkDeviceGroupDeviceCreateInfo-pPhysicalDevices-parameter"' : 'VALIDATION_ERROR_0621dc01',
    '"VUID-VkDeviceGroupDeviceCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0622b00b',
    '"VUID-VkDeviceGroupPresentInfoKHR-swapchainCount-01297"' : 'VALIDATION_ERROR_06400a22',
    '"VUID-VkDeviceGroupPresentInfoKHR-mode-01298"' : 'VALIDATION_ERROR_06400a24',
    '"VUID-VkDeviceGroupPresentInfoKHR-mode-01299"' : 'VALIDATION_ERROR_06400a26',
    '"VUID-VkDeviceGroupPresentInfoKHR-mode-01300"' : 'VALIDATION_ERROR_06400a28',
    '"VUID-VkDeviceGroupPresentInfoKHR-mode-01301"' : 'VALIDATION_ERROR_06400a2a',
    '"VUID-VkDeviceGroupPresentInfoKHR-pDeviceMasks-01302"' : 'VALIDATION_ERROR_06400a2c',
    '"VUID-VkDeviceGroupPresentInfoKHR-mode-01303"' : 'VALIDATION_ERROR_06400a2e',
    '"VUID-VkDeviceGroupPresentInfoKHR-mode-parameter"' : 'VALIDATION_ERROR_0640ce01',
    '"VUID-VkDeviceGroupPresentInfoKHR-pDeviceMasks-parameter"' : 'VALIDATION_ERROR_06414001',
    '"VUID-VkDeviceGroupPresentInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0642b00b',
    '"VUID-VkDeviceGroupRenderPassBeginInfo-deviceMask-00905"' : 'VALIDATION_ERROR_06600712',
    '"VUID-VkDeviceGroupRenderPassBeginInfo-deviceMask-00906"' : 'VALIDATION_ERROR_06600714',
    '"VUID-VkDeviceGroupRenderPassBeginInfo-deviceMask-00907"' : 'VALIDATION_ERROR_06600716',
    '"VUID-VkDeviceGroupRenderPassBeginInfo-deviceRenderAreaCount-00908"' : 'VALIDATION_ERROR_06600718',
    '"VUID-VkDeviceGroupRenderPassBeginInfo-pDeviceRenderAreas-parameter"' : 'VALIDATION_ERROR_06614201',
    '"VUID-VkDeviceGroupRenderPassBeginInfo-sType-sType"' : 'VALIDATION_ERROR_0662b00b',
    '"VUID-VkDeviceGroupSubmitInfo-waitSemaphoreCount-00082"' : 'VALIDATION_ERROR_068000a4',
    '"VUID-VkDeviceGroupSubmitInfo-commandBufferCount-00083"' : 'VALIDATION_ERROR_068000a6',
    '"VUID-VkDeviceGroupSubmitInfo-signalSemaphoreCount-00084"' : 'VALIDATION_ERROR_068000a8',
    '"VUID-VkDeviceGroupSubmitInfo-pWaitSemaphoreDeviceIndices-00085"' : 'VALIDATION_ERROR_068000aa',
    '"VUID-VkDeviceGroupSubmitInfo-pCommandBufferDeviceMasks-00086"' : 'VALIDATION_ERROR_068000ac',
    '"VUID-VkDeviceGroupSubmitInfo-pCommandBufferDeviceMasks-parameter"' : 'VALIDATION_ERROR_06811201',
    '"VUID-VkDeviceGroupSubmitInfo-pSignalSemaphoreDeviceIndices-parameter"' : 'VALIDATION_ERROR_06823001',
    '"VUID-VkDeviceGroupSubmitInfo-pWaitSemaphoreDeviceIndices-parameter"' : 'VALIDATION_ERROR_06827201',
    '"VUID-VkDeviceGroupSubmitInfo-sType-sType"' : 'VALIDATION_ERROR_0682b00b',
    '"VUID-VkDeviceGroupSwapchainCreateInfoKHR-modes-parameter"' : 'VALIDATION_ERROR_06a0d001',
    '"VUID-VkDeviceGroupSwapchainCreateInfoKHR-modes-requiredbitmask"' : 'VALIDATION_ERROR_06a0d003',
    '"VUID-VkDeviceGroupSwapchainCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_06a2b00b',
    '"VUID-VkDeviceQueueCreateInfo-queueFamilyIndex-00381"' : 'VALIDATION_ERROR_06c002fa',
    '"VUID-VkDeviceQueueCreateInfo-queueCount-00382"' : 'VALIDATION_ERROR_06c002fc',
    '"VUID-VkDeviceQueueCreateInfo-pQueuePriorities-00383"' : 'VALIDATION_ERROR_06c002fe',
    '"VUID-VkDeviceQueueCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_06c09001',
    '"VUID-VkDeviceQueueCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_06c1c40d',
    '"VUID-VkDeviceQueueCreateInfo-pQueuePriorities-parameter"' : 'VALIDATION_ERROR_06c20401',
    '"VUID-VkDeviceQueueCreateInfo-queueCount-arraylength"' : 'VALIDATION_ERROR_06c29e1b',
    '"VUID-VkDeviceQueueCreateInfo-sType-sType"' : 'VALIDATION_ERROR_06c2b00b',
    '"VUID-VkDispatchIndirectCommand-x-00417"' : 'VALIDATION_ERROR_06e00342',
    '"VUID-VkDispatchIndirectCommand-y-00418"' : 'VALIDATION_ERROR_06e00344',
    '"VUID-VkDispatchIndirectCommand-z-00419"' : 'VALIDATION_ERROR_06e00346',
    '"VUID-VkDisplayEventInfoEXT-displayEvent-parameter"' : 'VALIDATION_ERROR_07006201',
    '"VUID-VkDisplayEventInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_0701c40d',
    '"VUID-VkDisplayEventInfoEXT-sType-sType"' : 'VALIDATION_ERROR_0702b00b',
    '"VUID-VkDisplayModeCreateInfoKHR-width-01250"' : 'VALIDATION_ERROR_072009c4',
    '"VUID-VkDisplayModeCreateInfoKHR-refreshRate-01251"' : 'VALIDATION_ERROR_072009c6',
    '"VUID-VkDisplayModeCreateInfoKHR-flags-zerobitmask"' : 'VALIDATION_ERROR_07209005',
    '"VUID-VkDisplayModeCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_0721c40d',
    '"VUID-VkDisplayModeCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0722b00b',
    '"VUID-VkDisplayPowerInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_0741c40d',
    '"VUID-VkDisplayPowerInfoEXT-powerState-parameter"' : 'VALIDATION_ERROR_07428a01',
    '"VUID-VkDisplayPowerInfoEXT-sType-sType"' : 'VALIDATION_ERROR_0742b00b',
    '"VUID-VkDisplayPresentInfoKHR-srcRect-01257"' : 'VALIDATION_ERROR_076009d2',
    '"VUID-VkDisplayPresentInfoKHR-dstRect-01258"' : 'VALIDATION_ERROR_076009d4',
    '"VUID-VkDisplayPresentInfoKHR-persistentContent-01259"' : 'VALIDATION_ERROR_076009d6',
    '"VUID-VkDisplayPresentInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0762b00b',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-planeIndex-01252"' : 'VALIDATION_ERROR_078009c8',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-planeReorderPossible-01253"' : 'VALIDATION_ERROR_078009ca',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-alphaMode-01254"' : 'VALIDATION_ERROR_078009cc',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-alphaMode-01255"' : 'VALIDATION_ERROR_078009ce',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-width-01256"' : 'VALIDATION_ERROR_078009d0',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-alphaMode-parameter"' : 'VALIDATION_ERROR_07800a01',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-displayMode-parameter"' : 'VALIDATION_ERROR_07806401',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-flags-zerobitmask"' : 'VALIDATION_ERROR_07809005',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_0781c40d',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0782b00b',
    '"VUID-VkDisplaySurfaceCreateInfoKHR-transform-parameter"' : 'VALIDATION_ERROR_07830201',
    '"VUID-VkDrawIndexedIndirectCommand-None-00552"' : 'VALIDATION_ERROR_07a00450',
    '"VUID-VkDrawIndexedIndirectCommand-indexSize-00553"' : 'VALIDATION_ERROR_07a00452',
    '"VUID-VkDrawIndexedIndirectCommand-firstInstance-00554"' : 'VALIDATION_ERROR_07a00454',
    '"VUID-VkDrawIndirectCommand-None-00500"' : 'VALIDATION_ERROR_07c003e8',
    '"VUID-VkDrawIndirectCommand-firstInstance-00501"' : 'VALIDATION_ERROR_07c003ea',
    '"VUID-VkEventCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_07e09005',
    '"VUID-VkEventCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_07e1c40d',
    '"VUID-VkEventCreateInfo-sType-sType"' : 'VALIDATION_ERROR_07e2b00b',
    '"VUID-VkExportMemoryAllocateInfo-handleTypes-00656"' : 'VALIDATION_ERROR_08000520',
    '"VUID-VkExportMemoryAllocateInfo-handleTypes-parameter"' : 'VALIDATION_ERROR_08009e01',
    '"VUID-VkExportMemoryAllocateInfo-sType-sType"' : 'VALIDATION_ERROR_0802b00b',
    '"VUID-VkExportMemoryAllocateInfoNV-handleTypes-parameter"' : 'VALIDATION_ERROR_08209e01',
    '"VUID-VkExportMemoryAllocateInfoNV-sType-sType"' : 'VALIDATION_ERROR_0822b00b',
    '"VUID-VkExportMemoryWin32HandleInfoKHR-handleTypes-00657"' : 'VALIDATION_ERROR_08400522',
    '"VUID-VkExportMemoryWin32HandleInfoKHR-pAttributes-parameter"' : 'VALIDATION_ERROR_0840f401',
    '"VUID-VkExportMemoryWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0842b00b',
    '"VUID-VkExportMemoryWin32HandleInfoNV-pAttributes-parameter"' : 'VALIDATION_ERROR_0860f401',
    '"VUID-VkExportMemoryWin32HandleInfoNV-sType-sType"' : 'VALIDATION_ERROR_0862b00b',
    '"VUID-VkExportSemaphoreCreateInfo-handleTypes-01124"' : 'VALIDATION_ERROR_088008c8',
    '"VUID-VkExportSemaphoreCreateInfo-handleTypes-parameter"' : 'VALIDATION_ERROR_08809e01',
    '"VUID-VkExportSemaphoreCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0882b00b',
    '"VUID-VkExportSemaphoreWin32HandleInfoKHR-handleTypes-01125"' : 'VALIDATION_ERROR_08a008ca',
    '"VUID-VkExportSemaphoreWin32HandleInfoKHR-pAttributes-parameter"' : 'VALIDATION_ERROR_08a0f401',
    '"VUID-VkExportSemaphoreWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_08a2b00b',
    '"VUID-VkExternalMemoryBufferCreateInfo-handleTypes-parameter"' : 'VALIDATION_ERROR_08c09e01',
    '"VUID-VkExternalMemoryBufferCreateInfo-sType-sType"' : 'VALIDATION_ERROR_08c2b00b',
    '"VUID-VkExternalMemoryImageCreateInfo-handleTypes-parameter"' : 'VALIDATION_ERROR_08e09e01',
    '"VUID-VkExternalMemoryImageCreateInfo-handleTypes-requiredbitmask"' : 'VALIDATION_ERROR_08e09e03',
    '"VUID-VkExternalMemoryImageCreateInfo-sType-sType"' : 'VALIDATION_ERROR_08e2b00b',
    '"VUID-VkExternalMemoryImageCreateInfoNV-handleTypes-parameter"' : 'VALIDATION_ERROR_09009e01',
    '"VUID-VkExternalMemoryImageCreateInfoNV-sType-sType"' : 'VALIDATION_ERROR_0902b00b',
    '"VUID-VkFenceCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_09209001',
    '"VUID-VkFenceCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0921c40d',
    '"VUID-VkFenceCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0922b00b',
    '"VUID-VkFenceCreateInfo-sType-unique"' : 'VALIDATION_ERROR_0922b00f',
    '"VUID-VkFramebufferCreateInfo-commonparent"' : 'VALIDATION_ERROR_09400009',
    '"VUID-VkFramebufferCreateInfo-attachmentCount-00876"' : 'VALIDATION_ERROR_094006d8',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00877"' : 'VALIDATION_ERROR_094006da',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00878"' : 'VALIDATION_ERROR_094006dc',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00879"' : 'VALIDATION_ERROR_094006de',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00880"' : 'VALIDATION_ERROR_094006e0',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00881"' : 'VALIDATION_ERROR_094006e2',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00882"' : 'VALIDATION_ERROR_094006e4',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00883"' : 'VALIDATION_ERROR_094006e6',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00884"' : 'VALIDATION_ERROR_094006e8',
    '"VUID-VkFramebufferCreateInfo-width-00885"' : 'VALIDATION_ERROR_094006ea',
    '"VUID-VkFramebufferCreateInfo-width-00886"' : 'VALIDATION_ERROR_094006ec',
    '"VUID-VkFramebufferCreateInfo-height-00887"' : 'VALIDATION_ERROR_094006ee',
    '"VUID-VkFramebufferCreateInfo-height-00888"' : 'VALIDATION_ERROR_094006f0',
    '"VUID-VkFramebufferCreateInfo-layers-00889"' : 'VALIDATION_ERROR_094006f2',
    '"VUID-VkFramebufferCreateInfo-layers-00890"' : 'VALIDATION_ERROR_094006f4',
    '"VUID-VkFramebufferCreateInfo-pAttachments-00891"' : 'VALIDATION_ERROR_094006f6',
    '"VUID-VkFramebufferCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_09409005',
    '"VUID-VkFramebufferCreateInfo-pAttachments-parameter"' : 'VALIDATION_ERROR_0940f201',
    '"VUID-VkFramebufferCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0941c40d',
    '"VUID-VkFramebufferCreateInfo-renderPass-parameter"' : 'VALIDATION_ERROR_0942ae01',
    '"VUID-VkFramebufferCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0942b00b',
    '"VUID-VkGraphicsPipelineCreateInfo-commonparent"' : 'VALIDATION_ERROR_09600009',
    '"VUID-VkGraphicsPipelineCreateInfo-flags-00722"' : 'VALIDATION_ERROR_096005a4',
    '"VUID-VkGraphicsPipelineCreateInfo-flags-00723"' : 'VALIDATION_ERROR_096005a6',
    '"VUID-VkGraphicsPipelineCreateInfo-flags-00724"' : 'VALIDATION_ERROR_096005a8',
    '"VUID-VkGraphicsPipelineCreateInfo-flags-00725"' : 'VALIDATION_ERROR_096005aa',
    '"VUID-VkGraphicsPipelineCreateInfo-stage-00726"' : 'VALIDATION_ERROR_096005ac',
    '"VUID-VkGraphicsPipelineCreateInfo-stage-00727"' : 'VALIDATION_ERROR_096005ae',
    '"VUID-VkGraphicsPipelineCreateInfo-stage-00728"' : 'VALIDATION_ERROR_096005b0',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00729"' : 'VALIDATION_ERROR_096005b2',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00730"' : 'VALIDATION_ERROR_096005b4',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00731"' : 'VALIDATION_ERROR_096005b6',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00732"' : 'VALIDATION_ERROR_096005b8',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00733"' : 'VALIDATION_ERROR_096005ba',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00734"' : 'VALIDATION_ERROR_096005bc',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00735"' : 'VALIDATION_ERROR_096005be',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00736"' : 'VALIDATION_ERROR_096005c0',
    '"VUID-VkGraphicsPipelineCreateInfo-topology-00737"' : 'VALIDATION_ERROR_096005c2',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00738"' : 'VALIDATION_ERROR_096005c4',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00739"' : 'VALIDATION_ERROR_096005c6',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00740"' : 'VALIDATION_ERROR_096005c8',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00741"' : 'VALIDATION_ERROR_096005ca',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-00742"' : 'VALIDATION_ERROR_096005cc',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-00743"' : 'VALIDATION_ERROR_096005ce',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-00744"' : 'VALIDATION_ERROR_096005d0',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-00745"' : 'VALIDATION_ERROR_096005d2',
    '"VUID-VkGraphicsPipelineCreateInfo-attachmentCount-00746"' : 'VALIDATION_ERROR_096005d4',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-00747"' : 'VALIDATION_ERROR_096005d6',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-00748"' : 'VALIDATION_ERROR_096005d8',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-00749"' : 'VALIDATION_ERROR_096005da',
    '"VUID-VkGraphicsPipelineCreateInfo-rasterizerDiscardEnable-00750"' : 'VALIDATION_ERROR_096005dc',
    '"VUID-VkGraphicsPipelineCreateInfo-rasterizerDiscardEnable-00751"' : 'VALIDATION_ERROR_096005de',
    '"VUID-VkGraphicsPipelineCreateInfo-rasterizerDiscardEnable-00752"' : 'VALIDATION_ERROR_096005e0',
    '"VUID-VkGraphicsPipelineCreateInfo-rasterizerDiscardEnable-00753"' : 'VALIDATION_ERROR_096005e2',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-00754"' : 'VALIDATION_ERROR_096005e4',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-00755"' : 'VALIDATION_ERROR_096005e6',
    '"VUID-VkGraphicsPipelineCreateInfo-layout-00756"' : 'VALIDATION_ERROR_096005e8',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-00757"' : 'VALIDATION_ERROR_096005ea',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-00758"' : 'VALIDATION_ERROR_096005ec',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-00759"' : 'VALIDATION_ERROR_096005ee',
    '"VUID-VkGraphicsPipelineCreateInfo-renderPass-00760"' : 'VALIDATION_ERROR_096005f0',
    '"VUID-VkGraphicsPipelineCreateInfo-renderPass-00761"' : 'VALIDATION_ERROR_096005f2',
    '"VUID-VkGraphicsPipelineCreateInfo-renderPass-00762"' : 'VALIDATION_ERROR_096005f4',
    '"VUID-VkGraphicsPipelineCreateInfo-renderPass-00763"' : 'VALIDATION_ERROR_096005f6',
    '"VUID-VkGraphicsPipelineCreateInfo-flags-00764"' : 'VALIDATION_ERROR_096005f8',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-01411"' : 'VALIDATION_ERROR_09600b06',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-01412"' : 'VALIDATION_ERROR_09600b08',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-01505"' : 'VALIDATION_ERROR_09600bc2',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-01521"' : 'VALIDATION_ERROR_09600be2',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-01522"' : 'VALIDATION_ERROR_09600be4',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-01523"' : 'VALIDATION_ERROR_09600be6',
    '"VUID-VkGraphicsPipelineCreateInfo-sampleLocationsEnable-01524"' : 'VALIDATION_ERROR_09600be8',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-01565"' : 'VALIDATION_ERROR_09600c3a',
    '"VUID-VkGraphicsPipelineCreateInfo-layout-01688"' : 'VALIDATION_ERROR_09600d30',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicStates-01715"' : 'VALIDATION_ERROR_09600d66',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-01756"' : 'VALIDATION_ERROR_09600db8',
    '"VUID-VkGraphicsPipelineCreateInfo-subpass-01757"' : 'VALIDATION_ERROR_09600dba',
    '"VUID-VkGraphicsPipelineCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_09609001',
    '"VUID-VkGraphicsPipelineCreateInfo-layout-parameter"' : 'VALIDATION_ERROR_0960be01',
    '"VUID-VkGraphicsPipelineCreateInfo-pDynamicState-parameter"' : 'VALIDATION_ERROR_09615601',
    '"VUID-VkGraphicsPipelineCreateInfo-pInputAssemblyState-parameter"' : 'VALIDATION_ERROR_09619801',
    '"VUID-VkGraphicsPipelineCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0961c40d',
    '"VUID-VkGraphicsPipelineCreateInfo-pRasterizationState-parameter"' : 'VALIDATION_ERROR_09620801',
    '"VUID-VkGraphicsPipelineCreateInfo-pStages-parameter"' : 'VALIDATION_ERROR_09623e01',
    '"VUID-VkGraphicsPipelineCreateInfo-pVertexInputState-parameter"' : 'VALIDATION_ERROR_09626801',
    '"VUID-VkGraphicsPipelineCreateInfo-renderPass-parameter"' : 'VALIDATION_ERROR_0962ae01',
    '"VUID-VkGraphicsPipelineCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0962b00b',
    '"VUID-VkGraphicsPipelineCreateInfo-stageCount-arraylength"' : 'VALIDATION_ERROR_0962da1b',
    '"VUID-VkIOSSurfaceCreateInfoMVK-pView-01316"' : 'VALIDATION_ERROR_09800a48',
    '"VUID-VkIOSSurfaceCreateInfoMVK-flags-zerobitmask"' : 'VALIDATION_ERROR_09809005',
    '"VUID-VkIOSSurfaceCreateInfoMVK-pNext-pNext"' : 'VALIDATION_ERROR_0981c40d',
    '"VUID-VkIOSSurfaceCreateInfoMVK-sType-sType"' : 'VALIDATION_ERROR_0982b00b',
    '"VUID-VkImageBlit-aspectMask-00238"' : 'VALIDATION_ERROR_09a001dc',
    '"VUID-VkImageBlit-layerCount-00239"' : 'VALIDATION_ERROR_09a001de',
    '"VUID-VkImageBlit-srcImage-00240"' : 'VALIDATION_ERROR_09a001e0',
    '"VUID-VkImageBlit-aspectMask-00241"' : 'VALIDATION_ERROR_09a001e2',
    '"VUID-VkImageBlit-aspectMask-00242"' : 'VALIDATION_ERROR_09a001e4',
    '"VUID-VkImageBlit-srcOffset-00243"' : 'VALIDATION_ERROR_09a001e6',
    '"VUID-VkImageBlit-srcOffset-00244"' : 'VALIDATION_ERROR_09a001e8',
    '"VUID-VkImageBlit-srcImage-00245"' : 'VALIDATION_ERROR_09a001ea',
    '"VUID-VkImageBlit-srcOffset-00246"' : 'VALIDATION_ERROR_09a001ec',
    '"VUID-VkImageBlit-srcImage-00247"' : 'VALIDATION_ERROR_09a001ee',
    '"VUID-VkImageBlit-dstOffset-00248"' : 'VALIDATION_ERROR_09a001f0',
    '"VUID-VkImageBlit-dstOffset-00249"' : 'VALIDATION_ERROR_09a001f2',
    '"VUID-VkImageBlit-dstImage-00250"' : 'VALIDATION_ERROR_09a001f4',
    '"VUID-VkImageBlit-dstOffset-00251"' : 'VALIDATION_ERROR_09a001f6',
    '"VUID-VkImageBlit-dstImage-00252"' : 'VALIDATION_ERROR_09a001f8',
    '"VUID-VkImageBlit-dstSubresource-parameter"' : 'VALIDATION_ERROR_09a07a01',
    '"VUID-VkImageBlit-srcSubresource-parameter"' : 'VALIDATION_ERROR_09a2d601',
    '"VUID-VkImageCopy-aspectMask-00137"' : 'VALIDATION_ERROR_09c00112',
    '"VUID-VkImageCopy-layerCount-00138"' : 'VALIDATION_ERROR_09c00114',
    '"VUID-VkImageCopy-srcImage-00139"' : 'VALIDATION_ERROR_09c00116',
    '"VUID-VkImageCopy-extent-00140"' : 'VALIDATION_ERROR_09c00118',
    '"VUID-VkImageCopy-srcImage-00141"' : 'VALIDATION_ERROR_09c0011a',
    '"VUID-VkImageCopy-aspectMask-00142"' : 'VALIDATION_ERROR_09c0011c',
    '"VUID-VkImageCopy-aspectMask-00143"' : 'VALIDATION_ERROR_09c0011e',
    '"VUID-VkImageCopy-srcOffset-00144"' : 'VALIDATION_ERROR_09c00120',
    '"VUID-VkImageCopy-srcOffset-00145"' : 'VALIDATION_ERROR_09c00122',
    '"VUID-VkImageCopy-srcImage-00146"' : 'VALIDATION_ERROR_09c00124',
    '"VUID-VkImageCopy-srcOffset-00147"' : 'VALIDATION_ERROR_09c00126',
    '"VUID-VkImageCopy-dstOffset-00150"' : 'VALIDATION_ERROR_09c0012c',
    '"VUID-VkImageCopy-dstOffset-00151"' : 'VALIDATION_ERROR_09c0012e',
    '"VUID-VkImageCopy-dstImage-00152"' : 'VALIDATION_ERROR_09c00130',
    '"VUID-VkImageCopy-dstOffset-00153"' : 'VALIDATION_ERROR_09c00132',
    '"VUID-VkImageCopy-srcOffset-00157"' : 'VALIDATION_ERROR_09c0013a',
    '"VUID-VkImageCopy-extent-00158"' : 'VALIDATION_ERROR_09c0013c',
    '"VUID-VkImageCopy-extent-00159"' : 'VALIDATION_ERROR_09c0013e',
    '"VUID-VkImageCopy-extent-00160"' : 'VALIDATION_ERROR_09c00140',
    '"VUID-VkImageCopy-dstOffset-00162"' : 'VALIDATION_ERROR_09c00144',
    '"VUID-VkImageCopy-extent-00163"' : 'VALIDATION_ERROR_09c00146',
    '"VUID-VkImageCopy-extent-00164"' : 'VALIDATION_ERROR_09c00148',
    '"VUID-VkImageCopy-extent-00165"' : 'VALIDATION_ERROR_09c0014a',
    '"VUID-VkImageCopy-srcImage-01551"' : 'VALIDATION_ERROR_09c00c1e',
    '"VUID-VkImageCopy-srcImage-01552"' : 'VALIDATION_ERROR_09c00c20',
    '"VUID-VkImageCopy-srcImage-01553"' : 'VALIDATION_ERROR_09c00c22',
    '"VUID-VkImageCopy-dstImage-01554"' : 'VALIDATION_ERROR_09c00c24',
    '"VUID-VkImageCopy-dstImage-01555"' : 'VALIDATION_ERROR_09c00c26',
    '"VUID-VkImageCopy-srcImage-01556"' : 'VALIDATION_ERROR_09c00c28',
    '"VUID-VkImageCopy-dstImage-01557"' : 'VALIDATION_ERROR_09c00c2a',
    '"VUID-VkImageCopy-srcImage-01727"' : 'VALIDATION_ERROR_09c00d7e',
    '"VUID-VkImageCopy-srcImage-01728"' : 'VALIDATION_ERROR_09c00d80',
    '"VUID-VkImageCopy-srcImage-01729"' : 'VALIDATION_ERROR_09c00d82',
    '"VUID-VkImageCopy-srcImage-01730"' : 'VALIDATION_ERROR_09c00d84',
    '"VUID-VkImageCopy-dstImage-01731"' : 'VALIDATION_ERROR_09c00d86',
    '"VUID-VkImageCopy-dstImage-01732"' : 'VALIDATION_ERROR_09c00d88',
    '"VUID-VkImageCopy-dstImage-01733"' : 'VALIDATION_ERROR_09c00d8a',
    '"VUID-VkImageCopy-dstImage-01734"' : 'VALIDATION_ERROR_09c00d8c',
    '"VUID-VkImageCopy-srcImage-01785"' : 'VALIDATION_ERROR_09c00df2',
    '"VUID-VkImageCopy-dstImage-01786"' : 'VALIDATION_ERROR_09c00df4',
    '"VUID-VkImageCopy-srcImage-01787"' : 'VALIDATION_ERROR_09c00df6',
    '"VUID-VkImageCopy-dstImage-01788"' : 'VALIDATION_ERROR_09c00df8',
    '"VUID-VkImageCopy-srcImage-01789"' : 'VALIDATION_ERROR_09c00dfa',
    '"VUID-VkImageCopy-srcImage-01790"' : 'VALIDATION_ERROR_09c00dfc',
    '"VUID-VkImageCopy-srcImage-01791"' : 'VALIDATION_ERROR_09c00dfe',
    '"VUID-VkImageCopy-dstImage-01792"' : 'VALIDATION_ERROR_09c00e00',
    '"VUID-VkImageCopy-dstSubresource-parameter"' : 'VALIDATION_ERROR_09c07a01',
    '"VUID-VkImageCopy-srcSubresource-parameter"' : 'VALIDATION_ERROR_09c2d601',
    '"VUID-VkImageCreateInfo-format-00940"' : 'VALIDATION_ERROR_09e00758',
    '"VUID-VkImageCreateInfo-sharingMode-00941"' : 'VALIDATION_ERROR_09e0075a',
    '"VUID-VkImageCreateInfo-sharingMode-00942"' : 'VALIDATION_ERROR_09e0075c',
    '"VUID-VkImageCreateInfo-format-00943"' : 'VALIDATION_ERROR_09e0075e',
    '"VUID-VkImageCreateInfo-extent-00944"' : 'VALIDATION_ERROR_09e00760',
    '"VUID-VkImageCreateInfo-extent-00945"' : 'VALIDATION_ERROR_09e00762',
    '"VUID-VkImageCreateInfo-extent-00946"' : 'VALIDATION_ERROR_09e00764',
    '"VUID-VkImageCreateInfo-mipLevels-00947"' : 'VALIDATION_ERROR_09e00766',
    '"VUID-VkImageCreateInfo-arrayLayers-00948"' : 'VALIDATION_ERROR_09e00768',
    '"VUID-VkImageCreateInfo-flags-00949"' : 'VALIDATION_ERROR_09e0076a',
    '"VUID-VkImageCreateInfo-flags-00950"' : 'VALIDATION_ERROR_09e0076c',
    '"VUID-VkImageCreateInfo-imageType-00951"' : 'VALIDATION_ERROR_09e0076e',
    '"VUID-VkImageCreateInfo-imageType-00952"' : 'VALIDATION_ERROR_09e00770',
    '"VUID-VkImageCreateInfo-imageType-00953"' : 'VALIDATION_ERROR_09e00772',
    '"VUID-VkImageCreateInfo-imageType-00954"' : 'VALIDATION_ERROR_09e00774',
    '"VUID-VkImageCreateInfo-imageType-00955"' : 'VALIDATION_ERROR_09e00776',
    '"VUID-VkImageCreateInfo-imageType-00956"' : 'VALIDATION_ERROR_09e00778',
    '"VUID-VkImageCreateInfo-imageType-00957"' : 'VALIDATION_ERROR_09e0077a',
    '"VUID-VkImageCreateInfo-mipLevels-00958"' : 'VALIDATION_ERROR_09e0077c',
    '"VUID-VkImageCreateInfo-extent-00959"' : 'VALIDATION_ERROR_09e0077e',
    '"VUID-VkImageCreateInfo-arrayLayers-00960"' : 'VALIDATION_ERROR_09e00780',
    '"VUID-VkImageCreateInfo-imageType-00961"' : 'VALIDATION_ERROR_09e00782',
    '"VUID-VkImageCreateInfo-samples-00962"' : 'VALIDATION_ERROR_09e00784',
    '"VUID-VkImageCreateInfo-usage-00963"' : 'VALIDATION_ERROR_09e00786',
    '"VUID-VkImageCreateInfo-usage-00964"' : 'VALIDATION_ERROR_09e00788',
    '"VUID-VkImageCreateInfo-usage-00965"' : 'VALIDATION_ERROR_09e0078a',
    '"VUID-VkImageCreateInfo-usage-00966"' : 'VALIDATION_ERROR_09e0078c',
    '"VUID-VkImageCreateInfo-samples-00967"' : 'VALIDATION_ERROR_09e0078e',
    '"VUID-VkImageCreateInfo-usage-00968"' : 'VALIDATION_ERROR_09e00790',
    '"VUID-VkImageCreateInfo-flags-00969"' : 'VALIDATION_ERROR_09e00792',
    '"VUID-VkImageCreateInfo-imageType-00970"' : 'VALIDATION_ERROR_09e00794',
    '"VUID-VkImageCreateInfo-imageType-00971"' : 'VALIDATION_ERROR_09e00796',
    '"VUID-VkImageCreateInfo-imageType-00972"' : 'VALIDATION_ERROR_09e00798',
    '"VUID-VkImageCreateInfo-imageType-00973"' : 'VALIDATION_ERROR_09e0079a',
    '"VUID-VkImageCreateInfo-imageType-00974"' : 'VALIDATION_ERROR_09e0079c',
    '"VUID-VkImageCreateInfo-imageType-00975"' : 'VALIDATION_ERROR_09e0079e',
    '"VUID-VkImageCreateInfo-imageType-00976"' : 'VALIDATION_ERROR_09e007a0',
    '"VUID-VkImageCreateInfo-flags-00987"' : 'VALIDATION_ERROR_09e007b6',
    '"VUID-VkImageCreateInfo-pNext-00988"' : 'VALIDATION_ERROR_09e007b8',
    '"VUID-VkImageCreateInfo-pNext-00990"' : 'VALIDATION_ERROR_09e007bc',
    '"VUID-VkImageCreateInfo-pNext-00991"' : 'VALIDATION_ERROR_09e007be',
    '"VUID-VkImageCreateInfo-flags-00992"' : 'VALIDATION_ERROR_09e007c0',
    '"VUID-VkImageCreateInfo-initialLayout-00993"' : 'VALIDATION_ERROR_09e007c2',
    '"VUID-VkImageCreateInfo-sharingMode-01392"' : 'VALIDATION_ERROR_09e00ae0',
    '"VUID-VkImageCreateInfo-sharingMode-01420"' : 'VALIDATION_ERROR_09e00b18',
    '"VUID-VkImageCreateInfo-physicalDeviceCount-01421"' : 'VALIDATION_ERROR_09e00b1a',
    '"VUID-VkImageCreateInfo-pNext-01443"' : 'VALIDATION_ERROR_09e00b46',
    '"VUID-VkImageCreateInfo-flags-01533"' : 'VALIDATION_ERROR_09e00bfa',
    '"VUID-VkImageCreateInfo-flags-01572"' : 'VALIDATION_ERROR_09e00c48',
    '"VUID-VkImageCreateInfo-flags-01573"' : 'VALIDATION_ERROR_09e00c4a',
    '"VUID-VkImageCreateInfo-format-01574"' : 'VALIDATION_ERROR_09e00c4c',
    '"VUID-VkImageCreateInfo-tiling-01575"' : 'VALIDATION_ERROR_09e00c4e',
    '"VUID-VkImageCreateInfo-tiling-01576"' : 'VALIDATION_ERROR_09e00c50',
    '"VUID-VkImageCreateInfo-format-01577"' : 'VALIDATION_ERROR_09e00c52',
    '"VUID-VkImageCreateInfo-pNext-01889"' : 'VALIDATION_ERROR_09e00ec2',
    '"VUID-VkImageCreateInfo-flags-01890"' : 'VALIDATION_ERROR_09e00ec4',
    '"VUID-VkImageCreateInfo-None-01891"' : 'VALIDATION_ERROR_09e00ec6',
    '"VUID-VkImageCreateInfo-pNext-01892"' : 'VALIDATION_ERROR_09e00ec8',
    '"VUID-VkImageCreateInfo-pNext-01893"' : 'VALIDATION_ERROR_09e00eca',
    '"VUID-VkImageCreateInfo-flags-01924"' : 'VALIDATION_ERROR_09e00f08',
    '"VUID-VkImageCreateInfo-None-01925"' : 'VALIDATION_ERROR_09e00f0a',
    '"VUID-VkImageCreateInfo-flags-parameter"' : 'VALIDATION_ERROR_09e09001',
    '"VUID-VkImageCreateInfo-format-parameter"' : 'VALIDATION_ERROR_09e09201',
    '"VUID-VkImageCreateInfo-imageType-parameter"' : 'VALIDATION_ERROR_09e0ac01',
    '"VUID-VkImageCreateInfo-initialLayout-parameter"' : 'VALIDATION_ERROR_09e0b801',
    '"VUID-VkImageCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_09e1c40d',
    '"VUID-VkImageCreateInfo-sType-sType"' : 'VALIDATION_ERROR_09e2b00b',
    '"VUID-VkImageCreateInfo-sType-unique"' : 'VALIDATION_ERROR_09e2b00f',
    '"VUID-VkImageCreateInfo-samples-parameter"' : 'VALIDATION_ERROR_09e2b401',
    '"VUID-VkImageCreateInfo-sharingMode-parameter"' : 'VALIDATION_ERROR_09e2c001',
    '"VUID-VkImageCreateInfo-tiling-parameter"' : 'VALIDATION_ERROR_09e2fa01',
    '"VUID-VkImageCreateInfo-usage-parameter"' : 'VALIDATION_ERROR_09e30601',
    '"VUID-VkImageCreateInfo-usage-requiredbitmask"' : 'VALIDATION_ERROR_09e30603',
    '"VUID-VkImageMemoryBarrier-oldLayout-01197"' : 'VALIDATION_ERROR_0a00095a',
    '"VUID-VkImageMemoryBarrier-newLayout-01198"' : 'VALIDATION_ERROR_0a00095c',
    '"VUID-VkImageMemoryBarrier-image-01199"' : 'VALIDATION_ERROR_0a00095e',
    '"VUID-VkImageMemoryBarrier-image-01200"' : 'VALIDATION_ERROR_0a000960',
    '"VUID-VkImageMemoryBarrier-image-01201"' : 'VALIDATION_ERROR_0a000962',
    '"VUID-VkImageMemoryBarrier-image-01205"' : 'VALIDATION_ERROR_0a00096a',
    '"VUID-VkImageMemoryBarrier-image-01207"' : 'VALIDATION_ERROR_0a00096e',
    '"VUID-VkImageMemoryBarrier-oldLayout-01208"' : 'VALIDATION_ERROR_0a000970',
    '"VUID-VkImageMemoryBarrier-oldLayout-01209"' : 'VALIDATION_ERROR_0a000972',
    '"VUID-VkImageMemoryBarrier-oldLayout-01210"' : 'VALIDATION_ERROR_0a000974',
    '"VUID-VkImageMemoryBarrier-oldLayout-01211"' : 'VALIDATION_ERROR_0a000976',
    '"VUID-VkImageMemoryBarrier-oldLayout-01212"' : 'VALIDATION_ERROR_0a000978',
    '"VUID-VkImageMemoryBarrier-oldLayout-01213"' : 'VALIDATION_ERROR_0a00097a',
    '"VUID-VkImageMemoryBarrier-image-01381"' : 'VALIDATION_ERROR_0a000aca',
    '"VUID-VkImageMemoryBarrier-subresourceRange-01486"' : 'VALIDATION_ERROR_0a000b9c',
    '"VUID-VkImageMemoryBarrier-subresourceRange-01488"' : 'VALIDATION_ERROR_0a000ba0',
    '"VUID-VkImageMemoryBarrier-oldLayout-01658"' : 'VALIDATION_ERROR_0a000cf4',
    '"VUID-VkImageMemoryBarrier-oldLayout-01659"' : 'VALIDATION_ERROR_0a000cf6',
    '"VUID-VkImageMemoryBarrier-image-01671"' : 'VALIDATION_ERROR_0a000d0e',
    '"VUID-VkImageMemoryBarrier-image-01672"' : 'VALIDATION_ERROR_0a000d10',
    '"VUID-VkImageMemoryBarrier-image-01673"' : 'VALIDATION_ERROR_0a000d12',
    '"VUID-VkImageMemoryBarrier-subresourceRange-01724"' : 'VALIDATION_ERROR_0a000d78',
    '"VUID-VkImageMemoryBarrier-subresourceRange-01725"' : 'VALIDATION_ERROR_0a000d7a',
    '"VUID-VkImageMemoryBarrier-image-01766"' : 'VALIDATION_ERROR_0a000dcc',
    '"VUID-VkImageMemoryBarrier-image-01767"' : 'VALIDATION_ERROR_0a000dce',
    '"VUID-VkImageMemoryBarrier-image-01768"' : 'VALIDATION_ERROR_0a000dd0',
    '"VUID-VkImageMemoryBarrier-image-01932"' : 'VALIDATION_ERROR_0a000f18',
    '"VUID-VkImageMemoryBarrier-dstAccessMask-parameter"' : 'VALIDATION_ERROR_0a006801',
    '"VUID-VkImageMemoryBarrier-image-parameter"' : 'VALIDATION_ERROR_0a00a001',
    '"VUID-VkImageMemoryBarrier-newLayout-parameter"' : 'VALIDATION_ERROR_0a00d401',
    '"VUID-VkImageMemoryBarrier-oldLayout-parameter"' : 'VALIDATION_ERROR_0a00dc01',
    '"VUID-VkImageMemoryBarrier-pNext-pNext"' : 'VALIDATION_ERROR_0a01c40d',
    '"VUID-VkImageMemoryBarrier-sType-sType"' : 'VALIDATION_ERROR_0a02b00b',
    '"VUID-VkImageMemoryBarrier-srcAccessMask-parameter"' : 'VALIDATION_ERROR_0a02c401',
    '"VUID-VkImageMemoryBarrier-subresourceRange-parameter"' : 'VALIDATION_ERROR_0a02ea01',
    '"VUID-VkImageResolve-aspectMask-00266"' : 'VALIDATION_ERROR_0a200214',
    '"VUID-VkImageResolve-layerCount-00267"' : 'VALIDATION_ERROR_0a200216',
    '"VUID-VkImageResolve-srcImage-00268"' : 'VALIDATION_ERROR_0a200218',
    '"VUID-VkImageResolve-srcOffset-00269"' : 'VALIDATION_ERROR_0a20021a',
    '"VUID-VkImageResolve-srcOffset-00270"' : 'VALIDATION_ERROR_0a20021c',
    '"VUID-VkImageResolve-srcImage-00271"' : 'VALIDATION_ERROR_0a20021e',
    '"VUID-VkImageResolve-srcOffset-00272"' : 'VALIDATION_ERROR_0a200220',
    '"VUID-VkImageResolve-srcImage-00273"' : 'VALIDATION_ERROR_0a200222',
    '"VUID-VkImageResolve-dstOffset-00274"' : 'VALIDATION_ERROR_0a200224',
    '"VUID-VkImageResolve-dstOffset-00275"' : 'VALIDATION_ERROR_0a200226',
    '"VUID-VkImageResolve-dstImage-00276"' : 'VALIDATION_ERROR_0a200228',
    '"VUID-VkImageResolve-dstOffset-00277"' : 'VALIDATION_ERROR_0a20022a',
    '"VUID-VkImageResolve-dstImage-00278"' : 'VALIDATION_ERROR_0a20022c',
    '"VUID-VkImageResolve-dstSubresource-parameter"' : 'VALIDATION_ERROR_0a207a01',
    '"VUID-VkImageResolve-srcSubresource-parameter"' : 'VALIDATION_ERROR_0a22d601',
    '"VUID-VkImageSubresource-aspectMask-parameter"' : 'VALIDATION_ERROR_0a400c01',
    '"VUID-VkImageSubresource-aspectMask-requiredbitmask"' : 'VALIDATION_ERROR_0a400c03',
    '"VUID-VkImageSubresourceLayers-aspectMask-00167"' : 'VALIDATION_ERROR_0a60014e',
    '"VUID-VkImageSubresourceLayers-aspectMask-00168"' : 'VALIDATION_ERROR_0a600150',
    '"VUID-VkImageSubresourceLayers-aspectMask-parameter"' : 'VALIDATION_ERROR_0a600c01',
    '"VUID-VkImageSubresourceLayers-aspectMask-requiredbitmask"' : 'VALIDATION_ERROR_0a600c03',
    '"VUID-VkImageSubresourceLayers-layerCount-01700"' : 'VALIDATION_ERROR_0a600d48',
    '"VUID-VkImageSubresourceRange-aspectMask-parameter"' : 'VALIDATION_ERROR_0a800c01',
    '"VUID-VkImageSubresourceRange-aspectMask-requiredbitmask"' : 'VALIDATION_ERROR_0a800c03',
    '"VUID-VkImageSubresourceRange-aspectMask-01670"' : 'VALIDATION_ERROR_0a800d0c',
    '"VUID-VkImageSubresourceRange-levelCount-01720"' : 'VALIDATION_ERROR_0a800d70',
    '"VUID-VkImageSubresourceRange-layerCount-01721"' : 'VALIDATION_ERROR_0a800d72',
    '"VUID-VkImageSwapchainCreateInfoKHR-swapchain-00995"' : 'VALIDATION_ERROR_0aa007c6',
    '"VUID-VkImageSwapchainCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0aa2b00b',
    '"VUID-VkImageSwapchainCreateInfoKHR-swapchain-parameter"' : 'VALIDATION_ERROR_0aa2f001',
    '"VUID-VkImageViewCreateInfo-image-01003"' : 'VALIDATION_ERROR_0ac007d6',
    '"VUID-VkImageViewCreateInfo-viewType-01004"' : 'VALIDATION_ERROR_0ac007d8',
    '"VUID-VkImageViewCreateInfo-image-01005"' : 'VALIDATION_ERROR_0ac007da',
    '"VUID-VkImageViewCreateInfo-image-01006"' : 'VALIDATION_ERROR_0ac007dc',
    '"VUID-VkImageViewCreateInfo-image-01007"' : 'VALIDATION_ERROR_0ac007de',
    '"VUID-VkImageViewCreateInfo-image-01008"' : 'VALIDATION_ERROR_0ac007e0',
    '"VUID-VkImageViewCreateInfo-image-01009"' : 'VALIDATION_ERROR_0ac007e2',
    '"VUID-VkImageViewCreateInfo-image-01010"' : 'VALIDATION_ERROR_0ac007e4',
    '"VUID-VkImageViewCreateInfo-image-01011"' : 'VALIDATION_ERROR_0ac007e6',
    '"VUID-VkImageViewCreateInfo-image-01012"' : 'VALIDATION_ERROR_0ac007e8',
    '"VUID-VkImageViewCreateInfo-image-01013"' : 'VALIDATION_ERROR_0ac007ea',
    '"VUID-VkImageViewCreateInfo-image-01014"' : 'VALIDATION_ERROR_0ac007ec',
    '"VUID-VkImageViewCreateInfo-image-01015"' : 'VALIDATION_ERROR_0ac007ee',
    '"VUID-VkImageViewCreateInfo-image-01016"' : 'VALIDATION_ERROR_0ac007f0',
    '"VUID-VkImageViewCreateInfo-image-01018"' : 'VALIDATION_ERROR_0ac007f4',
    '"VUID-VkImageViewCreateInfo-image-01019"' : 'VALIDATION_ERROR_0ac007f6',
    '"VUID-VkImageViewCreateInfo-image-01020"' : 'VALIDATION_ERROR_0ac007f8',
    '"VUID-VkImageViewCreateInfo-subResourceRange-01021"' : 'VALIDATION_ERROR_0ac007fa',
    '"VUID-VkImageViewCreateInfo-subresourceRange-01478"' : 'VALIDATION_ERROR_0ac00b8c',
    '"VUID-VkImageViewCreateInfo-subresourceRange-01480"' : 'VALIDATION_ERROR_0ac00b90',
    '"VUID-VkImageViewCreateInfo-image-01482"' : 'VALIDATION_ERROR_0ac00b94',
    '"VUID-VkImageViewCreateInfo-subresourceRange-01483"' : 'VALIDATION_ERROR_0ac00b96',
    '"VUID-VkImageViewCreateInfo-image-01484"' : 'VALIDATION_ERROR_0ac00b98',
    '"VUID-VkImageViewCreateInfo-subresourceRange-01485"' : 'VALIDATION_ERROR_0ac00b9a',
    '"VUID-VkImageViewCreateInfo-image-01583"' : 'VALIDATION_ERROR_0ac00c5e',
    '"VUID-VkImageViewCreateInfo-image-01584"' : 'VALIDATION_ERROR_0ac00c60',
    '"VUID-VkImageViewCreateInfo-pNext-01585"' : 'VALIDATION_ERROR_0ac00c62',
    '"VUID-VkImageViewCreateInfo-image-01586"' : 'VALIDATION_ERROR_0ac00c64',
    '"VUID-VkImageViewCreateInfo-subresourceRange-01718"' : 'VALIDATION_ERROR_0ac00d6c',
    '"VUID-VkImageViewCreateInfo-subresourceRange-01719"' : 'VALIDATION_ERROR_0ac00d6e',
    '"VUID-VkImageViewCreateInfo-image-01759"' : 'VALIDATION_ERROR_0ac00dbe',
    '"VUID-VkImageViewCreateInfo-image-01760"' : 'VALIDATION_ERROR_0ac00dc0',
    '"VUID-VkImageViewCreateInfo-image-01761"' : 'VALIDATION_ERROR_0ac00dc2',
    '"VUID-VkImageViewCreateInfo-image-01762"' : 'VALIDATION_ERROR_0ac00dc4',
    '"VUID-VkImageViewCreateInfo-image-01896"' : 'VALIDATION_ERROR_0ac00ed0',
    '"VUID-VkImageViewCreateInfo-components-parameter"' : 'VALIDATION_ERROR_0ac02c01',
    '"VUID-VkImageViewCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_0ac09005',
    '"VUID-VkImageViewCreateInfo-format-parameter"' : 'VALIDATION_ERROR_0ac09201',
    '"VUID-VkImageViewCreateInfo-image-parameter"' : 'VALIDATION_ERROR_0ac0a001',
    '"VUID-VkImageViewCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0ac1c40d',
    '"VUID-VkImageViewCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0ac2b00b',
    '"VUID-VkImageViewCreateInfo-sType-unique"' : 'VALIDATION_ERROR_0ac2b00f',
    '"VUID-VkImageViewCreateInfo-subresourceRange-parameter"' : 'VALIDATION_ERROR_0ac2ea01',
    '"VUID-VkImageViewCreateInfo-viewType-parameter"' : 'VALIDATION_ERROR_0ac30801',
    '"VUID-VkImportMemoryFdInfoKHR-handleType-00667"' : 'VALIDATION_ERROR_0ae00536',
    '"VUID-VkImportMemoryFdInfoKHR-fd-00668"' : 'VALIDATION_ERROR_0ae00538',
    '"VUID-VkImportMemoryFdInfoKHR-handleType-00669"' : 'VALIDATION_ERROR_0ae0053a',
    '"VUID-VkImportMemoryFdInfoKHR-handleType-00670"' : 'VALIDATION_ERROR_0ae0053c',
    '"VUID-VkImportMemoryFdInfoKHR-fd-01520"' : 'VALIDATION_ERROR_0ae00be0',
    '"VUID-VkImportMemoryFdInfoKHR-fd-01746"' : 'VALIDATION_ERROR_0ae00da4',
    '"VUID-VkImportMemoryFdInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_0ae09c01',
    '"VUID-VkImportMemoryFdInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0ae2b00b',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handleType-00658"' : 'VALIDATION_ERROR_0b000524',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handle-00659"' : 'VALIDATION_ERROR_0b000526',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handleType-00660"' : 'VALIDATION_ERROR_0b000528',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handleType-00661"' : 'VALIDATION_ERROR_0b00052a',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handleType-01439"' : 'VALIDATION_ERROR_0b000b3e',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handleType-01440"' : 'VALIDATION_ERROR_0b000b40',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handle-01441"' : 'VALIDATION_ERROR_0b000b42',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handle-01518"' : 'VALIDATION_ERROR_0b000bdc',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-name-01519"' : 'VALIDATION_ERROR_0b000bde',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_0b009c01',
    '"VUID-VkImportMemoryWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0b02b00b',
    '"VUID-VkImportMemoryWin32HandleInfoNV-handleType-01327"' : 'VALIDATION_ERROR_0b200a5e',
    '"VUID-VkImportMemoryWin32HandleInfoNV-handle-01328"' : 'VALIDATION_ERROR_0b200a60',
    '"VUID-VkImportMemoryWin32HandleInfoNV-handleType-parameter"' : 'VALIDATION_ERROR_0b209c01',
    '"VUID-VkImportMemoryWin32HandleInfoNV-sType-sType"' : 'VALIDATION_ERROR_0b22b00b',
    '"VUID-VkImportSemaphoreFdInfoKHR-handleType-01143"' : 'VALIDATION_ERROR_0b4008ee',
    '"VUID-VkImportSemaphoreFdInfoKHR-fd-01544"' : 'VALIDATION_ERROR_0b400c10',
    '"VUID-VkImportSemaphoreFdInfoKHR-flags-parameter"' : 'VALIDATION_ERROR_0b409001',
    '"VUID-VkImportSemaphoreFdInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_0b409c01',
    '"VUID-VkImportSemaphoreFdInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_0b41c40d',
    '"VUID-VkImportSemaphoreFdInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0b42b00b',
    '"VUID-VkImportSemaphoreFdInfoKHR-semaphore-parameter"' : 'VALIDATION_ERROR_0b42b801',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-handleType-01140"' : 'VALIDATION_ERROR_0b6008e8',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-handleType-01466"' : 'VALIDATION_ERROR_0b600b74',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-handleType-01467"' : 'VALIDATION_ERROR_0b600b76',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-handleType-01468"' : 'VALIDATION_ERROR_0b600b78',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-handle-01469"' : 'VALIDATION_ERROR_0b600b7a',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-handle-01542"' : 'VALIDATION_ERROR_0b600c0c',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-name-01543"' : 'VALIDATION_ERROR_0b600c0e',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-flags-parameter"' : 'VALIDATION_ERROR_0b609001',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_0b609c01',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_0b61c40d',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0b62b00b',
    '"VUID-VkImportSemaphoreWin32HandleInfoKHR-semaphore-parameter"' : 'VALIDATION_ERROR_0b62b801',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-tokenCount-01347"' : 'VALIDATION_ERROR_0b800a86',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-computeBindingPointSupport-01348"' : 'VALIDATION_ERROR_0b800a88',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-pTokens-01349"' : 'VALIDATION_ERROR_0b800a8a',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-pTokens-01350"' : 'VALIDATION_ERROR_0b800a8c',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-pTokens-01351"' : 'VALIDATION_ERROR_0b800a8e',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-flags-parameter"' : 'VALIDATION_ERROR_0b809001',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-flags-requiredbitmask"' : 'VALIDATION_ERROR_0b809003',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-pNext-pNext"' : 'VALIDATION_ERROR_0b81c40d',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-pTokens-parameter"' : 'VALIDATION_ERROR_0b826001',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-pipelineBindPoint-parameter"' : 'VALIDATION_ERROR_0b827e01',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-sType-sType"' : 'VALIDATION_ERROR_0b82b00b',
    '"VUID-VkIndirectCommandsLayoutCreateInfoNVX-tokenCount-arraylength"' : 'VALIDATION_ERROR_0b82fc1b',
    '"VUID-VkIndirectCommandsLayoutTokenNVX-bindingUnit-01342"' : 'VALIDATION_ERROR_0ba00a7c',
    '"VUID-VkIndirectCommandsLayoutTokenNVX-dynamicCount-01343"' : 'VALIDATION_ERROR_0ba00a7e',
    '"VUID-VkIndirectCommandsLayoutTokenNVX-divisor-01344"' : 'VALIDATION_ERROR_0ba00a80',
    '"VUID-VkIndirectCommandsLayoutTokenNVX-tokenType-parameter"' : 'VALIDATION_ERROR_0ba2fe01',
    '"VUID-VkIndirectCommandsTokenNVX-buffer-01345"' : 'VALIDATION_ERROR_0bc00a82',
    '"VUID-VkIndirectCommandsTokenNVX-offset-01346"' : 'VALIDATION_ERROR_0bc00a84',
    '"VUID-VkIndirectCommandsTokenNVX-buffer-parameter"' : 'VALIDATION_ERROR_0bc01a01',
    '"VUID-VkIndirectCommandsTokenNVX-tokenType-parameter"' : 'VALIDATION_ERROR_0bc2fe01',
    '"VUID-VkInstanceCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_0be09005',
    '"VUID-VkInstanceCreateInfo-pApplicationInfo-parameter"' : 'VALIDATION_ERROR_0be0ee01',
    '"VUID-VkInstanceCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0be1c40d',
    '"VUID-VkInstanceCreateInfo-ppEnabledExtensionNames-parameter"' : 'VALIDATION_ERROR_0be28e01',
    '"VUID-VkInstanceCreateInfo-ppEnabledLayerNames-parameter"' : 'VALIDATION_ERROR_0be29001',
    '"VUID-VkInstanceCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0be2b00b',
    '"VUID-VkInstanceCreateInfo-sType-unique"' : 'VALIDATION_ERROR_0be2b00f',
    '"VUID-VkMacOSSurfaceCreateInfoMVK-pView-01317"' : 'VALIDATION_ERROR_0c000a4a',
    '"VUID-VkMacOSSurfaceCreateInfoMVK-flags-zerobitmask"' : 'VALIDATION_ERROR_0c009005',
    '"VUID-VkMacOSSurfaceCreateInfoMVK-pNext-pNext"' : 'VALIDATION_ERROR_0c01c40d',
    '"VUID-VkMacOSSurfaceCreateInfoMVK-sType-sType"' : 'VALIDATION_ERROR_0c02b00b',
    '"VUID-VkMappedMemoryRange-memory-00684"' : 'VALIDATION_ERROR_0c200558',
    '"VUID-VkMappedMemoryRange-size-00685"' : 'VALIDATION_ERROR_0c20055a',
    '"VUID-VkMappedMemoryRange-size-00686"' : 'VALIDATION_ERROR_0c20055c',
    '"VUID-VkMappedMemoryRange-offset-00687"' : 'VALIDATION_ERROR_0c20055e',
    '"VUID-VkMappedMemoryRange-size-01389"' : 'VALIDATION_ERROR_0c200ada',
    '"VUID-VkMappedMemoryRange-size-01390"' : 'VALIDATION_ERROR_0c200adc',
    '"VUID-VkMappedMemoryRange-memory-parameter"' : 'VALIDATION_ERROR_0c20c601',
    '"VUID-VkMappedMemoryRange-pNext-pNext"' : 'VALIDATION_ERROR_0c21c40d',
    '"VUID-VkMappedMemoryRange-sType-sType"' : 'VALIDATION_ERROR_0c22b00b',
    '"VUID-VkMemoryAllocateFlagsInfo-deviceMask-00675"' : 'VALIDATION_ERROR_0c400546',
    '"VUID-VkMemoryAllocateFlagsInfo-deviceMask-00676"' : 'VALIDATION_ERROR_0c400548',
    '"VUID-VkMemoryAllocateFlagsInfo-flags-parameter"' : 'VALIDATION_ERROR_0c409001',
    '"VUID-VkMemoryAllocateFlagsInfo-sType-sType"' : 'VALIDATION_ERROR_0c42b00b',
    '"VUID-VkMemoryAllocateInfo-allocationSize-00638"' : 'VALIDATION_ERROR_0c6004fc',
    '"VUID-VkMemoryAllocateInfo-pNext-00639"' : 'VALIDATION_ERROR_0c6004fe',
    '"VUID-VkMemoryAllocateInfo-pNext-00640"' : 'VALIDATION_ERROR_0c600500',
    '"VUID-VkMemoryAllocateInfo-pNext-00641"' : 'VALIDATION_ERROR_0c600502',
    '"VUID-VkMemoryAllocateInfo-None-00643"' : 'VALIDATION_ERROR_0c600506',
    '"VUID-VkMemoryAllocateInfo-None-00644"' : 'VALIDATION_ERROR_0c600508',
    '"VUID-VkMemoryAllocateInfo-memoryTypeIndex-00645"' : 'VALIDATION_ERROR_0c60050a',
    '"VUID-VkMemoryAllocateInfo-allocationSize-00646"' : 'VALIDATION_ERROR_0c60050c',
    '"VUID-VkMemoryAllocateInfo-allocationSize-00647"' : 'VALIDATION_ERROR_0c60050e',
    '"VUID-VkMemoryAllocateInfo-memoryTypeIndex-00648"' : 'VALIDATION_ERROR_0c600510',
    '"VUID-VkMemoryAllocateInfo-allocationSize-01742"' : 'VALIDATION_ERROR_0c600d9c',
    '"VUID-VkMemoryAllocateInfo-allocationSize-01743"' : 'VALIDATION_ERROR_0c600d9e',
    '"VUID-VkMemoryAllocateInfo-memoryTypeIndex-01744"' : 'VALIDATION_ERROR_0c600da0',
    '"VUID-VkMemoryAllocateInfo-allocationSize-01745"' : 'VALIDATION_ERROR_0c600da2',
    '"VUID-VkMemoryAllocateInfo-memoryTypeIndex-01872"' : 'VALIDATION_ERROR_0c600ea0',
    '"VUID-VkMemoryAllocateInfo-None-01873"' : 'VALIDATION_ERROR_0c600ea2',
    '"VUID-VkMemoryAllocateInfo-pNext-01874"' : 'VALIDATION_ERROR_0c600ea4',
    '"VUID-VkMemoryAllocateInfo-pNext-01875"' : 'VALIDATION_ERROR_0c600ea6',
    '"VUID-VkMemoryAllocateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0c61c40d',
    '"VUID-VkMemoryAllocateInfo-sType-sType"' : 'VALIDATION_ERROR_0c62b00b',
    '"VUID-VkMemoryAllocateInfo-sType-unique"' : 'VALIDATION_ERROR_0c62b00f',
    '"VUID-VkMemoryBarrier-dstAccessMask-parameter"' : 'VALIDATION_ERROR_0c806801',
    '"VUID-VkMemoryBarrier-pNext-pNext"' : 'VALIDATION_ERROR_0c81c40d',
    '"VUID-VkMemoryBarrier-sType-sType"' : 'VALIDATION_ERROR_0c82b00b',
    '"VUID-VkMemoryBarrier-srcAccessMask-parameter"' : 'VALIDATION_ERROR_0c82c401',
    '"VUID-VkMirSurfaceCreateInfoKHR-connection-01263"' : 'VALIDATION_ERROR_0ca009de',
    '"VUID-VkMirSurfaceCreateInfoKHR-surface-01264"' : 'VALIDATION_ERROR_0ca009e0',
    '"VUID-VkMirSurfaceCreateInfoKHR-flags-zerobitmask"' : 'VALIDATION_ERROR_0ca09005',
    '"VUID-VkMirSurfaceCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_0ca1c40d',
    '"VUID-VkMirSurfaceCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_0ca2b00b',
    '"VUID-VkObjectTableCreateInfoNVX-computeBindingPointSupport-01355"' : 'VALIDATION_ERROR_0cc00a96',
    '"VUID-VkObjectTableCreateInfoNVX-pObjectEntryCounts-01356"' : 'VALIDATION_ERROR_0cc00a98',
    '"VUID-VkObjectTableCreateInfoNVX-maxUniformBuffersPerDescriptor-01357"' : 'VALIDATION_ERROR_0cc00a9a',
    '"VUID-VkObjectTableCreateInfoNVX-maxStorageBuffersPerDescriptor-01358"' : 'VALIDATION_ERROR_0cc00a9c',
    '"VUID-VkObjectTableCreateInfoNVX-maxStorageImagesPerDescriptor-01359"' : 'VALIDATION_ERROR_0cc00a9e',
    '"VUID-VkObjectTableCreateInfoNVX-maxSampledImagesPerDescriptor-01360"' : 'VALIDATION_ERROR_0cc00aa0',
    '"VUID-VkObjectTableCreateInfoNVX-objectCount-arraylength"' : 'VALIDATION_ERROR_0cc0d61b',
    '"VUID-VkObjectTableCreateInfoNVX-pNext-pNext"' : 'VALIDATION_ERROR_0cc1c40d',
    '"VUID-VkObjectTableCreateInfoNVX-pObjectEntryCounts-parameter"' : 'VALIDATION_ERROR_0cc1c601',
    '"VUID-VkObjectTableCreateInfoNVX-pObjectEntryTypes-parameter"' : 'VALIDATION_ERROR_0cc1c801',
    '"VUID-VkObjectTableCreateInfoNVX-pObjectEntryUsageFlags-parameter"' : 'VALIDATION_ERROR_0cc1ca01',
    '"VUID-VkObjectTableCreateInfoNVX-pObjectEntryUsageFlags-requiredbitmask"' : 'VALIDATION_ERROR_0cc1ca03',
    '"VUID-VkObjectTableCreateInfoNVX-sType-sType"' : 'VALIDATION_ERROR_0cc2b00b',
    '"VUID-VkObjectTableDescriptorSetEntryNVX-commonparent"' : 'VALIDATION_ERROR_0ce00009',
    '"VUID-VkObjectTableDescriptorSetEntryNVX-type-01369"' : 'VALIDATION_ERROR_0ce00ab2',
    '"VUID-VkObjectTableDescriptorSetEntryNVX-descriptorSet-parameter"' : 'VALIDATION_ERROR_0ce04801',
    '"VUID-VkObjectTableDescriptorSetEntryNVX-flags-parameter"' : 'VALIDATION_ERROR_0ce09001',
    '"VUID-VkObjectTableDescriptorSetEntryNVX-flags-requiredbitmask"' : 'VALIDATION_ERROR_0ce09003',
    '"VUID-VkObjectTableDescriptorSetEntryNVX-pipelineLayout-parameter"' : 'VALIDATION_ERROR_0ce28201',
    '"VUID-VkObjectTableDescriptorSetEntryNVX-type-parameter"' : 'VALIDATION_ERROR_0ce30401',
    '"VUID-VkObjectTableEntryNVX-computeBindingPointSupport-01367"' : 'VALIDATION_ERROR_0d000aae',
    '"VUID-VkObjectTableEntryNVX-flags-parameter"' : 'VALIDATION_ERROR_0d009001',
    '"VUID-VkObjectTableEntryNVX-flags-requiredbitmask"' : 'VALIDATION_ERROR_0d009003',
    '"VUID-VkObjectTableEntryNVX-type-parameter"' : 'VALIDATION_ERROR_0d030401',
    '"VUID-VkObjectTableIndexBufferEntryNVX-type-01371"' : 'VALIDATION_ERROR_0d200ab6',
    '"VUID-VkObjectTableIndexBufferEntryNVX-buffer-parameter"' : 'VALIDATION_ERROR_0d201a01',
    '"VUID-VkObjectTableIndexBufferEntryNVX-flags-parameter"' : 'VALIDATION_ERROR_0d209001',
    '"VUID-VkObjectTableIndexBufferEntryNVX-flags-requiredbitmask"' : 'VALIDATION_ERROR_0d209003',
    '"VUID-VkObjectTableIndexBufferEntryNVX-indexType-parameter"' : 'VALIDATION_ERROR_0d20b201',
    '"VUID-VkObjectTableIndexBufferEntryNVX-type-parameter"' : 'VALIDATION_ERROR_0d230401',
    '"VUID-VkObjectTablePipelineEntryNVX-type-01368"' : 'VALIDATION_ERROR_0d400ab0',
    '"VUID-VkObjectTablePipelineEntryNVX-flags-parameter"' : 'VALIDATION_ERROR_0d409001',
    '"VUID-VkObjectTablePipelineEntryNVX-flags-requiredbitmask"' : 'VALIDATION_ERROR_0d409003',
    '"VUID-VkObjectTablePipelineEntryNVX-pipeline-parameter"' : 'VALIDATION_ERROR_0d427c01',
    '"VUID-VkObjectTablePipelineEntryNVX-type-parameter"' : 'VALIDATION_ERROR_0d430401',
    '"VUID-VkObjectTablePushConstantEntryNVX-type-01372"' : 'VALIDATION_ERROR_0d600ab8',
    '"VUID-VkObjectTablePushConstantEntryNVX-flags-parameter"' : 'VALIDATION_ERROR_0d609001',
    '"VUID-VkObjectTablePushConstantEntryNVX-flags-requiredbitmask"' : 'VALIDATION_ERROR_0d609003',
    '"VUID-VkObjectTablePushConstantEntryNVX-pipelineLayout-parameter"' : 'VALIDATION_ERROR_0d628201',
    '"VUID-VkObjectTablePushConstantEntryNVX-stageFlags-parameter"' : 'VALIDATION_ERROR_0d62dc01',
    '"VUID-VkObjectTablePushConstantEntryNVX-stageFlags-requiredbitmask"' : 'VALIDATION_ERROR_0d62dc03',
    '"VUID-VkObjectTablePushConstantEntryNVX-type-parameter"' : 'VALIDATION_ERROR_0d630401',
    '"VUID-VkObjectTableVertexBufferEntryNVX-type-01370"' : 'VALIDATION_ERROR_0d800ab4',
    '"VUID-VkObjectTableVertexBufferEntryNVX-buffer-parameter"' : 'VALIDATION_ERROR_0d801a01',
    '"VUID-VkObjectTableVertexBufferEntryNVX-flags-parameter"' : 'VALIDATION_ERROR_0d809001',
    '"VUID-VkObjectTableVertexBufferEntryNVX-flags-requiredbitmask"' : 'VALIDATION_ERROR_0d809003',
    '"VUID-VkObjectTableVertexBufferEntryNVX-type-parameter"' : 'VALIDATION_ERROR_0d830401',
    '"VUID-VkPhysicalDeviceDiscardRectanglePropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_0da2b00b',
    '"VUID-VkPhysicalDeviceExternalBufferInfo-flags-parameter"' : 'VALIDATION_ERROR_0dc09001',
    '"VUID-VkPhysicalDeviceExternalBufferInfo-handleType-parameter"' : 'VALIDATION_ERROR_0dc09c01',
    '"VUID-VkPhysicalDeviceExternalBufferInfo-pNext-pNext"' : 'VALIDATION_ERROR_0dc1c40d',
    '"VUID-VkPhysicalDeviceExternalBufferInfo-sType-sType"' : 'VALIDATION_ERROR_0dc2b00b',
    '"VUID-VkPhysicalDeviceExternalBufferInfo-usage-parameter"' : 'VALIDATION_ERROR_0dc30601',
    '"VUID-VkPhysicalDeviceExternalBufferInfo-usage-requiredbitmask"' : 'VALIDATION_ERROR_0dc30603',
    '"VUID-VkPhysicalDeviceExternalImageFormatInfo-handleType-parameter"' : 'VALIDATION_ERROR_0de09c01',
    '"VUID-VkPhysicalDeviceExternalImageFormatInfo-sType-sType"' : 'VALIDATION_ERROR_0de2b00b',
    '"VUID-VkPhysicalDeviceExternalSemaphoreInfo-handleType-parameter"' : 'VALIDATION_ERROR_0e009c01',
    '"VUID-VkPhysicalDeviceExternalSemaphoreInfo-pNext-pNext"' : 'VALIDATION_ERROR_0e01c40d',
    '"VUID-VkPhysicalDeviceExternalSemaphoreInfo-sType-sType"' : 'VALIDATION_ERROR_0e02b00b',
    '"VUID-VkPhysicalDeviceFeatures2-sType-sType"' : 'VALIDATION_ERROR_0e42b00b',
    '"VUID-VkPhysicalDeviceImageFormatInfo2-flags-parameter"' : 'VALIDATION_ERROR_0e609001',
    '"VUID-VkPhysicalDeviceImageFormatInfo2-format-parameter"' : 'VALIDATION_ERROR_0e609201',
    '"VUID-VkPhysicalDeviceImageFormatInfo2-pNext-pNext"' : 'VALIDATION_ERROR_0e61c40d',
    '"VUID-VkPhysicalDeviceImageFormatInfo2-sType-sType"' : 'VALIDATION_ERROR_0e62b00b',
    '"VUID-VkPhysicalDeviceImageFormatInfo2-tiling-parameter"' : 'VALIDATION_ERROR_0e62fa01',
    '"VUID-VkPhysicalDeviceImageFormatInfo2-type-parameter"' : 'VALIDATION_ERROR_0e630401',
    '"VUID-VkPhysicalDeviceImageFormatInfo2-usage-parameter"' : 'VALIDATION_ERROR_0e630601',
    '"VUID-VkPhysicalDeviceImageFormatInfo2-usage-requiredbitmask"' : 'VALIDATION_ERROR_0e630603',
    '"VUID-VkPhysicalDeviceMultiviewFeatures-multiviewGeometryShader-00580"' : 'VALIDATION_ERROR_0e800488',
    '"VUID-VkPhysicalDeviceMultiviewFeatures-multiviewTessellationShader-00581"' : 'VALIDATION_ERROR_0e80048a',
    '"VUID-VkPhysicalDeviceMultiviewFeatures-sType-sType"' : 'VALIDATION_ERROR_0e82b00b',
    '"VUID-VkPhysicalDevicePushDescriptorPropertiesKHR-sType-sType"' : 'VALIDATION_ERROR_0ea2b00b',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-samples-01095"' : 'VALIDATION_ERROR_0ec0088e',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-format-parameter"' : 'VALIDATION_ERROR_0ec09201',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-pNext-pNext"' : 'VALIDATION_ERROR_0ec1c40d',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-sType-sType"' : 'VALIDATION_ERROR_0ec2b00b',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-samples-parameter"' : 'VALIDATION_ERROR_0ec2b401',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-tiling-parameter"' : 'VALIDATION_ERROR_0ec2fa01',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-type-parameter"' : 'VALIDATION_ERROR_0ec30401',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-usage-parameter"' : 'VALIDATION_ERROR_0ec30601',
    '"VUID-VkPhysicalDeviceSparseImageFormatInfo2-usage-requiredbitmask"' : 'VALIDATION_ERROR_0ec30603',
    '"VUID-VkPhysicalDeviceSurfaceInfo2KHR-pNext-pNext"' : 'VALIDATION_ERROR_0ee1c40d',
    '"VUID-VkPhysicalDeviceSurfaceInfo2KHR-sType-sType"' : 'VALIDATION_ERROR_0ee2b00b',
    '"VUID-VkPhysicalDeviceSurfaceInfo2KHR-surface-parameter"' : 'VALIDATION_ERROR_0ee2ec01',
    '"VUID-VkPipelineCacheCreateInfo-initialDataSize-00768"' : 'VALIDATION_ERROR_0f000600',
    '"VUID-VkPipelineCacheCreateInfo-initialDataSize-00769"' : 'VALIDATION_ERROR_0f000602',
    '"VUID-VkPipelineCacheCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_0f009005',
    '"VUID-VkPipelineCacheCreateInfo-pInitialData-parameter"' : 'VALIDATION_ERROR_0f019601',
    '"VUID-VkPipelineCacheCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0f01c40d',
    '"VUID-VkPipelineCacheCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0f02b00b',
    '"VUID-VkPipelineColorBlendAttachmentState-srcColorBlendFactor-00608"' : 'VALIDATION_ERROR_0f2004c0',
    '"VUID-VkPipelineColorBlendAttachmentState-dstColorBlendFactor-00609"' : 'VALIDATION_ERROR_0f2004c2',
    '"VUID-VkPipelineColorBlendAttachmentState-srcAlphaBlendFactor-00610"' : 'VALIDATION_ERROR_0f2004c4',
    '"VUID-VkPipelineColorBlendAttachmentState-dstAlphaBlendFactor-00611"' : 'VALIDATION_ERROR_0f2004c6',
    '"VUID-VkPipelineColorBlendAttachmentState-alphaBlendOp-parameter"' : 'VALIDATION_ERROR_0f200801',
    '"VUID-VkPipelineColorBlendAttachmentState-colorBlendOp-01406"' : 'VALIDATION_ERROR_0f200afc',
    '"VUID-VkPipelineColorBlendAttachmentState-advancedBlendIndependentBlend-01407"' : 'VALIDATION_ERROR_0f200afe',
    '"VUID-VkPipelineColorBlendAttachmentState-advancedBlendIndependentBlend-01408"' : 'VALIDATION_ERROR_0f200b00',
    '"VUID-VkPipelineColorBlendAttachmentState-advancedBlendAllOperations-01409"' : 'VALIDATION_ERROR_0f200b02',
    '"VUID-VkPipelineColorBlendAttachmentState-colorBlendOp-01410"' : 'VALIDATION_ERROR_0f200b04',
    '"VUID-VkPipelineColorBlendAttachmentState-colorBlendOp-parameter"' : 'VALIDATION_ERROR_0f202001',
    '"VUID-VkPipelineColorBlendAttachmentState-colorWriteMask-parameter"' : 'VALIDATION_ERROR_0f202201',
    '"VUID-VkPipelineColorBlendAttachmentState-dstAlphaBlendFactor-parameter"' : 'VALIDATION_ERROR_0f206a01',
    '"VUID-VkPipelineColorBlendAttachmentState-dstColorBlendFactor-parameter"' : 'VALIDATION_ERROR_0f207001',
    '"VUID-VkPipelineColorBlendAttachmentState-srcAlphaBlendFactor-parameter"' : 'VALIDATION_ERROR_0f22c601',
    '"VUID-VkPipelineColorBlendAttachmentState-srcColorBlendFactor-parameter"' : 'VALIDATION_ERROR_0f22cc01',
    '"VUID-VkPipelineColorBlendStateCreateInfo-pAttachments-00605"' : 'VALIDATION_ERROR_0f4004ba',
    '"VUID-VkPipelineColorBlendStateCreateInfo-logicOpEnable-00606"' : 'VALIDATION_ERROR_0f4004bc',
    '"VUID-VkPipelineColorBlendStateCreateInfo-logicOpEnable-00607"' : 'VALIDATION_ERROR_0f4004be',
    '"VUID-VkPipelineColorBlendStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_0f409005',
    '"VUID-VkPipelineColorBlendStateCreateInfo-pAttachments-parameter"' : 'VALIDATION_ERROR_0f40f201',
    '"VUID-VkPipelineColorBlendStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0f41c40d',
    '"VUID-VkPipelineColorBlendStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0f42b00b',
    '"VUID-VkPipelineDepthStencilStateCreateInfo-depthBoundsTestEnable-00598"' : 'VALIDATION_ERROR_0f6004ac',
    '"VUID-VkPipelineDepthStencilStateCreateInfo-back-parameter"' : 'VALIDATION_ERROR_0f601201',
    '"VUID-VkPipelineDepthStencilStateCreateInfo-depthCompareOp-parameter"' : 'VALIDATION_ERROR_0f604001',
    '"VUID-VkPipelineDepthStencilStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_0f609005',
    '"VUID-VkPipelineDepthStencilStateCreateInfo-front-parameter"' : 'VALIDATION_ERROR_0f609601',
    '"VUID-VkPipelineDepthStencilStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0f61c40d',
    '"VUID-VkPipelineDepthStencilStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0f62b00b',
    '"VUID-VkPipelineDiscardRectangleStateCreateInfoEXT-discardRectangleCount-00582"' : 'VALIDATION_ERROR_0f80048c',
    '"VUID-VkPipelineDiscardRectangleStateCreateInfoEXT-discardRectangleMode-parameter"' : 'VALIDATION_ERROR_0f805e01',
    '"VUID-VkPipelineDiscardRectangleStateCreateInfoEXT-flags-zerobitmask"' : 'VALIDATION_ERROR_0f809005',
    '"VUID-VkPipelineDiscardRectangleStateCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_0f82b00b',
    '"VUID-VkPipelineDynamicStateCreateInfo-pDynamicStates-01442"' : 'VALIDATION_ERROR_0fa00b44',
    '"VUID-VkPipelineDynamicStateCreateInfo-dynamicStateCount-arraylength"' : 'VALIDATION_ERROR_0fa07c1b',
    '"VUID-VkPipelineDynamicStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_0fa09005',
    '"VUID-VkPipelineDynamicStateCreateInfo-pDynamicStates-parameter"' : 'VALIDATION_ERROR_0fa15801',
    '"VUID-VkPipelineDynamicStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0fa1c40d',
    '"VUID-VkPipelineDynamicStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0fa2b00b',
    '"VUID-VkPipelineInputAssemblyStateCreateInfo-topology-00428"' : 'VALIDATION_ERROR_0fc00358',
    '"VUID-VkPipelineInputAssemblyStateCreateInfo-topology-00429"' : 'VALIDATION_ERROR_0fc0035a',
    '"VUID-VkPipelineInputAssemblyStateCreateInfo-topology-00430"' : 'VALIDATION_ERROR_0fc0035c',
    '"VUID-VkPipelineInputAssemblyStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_0fc09005',
    '"VUID-VkPipelineInputAssemblyStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0fc1c40d',
    '"VUID-VkPipelineInputAssemblyStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0fc2b00b',
    '"VUID-VkPipelineInputAssemblyStateCreateInfo-topology-parameter"' : 'VALIDATION_ERROR_0fc30001',
    '"VUID-VkPipelineLayoutCreateInfo-setLayoutCount-00286"' : 'VALIDATION_ERROR_0fe0023c',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-00287"' : 'VALIDATION_ERROR_0fe0023e',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-00288"' : 'VALIDATION_ERROR_0fe00240',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-00289"' : 'VALIDATION_ERROR_0fe00242',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-00290"' : 'VALIDATION_ERROR_0fe00244',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-00291"' : 'VALIDATION_ERROR_0fe00246',
    '"VUID-VkPipelineLayoutCreateInfo-pPushConstantRanges-00292"' : 'VALIDATION_ERROR_0fe00248',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-00293"' : 'VALIDATION_ERROR_0fe0024a',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01676"' : 'VALIDATION_ERROR_0fe00d18',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01677"' : 'VALIDATION_ERROR_0fe00d1a',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01678"' : 'VALIDATION_ERROR_0fe00d1c',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01679"' : 'VALIDATION_ERROR_0fe00d1e',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01680"' : 'VALIDATION_ERROR_0fe00d20',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01681"' : 'VALIDATION_ERROR_0fe00d22',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01682"' : 'VALIDATION_ERROR_0fe00d24',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01683"' : 'VALIDATION_ERROR_0fe00d26',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-01684"' : 'VALIDATION_ERROR_0fe00d28',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03016"' : 'VALIDATION_ERROR_0fe01790',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03017"' : 'VALIDATION_ERROR_0fe01792',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03018"' : 'VALIDATION_ERROR_0fe01794',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03019"' : 'VALIDATION_ERROR_0fe01796',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03020"' : 'VALIDATION_ERROR_0fe01798',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03021"' : 'VALIDATION_ERROR_0fe0179a',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03022"' : 'VALIDATION_ERROR_0fe0179c',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03023"' : 'VALIDATION_ERROR_0fe0179e',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03024"' : 'VALIDATION_ERROR_0fe017a0',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03025"' : 'VALIDATION_ERROR_0fe017a2',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03026"' : 'VALIDATION_ERROR_0fe017a4',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03027"' : 'VALIDATION_ERROR_0fe017a6',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03028"' : 'VALIDATION_ERROR_0fe017a8',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03029"' : 'VALIDATION_ERROR_0fe017aa',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03030"' : 'VALIDATION_ERROR_0fe017ac',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03031"' : 'VALIDATION_ERROR_0fe017ae',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03032"' : 'VALIDATION_ERROR_0fe017b0',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03033"' : 'VALIDATION_ERROR_0fe017b2',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03034"' : 'VALIDATION_ERROR_0fe017b4',
    '"VUID-VkPipelineLayoutCreateInfo-descriptorType-03035"' : 'VALIDATION_ERROR_0fe017b6',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-03036"' : 'VALIDATION_ERROR_0fe017b8',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-03037"' : 'VALIDATION_ERROR_0fe017ba',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-03038"' : 'VALIDATION_ERROR_0fe017bc',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-03039"' : 'VALIDATION_ERROR_0fe017be',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-03040"' : 'VALIDATION_ERROR_0fe017c0',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-03041"' : 'VALIDATION_ERROR_0fe017c2',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-03042"' : 'VALIDATION_ERROR_0fe017c4',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-03043"' : 'VALIDATION_ERROR_0fe017c6',
    '"VUID-VkPipelineLayoutCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_0fe09005',
    '"VUID-VkPipelineLayoutCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_0fe1c40d',
    '"VUID-VkPipelineLayoutCreateInfo-pPushConstantRanges-parameter"' : 'VALIDATION_ERROR_0fe1f801',
    '"VUID-VkPipelineLayoutCreateInfo-pSetLayouts-parameter"' : 'VALIDATION_ERROR_0fe22c01',
    '"VUID-VkPipelineLayoutCreateInfo-sType-sType"' : 'VALIDATION_ERROR_0fe2b00b',
    '"VUID-VkPipelineMultisampleStateCreateInfo-sampleShadingEnable-00784"' : 'VALIDATION_ERROR_10000620',
    '"VUID-VkPipelineMultisampleStateCreateInfo-alphaToOneEnable-00785"' : 'VALIDATION_ERROR_10000622',
    '"VUID-VkPipelineMultisampleStateCreateInfo-minSampleShading-00786"' : 'VALIDATION_ERROR_10000624',
    '"VUID-VkPipelineMultisampleStateCreateInfo-rasterizationSamples-01415"' : 'VALIDATION_ERROR_10000b0e',
    '"VUID-VkPipelineMultisampleStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_10009005',
    '"VUID-VkPipelineMultisampleStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_1001c40d',
    '"VUID-VkPipelineMultisampleStateCreateInfo-pSampleMask-parameter"' : 'VALIDATION_ERROR_10022201',
    '"VUID-VkPipelineMultisampleStateCreateInfo-rasterizationSamples-parameter"' : 'VALIDATION_ERROR_1002a801',
    '"VUID-VkPipelineMultisampleStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_1002b00b',
    '"VUID-VkPipelineMultisampleStateCreateInfo-sType-unique"' : 'VALIDATION_ERROR_1002b00f',
    '"VUID-VkPipelineRasterizationStateCreateInfo-depthClampEnable-00782"' : 'VALIDATION_ERROR_1020061c',
    '"VUID-VkPipelineRasterizationStateCreateInfo-polygonMode-01413"' : 'VALIDATION_ERROR_10200b0a',
    '"VUID-VkPipelineRasterizationStateCreateInfo-polygonMode-01414"' : 'VALIDATION_ERROR_10200b0c',
    '"VUID-VkPipelineRasterizationStateCreateInfo-polygonMode-01507"' : 'VALIDATION_ERROR_10200bc6',
    '"VUID-VkPipelineRasterizationStateCreateInfo-cullMode-parameter"' : 'VALIDATION_ERROR_10203a01',
    '"VUID-VkPipelineRasterizationStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_10209005',
    '"VUID-VkPipelineRasterizationStateCreateInfo-frontFace-parameter"' : 'VALIDATION_ERROR_10209801',
    '"VUID-VkPipelineRasterizationStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_1021c40d',
    '"VUID-VkPipelineRasterizationStateCreateInfo-polygonMode-parameter"' : 'VALIDATION_ERROR_10228601',
    '"VUID-VkPipelineRasterizationStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_1022b00b',
    '"VUID-VkPipelineRasterizationStateCreateInfo-sType-unique"' : 'VALIDATION_ERROR_1022b00f',
    '"VUID-VkPipelineRasterizationStateRasterizationOrderAMD-rasterizationOrder-parameter"' : 'VALIDATION_ERROR_1042a601',
    '"VUID-VkPipelineRasterizationStateRasterizationOrderAMD-sType-sType"' : 'VALIDATION_ERROR_1042b00b',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00704"' : 'VALIDATION_ERROR_10600580',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00705"' : 'VALIDATION_ERROR_10600582',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00706"' : 'VALIDATION_ERROR_10600584',
    '"VUID-VkPipelineShaderStageCreateInfo-pName-00707"' : 'VALIDATION_ERROR_10600586',
    '"VUID-VkPipelineShaderStageCreateInfo-maxClipDistances-00708"' : 'VALIDATION_ERROR_10600588',
    '"VUID-VkPipelineShaderStageCreateInfo-maxCullDistances-00709"' : 'VALIDATION_ERROR_1060058a',
    '"VUID-VkPipelineShaderStageCreateInfo-maxCombinedClipAndCullDistances-00710"' : 'VALIDATION_ERROR_1060058c',
    '"VUID-VkPipelineShaderStageCreateInfo-maxSampleMaskWords-00711"' : 'VALIDATION_ERROR_1060058e',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00712"' : 'VALIDATION_ERROR_10600590',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00713"' : 'VALIDATION_ERROR_10600592',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00714"' : 'VALIDATION_ERROR_10600594',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00715"' : 'VALIDATION_ERROR_10600596',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00716"' : 'VALIDATION_ERROR_10600598',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00717"' : 'VALIDATION_ERROR_1060059a',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00718"' : 'VALIDATION_ERROR_1060059c',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-00719"' : 'VALIDATION_ERROR_1060059e',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-01511"' : 'VALIDATION_ERROR_10600bce',
    '"VUID-VkPipelineShaderStageCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_10609005',
    '"VUID-VkPipelineShaderStageCreateInfo-module-parameter"' : 'VALIDATION_ERROR_1060d201',
    '"VUID-VkPipelineShaderStageCreateInfo-pName-parameter"' : 'VALIDATION_ERROR_1061c001',
    '"VUID-VkPipelineShaderStageCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_1061c40d',
    '"VUID-VkPipelineShaderStageCreateInfo-pSpecializationInfo-parameter"' : 'VALIDATION_ERROR_10623a01',
    '"VUID-VkPipelineShaderStageCreateInfo-sType-sType"' : 'VALIDATION_ERROR_1062b00b',
    '"VUID-VkPipelineShaderStageCreateInfo-stage-parameter"' : 'VALIDATION_ERROR_1062d801',
    '"VUID-VkPipelineTessellationStateCreateInfo-patchControlPoints-01214"' : 'VALIDATION_ERROR_1080097c',
    '"VUID-VkPipelineTessellationStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_10809005',
    '"VUID-VkPipelineTessellationStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_1081c40d',
    '"VUID-VkPipelineTessellationStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_1082b00b',
    '"VUID-VkPipelineVertexInputStateCreateInfo-vertexBindingDescriptionCount-00613"' : 'VALIDATION_ERROR_10a004ca',
    '"VUID-VkPipelineVertexInputStateCreateInfo-vertexAttributeDescriptionCount-00614"' : 'VALIDATION_ERROR_10a004cc',
    '"VUID-VkPipelineVertexInputStateCreateInfo-binding-00615"' : 'VALIDATION_ERROR_10a004ce',
    '"VUID-VkPipelineVertexInputStateCreateInfo-pVertexBindingDescriptions-00616"' : 'VALIDATION_ERROR_10a004d0',
    '"VUID-VkPipelineVertexInputStateCreateInfo-pVertexAttributeDescriptions-00617"' : 'VALIDATION_ERROR_10a004d2',
    '"VUID-VkPipelineVertexInputStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_10a09005',
    '"VUID-VkPipelineVertexInputStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_10a1c40d',
    '"VUID-VkPipelineVertexInputStateCreateInfo-pVertexAttributeDescriptions-parameter"' : 'VALIDATION_ERROR_10a26401',
    '"VUID-VkPipelineVertexInputStateCreateInfo-pVertexBindingDescriptions-parameter"' : 'VALIDATION_ERROR_10a26601',
    '"VUID-VkPipelineVertexInputStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_10a2b00b',
    '"VUID-VkPipelineViewportStateCreateInfo-viewportCount-01216"' : 'VALIDATION_ERROR_10c00980',
    '"VUID-VkPipelineViewportStateCreateInfo-scissorCount-01217"' : 'VALIDATION_ERROR_10c00982',
    '"VUID-VkPipelineViewportStateCreateInfo-viewportCount-01218"' : 'VALIDATION_ERROR_10c00984',
    '"VUID-VkPipelineViewportStateCreateInfo-scissorCount-01219"' : 'VALIDATION_ERROR_10c00986',
    '"VUID-VkPipelineViewportStateCreateInfo-scissorCount-01220"' : 'VALIDATION_ERROR_10c00988',
    '"VUID-VkPipelineViewportStateCreateInfo-viewportWScalingEnable-01726"' : 'VALIDATION_ERROR_10c00d7c',
    '"VUID-VkPipelineViewportStateCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_10c09005',
    '"VUID-VkPipelineViewportStateCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_10c1c40d',
    '"VUID-VkPipelineViewportStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_10c2b00b',
    '"VUID-VkPipelineViewportStateCreateInfo-sType-unique"' : 'VALIDATION_ERROR_10c2b00f',
    '"VUID-VkPipelineViewportStateCreateInfo-scissorCount-arraylength"' : 'VALIDATION_ERROR_10c2b61b',
    '"VUID-VkPipelineViewportStateCreateInfo-viewportCount-arraylength"' : 'VALIDATION_ERROR_10c30a1b',
    '"VUID-VkPipelineViewportSwizzleStateCreateInfoNV-viewportCount-01215"' : 'VALIDATION_ERROR_10e0097e',
    '"VUID-VkPipelineViewportSwizzleStateCreateInfoNV-flags-zerobitmask"' : 'VALIDATION_ERROR_10e09005',
    '"VUID-VkPipelineViewportSwizzleStateCreateInfoNV-sType-sType"' : 'VALIDATION_ERROR_10e2b00b',
    '"VUID-VkPipelineViewportSwizzleStateCreateInfoNV-viewportCount-arraylength"' : 'VALIDATION_ERROR_10e30a1b',
    '"VUID-VkPipelineViewportWScalingStateCreateInfoNV-sType-sType"' : 'VALIDATION_ERROR_1102b00b',
    '"VUID-VkPipelineViewportWScalingStateCreateInfoNV-viewportCount-arraylength"' : 'VALIDATION_ERROR_11030a1b',
    '"VUID-VkPresentInfoKHR-commonparent"' : 'VALIDATION_ERROR_11200009',
    '"VUID-VkPresentInfoKHR-pImageIndices-01296"' : 'VALIDATION_ERROR_11200a20',
    '"VUID-VkPresentInfoKHR-pImageIndices-01430"' : 'VALIDATION_ERROR_11200b2c',
    '"VUID-VkPresentInfoKHR-pImageIndices-parameter"' : 'VALIDATION_ERROR_11218801',
    '"VUID-VkPresentInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_1121c40d',
    '"VUID-VkPresentInfoKHR-pResults-parameter"' : 'VALIDATION_ERROR_11221e01',
    '"VUID-VkPresentInfoKHR-pSwapchains-parameter"' : 'VALIDATION_ERROR_11225801',
    '"VUID-VkPresentInfoKHR-pWaitSemaphores-parameter"' : 'VALIDATION_ERROR_11227601',
    '"VUID-VkPresentInfoKHR-sType-sType"' : 'VALIDATION_ERROR_1122b00b',
    '"VUID-VkPresentInfoKHR-sType-unique"' : 'VALIDATION_ERROR_1122b00f',
    '"VUID-VkPresentInfoKHR-swapchainCount-arraylength"' : 'VALIDATION_ERROR_1122f21b',
    '"VUID-VkPresentRegionKHR-pRectangles-parameter"' : 'VALIDATION_ERROR_11420c01',
    '"VUID-VkPresentRegionsKHR-swapchainCount-01260"' : 'VALIDATION_ERROR_116009d8',
    '"VUID-VkPresentRegionsKHR-pRegions-parameter"' : 'VALIDATION_ERROR_11621001',
    '"VUID-VkPresentRegionsKHR-sType-sType"' : 'VALIDATION_ERROR_1162b00b',
    '"VUID-VkPresentRegionsKHR-swapchainCount-arraylength"' : 'VALIDATION_ERROR_1162f21b',
    '"VUID-VkPresentTimesInfoGOOGLE-swapchainCount-01247"' : 'VALIDATION_ERROR_118009be',
    '"VUID-VkPresentTimesInfoGOOGLE-pTimes-parameter"' : 'VALIDATION_ERROR_11825e01',
    '"VUID-VkPresentTimesInfoGOOGLE-sType-sType"' : 'VALIDATION_ERROR_1182b00b',
    '"VUID-VkPresentTimesInfoGOOGLE-swapchainCount-arraylength"' : 'VALIDATION_ERROR_1182f21b',
    '"VUID-VkPushConstantRange-offset-00294"' : 'VALIDATION_ERROR_11a0024c',
    '"VUID-VkPushConstantRange-offset-00295"' : 'VALIDATION_ERROR_11a0024e',
    '"VUID-VkPushConstantRange-size-00296"' : 'VALIDATION_ERROR_11a00250',
    '"VUID-VkPushConstantRange-size-00297"' : 'VALIDATION_ERROR_11a00252',
    '"VUID-VkPushConstantRange-size-00298"' : 'VALIDATION_ERROR_11a00254',
    '"VUID-VkPushConstantRange-stageFlags-parameter"' : 'VALIDATION_ERROR_11a2dc01',
    '"VUID-VkPushConstantRange-stageFlags-requiredbitmask"' : 'VALIDATION_ERROR_11a2dc03',
    '"VUID-VkQueryPoolCreateInfo-queryType-00791"' : 'VALIDATION_ERROR_11c0062e',
    '"VUID-VkQueryPoolCreateInfo-queryType-00792"' : 'VALIDATION_ERROR_11c00630',
    '"VUID-VkQueryPoolCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_11c09005',
    '"VUID-VkQueryPoolCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_11c1c40d',
    '"VUID-VkQueryPoolCreateInfo-queryType-parameter"' : 'VALIDATION_ERROR_11c29a01',
    '"VUID-VkQueryPoolCreateInfo-sType-sType"' : 'VALIDATION_ERROR_11c2b00b',
    '"VUID-VkRectLayerKHR-offset-01261"' : 'VALIDATION_ERROR_11e009da',
    '"VUID-VkRectLayerKHR-layer-01262"' : 'VALIDATION_ERROR_11e009dc',
    '"VUID-VkRenderPassBeginInfo-commonparent"' : 'VALIDATION_ERROR_12000009',
    '"VUID-VkRenderPassBeginInfo-clearValueCount-00902"' : 'VALIDATION_ERROR_1200070c',
    '"VUID-VkRenderPassBeginInfo-clearValueCount-00903"' : 'VALIDATION_ERROR_1200070e',
    '"VUID-VkRenderPassBeginInfo-renderPass-00904"' : 'VALIDATION_ERROR_12000710',
    '"VUID-VkRenderPassBeginInfo-framebuffer-parameter"' : 'VALIDATION_ERROR_12009401',
    '"VUID-VkRenderPassBeginInfo-pNext-pNext"' : 'VALIDATION_ERROR_1201c40d',
    '"VUID-VkRenderPassBeginInfo-renderPass-parameter"' : 'VALIDATION_ERROR_1202ae01',
    '"VUID-VkRenderPassBeginInfo-sType-sType"' : 'VALIDATION_ERROR_1202b00b',
    '"VUID-VkRenderPassBeginInfo-sType-unique"' : 'VALIDATION_ERROR_1202b00f',
    '"VUID-VkRenderPassCreateInfo-None-00832"' : 'VALIDATION_ERROR_12200680',
    '"VUID-VkRenderPassCreateInfo-attachment-00833"' : 'VALIDATION_ERROR_12200682',
    '"VUID-VkRenderPassCreateInfo-attachment-00834"' : 'VALIDATION_ERROR_12200684',
    '"VUID-VkRenderPassCreateInfo-pPreserveAttachments-00835"' : 'VALIDATION_ERROR_12200686',
    '"VUID-VkRenderPassCreateInfo-pAttachments-00836"' : 'VALIDATION_ERROR_12200688',
    '"VUID-VkRenderPassCreateInfo-pDependencies-00837"' : 'VALIDATION_ERROR_1220068a',
    '"VUID-VkRenderPassCreateInfo-pDependencies-00838"' : 'VALIDATION_ERROR_1220068c',
    '"VUID-VkRenderPassCreateInfo-pAttachments-01566"' : 'VALIDATION_ERROR_12200c3c',
    '"VUID-VkRenderPassCreateInfo-pAttachments-01567"' : 'VALIDATION_ERROR_12200c3e',
    '"VUID-VkRenderPassCreateInfo-pNext-01926"' : 'VALIDATION_ERROR_12200f0c',
    '"VUID-VkRenderPassCreateInfo-pNext-01927"' : 'VALIDATION_ERROR_12200f0e',
    '"VUID-VkRenderPassCreateInfo-pNext-01928"' : 'VALIDATION_ERROR_12200f10',
    '"VUID-VkRenderPassCreateInfo-pNext-01929"' : 'VALIDATION_ERROR_12200f12',
    '"VUID-VkRenderPassCreateInfo-pNext-01930"' : 'VALIDATION_ERROR_12200f14',
    '"VUID-VkRenderPassCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_12209005',
    '"VUID-VkRenderPassCreateInfo-pAttachments-parameter"' : 'VALIDATION_ERROR_1220f201',
    '"VUID-VkRenderPassCreateInfo-pDependencies-parameter"' : 'VALIDATION_ERROR_12212601',
    '"VUID-VkRenderPassCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_1221c40d',
    '"VUID-VkRenderPassCreateInfo-pSubpasses-parameter"' : 'VALIDATION_ERROR_12224201',
    '"VUID-VkRenderPassCreateInfo-sType-sType"' : 'VALIDATION_ERROR_1222b00b',
    '"VUID-VkRenderPassCreateInfo-sType-unique"' : 'VALIDATION_ERROR_1222b00f',
    '"VUID-VkRenderPassCreateInfo-subpassCount-arraylength"' : 'VALIDATION_ERROR_1222e61b',
    '"VUID-VkRenderPassMultiviewCreateInfo-pCorrelationMasks-00841"' : 'VALIDATION_ERROR_12400692',
    '"VUID-VkRenderPassMultiviewCreateInfo-pCorrelationMasks-parameter"' : 'VALIDATION_ERROR_12411a01',
    '"VUID-VkRenderPassMultiviewCreateInfo-pViewMasks-parameter"' : 'VALIDATION_ERROR_12426c01',
    '"VUID-VkRenderPassMultiviewCreateInfo-pViewOffsets-parameter"' : 'VALIDATION_ERROR_12426e01',
    '"VUID-VkRenderPassMultiviewCreateInfo-sType-sType"' : 'VALIDATION_ERROR_1242b00b',
    '"VUID-VkSamplerCreateInfo-addressModeU-parameter"' : 'VALIDATION_ERROR_12600201',
    '"VUID-VkSamplerCreateInfo-addressModeV-parameter"' : 'VALIDATION_ERROR_12600401',
    '"VUID-VkSamplerCreateInfo-addressModeW-parameter"' : 'VALIDATION_ERROR_12600601',
    '"VUID-VkSamplerCreateInfo-mipLodBias-01069"' : 'VALIDATION_ERROR_1260085a',
    '"VUID-VkSamplerCreateInfo-anisotropyEnable-01070"' : 'VALIDATION_ERROR_1260085c',
    '"VUID-VkSamplerCreateInfo-anisotropyEnable-01071"' : 'VALIDATION_ERROR_1260085e',
    '"VUID-VkSamplerCreateInfo-unnormalizedCoordinates-01072"' : 'VALIDATION_ERROR_12600860',
    '"VUID-VkSamplerCreateInfo-unnormalizedCoordinates-01073"' : 'VALIDATION_ERROR_12600862',
    '"VUID-VkSamplerCreateInfo-unnormalizedCoordinates-01074"' : 'VALIDATION_ERROR_12600864',
    '"VUID-VkSamplerCreateInfo-unnormalizedCoordinates-01075"' : 'VALIDATION_ERROR_12600866',
    '"VUID-VkSamplerCreateInfo-unnormalizedCoordinates-01076"' : 'VALIDATION_ERROR_12600868',
    '"VUID-VkSamplerCreateInfo-unnormalizedCoordinates-01077"' : 'VALIDATION_ERROR_1260086a',
    '"VUID-VkSamplerCreateInfo-addressModeU-01078"' : 'VALIDATION_ERROR_1260086c',
    '"VUID-VkSamplerCreateInfo-addressModeU-01079"' : 'VALIDATION_ERROR_1260086e',
    '"VUID-VkSamplerCreateInfo-compareEnable-01080"' : 'VALIDATION_ERROR_12600870',
    '"VUID-VkSamplerCreateInfo-magFilter-01081"' : 'VALIDATION_ERROR_12600872',
    '"VUID-VkSamplerCreateInfo-magFilter-01422"' : 'VALIDATION_ERROR_12600b1c',
    '"VUID-VkSamplerCreateInfo-compareEnable-01423"' : 'VALIDATION_ERROR_12600b1e',
    '"VUID-VkSamplerCreateInfo-minFilter-01645"' : 'VALIDATION_ERROR_12600cda',
    '"VUID-VkSamplerCreateInfo-addressModeU-01646"' : 'VALIDATION_ERROR_12600cdc',
    '"VUID-VkSamplerCreateInfo-None-01647"' : 'VALIDATION_ERROR_12600cde',
    '"VUID-VkSamplerCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_12609005',
    '"VUID-VkSamplerCreateInfo-magFilter-parameter"' : 'VALIDATION_ERROR_1260c401',
    '"VUID-VkSamplerCreateInfo-minFilter-parameter"' : 'VALIDATION_ERROR_1260ca01',
    '"VUID-VkSamplerCreateInfo-mipmapMode-parameter"' : 'VALIDATION_ERROR_1260cc01',
    '"VUID-VkSamplerCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_1261c40d',
    '"VUID-VkSamplerCreateInfo-sType-sType"' : 'VALIDATION_ERROR_1262b00b',
    '"VUID-VkSamplerCreateInfo-sType-unique"' : 'VALIDATION_ERROR_1262b00f',
    '"VUID-VkSemaphoreCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_12809005',
    '"VUID-VkSemaphoreCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_1281c40d',
    '"VUID-VkSemaphoreCreateInfo-sType-sType"' : 'VALIDATION_ERROR_1282b00b',
    '"VUID-VkSemaphoreCreateInfo-sType-unique"' : 'VALIDATION_ERROR_1282b00f',
    '"VUID-VkShaderModuleCreateInfo-codeSize-01085"' : 'VALIDATION_ERROR_12a0087a',
    '"VUID-VkShaderModuleCreateInfo-codeSize-01086"' : 'VALIDATION_ERROR_12a0087c',
    '"VUID-VkShaderModuleCreateInfo-pCode-01087"' : 'VALIDATION_ERROR_12a0087e',
    '"VUID-VkShaderModuleCreateInfo-pCode-01088"' : 'VALIDATION_ERROR_12a00880',
    '"VUID-VkShaderModuleCreateInfo-pCode-01089"' : 'VALIDATION_ERROR_12a00882',
    '"VUID-VkShaderModuleCreateInfo-pCode-01090"' : 'VALIDATION_ERROR_12a00884',
    '"VUID-VkShaderModuleCreateInfo-pCode-01091"' : 'VALIDATION_ERROR_12a00886',
    '"VUID-VkShaderModuleCreateInfo-pCode-01376"' : 'VALIDATION_ERROR_12a00ac0',
    '"VUID-VkShaderModuleCreateInfo-pCode-01377"' : 'VALIDATION_ERROR_12a00ac2',
    '"VUID-VkShaderModuleCreateInfo-pCode-01378"' : 'VALIDATION_ERROR_12a00ac4',
    '"VUID-VkShaderModuleCreateInfo-pCode-01379"' : 'VALIDATION_ERROR_12a00ac6',
    '"VUID-VkShaderModuleCreateInfo-flags-zerobitmask"' : 'VALIDATION_ERROR_12a09005',
    '"VUID-VkShaderModuleCreateInfo-pCode-parameter"' : 'VALIDATION_ERROR_12a10c01',
    '"VUID-VkShaderModuleCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_12a1c40d',
    '"VUID-VkShaderModuleCreateInfo-sType-sType"' : 'VALIDATION_ERROR_12a2b00b',
    '"VUID-VkSparseBufferMemoryBindInfo-bindCount-arraylength"' : 'VALIDATION_ERROR_12c0141b',
    '"VUID-VkSparseBufferMemoryBindInfo-buffer-parameter"' : 'VALIDATION_ERROR_12c01a01',
    '"VUID-VkSparseBufferMemoryBindInfo-pBinds-parameter"' : 'VALIDATION_ERROR_12c0fe01',
    '"VUID-VkSparseImageMemoryBind-memory-01104"' : 'VALIDATION_ERROR_12e008a0',
    '"VUID-VkSparseImageMemoryBind-memory-01105"' : 'VALIDATION_ERROR_12e008a2',
    '"VUID-VkSparseImageMemoryBind-subresource-01106"' : 'VALIDATION_ERROR_12e008a4',
    '"VUID-VkSparseImageMemoryBind-offset-01107"' : 'VALIDATION_ERROR_12e008a6',
    '"VUID-VkSparseImageMemoryBind-extent-01108"' : 'VALIDATION_ERROR_12e008a8',
    '"VUID-VkSparseImageMemoryBind-offset-01109"' : 'VALIDATION_ERROR_12e008aa',
    '"VUID-VkSparseImageMemoryBind-extent-01110"' : 'VALIDATION_ERROR_12e008ac',
    '"VUID-VkSparseImageMemoryBind-offset-01111"' : 'VALIDATION_ERROR_12e008ae',
    '"VUID-VkSparseImageMemoryBind-extent-01112"' : 'VALIDATION_ERROR_12e008b0',
    '"VUID-VkSparseImageMemoryBind-flags-parameter"' : 'VALIDATION_ERROR_12e09001',
    '"VUID-VkSparseImageMemoryBind-memory-parameter"' : 'VALIDATION_ERROR_12e0c601',
    '"VUID-VkSparseImageMemoryBind-subresource-parameter"' : 'VALIDATION_ERROR_12e2e801',
    '"VUID-VkSparseImageMemoryBindInfo-subresource-01722"' : 'VALIDATION_ERROR_13000d74',
    '"VUID-VkSparseImageMemoryBindInfo-subresource-01723"' : 'VALIDATION_ERROR_13000d76',
    '"VUID-VkSparseImageMemoryBindInfo-bindCount-arraylength"' : 'VALIDATION_ERROR_1300141b',
    '"VUID-VkSparseImageMemoryBindInfo-image-parameter"' : 'VALIDATION_ERROR_1300a001',
    '"VUID-VkSparseImageMemoryBindInfo-pBinds-parameter"' : 'VALIDATION_ERROR_1300fe01',
    '"VUID-VkSparseImageOpaqueMemoryBindInfo-pBinds-01103"' : 'VALIDATION_ERROR_1320089e',
    '"VUID-VkSparseImageOpaqueMemoryBindInfo-bindCount-arraylength"' : 'VALIDATION_ERROR_1320141b',
    '"VUID-VkSparseImageOpaqueMemoryBindInfo-image-parameter"' : 'VALIDATION_ERROR_1320a001',
    '"VUID-VkSparseImageOpaqueMemoryBindInfo-pBinds-parameter"' : 'VALIDATION_ERROR_1320fe01',
    '"VUID-VkSparseMemoryBind-memory-01096"' : 'VALIDATION_ERROR_13400890',
    '"VUID-VkSparseMemoryBind-memory-01097"' : 'VALIDATION_ERROR_13400892',
    '"VUID-VkSparseMemoryBind-size-01098"' : 'VALIDATION_ERROR_13400894',
    '"VUID-VkSparseMemoryBind-resourceOffset-01099"' : 'VALIDATION_ERROR_13400896',
    '"VUID-VkSparseMemoryBind-size-01100"' : 'VALIDATION_ERROR_13400898',
    '"VUID-VkSparseMemoryBind-memoryOffset-01101"' : 'VALIDATION_ERROR_1340089a',
    '"VUID-VkSparseMemoryBind-size-01102"' : 'VALIDATION_ERROR_1340089c',
    '"VUID-VkSparseMemoryBind-flags-parameter"' : 'VALIDATION_ERROR_13409001',
    '"VUID-VkSparseMemoryBind-memory-parameter"' : 'VALIDATION_ERROR_1340c601',
    '"VUID-VkSpecializationInfo-offset-00773"' : 'VALIDATION_ERROR_1360060a',
    '"VUID-VkSpecializationInfo-pMapEntries-00774"' : 'VALIDATION_ERROR_1360060c',
    '"VUID-VkSpecializationInfo-mapEntryCount-00775"' : 'VALIDATION_ERROR_1360060e',
    '"VUID-VkSpecializationInfo-pData-parameter"' : 'VALIDATION_ERROR_13612201',
    '"VUID-VkSpecializationMapEntry-constantID-00776"' : 'VALIDATION_ERROR_13800610',
    '"VUID-VkStencilOpState-compareOp-parameter"' : 'VALIDATION_ERROR_13a02a01',
    '"VUID-VkStencilOpState-depthFailOp-parameter"' : 'VALIDATION_ERROR_13a04201',
    '"VUID-VkStencilOpState-failOp-parameter"' : 'VALIDATION_ERROR_13a08601',
    '"VUID-VkStencilOpState-passOp-parameter"' : 'VALIDATION_ERROR_13a27801',
    '"VUID-VkSubmitInfo-commonparent"' : 'VALIDATION_ERROR_13c00009',
    '"VUID-VkSubmitInfo-pCommandBuffers-00075"' : 'VALIDATION_ERROR_13c00096',
    '"VUID-VkSubmitInfo-pWaitDstStageMask-00076"' : 'VALIDATION_ERROR_13c00098',
    '"VUID-VkSubmitInfo-pWaitDstStageMask-00077"' : 'VALIDATION_ERROR_13c0009a',
    '"VUID-VkSubmitInfo-pWaitDstStageMask-00078"' : 'VALIDATION_ERROR_13c0009c',
    '"VUID-VkSubmitInfo-pCommandBuffers-parameter"' : 'VALIDATION_ERROR_13c11401',
    '"VUID-VkSubmitInfo-pNext-pNext"' : 'VALIDATION_ERROR_13c1c40d',
    '"VUID-VkSubmitInfo-pSignalSemaphores-parameter"' : 'VALIDATION_ERROR_13c23401',
    '"VUID-VkSubmitInfo-pWaitDstStageMask-parameter"' : 'VALIDATION_ERROR_13c27001',
    '"VUID-VkSubmitInfo-pWaitDstStageMask-requiredbitmask"' : 'VALIDATION_ERROR_13c27003',
    '"VUID-VkSubmitInfo-pWaitSemaphores-parameter"' : 'VALIDATION_ERROR_13c27601',
    '"VUID-VkSubmitInfo-sType-sType"' : 'VALIDATION_ERROR_13c2b00b',
    '"VUID-VkSubmitInfo-sType-unique"' : 'VALIDATION_ERROR_13c2b00f',
    '"VUID-VkSubpassDependency-srcSubpass-00858"' : 'VALIDATION_ERROR_13e006b4',
    '"VUID-VkSubpassDependency-dstSubpass-00859"' : 'VALIDATION_ERROR_13e006b6',
    '"VUID-VkSubpassDependency-srcStageMask-00860"' : 'VALIDATION_ERROR_13e006b8',
    '"VUID-VkSubpassDependency-dstStageMask-00861"' : 'VALIDATION_ERROR_13e006ba',
    '"VUID-VkSubpassDependency-srcStageMask-00862"' : 'VALIDATION_ERROR_13e006bc',
    '"VUID-VkSubpassDependency-dstStageMask-00863"' : 'VALIDATION_ERROR_13e006be',
    '"VUID-VkSubpassDependency-srcSubpass-00864"' : 'VALIDATION_ERROR_13e006c0',
    '"VUID-VkSubpassDependency-srcSubpass-00865"' : 'VALIDATION_ERROR_13e006c2',
    '"VUID-VkSubpassDependency-srcSubpass-00866"' : 'VALIDATION_ERROR_13e006c4',
    '"VUID-VkSubpassDependency-srcSubpass-00867"' : 'VALIDATION_ERROR_13e006c6',
    '"VUID-VkSubpassDependency-srcAccessMask-00868"' : 'VALIDATION_ERROR_13e006c8',
    '"VUID-VkSubpassDependency-dstAccessMask-00869"' : 'VALIDATION_ERROR_13e006ca',
    '"VUID-VkSubpassDependency-dependencyFlags-00870"' : 'VALIDATION_ERROR_13e006cc',
    '"VUID-VkSubpassDependency-dependencyFlags-00871"' : 'VALIDATION_ERROR_13e006ce',
    '"VUID-VkSubpassDependency-srcSubpass-00872"' : 'VALIDATION_ERROR_13e006d0',
    '"VUID-VkSubpassDependency-dependencyFlags-parameter"' : 'VALIDATION_ERROR_13e03e01',
    '"VUID-VkSubpassDependency-dstAccessMask-parameter"' : 'VALIDATION_ERROR_13e06801',
    '"VUID-VkSubpassDependency-dstStageMask-parameter"' : 'VALIDATION_ERROR_13e07801',
    '"VUID-VkSubpassDependency-dstStageMask-requiredbitmask"' : 'VALIDATION_ERROR_13e07803',
    '"VUID-VkSubpassDependency-srcAccessMask-parameter"' : 'VALIDATION_ERROR_13e2c401',
    '"VUID-VkSubpassDependency-srcStageMask-parameter"' : 'VALIDATION_ERROR_13e2d401',
    '"VUID-VkSubpassDependency-srcStageMask-requiredbitmask"' : 'VALIDATION_ERROR_13e2d403',
    '"VUID-VkSubpassDescription-pipelineBindPoint-00844"' : 'VALIDATION_ERROR_14000698',
    '"VUID-VkSubpassDescription-colorAttachmentCount-00845"' : 'VALIDATION_ERROR_1400069a',
    '"VUID-VkSubpassDescription-loadOp-00846"' : 'VALIDATION_ERROR_1400069c',
    '"VUID-VkSubpassDescription-pResolveAttachments-00847"' : 'VALIDATION_ERROR_1400069e',
    '"VUID-VkSubpassDescription-pResolveAttachments-00848"' : 'VALIDATION_ERROR_140006a0',
    '"VUID-VkSubpassDescription-pResolveAttachments-00849"' : 'VALIDATION_ERROR_140006a2',
    '"VUID-VkSubpassDescription-pResolveAttachments-00850"' : 'VALIDATION_ERROR_140006a4',
    '"VUID-VkSubpassDescription-None-00852"' : 'VALIDATION_ERROR_140006a8',
    '"VUID-VkSubpassDescription-attachment-00853"' : 'VALIDATION_ERROR_140006aa',
    '"VUID-VkSubpassDescription-pPreserveAttachments-00854"' : 'VALIDATION_ERROR_140006ac',
    '"VUID-VkSubpassDescription-layout-00855"' : 'VALIDATION_ERROR_140006ae',
    '"VUID-VkSubpassDescription-flags-00856"' : 'VALIDATION_ERROR_140006b0',
    '"VUID-VkSubpassDescription-pColorAttachments-01417"' : 'VALIDATION_ERROR_14000b12',
    '"VUID-VkSubpassDescription-pDepthStencilAttachment-01418"' : 'VALIDATION_ERROR_14000b14',
    '"VUID-VkSubpassDescription-pColorAttachments-01506"' : 'VALIDATION_ERROR_14000bc4',
    '"VUID-VkSubpassDescription-flags-parameter"' : 'VALIDATION_ERROR_14009001',
    '"VUID-VkSubpassDescription-pColorAttachments-parameter"' : 'VALIDATION_ERROR_14011001',
    '"VUID-VkSubpassDescription-pDepthStencilAttachment-parameter"' : 'VALIDATION_ERROR_14012a01',
    '"VUID-VkSubpassDescription-pInputAttachments-parameter"' : 'VALIDATION_ERROR_14019a01',
    '"VUID-VkSubpassDescription-pPreserveAttachments-parameter"' : 'VALIDATION_ERROR_1401f001',
    '"VUID-VkSubpassDescription-pResolveAttachments-parameter"' : 'VALIDATION_ERROR_14021c01',
    '"VUID-VkSubpassDescription-pipelineBindPoint-parameter"' : 'VALIDATION_ERROR_14027e01',
    '"VUID-VkSurfaceCapabilities2EXT-supportedSurfaceCounters-01246"' : 'VALIDATION_ERROR_142009bc',
    '"VUID-VkSurfaceCapabilities2EXT-pNext-pNext"' : 'VALIDATION_ERROR_1421c40d',
    '"VUID-VkSurfaceCapabilities2EXT-sType-sType"' : 'VALIDATION_ERROR_1422b00b',
    '"VUID-VkSwapchainCounterCreateInfoEXT-surfaceCounters-01244"' : 'VALIDATION_ERROR_144009b8',
    '"VUID-VkSwapchainCounterCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_1442b00b',
    '"VUID-VkSwapchainCounterCreateInfoEXT-surfaceCounters-parameter"' : 'VALIDATION_ERROR_1442ee01',
    '"VUID-VkSwapchainCreateInfoKHR-commonparent"' : 'VALIDATION_ERROR_14600009',
    '"VUID-VkSwapchainCreateInfoKHR-surface-01270"' : 'VALIDATION_ERROR_146009ec',
    '"VUID-VkSwapchainCreateInfoKHR-minImageCount-01271"' : 'VALIDATION_ERROR_146009ee',
    '"VUID-VkSwapchainCreateInfoKHR-minImageCount-01272"' : 'VALIDATION_ERROR_146009f0',
    '"VUID-VkSwapchainCreateInfoKHR-imageFormat-01273"' : 'VALIDATION_ERROR_146009f2',
    '"VUID-VkSwapchainCreateInfoKHR-imageExtent-01274"' : 'VALIDATION_ERROR_146009f4',
    '"VUID-VkSwapchainCreateInfoKHR-imageArrayLayers-01275"' : 'VALIDATION_ERROR_146009f6',
    '"VUID-VkSwapchainCreateInfoKHR-imageUsage-01276"' : 'VALIDATION_ERROR_146009f8',
    '"VUID-VkSwapchainCreateInfoKHR-imageSharingMode-01277"' : 'VALIDATION_ERROR_146009fa',
    '"VUID-VkSwapchainCreateInfoKHR-imageSharingMode-01278"' : 'VALIDATION_ERROR_146009fc',
    '"VUID-VkSwapchainCreateInfoKHR-preTransform-01279"' : 'VALIDATION_ERROR_146009fe',
    '"VUID-VkSwapchainCreateInfoKHR-compositeAlpha-01280"' : 'VALIDATION_ERROR_14600a00',
    '"VUID-VkSwapchainCreateInfoKHR-presentMode-01281"' : 'VALIDATION_ERROR_14600a02',
    '"VUID-VkSwapchainCreateInfoKHR-minImageCount-01383"' : 'VALIDATION_ERROR_14600ace',
    '"VUID-VkSwapchainCreateInfoKHR-imageUsage-01384"' : 'VALIDATION_ERROR_14600ad0',
    '"VUID-VkSwapchainCreateInfoKHR-imageSharingMode-01393"' : 'VALIDATION_ERROR_14600ae2',
    '"VUID-VkSwapchainCreateInfoKHR-presentMode-01427"' : 'VALIDATION_ERROR_14600b26',
    '"VUID-VkSwapchainCreateInfoKHR-imageSharingMode-01428"' : 'VALIDATION_ERROR_14600b28',
    '"VUID-VkSwapchainCreateInfoKHR-physicalDeviceCount-01429"' : 'VALIDATION_ERROR_14600b2a',
    '"VUID-VkSwapchainCreateInfoKHR-imageExtent-01689"' : 'VALIDATION_ERROR_14600d32',
    '"VUID-VkSwapchainCreateInfoKHR-imageFormat-01778"' : 'VALIDATION_ERROR_14600de4',
    '"VUID-VkSwapchainCreateInfoKHR-oldSwapchain-01933"' : 'VALIDATION_ERROR_14600f1a',
    '"VUID-VkSwapchainCreateInfoKHR-compositeAlpha-parameter"' : 'VALIDATION_ERROR_14602e01',
    '"VUID-VkSwapchainCreateInfoKHR-flags-parameter"' : 'VALIDATION_ERROR_14609001',
    '"VUID-VkSwapchainCreateInfoKHR-imageColorSpace-parameter"' : 'VALIDATION_ERROR_1460a201',
    '"VUID-VkSwapchainCreateInfoKHR-imageFormat-parameter"' : 'VALIDATION_ERROR_1460a401',
    '"VUID-VkSwapchainCreateInfoKHR-imageSharingMode-parameter"' : 'VALIDATION_ERROR_1460a801',
    '"VUID-VkSwapchainCreateInfoKHR-imageUsage-parameter"' : 'VALIDATION_ERROR_1460ae01',
    '"VUID-VkSwapchainCreateInfoKHR-imageUsage-requiredbitmask"' : 'VALIDATION_ERROR_1460ae03',
    '"VUID-VkSwapchainCreateInfoKHR-oldSwapchain-parameter"' : 'VALIDATION_ERROR_1460de01',
    '"VUID-VkSwapchainCreateInfoKHR-oldSwapchain-parent"' : 'VALIDATION_ERROR_1460de07',
    '"VUID-VkSwapchainCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_1461c40d',
    '"VUID-VkSwapchainCreateInfoKHR-preTransform-parameter"' : 'VALIDATION_ERROR_14629401',
    '"VUID-VkSwapchainCreateInfoKHR-presentMode-parameter"' : 'VALIDATION_ERROR_14629601',
    '"VUID-VkSwapchainCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_1462b00b',
    '"VUID-VkSwapchainCreateInfoKHR-sType-unique"' : 'VALIDATION_ERROR_1462b00f',
    '"VUID-VkSwapchainCreateInfoKHR-surface-parameter"' : 'VALIDATION_ERROR_1462ec01',
    '"VUID-VkValidationFlagsEXT-disabledValidationCheckCount-arraylength"' : 'VALIDATION_ERROR_14805a1b',
    '"VUID-VkValidationFlagsEXT-pDisabledValidationChecks-parameter"' : 'VALIDATION_ERROR_14814401',
    '"VUID-VkValidationFlagsEXT-sType-sType"' : 'VALIDATION_ERROR_1482b00b',
    '"VUID-VkVertexInputAttributeDescription-location-00620"' : 'VALIDATION_ERROR_14a004d8',
    '"VUID-VkVertexInputAttributeDescription-binding-00621"' : 'VALIDATION_ERROR_14a004da',
    '"VUID-VkVertexInputAttributeDescription-offset-00622"' : 'VALIDATION_ERROR_14a004dc',
    '"VUID-VkVertexInputAttributeDescription-format-00623"' : 'VALIDATION_ERROR_14a004de',
    '"VUID-VkVertexInputAttributeDescription-format-parameter"' : 'VALIDATION_ERROR_14a09201',
    '"VUID-VkVertexInputBindingDescription-binding-00618"' : 'VALIDATION_ERROR_14c004d4',
    '"VUID-VkVertexInputBindingDescription-stride-00619"' : 'VALIDATION_ERROR_14c004d6',
    '"VUID-VkVertexInputBindingDescription-inputRate-parameter"' : 'VALIDATION_ERROR_14c0ba01',
    '"VUID-VkViSurfaceCreateInfoNN-window-01318"' : 'VALIDATION_ERROR_14e00a4c',
    '"VUID-VkViSurfaceCreateInfoNN-flags-zerobitmask"' : 'VALIDATION_ERROR_14e09005',
    '"VUID-VkViSurfaceCreateInfoNN-pNext-pNext"' : 'VALIDATION_ERROR_14e1c40d',
    '"VUID-VkViSurfaceCreateInfoNN-sType-sType"' : 'VALIDATION_ERROR_14e2b00b',
    '"VUID-VkViewport-x-01232"' : 'VALIDATION_ERROR_150009a0',
    '"VUID-VkViewport-y-01233"' : 'VALIDATION_ERROR_150009a2',
    '"VUID-VkViewport-minDepth-01234"' : 'VALIDATION_ERROR_150009a4',
    '"VUID-VkViewport-maxDepth-01235"' : 'VALIDATION_ERROR_150009a6',
    '"VUID-VkViewport-width-01770"' : 'VALIDATION_ERROR_15000dd4',
    '"VUID-VkViewport-width-01771"' : 'VALIDATION_ERROR_15000dd6',
    '"VUID-VkViewport-height-01772"' : 'VALIDATION_ERROR_15000dd8',
    '"VUID-VkViewport-height-01773"' : 'VALIDATION_ERROR_15000dda',
    '"VUID-VkViewport-x-01774"' : 'VALIDATION_ERROR_15000ddc',
    '"VUID-VkViewport-y-01775"' : 'VALIDATION_ERROR_15000dde',
    '"VUID-VkViewport-y-01776"' : 'VALIDATION_ERROR_15000de0',
    '"VUID-VkViewport-y-01777"' : 'VALIDATION_ERROR_15000de2',
    '"VUID-VkViewportSwizzleNV-w-parameter"' : 'VALIDATION_ERROR_15230c01',
    '"VUID-VkViewportSwizzleNV-x-parameter"' : 'VALIDATION_ERROR_15231001',
    '"VUID-VkViewportSwizzleNV-y-parameter"' : 'VALIDATION_ERROR_15231201',
    '"VUID-VkViewportSwizzleNV-z-parameter"' : 'VALIDATION_ERROR_15231401',
    '"VUID-VkWaylandSurfaceCreateInfoKHR-display-01304"' : 'VALIDATION_ERROR_15400a30',
    '"VUID-VkWaylandSurfaceCreateInfoKHR-surface-01305"' : 'VALIDATION_ERROR_15400a32',
    '"VUID-VkWaylandSurfaceCreateInfoKHR-flags-zerobitmask"' : 'VALIDATION_ERROR_15409005',
    '"VUID-VkWaylandSurfaceCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_1541c40d',
    '"VUID-VkWaylandSurfaceCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_1542b00b',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoKHR-commonparent"' : 'VALIDATION_ERROR_15600009',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoKHR-pAcquireSyncs-00081"' : 'VALIDATION_ERROR_156000a2',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoKHR-pAcquireKeys-parameter"' : 'VALIDATION_ERROR_1560e201',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoKHR-pAcquireSyncs-parameter"' : 'VALIDATION_ERROR_1560e401',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoKHR-pAcquireTimeouts-parameter"' : 'VALIDATION_ERROR_1560e801',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoKHR-pReleaseKeys-parameter"' : 'VALIDATION_ERROR_15621201',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoKHR-pReleaseSyncs-parameter"' : 'VALIDATION_ERROR_15621401',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoKHR-sType-sType"' : 'VALIDATION_ERROR_1562b00b',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoNV-commonparent"' : 'VALIDATION_ERROR_15800009',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoNV-pAcquireKeys-parameter"' : 'VALIDATION_ERROR_1580e201',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoNV-pAcquireSyncs-parameter"' : 'VALIDATION_ERROR_1580e401',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoNV-pAcquireTimeoutMilliseconds-parameter"' : 'VALIDATION_ERROR_1580e601',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoNV-pReleaseKeys-parameter"' : 'VALIDATION_ERROR_15821201',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoNV-pReleaseSyncs-parameter"' : 'VALIDATION_ERROR_15821401',
    '"VUID-VkWin32KeyedMutexAcquireReleaseInfoNV-sType-sType"' : 'VALIDATION_ERROR_1582b00b',
    '"VUID-VkWin32SurfaceCreateInfoKHR-hinstance-01307"' : 'VALIDATION_ERROR_15a00a36',
    '"VUID-VkWin32SurfaceCreateInfoKHR-hwnd-01308"' : 'VALIDATION_ERROR_15a00a38',
    '"VUID-VkWin32SurfaceCreateInfoKHR-flags-zerobitmask"' : 'VALIDATION_ERROR_15a09005',
    '"VUID-VkWin32SurfaceCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_15a1c40d',
    '"VUID-VkWin32SurfaceCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_15a2b00b',
    '"VUID-VkWriteDescriptorSet-commonparent"' : 'VALIDATION_ERROR_15c00009',
    '"VUID-VkWriteDescriptorSet-dstBinding-00315"' : 'VALIDATION_ERROR_15c00276',
    '"VUID-VkWriteDescriptorSet-dstBinding-00316"' : 'VALIDATION_ERROR_15c00278',
    '"VUID-VkWriteDescriptorSet-descriptorCount-00317"' : 'VALIDATION_ERROR_15c0027a',
    '"VUID-VkWriteDescriptorSet-descriptorCount-00318"' : 'VALIDATION_ERROR_15c0027c',
    '"VUID-VkWriteDescriptorSet-descriptorType-00319"' : 'VALIDATION_ERROR_15c0027e',
    '"VUID-VkWriteDescriptorSet-dstSet-00320"' : 'VALIDATION_ERROR_15c00280',
    '"VUID-VkWriteDescriptorSet-dstArrayElement-00321"' : 'VALIDATION_ERROR_15c00282',
    '"VUID-VkWriteDescriptorSet-descriptorType-00322"' : 'VALIDATION_ERROR_15c00284',
    '"VUID-VkWriteDescriptorSet-descriptorType-00323"' : 'VALIDATION_ERROR_15c00286',
    '"VUID-VkWriteDescriptorSet-descriptorType-00324"' : 'VALIDATION_ERROR_15c00288',
    '"VUID-VkWriteDescriptorSet-descriptorType-00325"' : 'VALIDATION_ERROR_15c0028a',
    '"VUID-VkWriteDescriptorSet-descriptorType-00326"' : 'VALIDATION_ERROR_15c0028c',
    '"VUID-VkWriteDescriptorSet-descriptorType-00327"' : 'VALIDATION_ERROR_15c0028e',
    '"VUID-VkWriteDescriptorSet-descriptorType-00328"' : 'VALIDATION_ERROR_15c00290',
    '"VUID-VkWriteDescriptorSet-descriptorType-00329"' : 'VALIDATION_ERROR_15c00292',
    '"VUID-VkWriteDescriptorSet-descriptorType-00330"' : 'VALIDATION_ERROR_15c00294',
    '"VUID-VkWriteDescriptorSet-descriptorType-00331"' : 'VALIDATION_ERROR_15c00296',
    '"VUID-VkWriteDescriptorSet-descriptorType-00332"' : 'VALIDATION_ERROR_15c00298',
    '"VUID-VkWriteDescriptorSet-descriptorType-00333"' : 'VALIDATION_ERROR_15c0029a',
    '"VUID-VkWriteDescriptorSet-descriptorType-00334"' : 'VALIDATION_ERROR_15c0029c',
    '"VUID-VkWriteDescriptorSet-descriptorType-00335"' : 'VALIDATION_ERROR_15c0029e',
    '"VUID-VkWriteDescriptorSet-descriptorType-00336"' : 'VALIDATION_ERROR_15c002a0',
    '"VUID-VkWriteDescriptorSet-descriptorType-00337"' : 'VALIDATION_ERROR_15c002a2',
    '"VUID-VkWriteDescriptorSet-descriptorType-00338"' : 'VALIDATION_ERROR_15c002a4',
    '"VUID-VkWriteDescriptorSet-descriptorType-00339"' : 'VALIDATION_ERROR_15c002a6',
    '"VUID-VkWriteDescriptorSet-descriptorType-01402"' : 'VALIDATION_ERROR_15c00af4',
    '"VUID-VkWriteDescriptorSet-descriptorType-01403"' : 'VALIDATION_ERROR_15c00af6',
    '"VUID-VkWriteDescriptorSet-descriptorCount-03048"' : 'VALIDATION_ERROR_15c017d0',
    '"VUID-VkWriteDescriptorSet-descriptorCount-arraylength"' : 'VALIDATION_ERROR_15c0441b',
    '"VUID-VkWriteDescriptorSet-descriptorType-parameter"' : 'VALIDATION_ERROR_15c04e01',
    '"VUID-VkWriteDescriptorSet-pNext-pNext"' : 'VALIDATION_ERROR_15c1c40d',
    '"VUID-VkWriteDescriptorSet-sType-sType"' : 'VALIDATION_ERROR_15c2b00b',
    '"VUID-VkXcbSurfaceCreateInfoKHR-connection-01310"' : 'VALIDATION_ERROR_15e00a3c',
    '"VUID-VkXcbSurfaceCreateInfoKHR-window-01311"' : 'VALIDATION_ERROR_15e00a3e',
    '"VUID-VkXcbSurfaceCreateInfoKHR-flags-zerobitmask"' : 'VALIDATION_ERROR_15e09005',
    '"VUID-VkXcbSurfaceCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_15e1c40d',
    '"VUID-VkXcbSurfaceCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_15e2b00b',
    '"VUID-VkXlibSurfaceCreateInfoKHR-dpy-01313"' : 'VALIDATION_ERROR_16000a42',
    '"VUID-VkXlibSurfaceCreateInfoKHR-window-01314"' : 'VALIDATION_ERROR_16000a44',
    '"VUID-VkXlibSurfaceCreateInfoKHR-flags-zerobitmask"' : 'VALIDATION_ERROR_16009005',
    '"VUID-VkXlibSurfaceCreateInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_1601c40d',
    '"VUID-VkXlibSurfaceCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_1602b00b',
    '"VUID-vkAcquireNextImage2KHR-swapchain-01803"' : 'VALIDATION_ERROR_16200e16',
    '"VUID-vkAcquireNextImage2KHR-device-parameter"' : 'VALIDATION_ERROR_16205601',
    '"VUID-vkAcquireNextImage2KHR-pAcquireInfo-parameter"' : 'VALIDATION_ERROR_1620e001',
    '"VUID-vkAcquireNextImage2KHR-pImageIndex-parameter"' : 'VALIDATION_ERROR_16218601',
    '"VUID-vkAcquireNextImageKHR-commonparent"' : 'VALIDATION_ERROR_16400009',
    '"VUID-vkAcquireNextImageKHR-swapchain-01285"' : 'VALIDATION_ERROR_16400a0a',
    '"VUID-vkAcquireNextImageKHR-semaphore-01286"' : 'VALIDATION_ERROR_16400a0c',
    '"VUID-vkAcquireNextImageKHR-fence-01287"' : 'VALIDATION_ERROR_16400a0e',
    '"VUID-vkAcquireNextImageKHR-semaphore-01779"' : 'VALIDATION_ERROR_16400de6',
    '"VUID-vkAcquireNextImageKHR-semaphore-01780"' : 'VALIDATION_ERROR_16400de8',
    '"VUID-vkAcquireNextImageKHR-swapchain-01802"' : 'VALIDATION_ERROR_16400e14',
    '"VUID-vkAcquireNextImageKHR-device-parameter"' : 'VALIDATION_ERROR_16405601',
    '"VUID-vkAcquireNextImageKHR-fence-parameter"' : 'VALIDATION_ERROR_16408801',
    '"VUID-vkAcquireNextImageKHR-fence-parent"' : 'VALIDATION_ERROR_16408807',
    '"VUID-vkAcquireNextImageKHR-pImageIndex-parameter"' : 'VALIDATION_ERROR_16418601',
    '"VUID-vkAcquireNextImageKHR-semaphore-parameter"' : 'VALIDATION_ERROR_1642b801',
    '"VUID-vkAcquireNextImageKHR-semaphore-parent"' : 'VALIDATION_ERROR_1642b807',
    '"VUID-vkAcquireNextImageKHR-swapchain-parameter"' : 'VALIDATION_ERROR_1642f001',
    '"VUID-vkAcquireXlibDisplayEXT-display-parameter"' : 'VALIDATION_ERROR_16606001',
    '"VUID-vkAcquireXlibDisplayEXT-dpy-parameter"' : 'VALIDATION_ERROR_16606601',
    '"VUID-vkAcquireXlibDisplayEXT-physicalDevice-parameter"' : 'VALIDATION_ERROR_16627a01',
    '"VUID-vkAllocateCommandBuffers-device-parameter"' : 'VALIDATION_ERROR_16805601',
    '"VUID-vkAllocateCommandBuffers-pAllocateInfo-parameter"' : 'VALIDATION_ERROR_1680ea01',
    '"VUID-vkAllocateCommandBuffers-pCommandBuffers-parameter"' : 'VALIDATION_ERROR_16811401',
    '"VUID-vkAllocateDescriptorSets-device-parameter"' : 'VALIDATION_ERROR_16a05601',
    '"VUID-vkAllocateDescriptorSets-pAllocateInfo-parameter"' : 'VALIDATION_ERROR_16a0ea01',
    '"VUID-vkAllocateDescriptorSets-pDescriptorSets-parameter"' : 'VALIDATION_ERROR_16a13001',
    '"VUID-vkAllocateMemory-pAllocateInfo-01713"' : 'VALIDATION_ERROR_16c00d62',
    '"VUID-vkAllocateMemory-pAllocateInfo-01714"' : 'VALIDATION_ERROR_16c00d64',
    '"VUID-vkAllocateMemory-device-parameter"' : 'VALIDATION_ERROR_16c05601',
    '"VUID-vkAllocateMemory-pAllocateInfo-parameter"' : 'VALIDATION_ERROR_16c0ea01',
    '"VUID-vkAllocateMemory-pAllocator-parameter"' : 'VALIDATION_ERROR_16c0ec01',
    '"VUID-vkAllocateMemory-pMemory-parameter"' : 'VALIDATION_ERROR_16c1aa01',
    '"VUID-vkBeginCommandBuffer-commandBuffer-00049"' : 'VALIDATION_ERROR_16e00062',
    '"VUID-vkBeginCommandBuffer-commandBuffer-00050"' : 'VALIDATION_ERROR_16e00064',
    '"VUID-vkBeginCommandBuffer-commandBuffer-00051"' : 'VALIDATION_ERROR_16e00066',
    '"VUID-vkBeginCommandBuffer-commandBuffer-00052"' : 'VALIDATION_ERROR_16e00068',
    '"VUID-vkBeginCommandBuffer-commandBuffer-parameter"' : 'VALIDATION_ERROR_16e02401',
    '"VUID-vkBeginCommandBuffer-pBeginInfo-parameter"' : 'VALIDATION_ERROR_16e0f601',
    '"VUID-vkBindBufferMemory-buffer-01029"' : 'VALIDATION_ERROR_1700080a',
    '"VUID-vkBindBufferMemory-buffer-01030"' : 'VALIDATION_ERROR_1700080c',
    '"VUID-vkBindBufferMemory-memoryOffset-01031"' : 'VALIDATION_ERROR_1700080e',
    '"VUID-vkBindBufferMemory-buffer-01032"' : 'VALIDATION_ERROR_17000810',
    '"VUID-vkBindBufferMemory-buffer-01033"' : 'VALIDATION_ERROR_17000812',
    '"VUID-vkBindBufferMemory-buffer-01034"' : 'VALIDATION_ERROR_17000814',
    '"VUID-vkBindBufferMemory-memory-01035"' : 'VALIDATION_ERROR_17000816',
    '"VUID-vkBindBufferMemory-memoryOffset-01036"' : 'VALIDATION_ERROR_17000818',
    '"VUID-vkBindBufferMemory-size-01037"' : 'VALIDATION_ERROR_1700081a',
    '"VUID-vkBindBufferMemory-buffer-01038"' : 'VALIDATION_ERROR_1700081c',
    '"VUID-vkBindBufferMemory-buffer-01039"' : 'VALIDATION_ERROR_1700081e',
    '"VUID-vkBindBufferMemory-buffer-01444"' : 'VALIDATION_ERROR_17000b48',
    '"VUID-vkBindBufferMemory-memory-01508"' : 'VALIDATION_ERROR_17000bc8',
    '"VUID-vkBindBufferMemory-None-01898"' : 'VALIDATION_ERROR_17000ed4',
    '"VUID-vkBindBufferMemory-None-01899"' : 'VALIDATION_ERROR_17000ed6',
    '"VUID-vkBindBufferMemory-buffer-parameter"' : 'VALIDATION_ERROR_17001a01',
    '"VUID-vkBindBufferMemory-buffer-parent"' : 'VALIDATION_ERROR_17001a07',
    '"VUID-vkBindBufferMemory-device-parameter"' : 'VALIDATION_ERROR_17005601',
    '"VUID-vkBindBufferMemory-memory-parameter"' : 'VALIDATION_ERROR_1700c601',
    '"VUID-vkBindBufferMemory-memory-parent"' : 'VALIDATION_ERROR_1700c607',
    '"VUID-vkBindBufferMemory2-bindInfoCount-arraylength"' : 'VALIDATION_ERROR_1720161b',
    '"VUID-vkBindBufferMemory2-device-parameter"' : 'VALIDATION_ERROR_17205601',
    '"VUID-vkBindBufferMemory2-pBindInfos-parameter"' : 'VALIDATION_ERROR_1720fa01',
    '"VUID-vkBindImageMemory-image-01044"' : 'VALIDATION_ERROR_17400828',
    '"VUID-vkBindImageMemory-image-01045"' : 'VALIDATION_ERROR_1740082a',
    '"VUID-vkBindImageMemory-memoryOffset-01046"' : 'VALIDATION_ERROR_1740082c',
    '"VUID-vkBindImageMemory-memory-01047"' : 'VALIDATION_ERROR_1740082e',
    '"VUID-vkBindImageMemory-memoryOffset-01048"' : 'VALIDATION_ERROR_17400830',
    '"VUID-vkBindImageMemory-size-01049"' : 'VALIDATION_ERROR_17400832',
    '"VUID-vkBindImageMemory-image-01050"' : 'VALIDATION_ERROR_17400834',
    '"VUID-vkBindImageMemory-image-01051"' : 'VALIDATION_ERROR_17400836',
    '"VUID-vkBindImageMemory-image-01445"' : 'VALIDATION_ERROR_17400b4a',
    '"VUID-vkBindImageMemory-memory-01509"' : 'VALIDATION_ERROR_17400bca',
    '"VUID-vkBindImageMemory-image-01608"' : 'VALIDATION_ERROR_17400c90',
    '"VUID-vkBindImageMemory-None-01901"' : 'VALIDATION_ERROR_17400eda',
    '"VUID-vkBindImageMemory-None-01902"' : 'VALIDATION_ERROR_17400edc',
    '"VUID-vkBindImageMemory-device-parameter"' : 'VALIDATION_ERROR_17405601',
    '"VUID-vkBindImageMemory-image-parameter"' : 'VALIDATION_ERROR_1740a001',
    '"VUID-vkBindImageMemory-image-parent"' : 'VALIDATION_ERROR_1740a007',
    '"VUID-vkBindImageMemory-memory-parameter"' : 'VALIDATION_ERROR_1740c601',
    '"VUID-vkBindImageMemory-memory-parent"' : 'VALIDATION_ERROR_1740c607',
    '"VUID-vkBindImageMemory2-bindInfoCount-arraylength"' : 'VALIDATION_ERROR_1760161b',
    '"VUID-vkBindImageMemory2-device-parameter"' : 'VALIDATION_ERROR_17605601',
    '"VUID-vkBindImageMemory2-pBindInfos-parameter"' : 'VALIDATION_ERROR_1760fa01',
    '"VUID-vkCmdBeginQuery-commonparent"' : 'VALIDATION_ERROR_17800009',
    '"VUID-vkCmdBeginQuery-queryType-00800"' : 'VALIDATION_ERROR_17800640',
    '"VUID-vkCmdBeginQuery-query-00802"' : 'VALIDATION_ERROR_17800644',
    '"VUID-vkCmdBeginQuery-queryType-00803"' : 'VALIDATION_ERROR_17800646',
    '"VUID-vkCmdBeginQuery-queryType-00804"' : 'VALIDATION_ERROR_17800648',
    '"VUID-vkCmdBeginQuery-queryType-00805"' : 'VALIDATION_ERROR_1780064a',
    '"VUID-vkCmdBeginQuery-None-00807"' : 'VALIDATION_ERROR_1780064e',
    '"VUID-vkCmdBeginQuery-query-00808"' : 'VALIDATION_ERROR_17800650',
    '"VUID-vkCmdBeginQuery-commandBuffer-01885"' : 'VALIDATION_ERROR_17800eba',
    '"VUID-vkCmdBeginQuery-queryPool-01922"' : 'VALIDATION_ERROR_17800f04',
    '"VUID-vkCmdBeginQuery-commandBuffer-parameter"' : 'VALIDATION_ERROR_17802401',
    '"VUID-vkCmdBeginQuery-commandBuffer-recording"' : 'VALIDATION_ERROR_17802413',
    '"VUID-vkCmdBeginQuery-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_17802415',
    '"VUID-vkCmdBeginQuery-flags-parameter"' : 'VALIDATION_ERROR_17809001',
    '"VUID-vkCmdBeginQuery-queryPool-parameter"' : 'VALIDATION_ERROR_17829801',
    '"VUID-vkCmdBeginRenderPass-renderpass"' : 'VALIDATION_ERROR_17a00017',
    '"VUID-vkCmdBeginRenderPass-bufferlevel"' : 'VALIDATION_ERROR_17a00019',
    '"VUID-vkCmdBeginRenderPass-initialLayout-00895"' : 'VALIDATION_ERROR_17a006fe',
    '"VUID-vkCmdBeginRenderPass-initialLayout-00896"' : 'VALIDATION_ERROR_17a00700',
    '"VUID-vkCmdBeginRenderPass-initialLayout-00897"' : 'VALIDATION_ERROR_17a00702',
    '"VUID-vkCmdBeginRenderPass-initialLayout-00898"' : 'VALIDATION_ERROR_17a00704',
    '"VUID-vkCmdBeginRenderPass-initialLayout-00899"' : 'VALIDATION_ERROR_17a00706',
    '"VUID-vkCmdBeginRenderPass-initialLayout-00900"' : 'VALIDATION_ERROR_17a00708',
    '"VUID-vkCmdBeginRenderPass-srcStageMask-00901"' : 'VALIDATION_ERROR_17a0070a',
    '"VUID-vkCmdBeginRenderPass-initialLayout-01758"' : 'VALIDATION_ERROR_17a00dbc',
    '"VUID-vkCmdBeginRenderPass-commandBuffer-parameter"' : 'VALIDATION_ERROR_17a02401',
    '"VUID-vkCmdBeginRenderPass-commandBuffer-recording"' : 'VALIDATION_ERROR_17a02413',
    '"VUID-vkCmdBeginRenderPass-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_17a02415',
    '"VUID-vkCmdBeginRenderPass-contents-parameter"' : 'VALIDATION_ERROR_17a03201',
    '"VUID-vkCmdBeginRenderPass-pRenderPassBegin-parameter"' : 'VALIDATION_ERROR_17a21801',
    '"VUID-vkCmdBindDescriptorSets-commonparent"' : 'VALIDATION_ERROR_17c00009',
    '"VUID-vkCmdBindDescriptorSets-pDescriptorSets-00358"' : 'VALIDATION_ERROR_17c002cc',
    '"VUID-vkCmdBindDescriptorSets-dynamicOffsetCount-00359"' : 'VALIDATION_ERROR_17c002ce',
    '"VUID-vkCmdBindDescriptorSets-firstSet-00360"' : 'VALIDATION_ERROR_17c002d0',
    '"VUID-vkCmdBindDescriptorSets-pipelineBindPoint-00361"' : 'VALIDATION_ERROR_17c002d2',
    '"VUID-vkCmdBindDescriptorSets-pDynamicOffsets-00362"' : 'VALIDATION_ERROR_17c002d4',
    '"VUID-vkCmdBindDescriptorSets-commandBuffer-parameter"' : 'VALIDATION_ERROR_17c02401',
    '"VUID-vkCmdBindDescriptorSets-commandBuffer-recording"' : 'VALIDATION_ERROR_17c02413',
    '"VUID-vkCmdBindDescriptorSets-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_17c02415',
    '"VUID-vkCmdBindDescriptorSets-descriptorSetCount-arraylength"' : 'VALIDATION_ERROR_17c04a1b',
    '"VUID-vkCmdBindDescriptorSets-layout-parameter"' : 'VALIDATION_ERROR_17c0be01',
    '"VUID-vkCmdBindDescriptorSets-pDescriptorSets-parameter"' : 'VALIDATION_ERROR_17c13001',
    '"VUID-vkCmdBindDescriptorSets-pDynamicOffsets-parameter"' : 'VALIDATION_ERROR_17c15401',
    '"VUID-vkCmdBindDescriptorSets-pipelineBindPoint-parameter"' : 'VALIDATION_ERROR_17c27e01',
    '"VUID-vkCmdBindIndexBuffer-commonparent"' : 'VALIDATION_ERROR_17e00009',
    '"VUID-vkCmdBindIndexBuffer-offset-00431"' : 'VALIDATION_ERROR_17e0035e',
    '"VUID-vkCmdBindIndexBuffer-offset-00432"' : 'VALIDATION_ERROR_17e00360',
    '"VUID-vkCmdBindIndexBuffer-buffer-00433"' : 'VALIDATION_ERROR_17e00362',
    '"VUID-vkCmdBindIndexBuffer-buffer-00434"' : 'VALIDATION_ERROR_17e00364',
    '"VUID-vkCmdBindIndexBuffer-buffer-parameter"' : 'VALIDATION_ERROR_17e01a01',
    '"VUID-vkCmdBindIndexBuffer-commandBuffer-parameter"' : 'VALIDATION_ERROR_17e02401',
    '"VUID-vkCmdBindIndexBuffer-commandBuffer-recording"' : 'VALIDATION_ERROR_17e02413',
    '"VUID-vkCmdBindIndexBuffer-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_17e02415',
    '"VUID-vkCmdBindIndexBuffer-indexType-parameter"' : 'VALIDATION_ERROR_17e0b201',
    '"VUID-vkCmdBindPipeline-commonparent"' : 'VALIDATION_ERROR_18000009',
    '"VUID-vkCmdBindPipeline-pipelineBindPoint-00777"' : 'VALIDATION_ERROR_18000612',
    '"VUID-vkCmdBindPipeline-pipelineBindPoint-00778"' : 'VALIDATION_ERROR_18000614',
    '"VUID-vkCmdBindPipeline-pipelineBindPoint-00779"' : 'VALIDATION_ERROR_18000616',
    '"VUID-vkCmdBindPipeline-pipelineBindPoint-00780"' : 'VALIDATION_ERROR_18000618',
    '"VUID-vkCmdBindPipeline-pipeline-00781"' : 'VALIDATION_ERROR_1800061a',
    '"VUID-vkCmdBindPipeline-variableSampleLocations-01525"' : 'VALIDATION_ERROR_18000bea',
    '"VUID-vkCmdBindPipeline-commandBuffer-parameter"' : 'VALIDATION_ERROR_18002401',
    '"VUID-vkCmdBindPipeline-commandBuffer-recording"' : 'VALIDATION_ERROR_18002413',
    '"VUID-vkCmdBindPipeline-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_18002415',
    '"VUID-vkCmdBindPipeline-pipeline-parameter"' : 'VALIDATION_ERROR_18027c01',
    '"VUID-vkCmdBindPipeline-pipelineBindPoint-parameter"' : 'VALIDATION_ERROR_18027e01',
    '"VUID-vkCmdBindVertexBuffers-commonparent"' : 'VALIDATION_ERROR_18200009',
    '"VUID-vkCmdBindVertexBuffers-firstBinding-00624"' : 'VALIDATION_ERROR_182004e0',
    '"VUID-vkCmdBindVertexBuffers-firstBinding-00625"' : 'VALIDATION_ERROR_182004e2',
    '"VUID-vkCmdBindVertexBuffers-pOffsets-00626"' : 'VALIDATION_ERROR_182004e4',
    '"VUID-vkCmdBindVertexBuffers-pBuffers-00627"' : 'VALIDATION_ERROR_182004e6',
    '"VUID-vkCmdBindVertexBuffers-pBuffers-00628"' : 'VALIDATION_ERROR_182004e8',
    '"VUID-vkCmdBindVertexBuffers-bindingCount-arraylength"' : 'VALIDATION_ERROR_1820181b',
    '"VUID-vkCmdBindVertexBuffers-commandBuffer-parameter"' : 'VALIDATION_ERROR_18202401',
    '"VUID-vkCmdBindVertexBuffers-commandBuffer-recording"' : 'VALIDATION_ERROR_18202413',
    '"VUID-vkCmdBindVertexBuffers-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_18202415',
    '"VUID-vkCmdBindVertexBuffers-pBuffers-parameter"' : 'VALIDATION_ERROR_18210601',
    '"VUID-vkCmdBindVertexBuffers-pOffsets-parameter"' : 'VALIDATION_ERROR_1821d201',
    '"VUID-vkCmdBlitImage-commonparent"' : 'VALIDATION_ERROR_18400009',
    '"VUID-vkCmdBlitImage-renderpass"' : 'VALIDATION_ERROR_18400017',
    '"VUID-vkCmdBlitImage-pRegions-00215"' : 'VALIDATION_ERROR_184001ae',
    '"VUID-vkCmdBlitImage-pRegions-00216"' : 'VALIDATION_ERROR_184001b0',
    '"VUID-vkCmdBlitImage-pRegions-00217"' : 'VALIDATION_ERROR_184001b2',
    '"VUID-vkCmdBlitImage-srcImage-00218"' : 'VALIDATION_ERROR_184001b4',
    '"VUID-vkCmdBlitImage-srcImage-00219"' : 'VALIDATION_ERROR_184001b6',
    '"VUID-vkCmdBlitImage-srcImage-00220"' : 'VALIDATION_ERROR_184001b8',
    '"VUID-vkCmdBlitImage-srcImageLayout-00221"' : 'VALIDATION_ERROR_184001ba',
    '"VUID-vkCmdBlitImage-srcImageLayout-00222"' : 'VALIDATION_ERROR_184001bc',
    '"VUID-vkCmdBlitImage-dstImage-00223"' : 'VALIDATION_ERROR_184001be',
    '"VUID-vkCmdBlitImage-dstImage-00224"' : 'VALIDATION_ERROR_184001c0',
    '"VUID-vkCmdBlitImage-dstImage-00225"' : 'VALIDATION_ERROR_184001c2',
    '"VUID-vkCmdBlitImage-dstImageLayout-00226"' : 'VALIDATION_ERROR_184001c4',
    '"VUID-vkCmdBlitImage-dstImageLayout-00227"' : 'VALIDATION_ERROR_184001c6',
    '"VUID-vkCmdBlitImage-srcImage-00228"' : 'VALIDATION_ERROR_184001c8',
    '"VUID-vkCmdBlitImage-srcImage-00229"' : 'VALIDATION_ERROR_184001ca',
    '"VUID-vkCmdBlitImage-srcImage-00230"' : 'VALIDATION_ERROR_184001cc',
    '"VUID-vkCmdBlitImage-srcImage-00231"' : 'VALIDATION_ERROR_184001ce',
    '"VUID-vkCmdBlitImage-srcImage-00232"' : 'VALIDATION_ERROR_184001d0',
    '"VUID-vkCmdBlitImage-srcImage-00233"' : 'VALIDATION_ERROR_184001d2',
    '"VUID-vkCmdBlitImage-dstImage-00234"' : 'VALIDATION_ERROR_184001d4',
    '"VUID-vkCmdBlitImage-filter-00235"' : 'VALIDATION_ERROR_184001d6',
    '"VUID-vkCmdBlitImage-filter-00236"' : 'VALIDATION_ERROR_184001d8',
    '"VUID-vkCmdBlitImage-filter-00237"' : 'VALIDATION_ERROR_184001da',
    '"VUID-vkCmdBlitImage-srcImageLayout-01398"' : 'VALIDATION_ERROR_18400aec',
    '"VUID-vkCmdBlitImage-dstImageLayout-01399"' : 'VALIDATION_ERROR_18400aee',
    '"VUID-vkCmdBlitImage-srcImage-01561"' : 'VALIDATION_ERROR_18400c32',
    '"VUID-vkCmdBlitImage-dstImage-01562"' : 'VALIDATION_ERROR_18400c34',
    '"VUID-vkCmdBlitImage-srcSubresource-01705"' : 'VALIDATION_ERROR_18400d52',
    '"VUID-vkCmdBlitImage-dstSubresource-01706"' : 'VALIDATION_ERROR_18400d54',
    '"VUID-vkCmdBlitImage-srcSubresource-01707"' : 'VALIDATION_ERROR_18400d56',
    '"VUID-vkCmdBlitImage-dstSubresource-01708"' : 'VALIDATION_ERROR_18400d58',
    '"VUID-vkCmdBlitImage-commandBuffer-01834"' : 'VALIDATION_ERROR_18400e54',
    '"VUID-vkCmdBlitImage-commandBuffer-01835"' : 'VALIDATION_ERROR_18400e56',
    '"VUID-vkCmdBlitImage-commandBuffer-01836"' : 'VALIDATION_ERROR_18400e58',
    '"VUID-vkCmdBlitImage-commandBuffer-parameter"' : 'VALIDATION_ERROR_18402401',
    '"VUID-vkCmdBlitImage-commandBuffer-recording"' : 'VALIDATION_ERROR_18402413',
    '"VUID-vkCmdBlitImage-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_18402415',
    '"VUID-vkCmdBlitImage-dstImage-parameter"' : 'VALIDATION_ERROR_18407201',
    '"VUID-vkCmdBlitImage-dstImageLayout-parameter"' : 'VALIDATION_ERROR_18407401',
    '"VUID-vkCmdBlitImage-filter-parameter"' : 'VALIDATION_ERROR_18408c01',
    '"VUID-vkCmdBlitImage-pRegions-parameter"' : 'VALIDATION_ERROR_18421001',
    '"VUID-vkCmdBlitImage-regionCount-arraylength"' : 'VALIDATION_ERROR_1842ac1b',
    '"VUID-vkCmdBlitImage-srcImage-parameter"' : 'VALIDATION_ERROR_1842ce01',
    '"VUID-vkCmdBlitImage-srcImageLayout-parameter"' : 'VALIDATION_ERROR_1842d001',
    '"VUID-vkCmdClearAttachments-renderpass"' : 'VALIDATION_ERROR_18600017',
    '"VUID-vkCmdClearAttachments-aspectMask-00015"' : 'VALIDATION_ERROR_1860001e',
    '"VUID-vkCmdClearAttachments-pRects-00016"' : 'VALIDATION_ERROR_18600020',
    '"VUID-vkCmdClearAttachments-pRects-00017"' : 'VALIDATION_ERROR_18600022',
    '"VUID-vkCmdClearAttachments-baseArrayLayer-00018"' : 'VALIDATION_ERROR_18600024',
    '"VUID-vkCmdClearAttachments-attachmentCount-arraylength"' : 'VALIDATION_ERROR_18600e1b',
    '"VUID-vkCmdClearAttachments-layerCount-01934"' : 'VALIDATION_ERROR_18600f1c',
    '"VUID-vkCmdClearAttachments-commandBuffer-parameter"' : 'VALIDATION_ERROR_18602401',
    '"VUID-vkCmdClearAttachments-commandBuffer-recording"' : 'VALIDATION_ERROR_18602413',
    '"VUID-vkCmdClearAttachments-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_18602415',
    '"VUID-vkCmdClearAttachments-pAttachments-parameter"' : 'VALIDATION_ERROR_1860f201',
    '"VUID-vkCmdClearAttachments-pRects-parameter"' : 'VALIDATION_ERROR_18620e01',
    '"VUID-vkCmdClearAttachments-rectCount-arraylength"' : 'VALIDATION_ERROR_1862aa1b',
    '"VUID-vkCmdClearColorImage-image-00001"' : 'VALIDATION_ERROR_18800002',
    '"VUID-vkCmdClearColorImage-image-00002"' : 'VALIDATION_ERROR_18800004',
    '"VUID-vkCmdClearColorImage-image-00003"' : 'VALIDATION_ERROR_18800006',
    '"VUID-vkCmdClearColorImage-imageLayout-00004"' : 'VALIDATION_ERROR_18800008',
    '"VUID-vkCmdClearColorImage-commonparent"' : 'VALIDATION_ERROR_18800009',
    '"VUID-vkCmdClearColorImage-imageLayout-00005"' : 'VALIDATION_ERROR_1880000a',
    '"VUID-vkCmdClearColorImage-image-00007"' : 'VALIDATION_ERROR_1880000e',
    '"VUID-vkCmdClearColorImage-renderpass"' : 'VALIDATION_ERROR_18800017',
    '"VUID-vkCmdClearColorImage-imageLayout-01394"' : 'VALIDATION_ERROR_18800ae4',
    '"VUID-vkCmdClearColorImage-baseMipLevel-01470"' : 'VALIDATION_ERROR_18800b7c',
    '"VUID-vkCmdClearColorImage-baseArrayLayer-01472"' : 'VALIDATION_ERROR_18800b80',
    '"VUID-vkCmdClearColorImage-image-01545"' : 'VALIDATION_ERROR_18800c12',
    '"VUID-vkCmdClearColorImage-pRanges-01692"' : 'VALIDATION_ERROR_18800d38',
    '"VUID-vkCmdClearColorImage-pRanges-01693"' : 'VALIDATION_ERROR_18800d3a',
    '"VUID-vkCmdClearColorImage-commandBuffer-01805"' : 'VALIDATION_ERROR_18800e1a',
    '"VUID-vkCmdClearColorImage-commandBuffer-01806"' : 'VALIDATION_ERROR_18800e1c',
    '"VUID-vkCmdClearColorImage-commandBuffer-parameter"' : 'VALIDATION_ERROR_18802401',
    '"VUID-vkCmdClearColorImage-commandBuffer-recording"' : 'VALIDATION_ERROR_18802413',
    '"VUID-vkCmdClearColorImage-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_18802415',
    '"VUID-vkCmdClearColorImage-image-parameter"' : 'VALIDATION_ERROR_1880a001',
    '"VUID-vkCmdClearColorImage-imageLayout-parameter"' : 'VALIDATION_ERROR_1880a601',
    '"VUID-vkCmdClearColorImage-pColor-parameter"' : 'VALIDATION_ERROR_18810e01',
    '"VUID-vkCmdClearColorImage-pRanges-parameter"' : 'VALIDATION_ERROR_18820601',
    '"VUID-vkCmdClearColorImage-rangeCount-arraylength"' : 'VALIDATION_ERROR_1882a41b',
    '"VUID-vkCmdClearDepthStencilImage-commonparent"' : 'VALIDATION_ERROR_18a00009',
    '"VUID-vkCmdClearDepthStencilImage-image-00008"' : 'VALIDATION_ERROR_18a00010',
    '"VUID-vkCmdClearDepthStencilImage-image-00009"' : 'VALIDATION_ERROR_18a00012',
    '"VUID-vkCmdClearDepthStencilImage-image-00010"' : 'VALIDATION_ERROR_18a00014',
    '"VUID-vkCmdClearDepthStencilImage-imageLayout-00011"' : 'VALIDATION_ERROR_18a00016',
    '"VUID-vkCmdClearDepthStencilImage-renderpass"' : 'VALIDATION_ERROR_18a00017',
    '"VUID-vkCmdClearDepthStencilImage-imageLayout-00012"' : 'VALIDATION_ERROR_18a00018',
    '"VUID-vkCmdClearDepthStencilImage-image-00014"' : 'VALIDATION_ERROR_18a0001c',
    '"VUID-vkCmdClearDepthStencilImage-baseMipLevel-01474"' : 'VALIDATION_ERROR_18a00b84',
    '"VUID-vkCmdClearDepthStencilImage-baseArrayLayer-01476"' : 'VALIDATION_ERROR_18a00b88',
    '"VUID-vkCmdClearDepthStencilImage-pRanges-01694"' : 'VALIDATION_ERROR_18a00d3c',
    '"VUID-vkCmdClearDepthStencilImage-pRanges-01695"' : 'VALIDATION_ERROR_18a00d3e',
    '"VUID-vkCmdClearDepthStencilImage-commandBuffer-01807"' : 'VALIDATION_ERROR_18a00e1e',
    '"VUID-vkCmdClearDepthStencilImage-commandBuffer-01808"' : 'VALIDATION_ERROR_18a00e20',
    '"VUID-vkCmdClearDepthStencilImage-commandBuffer-parameter"' : 'VALIDATION_ERROR_18a02401',
    '"VUID-vkCmdClearDepthStencilImage-commandBuffer-recording"' : 'VALIDATION_ERROR_18a02413',
    '"VUID-vkCmdClearDepthStencilImage-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_18a02415',
    '"VUID-vkCmdClearDepthStencilImage-image-parameter"' : 'VALIDATION_ERROR_18a0a001',
    '"VUID-vkCmdClearDepthStencilImage-imageLayout-parameter"' : 'VALIDATION_ERROR_18a0a601',
    '"VUID-vkCmdClearDepthStencilImage-pDepthStencil-parameter"' : 'VALIDATION_ERROR_18a12801',
    '"VUID-vkCmdClearDepthStencilImage-pRanges-parameter"' : 'VALIDATION_ERROR_18a20601',
    '"VUID-vkCmdClearDepthStencilImage-rangeCount-arraylength"' : 'VALIDATION_ERROR_18a2a41b',
    '"VUID-vkCmdCopyBuffer-commonparent"' : 'VALIDATION_ERROR_18c00009',
    '"VUID-vkCmdCopyBuffer-renderpass"' : 'VALIDATION_ERROR_18c00017',
    '"VUID-vkCmdCopyBuffer-size-00112"' : 'VALIDATION_ERROR_18c000e0',
    '"VUID-vkCmdCopyBuffer-srcOffset-00113"' : 'VALIDATION_ERROR_18c000e2',
    '"VUID-vkCmdCopyBuffer-dstOffset-00114"' : 'VALIDATION_ERROR_18c000e4',
    '"VUID-vkCmdCopyBuffer-size-00115"' : 'VALIDATION_ERROR_18c000e6',
    '"VUID-vkCmdCopyBuffer-size-00116"' : 'VALIDATION_ERROR_18c000e8',
    '"VUID-vkCmdCopyBuffer-pRegions-00117"' : 'VALIDATION_ERROR_18c000ea',
    '"VUID-vkCmdCopyBuffer-srcBuffer-00118"' : 'VALIDATION_ERROR_18c000ec',
    '"VUID-vkCmdCopyBuffer-srcBuffer-00119"' : 'VALIDATION_ERROR_18c000ee',
    '"VUID-vkCmdCopyBuffer-dstBuffer-00120"' : 'VALIDATION_ERROR_18c000f0',
    '"VUID-vkCmdCopyBuffer-dstBuffer-00121"' : 'VALIDATION_ERROR_18c000f2',
    '"VUID-vkCmdCopyBuffer-commandBuffer-01822"' : 'VALIDATION_ERROR_18c00e3c',
    '"VUID-vkCmdCopyBuffer-commandBuffer-01823"' : 'VALIDATION_ERROR_18c00e3e',
    '"VUID-vkCmdCopyBuffer-commandBuffer-01824"' : 'VALIDATION_ERROR_18c00e40',
    '"VUID-vkCmdCopyBuffer-commandBuffer-parameter"' : 'VALIDATION_ERROR_18c02401',
    '"VUID-vkCmdCopyBuffer-commandBuffer-recording"' : 'VALIDATION_ERROR_18c02413',
    '"VUID-vkCmdCopyBuffer-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_18c02415',
    '"VUID-vkCmdCopyBuffer-dstBuffer-parameter"' : 'VALIDATION_ERROR_18c06c01',
    '"VUID-vkCmdCopyBuffer-pRegions-parameter"' : 'VALIDATION_ERROR_18c21001',
    '"VUID-vkCmdCopyBuffer-regionCount-arraylength"' : 'VALIDATION_ERROR_18c2ac1b',
    '"VUID-vkCmdCopyBuffer-srcBuffer-parameter"' : 'VALIDATION_ERROR_18c2c801',
    '"VUID-vkCmdCopyBufferToImage-commonparent"' : 'VALIDATION_ERROR_18e00009',
    '"VUID-vkCmdCopyBufferToImage-renderpass"' : 'VALIDATION_ERROR_18e00017',
    '"VUID-vkCmdCopyBufferToImage-pRegions-00171"' : 'VALIDATION_ERROR_18e00156',
    '"VUID-vkCmdCopyBufferToImage-pRegions-00172"' : 'VALIDATION_ERROR_18e00158',
    '"VUID-vkCmdCopyBufferToImage-pRegions-00173"' : 'VALIDATION_ERROR_18e0015a',
    '"VUID-vkCmdCopyBufferToImage-srcBuffer-00174"' : 'VALIDATION_ERROR_18e0015c',
    '"VUID-vkCmdCopyBufferToImage-dstImage-00175"' : 'VALIDATION_ERROR_18e0015e',
    '"VUID-vkCmdCopyBufferToImage-srcBuffer-00176"' : 'VALIDATION_ERROR_18e00160',
    '"VUID-vkCmdCopyBufferToImage-dstImage-00177"' : 'VALIDATION_ERROR_18e00162',
    '"VUID-vkCmdCopyBufferToImage-dstImage-00178"' : 'VALIDATION_ERROR_18e00164',
    '"VUID-vkCmdCopyBufferToImage-dstImage-00179"' : 'VALIDATION_ERROR_18e00166',
    '"VUID-vkCmdCopyBufferToImage-dstImageLayout-00180"' : 'VALIDATION_ERROR_18e00168',
    '"VUID-vkCmdCopyBufferToImage-dstImageLayout-00181"' : 'VALIDATION_ERROR_18e0016a',
    '"VUID-vkCmdCopyBufferToImage-dstImageLayout-01396"' : 'VALIDATION_ERROR_18e00ae8',
    '"VUID-vkCmdCopyBufferToImage-imageSubresource-01701"' : 'VALIDATION_ERROR_18e00d4a',
    '"VUID-vkCmdCopyBufferToImage-imageSubresource-01702"' : 'VALIDATION_ERROR_18e00d4c',
    '"VUID-vkCmdCopyBufferToImage-imageOffset-01793"' : 'VALIDATION_ERROR_18e00e02',
    '"VUID-vkCmdCopyBufferToImage-commandBuffer-01828"' : 'VALIDATION_ERROR_18e00e48',
    '"VUID-vkCmdCopyBufferToImage-commandBuffer-01829"' : 'VALIDATION_ERROR_18e00e4a',
    '"VUID-vkCmdCopyBufferToImage-commandBuffer-01830"' : 'VALIDATION_ERROR_18e00e4c',
    '"VUID-vkCmdCopyBufferToImage-commandBuffer-parameter"' : 'VALIDATION_ERROR_18e02401',
    '"VUID-vkCmdCopyBufferToImage-commandBuffer-recording"' : 'VALIDATION_ERROR_18e02413',
    '"VUID-vkCmdCopyBufferToImage-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_18e02415',
    '"VUID-vkCmdCopyBufferToImage-dstImage-parameter"' : 'VALIDATION_ERROR_18e07201',
    '"VUID-vkCmdCopyBufferToImage-dstImageLayout-parameter"' : 'VALIDATION_ERROR_18e07401',
    '"VUID-vkCmdCopyBufferToImage-pRegions-parameter"' : 'VALIDATION_ERROR_18e21001',
    '"VUID-vkCmdCopyBufferToImage-regionCount-arraylength"' : 'VALIDATION_ERROR_18e2ac1b',
    '"VUID-vkCmdCopyBufferToImage-srcBuffer-parameter"' : 'VALIDATION_ERROR_18e2c801',
    '"VUID-vkCmdCopyImage-commonparent"' : 'VALIDATION_ERROR_19000009',
    '"VUID-vkCmdCopyImage-renderpass"' : 'VALIDATION_ERROR_19000017',
    '"VUID-vkCmdCopyImage-pRegions-00122"' : 'VALIDATION_ERROR_190000f4',
    '"VUID-vkCmdCopyImage-pRegions-00123"' : 'VALIDATION_ERROR_190000f6',
    '"VUID-vkCmdCopyImage-pRegions-00124"' : 'VALIDATION_ERROR_190000f8',
    '"VUID-vkCmdCopyImage-srcImage-00125"' : 'VALIDATION_ERROR_190000fa',
    '"VUID-vkCmdCopyImage-srcImage-00126"' : 'VALIDATION_ERROR_190000fc',
    '"VUID-vkCmdCopyImage-srcImage-00127"' : 'VALIDATION_ERROR_190000fe',
    '"VUID-vkCmdCopyImage-srcImageLayout-00128"' : 'VALIDATION_ERROR_19000100',
    '"VUID-vkCmdCopyImage-srcImageLayout-00129"' : 'VALIDATION_ERROR_19000102',
    '"VUID-vkCmdCopyImage-dstImage-00130"' : 'VALIDATION_ERROR_19000104',
    '"VUID-vkCmdCopyImage-dstImage-00131"' : 'VALIDATION_ERROR_19000106',
    '"VUID-vkCmdCopyImage-dstImage-00132"' : 'VALIDATION_ERROR_19000108',
    '"VUID-vkCmdCopyImage-dstImageLayout-00133"' : 'VALIDATION_ERROR_1900010a',
    '"VUID-vkCmdCopyImage-dstImageLayout-00134"' : 'VALIDATION_ERROR_1900010c',
    '"VUID-vkCmdCopyImage-srcImage-00135"' : 'VALIDATION_ERROR_1900010e',
    '"VUID-vkCmdCopyImage-srcImage-00136"' : 'VALIDATION_ERROR_19000110',
    '"VUID-vkCmdCopyImage-dstImageLayout-01395"' : 'VALIDATION_ERROR_19000ae6',
    '"VUID-vkCmdCopyImage-srcImage-01546"' : 'VALIDATION_ERROR_19000c14',
    '"VUID-vkCmdCopyImage-dstImage-01547"' : 'VALIDATION_ERROR_19000c16',
    '"VUID-vkCmdCopyImage-srcImage-01548"' : 'VALIDATION_ERROR_19000c18',
    '"VUID-vkCmdCopyImage-None-01549"' : 'VALIDATION_ERROR_19000c1a',
    '"VUID-vkCmdCopyImage-aspectMask-01550"' : 'VALIDATION_ERROR_19000c1c',
    '"VUID-vkCmdCopyImage-srcSubresource-01696"' : 'VALIDATION_ERROR_19000d40',
    '"VUID-vkCmdCopyImage-dstSubresource-01697"' : 'VALIDATION_ERROR_19000d42',
    '"VUID-vkCmdCopyImage-srcSubresource-01698"' : 'VALIDATION_ERROR_19000d44',
    '"VUID-vkCmdCopyImage-dstSubresource-01699"' : 'VALIDATION_ERROR_19000d46',
    '"VUID-vkCmdCopyImage-srcOffset-01783"' : 'VALIDATION_ERROR_19000dee',
    '"VUID-vkCmdCopyImage-dstOffset-01784"' : 'VALIDATION_ERROR_19000df0',
    '"VUID-vkCmdCopyImage-commandBuffer-01825"' : 'VALIDATION_ERROR_19000e42',
    '"VUID-vkCmdCopyImage-commandBuffer-01826"' : 'VALIDATION_ERROR_19000e44',
    '"VUID-vkCmdCopyImage-commandBuffer-01827"' : 'VALIDATION_ERROR_19000e46',
    '"VUID-vkCmdCopyImage-srcImageLayout-01917"' : 'VALIDATION_ERROR_19000efa',
    '"VUID-vkCmdCopyImage-commandBuffer-parameter"' : 'VALIDATION_ERROR_19002401',
    '"VUID-vkCmdCopyImage-commandBuffer-recording"' : 'VALIDATION_ERROR_19002413',
    '"VUID-vkCmdCopyImage-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_19002415',
    '"VUID-vkCmdCopyImage-dstImage-parameter"' : 'VALIDATION_ERROR_19007201',
    '"VUID-vkCmdCopyImage-dstImageLayout-parameter"' : 'VALIDATION_ERROR_19007401',
    '"VUID-vkCmdCopyImage-pRegions-parameter"' : 'VALIDATION_ERROR_19021001',
    '"VUID-vkCmdCopyImage-regionCount-arraylength"' : 'VALIDATION_ERROR_1902ac1b',
    '"VUID-vkCmdCopyImage-srcImage-parameter"' : 'VALIDATION_ERROR_1902ce01',
    '"VUID-vkCmdCopyImage-srcImageLayout-parameter"' : 'VALIDATION_ERROR_1902d001',
    '"VUID-vkCmdCopyImageToBuffer-commonparent"' : 'VALIDATION_ERROR_19200009',
    '"VUID-vkCmdCopyImageToBuffer-renderpass"' : 'VALIDATION_ERROR_19200017',
    '"VUID-vkCmdCopyImageToBuffer-pRegions-00182"' : 'VALIDATION_ERROR_1920016c',
    '"VUID-vkCmdCopyImageToBuffer-pRegions-00183"' : 'VALIDATION_ERROR_1920016e',
    '"VUID-vkCmdCopyImageToBuffer-pRegions-00184"' : 'VALIDATION_ERROR_19200170',
    '"VUID-vkCmdCopyImageToBuffer-srcImage-00185"' : 'VALIDATION_ERROR_19200172',
    '"VUID-vkCmdCopyImageToBuffer-srcImage-00186"' : 'VALIDATION_ERROR_19200174',
    '"VUID-vkCmdCopyImageToBuffer-srcImage-00187"' : 'VALIDATION_ERROR_19200176',
    '"VUID-vkCmdCopyImageToBuffer-srcImage-00188"' : 'VALIDATION_ERROR_19200178',
    '"VUID-vkCmdCopyImageToBuffer-srcImageLayout-00189"' : 'VALIDATION_ERROR_1920017a',
    '"VUID-vkCmdCopyImageToBuffer-srcImageLayout-00190"' : 'VALIDATION_ERROR_1920017c',
    '"VUID-vkCmdCopyImageToBuffer-dstBuffer-00191"' : 'VALIDATION_ERROR_1920017e',
    '"VUID-vkCmdCopyImageToBuffer-dstBuffer-00192"' : 'VALIDATION_ERROR_19200180',
    '"VUID-vkCmdCopyImageToBuffer-srcImageLayout-01397"' : 'VALIDATION_ERROR_19200aea',
    '"VUID-vkCmdCopyImageToBuffer-imageSubresource-01703"' : 'VALIDATION_ERROR_19200d4e',
    '"VUID-vkCmdCopyImageToBuffer-imageSubresource-01704"' : 'VALIDATION_ERROR_19200d50',
    '"VUID-vkCmdCopyImageToBuffer-imageOffset-01794"' : 'VALIDATION_ERROR_19200e04',
    '"VUID-vkCmdCopyImageToBuffer-commandBuffer-01831"' : 'VALIDATION_ERROR_19200e4e',
    '"VUID-vkCmdCopyImageToBuffer-commandBuffer-01832"' : 'VALIDATION_ERROR_19200e50',
    '"VUID-vkCmdCopyImageToBuffer-commandBuffer-01833"' : 'VALIDATION_ERROR_19200e52',
    '"VUID-vkCmdCopyImageToBuffer-commandBuffer-parameter"' : 'VALIDATION_ERROR_19202401',
    '"VUID-vkCmdCopyImageToBuffer-commandBuffer-recording"' : 'VALIDATION_ERROR_19202413',
    '"VUID-vkCmdCopyImageToBuffer-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_19202415',
    '"VUID-vkCmdCopyImageToBuffer-dstBuffer-parameter"' : 'VALIDATION_ERROR_19206c01',
    '"VUID-vkCmdCopyImageToBuffer-pRegions-parameter"' : 'VALIDATION_ERROR_19221001',
    '"VUID-vkCmdCopyImageToBuffer-regionCount-arraylength"' : 'VALIDATION_ERROR_1922ac1b',
    '"VUID-vkCmdCopyImageToBuffer-srcImage-parameter"' : 'VALIDATION_ERROR_1922ce01',
    '"VUID-vkCmdCopyImageToBuffer-srcImageLayout-parameter"' : 'VALIDATION_ERROR_1922d001',
    '"VUID-vkCmdCopyQueryPoolResults-commonparent"' : 'VALIDATION_ERROR_19400009',
    '"VUID-vkCmdCopyQueryPoolResults-renderpass"' : 'VALIDATION_ERROR_19400017',
    '"VUID-vkCmdCopyQueryPoolResults-dstOffset-00819"' : 'VALIDATION_ERROR_19400666',
    '"VUID-vkCmdCopyQueryPoolResults-firstQuery-00820"' : 'VALIDATION_ERROR_19400668',
    '"VUID-vkCmdCopyQueryPoolResults-firstQuery-00821"' : 'VALIDATION_ERROR_1940066a',
    '"VUID-vkCmdCopyQueryPoolResults-flags-00822"' : 'VALIDATION_ERROR_1940066c',
    '"VUID-vkCmdCopyQueryPoolResults-flags-00823"' : 'VALIDATION_ERROR_1940066e',
    '"VUID-vkCmdCopyQueryPoolResults-dstBuffer-00824"' : 'VALIDATION_ERROR_19400670',
    '"VUID-vkCmdCopyQueryPoolResults-dstBuffer-00825"' : 'VALIDATION_ERROR_19400672',
    '"VUID-vkCmdCopyQueryPoolResults-dstBuffer-00826"' : 'VALIDATION_ERROR_19400674',
    '"VUID-vkCmdCopyQueryPoolResults-queryType-00827"' : 'VALIDATION_ERROR_19400676',
    '"VUID-vkCmdCopyQueryPoolResults-commandBuffer-parameter"' : 'VALIDATION_ERROR_19402401',
    '"VUID-vkCmdCopyQueryPoolResults-commandBuffer-recording"' : 'VALIDATION_ERROR_19402413',
    '"VUID-vkCmdCopyQueryPoolResults-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_19402415',
    '"VUID-vkCmdCopyQueryPoolResults-dstBuffer-parameter"' : 'VALIDATION_ERROR_19406c01',
    '"VUID-vkCmdCopyQueryPoolResults-flags-parameter"' : 'VALIDATION_ERROR_19409001',
    '"VUID-vkCmdCopyQueryPoolResults-queryPool-parameter"' : 'VALIDATION_ERROR_19429801',
    '"VUID-vkCmdDebugMarkerBeginEXT-commandBuffer-parameter"' : 'VALIDATION_ERROR_19602401',
    '"VUID-vkCmdDebugMarkerBeginEXT-commandBuffer-recording"' : 'VALIDATION_ERROR_19602413',
    '"VUID-vkCmdDebugMarkerBeginEXT-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_19602415',
    '"VUID-vkCmdDebugMarkerBeginEXT-pMarkerInfo-parameter"' : 'VALIDATION_ERROR_1961a601',
    '"VUID-vkCmdDebugMarkerEndEXT-commandBuffer-01239"' : 'VALIDATION_ERROR_198009ae',
    '"VUID-vkCmdDebugMarkerEndEXT-commandBuffer-01240"' : 'VALIDATION_ERROR_198009b0',
    '"VUID-vkCmdDebugMarkerEndEXT-commandBuffer-parameter"' : 'VALIDATION_ERROR_19802401',
    '"VUID-vkCmdDebugMarkerEndEXT-commandBuffer-recording"' : 'VALIDATION_ERROR_19802413',
    '"VUID-vkCmdDebugMarkerEndEXT-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_19802415',
    '"VUID-vkCmdDebugMarkerInsertEXT-commandBuffer-parameter"' : 'VALIDATION_ERROR_19a02401',
    '"VUID-vkCmdDebugMarkerInsertEXT-commandBuffer-recording"' : 'VALIDATION_ERROR_19a02413',
    '"VUID-vkCmdDebugMarkerInsertEXT-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_19a02415',
    '"VUID-vkCmdDebugMarkerInsertEXT-pMarkerInfo-parameter"' : 'VALIDATION_ERROR_19a1a601',
    '"VUID-vkCmdDispatch-renderpass"' : 'VALIDATION_ERROR_19c00017',
    '"VUID-vkCmdDispatch-groupCountX-00386"' : 'VALIDATION_ERROR_19c00304',
    '"VUID-vkCmdDispatch-groupCountY-00387"' : 'VALIDATION_ERROR_19c00306',
    '"VUID-vkCmdDispatch-groupCountZ-00388"' : 'VALIDATION_ERROR_19c00308',
    '"VUID-vkCmdDispatch-None-00389"' : 'VALIDATION_ERROR_19c0030a',
    '"VUID-vkCmdDispatch-None-00390"' : 'VALIDATION_ERROR_19c0030c',
    '"VUID-vkCmdDispatch-None-00391"' : 'VALIDATION_ERROR_19c0030e',
    '"VUID-vkCmdDispatch-None-00392"' : 'VALIDATION_ERROR_19c00310',
    '"VUID-vkCmdDispatch-None-00393"' : 'VALIDATION_ERROR_19c00312',
    '"VUID-vkCmdDispatch-None-00394"' : 'VALIDATION_ERROR_19c00314',
    '"VUID-vkCmdDispatch-None-00395"' : 'VALIDATION_ERROR_19c00316',
    '"VUID-vkCmdDispatch-None-00396"' : 'VALIDATION_ERROR_19c00318',
    '"VUID-vkCmdDispatch-None-00397"' : 'VALIDATION_ERROR_19c0031a',
    '"VUID-vkCmdDispatch-linearTilingFeatures-00398"' : 'VALIDATION_ERROR_19c0031c',
    '"VUID-vkCmdDispatch-linearTilingFeatures-00399"' : 'VALIDATION_ERROR_19c0031e',
    '"VUID-vkCmdDispatch-None-00400"' : 'VALIDATION_ERROR_19c00320',
    '"VUID-vkCmdDispatch-commandBuffer-01844"' : 'VALIDATION_ERROR_19c00e68',
    '"VUID-vkCmdDispatch-commandBuffer-01845"' : 'VALIDATION_ERROR_19c00e6a',
    '"VUID-vkCmdDispatch-commandBuffer-01846"' : 'VALIDATION_ERROR_19c00e6c',
    '"VUID-vkCmdDispatch-commandBuffer-parameter"' : 'VALIDATION_ERROR_19c02401',
    '"VUID-vkCmdDispatch-commandBuffer-recording"' : 'VALIDATION_ERROR_19c02413',
    '"VUID-vkCmdDispatch-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_19c02415',
    '"VUID-vkCmdDispatchBase-renderpass"' : 'VALIDATION_ERROR_19e00017',
    '"VUID-vkCmdDispatchBase-None-00420"' : 'VALIDATION_ERROR_19e00348',
    '"VUID-vkCmdDispatchBase-baseGroupX-00421"' : 'VALIDATION_ERROR_19e0034a',
    '"VUID-vkCmdDispatchBase-baseGroupX-00422"' : 'VALIDATION_ERROR_19e0034c',
    '"VUID-vkCmdDispatchBase-baseGroupZ-00423"' : 'VALIDATION_ERROR_19e0034e',
    '"VUID-vkCmdDispatchBase-groupCountX-00424"' : 'VALIDATION_ERROR_19e00350',
    '"VUID-vkCmdDispatchBase-groupCountY-00425"' : 'VALIDATION_ERROR_19e00352',
    '"VUID-vkCmdDispatchBase-groupCountZ-00426"' : 'VALIDATION_ERROR_19e00354',
    '"VUID-vkCmdDispatchBase-baseGroupX-00427"' : 'VALIDATION_ERROR_19e00356',
    '"VUID-vkCmdDispatchBase-commandBuffer-parameter"' : 'VALIDATION_ERROR_19e02401',
    '"VUID-vkCmdDispatchBase-commandBuffer-recording"' : 'VALIDATION_ERROR_19e02413',
    '"VUID-vkCmdDispatchBase-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_19e02415',
    '"VUID-vkCmdDispatchIndirect-commonparent"' : 'VALIDATION_ERROR_1a000009',
    '"VUID-vkCmdDispatchIndirect-renderpass"' : 'VALIDATION_ERROR_1a000017',
    '"VUID-vkCmdDispatchIndirect-buffer-00401"' : 'VALIDATION_ERROR_1a000322',
    '"VUID-vkCmdDispatchIndirect-None-00402"' : 'VALIDATION_ERROR_1a000324',
    '"VUID-vkCmdDispatchIndirect-None-00403"' : 'VALIDATION_ERROR_1a000326',
    '"VUID-vkCmdDispatchIndirect-None-00404"' : 'VALIDATION_ERROR_1a000328',
    '"VUID-vkCmdDispatchIndirect-buffer-00405"' : 'VALIDATION_ERROR_1a00032a',
    '"VUID-vkCmdDispatchIndirect-offset-00406"' : 'VALIDATION_ERROR_1a00032c',
    '"VUID-vkCmdDispatchIndirect-offset-00407"' : 'VALIDATION_ERROR_1a00032e',
    '"VUID-vkCmdDispatchIndirect-None-00408"' : 'VALIDATION_ERROR_1a000330',
    '"VUID-vkCmdDispatchIndirect-None-00409"' : 'VALIDATION_ERROR_1a000332',
    '"VUID-vkCmdDispatchIndirect-None-00410"' : 'VALIDATION_ERROR_1a000334',
    '"VUID-vkCmdDispatchIndirect-None-00411"' : 'VALIDATION_ERROR_1a000336',
    '"VUID-vkCmdDispatchIndirect-None-00412"' : 'VALIDATION_ERROR_1a000338',
    '"VUID-vkCmdDispatchIndirect-None-00413"' : 'VALIDATION_ERROR_1a00033a',
    '"VUID-vkCmdDispatchIndirect-linearTilingFeatures-00414"' : 'VALIDATION_ERROR_1a00033c',
    '"VUID-vkCmdDispatchIndirect-linearTilingFeatures-00415"' : 'VALIDATION_ERROR_1a00033e',
    '"VUID-vkCmdDispatchIndirect-None-00416"' : 'VALIDATION_ERROR_1a000340',
    '"VUID-vkCmdDispatchIndirect-commandBuffer-01847"' : 'VALIDATION_ERROR_1a000e6e',
    '"VUID-vkCmdDispatchIndirect-commandBuffer-01848"' : 'VALIDATION_ERROR_1a000e70',
    '"VUID-vkCmdDispatchIndirect-commandBuffer-01849"' : 'VALIDATION_ERROR_1a000e72',
    '"VUID-vkCmdDispatchIndirect-buffer-parameter"' : 'VALIDATION_ERROR_1a001a01',
    '"VUID-vkCmdDispatchIndirect-commandBuffer-parameter"' : 'VALIDATION_ERROR_1a002401',
    '"VUID-vkCmdDispatchIndirect-commandBuffer-recording"' : 'VALIDATION_ERROR_1a002413',
    '"VUID-vkCmdDispatchIndirect-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1a002415',
    '"VUID-vkCmdDraw-renderpass"' : 'VALIDATION_ERROR_1a200017',
    '"VUID-vkCmdDraw-renderPass-00435"' : 'VALIDATION_ERROR_1a200366',
    '"VUID-vkCmdDraw-subpass-00436"' : 'VALIDATION_ERROR_1a200368',
    '"VUID-vkCmdDraw-None-00437"' : 'VALIDATION_ERROR_1a20036a',
    '"VUID-vkCmdDraw-None-00438"' : 'VALIDATION_ERROR_1a20036c',
    '"VUID-vkCmdDraw-None-00439"' : 'VALIDATION_ERROR_1a20036e',
    '"VUID-vkCmdDraw-None-00440"' : 'VALIDATION_ERROR_1a200370',
    '"VUID-vkCmdDraw-None-00441"' : 'VALIDATION_ERROR_1a200372',
    '"VUID-vkCmdDraw-None-00442"' : 'VALIDATION_ERROR_1a200374',
    '"VUID-vkCmdDraw-None-00443"' : 'VALIDATION_ERROR_1a200376',
    '"VUID-vkCmdDraw-None-00444"' : 'VALIDATION_ERROR_1a200378',
    '"VUID-vkCmdDraw-None-00445"' : 'VALIDATION_ERROR_1a20037a',
    '"VUID-vkCmdDraw-None-00446"' : 'VALIDATION_ERROR_1a20037c',
    '"VUID-vkCmdDraw-None-00447"' : 'VALIDATION_ERROR_1a20037e',
    '"VUID-vkCmdDraw-None-00448"' : 'VALIDATION_ERROR_1a200380',
    '"VUID-vkCmdDraw-None-00449"' : 'VALIDATION_ERROR_1a200382',
    '"VUID-vkCmdDraw-linearTilingFeatures-00450"' : 'VALIDATION_ERROR_1a200384',
    '"VUID-vkCmdDraw-linearTilingFeatures-00451"' : 'VALIDATION_ERROR_1a200386',
    '"VUID-vkCmdDraw-None-00452"' : 'VALIDATION_ERROR_1a200388',
    '"VUID-vkCmdDraw-maxMultiviewInstanceIndex-00453"' : 'VALIDATION_ERROR_1a20038a',
    '"VUID-vkCmdDraw-None-01499"' : 'VALIDATION_ERROR_1a200bb6',
    '"VUID-vkCmdDraw-sampleLocationsEnable-01512"' : 'VALIDATION_ERROR_1a200bd0',
    '"VUID-vkCmdDraw-commandBuffer-01850"' : 'VALIDATION_ERROR_1a200e74',
    '"VUID-vkCmdDraw-commandBuffer-01851"' : 'VALIDATION_ERROR_1a200e76',
    '"VUID-vkCmdDraw-commandBuffer-01852"' : 'VALIDATION_ERROR_1a200e78',
    '"VUID-vkCmdDraw-commandBuffer-parameter"' : 'VALIDATION_ERROR_1a202401',
    '"VUID-vkCmdDraw-commandBuffer-recording"' : 'VALIDATION_ERROR_1a202413',
    '"VUID-vkCmdDraw-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1a202415',
    '"VUID-vkCmdDrawIndexed-renderpass"' : 'VALIDATION_ERROR_1a400017',
    '"VUID-vkCmdDrawIndexed-renderPass-00454"' : 'VALIDATION_ERROR_1a40038c',
    '"VUID-vkCmdDrawIndexed-subpass-00455"' : 'VALIDATION_ERROR_1a40038e',
    '"VUID-vkCmdDrawIndexed-None-00456"' : 'VALIDATION_ERROR_1a400390',
    '"VUID-vkCmdDrawIndexed-None-00457"' : 'VALIDATION_ERROR_1a400392',
    '"VUID-vkCmdDrawIndexed-None-00458"' : 'VALIDATION_ERROR_1a400394',
    '"VUID-vkCmdDrawIndexed-None-00459"' : 'VALIDATION_ERROR_1a400396',
    '"VUID-vkCmdDrawIndexed-None-00460"' : 'VALIDATION_ERROR_1a400398',
    '"VUID-vkCmdDrawIndexed-None-00461"' : 'VALIDATION_ERROR_1a40039a',
    '"VUID-vkCmdDrawIndexed-None-00462"' : 'VALIDATION_ERROR_1a40039c',
    '"VUID-vkCmdDrawIndexed-indexSize-00463"' : 'VALIDATION_ERROR_1a40039e',
    '"VUID-vkCmdDrawIndexed-None-00464"' : 'VALIDATION_ERROR_1a4003a0',
    '"VUID-vkCmdDrawIndexed-None-00465"' : 'VALIDATION_ERROR_1a4003a2',
    '"VUID-vkCmdDrawIndexed-None-00466"' : 'VALIDATION_ERROR_1a4003a4',
    '"VUID-vkCmdDrawIndexed-None-00467"' : 'VALIDATION_ERROR_1a4003a6',
    '"VUID-vkCmdDrawIndexed-None-00468"' : 'VALIDATION_ERROR_1a4003a8',
    '"VUID-vkCmdDrawIndexed-None-00469"' : 'VALIDATION_ERROR_1a4003aa',
    '"VUID-vkCmdDrawIndexed-linearTilingFeatures-00470"' : 'VALIDATION_ERROR_1a4003ac',
    '"VUID-vkCmdDrawIndexed-linearTilingFeatures-00471"' : 'VALIDATION_ERROR_1a4003ae',
    '"VUID-vkCmdDrawIndexed-None-00472"' : 'VALIDATION_ERROR_1a4003b0',
    '"VUID-vkCmdDrawIndexed-maxMultiviewInstanceIndex-00473"' : 'VALIDATION_ERROR_1a4003b2',
    '"VUID-vkCmdDrawIndexed-None-01500"' : 'VALIDATION_ERROR_1a400bb8',
    '"VUID-vkCmdDrawIndexed-sampleLocationsEnable-01513"' : 'VALIDATION_ERROR_1a400bd2',
    '"VUID-vkCmdDrawIndexed-commandBuffer-01853"' : 'VALIDATION_ERROR_1a400e7a',
    '"VUID-vkCmdDrawIndexed-commandBuffer-01854"' : 'VALIDATION_ERROR_1a400e7c',
    '"VUID-vkCmdDrawIndexed-commandBuffer-01855"' : 'VALIDATION_ERROR_1a400e7e',
    '"VUID-vkCmdDrawIndexed-commandBuffer-parameter"' : 'VALIDATION_ERROR_1a402401',
    '"VUID-vkCmdDrawIndexed-commandBuffer-recording"' : 'VALIDATION_ERROR_1a402413',
    '"VUID-vkCmdDrawIndexed-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1a402415',
    '"VUID-vkCmdDrawIndexedIndirect-commonparent"' : 'VALIDATION_ERROR_1a600009',
    '"VUID-vkCmdDrawIndexedIndirect-renderpass"' : 'VALIDATION_ERROR_1a600017',
    '"VUID-vkCmdDrawIndexedIndirect-buffer-00526"' : 'VALIDATION_ERROR_1a60041c',
    '"VUID-vkCmdDrawIndexedIndirect-offset-00527"' : 'VALIDATION_ERROR_1a60041e',
    '"VUID-vkCmdDrawIndexedIndirect-drawCount-00528"' : 'VALIDATION_ERROR_1a600420',
    '"VUID-vkCmdDrawIndexedIndirect-drawCount-00529"' : 'VALIDATION_ERROR_1a600422',
    '"VUID-vkCmdDrawIndexedIndirect-firstInstance-00530"' : 'VALIDATION_ERROR_1a600424',
    '"VUID-vkCmdDrawIndexedIndirect-renderPass-00531"' : 'VALIDATION_ERROR_1a600426',
    '"VUID-vkCmdDrawIndexedIndirect-subpass-00532"' : 'VALIDATION_ERROR_1a600428',
    '"VUID-vkCmdDrawIndexedIndirect-None-00533"' : 'VALIDATION_ERROR_1a60042a',
    '"VUID-vkCmdDrawIndexedIndirect-None-00534"' : 'VALIDATION_ERROR_1a60042c',
    '"VUID-vkCmdDrawIndexedIndirect-None-00535"' : 'VALIDATION_ERROR_1a60042e',
    '"VUID-vkCmdDrawIndexedIndirect-None-00536"' : 'VALIDATION_ERROR_1a600430',
    '"VUID-vkCmdDrawIndexedIndirect-None-00537"' : 'VALIDATION_ERROR_1a600432',
    '"VUID-vkCmdDrawIndexedIndirect-None-00538"' : 'VALIDATION_ERROR_1a600434',
    '"VUID-vkCmdDrawIndexedIndirect-drawCount-00539"' : 'VALIDATION_ERROR_1a600436',
    '"VUID-vkCmdDrawIndexedIndirect-drawCount-00540"' : 'VALIDATION_ERROR_1a600438',
    '"VUID-vkCmdDrawIndexedIndirect-drawCount-00541"' : 'VALIDATION_ERROR_1a60043a',
    '"VUID-vkCmdDrawIndexedIndirect-None-00542"' : 'VALIDATION_ERROR_1a60043c',
    '"VUID-vkCmdDrawIndexedIndirect-None-00543"' : 'VALIDATION_ERROR_1a60043e',
    '"VUID-vkCmdDrawIndexedIndirect-None-00544"' : 'VALIDATION_ERROR_1a600440',
    '"VUID-vkCmdDrawIndexedIndirect-None-00545"' : 'VALIDATION_ERROR_1a600442',
    '"VUID-vkCmdDrawIndexedIndirect-None-00546"' : 'VALIDATION_ERROR_1a600444',
    '"VUID-vkCmdDrawIndexedIndirect-None-00547"' : 'VALIDATION_ERROR_1a600446',
    '"VUID-vkCmdDrawIndexedIndirect-linearTilingFeatures-00548"' : 'VALIDATION_ERROR_1a600448',
    '"VUID-vkCmdDrawIndexedIndirect-linearTilingFeatures-00549"' : 'VALIDATION_ERROR_1a60044a',
    '"VUID-vkCmdDrawIndexedIndirect-None-00550"' : 'VALIDATION_ERROR_1a60044c',
    '"VUID-vkCmdDrawIndexedIndirect-maxMultiviewInstanceIndex-00551"' : 'VALIDATION_ERROR_1a60044e',
    '"VUID-vkCmdDrawIndexedIndirect-None-01503"' : 'VALIDATION_ERROR_1a600bbe',
    '"VUID-vkCmdDrawIndexedIndirect-sampleLocationsEnable-01516"' : 'VALIDATION_ERROR_1a600bd8',
    '"VUID-vkCmdDrawIndexedIndirect-buffer-01665"' : 'VALIDATION_ERROR_1a600d02',
    '"VUID-vkCmdDrawIndexedIndirect-commandBuffer-01862"' : 'VALIDATION_ERROR_1a600e8c',
    '"VUID-vkCmdDrawIndexedIndirect-commandBuffer-01863"' : 'VALIDATION_ERROR_1a600e8e',
    '"VUID-vkCmdDrawIndexedIndirect-commandBuffer-01864"' : 'VALIDATION_ERROR_1a600e90',
    '"VUID-vkCmdDrawIndexedIndirect-buffer-parameter"' : 'VALIDATION_ERROR_1a601a01',
    '"VUID-vkCmdDrawIndexedIndirect-commandBuffer-parameter"' : 'VALIDATION_ERROR_1a602401',
    '"VUID-vkCmdDrawIndexedIndirect-commandBuffer-recording"' : 'VALIDATION_ERROR_1a602413',
    '"VUID-vkCmdDrawIndexedIndirect-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1a602415',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-commonparent"' : 'VALIDATION_ERROR_1a800009',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-renderpass"' : 'VALIDATION_ERROR_1a800017',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-offset-00555"' : 'VALIDATION_ERROR_1a800456',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-countBufferOffset-00556"' : 'VALIDATION_ERROR_1a800458',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-stride-00557"' : 'VALIDATION_ERROR_1a80045a',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-maxDrawCount-00558"' : 'VALIDATION_ERROR_1a80045c',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-firstInstance-00559"' : 'VALIDATION_ERROR_1a80045e',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-renderPass-00560"' : 'VALIDATION_ERROR_1a800460',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-subpass-00561"' : 'VALIDATION_ERROR_1a800462',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00562"' : 'VALIDATION_ERROR_1a800464',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00563"' : 'VALIDATION_ERROR_1a800466',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00564"' : 'VALIDATION_ERROR_1a800468',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00565"' : 'VALIDATION_ERROR_1a80046a',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00566"' : 'VALIDATION_ERROR_1a80046c',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00567"' : 'VALIDATION_ERROR_1a80046e',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-countBuffer-00568"' : 'VALIDATION_ERROR_1a800470',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-countBuffer-00569"' : 'VALIDATION_ERROR_1a800472',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-drawCount-00570"' : 'VALIDATION_ERROR_1a800474',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00571"' : 'VALIDATION_ERROR_1a800476',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00572"' : 'VALIDATION_ERROR_1a800478',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00573"' : 'VALIDATION_ERROR_1a80047a',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00574"' : 'VALIDATION_ERROR_1a80047c',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00575"' : 'VALIDATION_ERROR_1a80047e',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-00576"' : 'VALIDATION_ERROR_1a800480',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-linearTilingFeatures-00577"' : 'VALIDATION_ERROR_1a800482',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-maxMultiviewInstanceIndex-00578"' : 'VALIDATION_ERROR_1a800484',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-None-01504"' : 'VALIDATION_ERROR_1a800bc0',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-sampleLocationsEnable-01517"' : 'VALIDATION_ERROR_1a800bda',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-buffer-01666"' : 'VALIDATION_ERROR_1a800d04',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-buffer-01667"' : 'VALIDATION_ERROR_1a800d06',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-countBuffer-01668"' : 'VALIDATION_ERROR_1a800d08',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-countBuffer-01669"' : 'VALIDATION_ERROR_1a800d0a',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-commandBuffer-01865"' : 'VALIDATION_ERROR_1a800e92',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-commandBuffer-01866"' : 'VALIDATION_ERROR_1a800e94',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-commandBuffer-01867"' : 'VALIDATION_ERROR_1a800e96',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-buffer-parameter"' : 'VALIDATION_ERROR_1a801a01',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-commandBuffer-parameter"' : 'VALIDATION_ERROR_1a802401',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-commandBuffer-recording"' : 'VALIDATION_ERROR_1a802413',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1a802415',
    '"VUID-vkCmdDrawIndexedIndirectCountAMD-countBuffer-parameter"' : 'VALIDATION_ERROR_1a803401',
    '"VUID-vkCmdDrawIndirect-commonparent"' : 'VALIDATION_ERROR_1aa00009',
    '"VUID-vkCmdDrawIndirect-renderpass"' : 'VALIDATION_ERROR_1aa00017',
    '"VUID-vkCmdDrawIndirect-buffer-00474"' : 'VALIDATION_ERROR_1aa003b4',
    '"VUID-vkCmdDrawIndirect-offset-00475"' : 'VALIDATION_ERROR_1aa003b6',
    '"VUID-vkCmdDrawIndirect-drawCount-00476"' : 'VALIDATION_ERROR_1aa003b8',
    '"VUID-vkCmdDrawIndirect-drawCount-00477"' : 'VALIDATION_ERROR_1aa003ba',
    '"VUID-vkCmdDrawIndirect-firstInstance-00478"' : 'VALIDATION_ERROR_1aa003bc',
    '"VUID-vkCmdDrawIndirect-renderPass-00479"' : 'VALIDATION_ERROR_1aa003be',
    '"VUID-vkCmdDrawIndirect-subpass-00480"' : 'VALIDATION_ERROR_1aa003c0',
    '"VUID-vkCmdDrawIndirect-None-00481"' : 'VALIDATION_ERROR_1aa003c2',
    '"VUID-vkCmdDrawIndirect-None-00482"' : 'VALIDATION_ERROR_1aa003c4',
    '"VUID-vkCmdDrawIndirect-None-00483"' : 'VALIDATION_ERROR_1aa003c6',
    '"VUID-vkCmdDrawIndirect-None-00484"' : 'VALIDATION_ERROR_1aa003c8',
    '"VUID-vkCmdDrawIndirect-None-00485"' : 'VALIDATION_ERROR_1aa003ca',
    '"VUID-vkCmdDrawIndirect-None-00486"' : 'VALIDATION_ERROR_1aa003cc',
    '"VUID-vkCmdDrawIndirect-drawCount-00487"' : 'VALIDATION_ERROR_1aa003ce',
    '"VUID-vkCmdDrawIndirect-drawCount-00488"' : 'VALIDATION_ERROR_1aa003d0',
    '"VUID-vkCmdDrawIndirect-drawCount-00489"' : 'VALIDATION_ERROR_1aa003d2',
    '"VUID-vkCmdDrawIndirect-None-00490"' : 'VALIDATION_ERROR_1aa003d4',
    '"VUID-vkCmdDrawIndirect-None-00491"' : 'VALIDATION_ERROR_1aa003d6',
    '"VUID-vkCmdDrawIndirect-None-00492"' : 'VALIDATION_ERROR_1aa003d8',
    '"VUID-vkCmdDrawIndirect-None-00493"' : 'VALIDATION_ERROR_1aa003da',
    '"VUID-vkCmdDrawIndirect-None-00494"' : 'VALIDATION_ERROR_1aa003dc',
    '"VUID-vkCmdDrawIndirect-None-00495"' : 'VALIDATION_ERROR_1aa003de',
    '"VUID-vkCmdDrawIndirect-linearTilingFeatures-00496"' : 'VALIDATION_ERROR_1aa003e0',
    '"VUID-vkCmdDrawIndirect-linearTilingFeatures-00497"' : 'VALIDATION_ERROR_1aa003e2',
    '"VUID-vkCmdDrawIndirect-None-00498"' : 'VALIDATION_ERROR_1aa003e4',
    '"VUID-vkCmdDrawIndirect-maxMultiviewInstanceIndex-00499"' : 'VALIDATION_ERROR_1aa003e6',
    '"VUID-vkCmdDrawIndirect-None-01501"' : 'VALIDATION_ERROR_1aa00bba',
    '"VUID-vkCmdDrawIndirect-sampleLocationsEnable-01514"' : 'VALIDATION_ERROR_1aa00bd4',
    '"VUID-vkCmdDrawIndirect-buffer-01660"' : 'VALIDATION_ERROR_1aa00cf8',
    '"VUID-vkCmdDrawIndirect-commandBuffer-01856"' : 'VALIDATION_ERROR_1aa00e80',
    '"VUID-vkCmdDrawIndirect-commandBuffer-01857"' : 'VALIDATION_ERROR_1aa00e82',
    '"VUID-vkCmdDrawIndirect-commandBuffer-01858"' : 'VALIDATION_ERROR_1aa00e84',
    '"VUID-vkCmdDrawIndirect-buffer-parameter"' : 'VALIDATION_ERROR_1aa01a01',
    '"VUID-vkCmdDrawIndirect-commandBuffer-parameter"' : 'VALIDATION_ERROR_1aa02401',
    '"VUID-vkCmdDrawIndirect-commandBuffer-recording"' : 'VALIDATION_ERROR_1aa02413',
    '"VUID-vkCmdDrawIndirect-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1aa02415',
    '"VUID-vkCmdDrawIndirectCountAMD-commonparent"' : 'VALIDATION_ERROR_1ac00009',
    '"VUID-vkCmdDrawIndirectCountAMD-renderpass"' : 'VALIDATION_ERROR_1ac00017',
    '"VUID-vkCmdDrawIndirectCountAMD-offset-00502"' : 'VALIDATION_ERROR_1ac003ec',
    '"VUID-vkCmdDrawIndirectCountAMD-countBufferOffset-00503"' : 'VALIDATION_ERROR_1ac003ee',
    '"VUID-vkCmdDrawIndirectCountAMD-stride-00504"' : 'VALIDATION_ERROR_1ac003f0',
    '"VUID-vkCmdDrawIndirectCountAMD-maxDrawCount-00505"' : 'VALIDATION_ERROR_1ac003f2',
    '"VUID-vkCmdDrawIndirectCountAMD-firstInstance-00506"' : 'VALIDATION_ERROR_1ac003f4',
    '"VUID-vkCmdDrawIndirectCountAMD-renderPass-00507"' : 'VALIDATION_ERROR_1ac003f6',
    '"VUID-vkCmdDrawIndirectCountAMD-subpass-00508"' : 'VALIDATION_ERROR_1ac003f8',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00509"' : 'VALIDATION_ERROR_1ac003fa',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00510"' : 'VALIDATION_ERROR_1ac003fc',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00511"' : 'VALIDATION_ERROR_1ac003fe',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00512"' : 'VALIDATION_ERROR_1ac00400',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00513"' : 'VALIDATION_ERROR_1ac00402',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00514"' : 'VALIDATION_ERROR_1ac00404',
    '"VUID-vkCmdDrawIndirectCountAMD-countBuffer-00515"' : 'VALIDATION_ERROR_1ac00406',
    '"VUID-vkCmdDrawIndirectCountAMD-countBuffer-00516"' : 'VALIDATION_ERROR_1ac00408',
    '"VUID-vkCmdDrawIndirectCountAMD-countBuffer-00517"' : 'VALIDATION_ERROR_1ac0040a',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00518"' : 'VALIDATION_ERROR_1ac0040c',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00519"' : 'VALIDATION_ERROR_1ac0040e',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00520"' : 'VALIDATION_ERROR_1ac00410',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00521"' : 'VALIDATION_ERROR_1ac00412',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00522"' : 'VALIDATION_ERROR_1ac00414',
    '"VUID-vkCmdDrawIndirectCountAMD-None-00523"' : 'VALIDATION_ERROR_1ac00416',
    '"VUID-vkCmdDrawIndirectCountAMD-linearTilingFeatures-00524"' : 'VALIDATION_ERROR_1ac00418',
    '"VUID-vkCmdDrawIndirectCountAMD-maxMultiviewInstanceIndex-00525"' : 'VALIDATION_ERROR_1ac0041a',
    '"VUID-vkCmdDrawIndirectCountAMD-None-01502"' : 'VALIDATION_ERROR_1ac00bbc',
    '"VUID-vkCmdDrawIndirectCountAMD-sampleLocationsEnable-01515"' : 'VALIDATION_ERROR_1ac00bd6',
    '"VUID-vkCmdDrawIndirectCountAMD-buffer-01661"' : 'VALIDATION_ERROR_1ac00cfa',
    '"VUID-vkCmdDrawIndirectCountAMD-buffer-01662"' : 'VALIDATION_ERROR_1ac00cfc',
    '"VUID-vkCmdDrawIndirectCountAMD-countBuffer-01663"' : 'VALIDATION_ERROR_1ac00cfe',
    '"VUID-vkCmdDrawIndirectCountAMD-countBuffer-01664"' : 'VALIDATION_ERROR_1ac00d00',
    '"VUID-vkCmdDrawIndirectCountAMD-commandBuffer-01859"' : 'VALIDATION_ERROR_1ac00e86',
    '"VUID-vkCmdDrawIndirectCountAMD-commandBuffer-01860"' : 'VALIDATION_ERROR_1ac00e88',
    '"VUID-vkCmdDrawIndirectCountAMD-commandBuffer-01861"' : 'VALIDATION_ERROR_1ac00e8a',
    '"VUID-vkCmdDrawIndirectCountAMD-buffer-parameter"' : 'VALIDATION_ERROR_1ac01a01',
    '"VUID-vkCmdDrawIndirectCountAMD-commandBuffer-parameter"' : 'VALIDATION_ERROR_1ac02401',
    '"VUID-vkCmdDrawIndirectCountAMD-commandBuffer-recording"' : 'VALIDATION_ERROR_1ac02413',
    '"VUID-vkCmdDrawIndirectCountAMD-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1ac02415',
    '"VUID-vkCmdDrawIndirectCountAMD-countBuffer-parameter"' : 'VALIDATION_ERROR_1ac03401',
    '"VUID-vkCmdEndQuery-commonparent"' : 'VALIDATION_ERROR_1ae00009',
    '"VUID-vkCmdEndQuery-query-00810"' : 'VALIDATION_ERROR_1ae00654',
    '"VUID-vkCmdEndQuery-query-00812"' : 'VALIDATION_ERROR_1ae00658',
    '"VUID-vkCmdEndQuery-commandBuffer-01886"' : 'VALIDATION_ERROR_1ae00ebc',
    '"VUID-vkCmdEndQuery-None-01923"' : 'VALIDATION_ERROR_1ae00f06',
    '"VUID-vkCmdEndQuery-commandBuffer-parameter"' : 'VALIDATION_ERROR_1ae02401',
    '"VUID-vkCmdEndQuery-commandBuffer-recording"' : 'VALIDATION_ERROR_1ae02413',
    '"VUID-vkCmdEndQuery-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1ae02415',
    '"VUID-vkCmdEndQuery-queryPool-parameter"' : 'VALIDATION_ERROR_1ae29801',
    '"VUID-vkCmdEndRenderPass-renderpass"' : 'VALIDATION_ERROR_1b000017',
    '"VUID-vkCmdEndRenderPass-bufferlevel"' : 'VALIDATION_ERROR_1b000019',
    '"VUID-vkCmdEndRenderPass-None-00910"' : 'VALIDATION_ERROR_1b00071c',
    '"VUID-vkCmdEndRenderPass-commandBuffer-parameter"' : 'VALIDATION_ERROR_1b002401',
    '"VUID-vkCmdEndRenderPass-commandBuffer-recording"' : 'VALIDATION_ERROR_1b002413',
    '"VUID-vkCmdEndRenderPass-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1b002415',
    '"VUID-vkCmdExecuteCommands-commonparent"' : 'VALIDATION_ERROR_1b200009',
    '"VUID-vkCmdExecuteCommands-bufferlevel"' : 'VALIDATION_ERROR_1b200019',
    '"VUID-vkCmdExecuteCommands-commandBuffer-00087"' : 'VALIDATION_ERROR_1b2000ae',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00088"' : 'VALIDATION_ERROR_1b2000b0',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00089"' : 'VALIDATION_ERROR_1b2000b2',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00090"' : 'VALIDATION_ERROR_1b2000b4',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00091"' : 'VALIDATION_ERROR_1b2000b6',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00092"' : 'VALIDATION_ERROR_1b2000b8',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00093"' : 'VALIDATION_ERROR_1b2000ba',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00094"' : 'VALIDATION_ERROR_1b2000bc',
    '"VUID-vkCmdExecuteCommands-contents-00095"' : 'VALIDATION_ERROR_1b2000be',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00096"' : 'VALIDATION_ERROR_1b2000c0',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00097"' : 'VALIDATION_ERROR_1b2000c2',
    '"VUID-vkCmdExecuteCommands-pInheritanceInfo-00098"' : 'VALIDATION_ERROR_1b2000c4',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00099"' : 'VALIDATION_ERROR_1b2000c6',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00100"' : 'VALIDATION_ERROR_1b2000c8',
    '"VUID-vkCmdExecuteCommands-commandBuffer-00101"' : 'VALIDATION_ERROR_1b2000ca',
    '"VUID-vkCmdExecuteCommands-commandBuffer-00102"' : 'VALIDATION_ERROR_1b2000cc',
    '"VUID-vkCmdExecuteCommands-commandBuffer-00103"' : 'VALIDATION_ERROR_1b2000ce',
    '"VUID-vkCmdExecuteCommands-commandBuffer-00104"' : 'VALIDATION_ERROR_1b2000d0',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-00105"' : 'VALIDATION_ERROR_1b2000d2',
    '"VUID-vkCmdExecuteCommands-commandBuffer-01820"' : 'VALIDATION_ERROR_1b200e38',
    '"VUID-vkCmdExecuteCommands-commandBuffer-01821"' : 'VALIDATION_ERROR_1b200e3a',
    '"VUID-vkCmdExecuteCommands-commandBuffer-parameter"' : 'VALIDATION_ERROR_1b202401',
    '"VUID-vkCmdExecuteCommands-commandBuffer-recording"' : 'VALIDATION_ERROR_1b202413',
    '"VUID-vkCmdExecuteCommands-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1b202415',
    '"VUID-vkCmdExecuteCommands-commandBufferCount-arraylength"' : 'VALIDATION_ERROR_1b20261b',
    '"VUID-vkCmdExecuteCommands-pCommandBuffers-parameter"' : 'VALIDATION_ERROR_1b211401',
    '"VUID-vkCmdFillBuffer-commonparent"' : 'VALIDATION_ERROR_1b400009',
    '"VUID-vkCmdFillBuffer-renderpass"' : 'VALIDATION_ERROR_1b400017',
    '"VUID-vkCmdFillBuffer-dstOffset-00024"' : 'VALIDATION_ERROR_1b400030',
    '"VUID-vkCmdFillBuffer-dstOffset-00025"' : 'VALIDATION_ERROR_1b400032',
    '"VUID-vkCmdFillBuffer-size-00026"' : 'VALIDATION_ERROR_1b400034',
    '"VUID-vkCmdFillBuffer-size-00027"' : 'VALIDATION_ERROR_1b400036',
    '"VUID-vkCmdFillBuffer-size-00028"' : 'VALIDATION_ERROR_1b400038',
    '"VUID-vkCmdFillBuffer-dstBuffer-00029"' : 'VALIDATION_ERROR_1b40003a',
    '"VUID-vkCmdFillBuffer-commandBuffer-00030"' : 'VALIDATION_ERROR_1b40003c',
    '"VUID-vkCmdFillBuffer-dstBuffer-00031"' : 'VALIDATION_ERROR_1b40003e',
    '"VUID-vkCmdFillBuffer-commandBuffer-01811"' : 'VALIDATION_ERROR_1b400e26',
    '"VUID-vkCmdFillBuffer-commandBuffer-01812"' : 'VALIDATION_ERROR_1b400e28',
    '"VUID-vkCmdFillBuffer-commandBuffer-parameter"' : 'VALIDATION_ERROR_1b402401',
    '"VUID-vkCmdFillBuffer-commandBuffer-recording"' : 'VALIDATION_ERROR_1b402413',
    '"VUID-vkCmdFillBuffer-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1b402415',
    '"VUID-vkCmdFillBuffer-dstBuffer-parameter"' : 'VALIDATION_ERROR_1b406c01',
    '"VUID-vkCmdNextSubpass-renderpass"' : 'VALIDATION_ERROR_1b600017',
    '"VUID-vkCmdNextSubpass-bufferlevel"' : 'VALIDATION_ERROR_1b600019',
    '"VUID-vkCmdNextSubpass-None-00909"' : 'VALIDATION_ERROR_1b60071a',
    '"VUID-vkCmdNextSubpass-commandBuffer-parameter"' : 'VALIDATION_ERROR_1b602401',
    '"VUID-vkCmdNextSubpass-commandBuffer-recording"' : 'VALIDATION_ERROR_1b602413',
    '"VUID-vkCmdNextSubpass-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1b602415',
    '"VUID-vkCmdNextSubpass-contents-parameter"' : 'VALIDATION_ERROR_1b603201',
    '"VUID-vkCmdPipelineBarrier-srcStageMask-01168"' : 'VALIDATION_ERROR_1b800920',
    '"VUID-vkCmdPipelineBarrier-dstStageMask-01169"' : 'VALIDATION_ERROR_1b800922',
    '"VUID-vkCmdPipelineBarrier-srcStageMask-01170"' : 'VALIDATION_ERROR_1b800924',
    '"VUID-vkCmdPipelineBarrier-dstStageMask-01171"' : 'VALIDATION_ERROR_1b800926',
    '"VUID-vkCmdPipelineBarrier-pDependencies-01172"' : 'VALIDATION_ERROR_1b800928',
    '"VUID-vkCmdPipelineBarrier-srcStageMask-01173"' : 'VALIDATION_ERROR_1b80092a',
    '"VUID-vkCmdPipelineBarrier-dstStageMask-01174"' : 'VALIDATION_ERROR_1b80092c',
    '"VUID-vkCmdPipelineBarrier-srcAccessMask-01175"' : 'VALIDATION_ERROR_1b80092e',
    '"VUID-vkCmdPipelineBarrier-dstAccessMask-01176"' : 'VALIDATION_ERROR_1b800930',
    '"VUID-vkCmdPipelineBarrier-dependencyFlags-01177"' : 'VALIDATION_ERROR_1b800932',
    '"VUID-vkCmdPipelineBarrier-bufferMemoryBarrierCount-01178"' : 'VALIDATION_ERROR_1b800934',
    '"VUID-vkCmdPipelineBarrier-image-01179"' : 'VALIDATION_ERROR_1b800936',
    '"VUID-vkCmdPipelineBarrier-oldLayout-01180"' : 'VALIDATION_ERROR_1b800938',
    '"VUID-vkCmdPipelineBarrier-oldLayout-01181"' : 'VALIDATION_ERROR_1b80093a',
    '"VUID-vkCmdPipelineBarrier-srcQueueFamilyIndex-01182"' : 'VALIDATION_ERROR_1b80093c',
    '"VUID-vkCmdPipelineBarrier-srcStageMask-01183"' : 'VALIDATION_ERROR_1b80093e',
    '"VUID-vkCmdPipelineBarrier-pMemoryBarriers-01184"' : 'VALIDATION_ERROR_1b800940',
    '"VUID-vkCmdPipelineBarrier-pMemoryBarriers-01185"' : 'VALIDATION_ERROR_1b800942',
    '"VUID-vkCmdPipelineBarrier-dependencyFlags-01186"' : 'VALIDATION_ERROR_1b800944',
    '"VUID-vkCmdPipelineBarrier-commandBuffer-parameter"' : 'VALIDATION_ERROR_1b802401',
    '"VUID-vkCmdPipelineBarrier-commandBuffer-recording"' : 'VALIDATION_ERROR_1b802413',
    '"VUID-vkCmdPipelineBarrier-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1b802415',
    '"VUID-vkCmdPipelineBarrier-dependencyFlags-parameter"' : 'VALIDATION_ERROR_1b803e01',
    '"VUID-vkCmdPipelineBarrier-dstStageMask-parameter"' : 'VALIDATION_ERROR_1b807801',
    '"VUID-vkCmdPipelineBarrier-dstStageMask-requiredbitmask"' : 'VALIDATION_ERROR_1b807803',
    '"VUID-vkCmdPipelineBarrier-pBufferMemoryBarriers-parameter"' : 'VALIDATION_ERROR_1b810401',
    '"VUID-vkCmdPipelineBarrier-pImageMemoryBarriers-parameter"' : 'VALIDATION_ERROR_1b818a01',
    '"VUID-vkCmdPipelineBarrier-pMemoryBarriers-parameter"' : 'VALIDATION_ERROR_1b81ac01',
    '"VUID-vkCmdPipelineBarrier-srcStageMask-parameter"' : 'VALIDATION_ERROR_1b82d401',
    '"VUID-vkCmdPipelineBarrier-srcStageMask-requiredbitmask"' : 'VALIDATION_ERROR_1b82d403',
    '"VUID-vkCmdProcessCommandsNVX-renderpass"' : 'VALIDATION_ERROR_1ba00017',
    '"VUID-vkCmdProcessCommandsNVX-commandBuffer-parameter"' : 'VALIDATION_ERROR_1ba02401',
    '"VUID-vkCmdProcessCommandsNVX-commandBuffer-recording"' : 'VALIDATION_ERROR_1ba02413',
    '"VUID-vkCmdProcessCommandsNVX-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1ba02415',
    '"VUID-vkCmdProcessCommandsNVX-pProcessCommandsInfo-parameter"' : 'VALIDATION_ERROR_1ba1f201',
    '"VUID-vkCmdPushConstants-commonparent"' : 'VALIDATION_ERROR_1bc00009',
    '"VUID-vkCmdPushConstants-offset-00368"' : 'VALIDATION_ERROR_1bc002e0',
    '"VUID-vkCmdPushConstants-size-00369"' : 'VALIDATION_ERROR_1bc002e2',
    '"VUID-vkCmdPushConstants-offset-00370"' : 'VALIDATION_ERROR_1bc002e4',
    '"VUID-vkCmdPushConstants-size-00371"' : 'VALIDATION_ERROR_1bc002e6',
    '"VUID-vkCmdPushConstants-offset-01795"' : 'VALIDATION_ERROR_1bc00e06',
    '"VUID-vkCmdPushConstants-offset-01796"' : 'VALIDATION_ERROR_1bc00e08',
    '"VUID-vkCmdPushConstants-commandBuffer-parameter"' : 'VALIDATION_ERROR_1bc02401',
    '"VUID-vkCmdPushConstants-commandBuffer-recording"' : 'VALIDATION_ERROR_1bc02413',
    '"VUID-vkCmdPushConstants-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1bc02415',
    '"VUID-vkCmdPushConstants-layout-parameter"' : 'VALIDATION_ERROR_1bc0be01',
    '"VUID-vkCmdPushConstants-pValues-parameter"' : 'VALIDATION_ERROR_1bc26201',
    '"VUID-vkCmdPushConstants-size-arraylength"' : 'VALIDATION_ERROR_1bc2c21b',
    '"VUID-vkCmdPushConstants-stageFlags-parameter"' : 'VALIDATION_ERROR_1bc2dc01',
    '"VUID-vkCmdPushConstants-stageFlags-requiredbitmask"' : 'VALIDATION_ERROR_1bc2dc03',
    '"VUID-vkCmdPushDescriptorSetKHR-commonparent"' : 'VALIDATION_ERROR_1be00009',
    '"VUID-vkCmdPushDescriptorSetKHR-pipelineBindPoint-00363"' : 'VALIDATION_ERROR_1be002d6',
    '"VUID-vkCmdPushDescriptorSetKHR-set-00364"' : 'VALIDATION_ERROR_1be002d8',
    '"VUID-vkCmdPushDescriptorSetKHR-set-00365"' : 'VALIDATION_ERROR_1be002da',
    '"VUID-vkCmdPushDescriptorSetKHR-commandBuffer-parameter"' : 'VALIDATION_ERROR_1be02401',
    '"VUID-vkCmdPushDescriptorSetKHR-commandBuffer-recording"' : 'VALIDATION_ERROR_1be02413',
    '"VUID-vkCmdPushDescriptorSetKHR-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1be02415',
    '"VUID-vkCmdPushDescriptorSetKHR-descriptorWriteCount-arraylength"' : 'VALIDATION_ERROR_1be0541b',
    '"VUID-vkCmdPushDescriptorSetKHR-layout-parameter"' : 'VALIDATION_ERROR_1be0be01',
    '"VUID-vkCmdPushDescriptorSetKHR-pDescriptorWrites-parameter"' : 'VALIDATION_ERROR_1be13601',
    '"VUID-vkCmdPushDescriptorSetKHR-pipelineBindPoint-parameter"' : 'VALIDATION_ERROR_1be27e01',
    '"VUID-vkCmdPushDescriptorSetWithTemplateKHR-commonparent"' : 'VALIDATION_ERROR_1c000009',
    '"VUID-vkCmdPushDescriptorSetWithTemplateKHR-commandBuffer-00366"' : 'VALIDATION_ERROR_1c0002dc',
    '"VUID-vkCmdPushDescriptorSetWithTemplateKHR-pData-01686"' : 'VALIDATION_ERROR_1c000d2c',
    '"VUID-vkCmdPushDescriptorSetWithTemplateKHR-commandBuffer-parameter"' : 'VALIDATION_ERROR_1c002401',
    '"VUID-vkCmdPushDescriptorSetWithTemplateKHR-commandBuffer-recording"' : 'VALIDATION_ERROR_1c002413',
    '"VUID-vkCmdPushDescriptorSetWithTemplateKHR-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1c002415',
    '"VUID-vkCmdPushDescriptorSetWithTemplateKHR-descriptorUpdateTemplate-parameter"' : 'VALIDATION_ERROR_1c005201',
    '"VUID-vkCmdPushDescriptorSetWithTemplateKHR-layout-parameter"' : 'VALIDATION_ERROR_1c00be01',
    '"VUID-vkCmdReserveSpaceForCommandsNVX-renderpass"' : 'VALIDATION_ERROR_1c200017',
    '"VUID-vkCmdReserveSpaceForCommandsNVX-bufferlevel"' : 'VALIDATION_ERROR_1c200019',
    '"VUID-vkCmdReserveSpaceForCommandsNVX-commandBuffer-01329"' : 'VALIDATION_ERROR_1c200a62',
    '"VUID-vkCmdReserveSpaceForCommandsNVX-commandBuffer-01330"' : 'VALIDATION_ERROR_1c200a64',
    '"VUID-vkCmdReserveSpaceForCommandsNVX-commandBuffer-parameter"' : 'VALIDATION_ERROR_1c202401',
    '"VUID-vkCmdReserveSpaceForCommandsNVX-commandBuffer-recording"' : 'VALIDATION_ERROR_1c202413',
    '"VUID-vkCmdReserveSpaceForCommandsNVX-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1c202415',
    '"VUID-vkCmdReserveSpaceForCommandsNVX-pReserveSpaceInfo-parameter"' : 'VALIDATION_ERROR_1c221a01',
    '"VUID-vkCmdResetEvent-commonparent"' : 'VALIDATION_ERROR_1c400009',
    '"VUID-vkCmdResetEvent-renderpass"' : 'VALIDATION_ERROR_1c400017',
    '"VUID-vkCmdResetEvent-stageMask-01153"' : 'VALIDATION_ERROR_1c400902',
    '"VUID-vkCmdResetEvent-stageMask-01154"' : 'VALIDATION_ERROR_1c400904',
    '"VUID-vkCmdResetEvent-stageMask-01155"' : 'VALIDATION_ERROR_1c400906',
    '"VUID-vkCmdResetEvent-event-01156"' : 'VALIDATION_ERROR_1c400908',
    '"VUID-vkCmdResetEvent-commandBuffer-01157"' : 'VALIDATION_ERROR_1c40090a',
    '"VUID-vkCmdResetEvent-commandBuffer-parameter"' : 'VALIDATION_ERROR_1c402401',
    '"VUID-vkCmdResetEvent-commandBuffer-recording"' : 'VALIDATION_ERROR_1c402413',
    '"VUID-vkCmdResetEvent-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1c402415',
    '"VUID-vkCmdResetEvent-event-parameter"' : 'VALIDATION_ERROR_1c407e01',
    '"VUID-vkCmdResetEvent-stageMask-parameter"' : 'VALIDATION_ERROR_1c42de01',
    '"VUID-vkCmdResetEvent-stageMask-requiredbitmask"' : 'VALIDATION_ERROR_1c42de03',
    '"VUID-vkCmdResetQueryPool-commonparent"' : 'VALIDATION_ERROR_1c600009',
    '"VUID-vkCmdResetQueryPool-renderpass"' : 'VALIDATION_ERROR_1c600017',
    '"VUID-vkCmdResetQueryPool-firstQuery-00796"' : 'VALIDATION_ERROR_1c600638',
    '"VUID-vkCmdResetQueryPool-firstQuery-00797"' : 'VALIDATION_ERROR_1c60063a',
    '"VUID-vkCmdResetQueryPool-commandBuffer-parameter"' : 'VALIDATION_ERROR_1c602401',
    '"VUID-vkCmdResetQueryPool-commandBuffer-recording"' : 'VALIDATION_ERROR_1c602413',
    '"VUID-vkCmdResetQueryPool-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1c602415',
    '"VUID-vkCmdResetQueryPool-queryPool-parameter"' : 'VALIDATION_ERROR_1c629801',
    '"VUID-vkCmdResolveImage-commonparent"' : 'VALIDATION_ERROR_1c800009',
    '"VUID-vkCmdResolveImage-renderpass"' : 'VALIDATION_ERROR_1c800017',
    '"VUID-vkCmdResolveImage-pRegions-00253"' : 'VALIDATION_ERROR_1c8001fa',
    '"VUID-vkCmdResolveImage-pRegions-00254"' : 'VALIDATION_ERROR_1c8001fc',
    '"VUID-vkCmdResolveImage-pRegions-00255"' : 'VALIDATION_ERROR_1c8001fe',
    '"VUID-vkCmdResolveImage-srcImage-00256"' : 'VALIDATION_ERROR_1c800200',
    '"VUID-vkCmdResolveImage-srcImage-00257"' : 'VALIDATION_ERROR_1c800202',
    '"VUID-vkCmdResolveImage-dstImage-00258"' : 'VALIDATION_ERROR_1c800204',
    '"VUID-vkCmdResolveImage-dstImage-00259"' : 'VALIDATION_ERROR_1c800206',
    '"VUID-vkCmdResolveImage-srcImageLayout-00260"' : 'VALIDATION_ERROR_1c800208',
    '"VUID-vkCmdResolveImage-srcImageLayout-00261"' : 'VALIDATION_ERROR_1c80020a',
    '"VUID-vkCmdResolveImage-dstImageLayout-00262"' : 'VALIDATION_ERROR_1c80020c',
    '"VUID-vkCmdResolveImage-dstImageLayout-00263"' : 'VALIDATION_ERROR_1c80020e',
    '"VUID-vkCmdResolveImage-dstImage-00264"' : 'VALIDATION_ERROR_1c800210',
    '"VUID-vkCmdResolveImage-dstImage-00265"' : 'VALIDATION_ERROR_1c800212',
    '"VUID-vkCmdResolveImage-srcImage-01386"' : 'VALIDATION_ERROR_1c800ad4',
    '"VUID-vkCmdResolveImage-srcImageLayout-01400"' : 'VALIDATION_ERROR_1c800af0',
    '"VUID-vkCmdResolveImage-dstImageLayout-01401"' : 'VALIDATION_ERROR_1c800af2',
    '"VUID-vkCmdResolveImage-srcSubresource-01709"' : 'VALIDATION_ERROR_1c800d5a',
    '"VUID-vkCmdResolveImage-dstSubresource-01710"' : 'VALIDATION_ERROR_1c800d5c',
    '"VUID-vkCmdResolveImage-srcSubresource-01711"' : 'VALIDATION_ERROR_1c800d5e',
    '"VUID-vkCmdResolveImage-dstSubresource-01712"' : 'VALIDATION_ERROR_1c800d60',
    '"VUID-vkCmdResolveImage-commandBuffer-01837"' : 'VALIDATION_ERROR_1c800e5a',
    '"VUID-vkCmdResolveImage-commandBuffer-01838"' : 'VALIDATION_ERROR_1c800e5c',
    '"VUID-vkCmdResolveImage-commandBuffer-01839"' : 'VALIDATION_ERROR_1c800e5e',
    '"VUID-vkCmdResolveImage-commandBuffer-parameter"' : 'VALIDATION_ERROR_1c802401',
    '"VUID-vkCmdResolveImage-commandBuffer-recording"' : 'VALIDATION_ERROR_1c802413',
    '"VUID-vkCmdResolveImage-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1c802415',
    '"VUID-vkCmdResolveImage-dstImage-parameter"' : 'VALIDATION_ERROR_1c807201',
    '"VUID-vkCmdResolveImage-dstImageLayout-parameter"' : 'VALIDATION_ERROR_1c807401',
    '"VUID-vkCmdResolveImage-pRegions-parameter"' : 'VALIDATION_ERROR_1c821001',
    '"VUID-vkCmdResolveImage-regionCount-arraylength"' : 'VALIDATION_ERROR_1c82ac1b',
    '"VUID-vkCmdResolveImage-srcImage-parameter"' : 'VALIDATION_ERROR_1c82ce01',
    '"VUID-vkCmdResolveImage-srcImageLayout-parameter"' : 'VALIDATION_ERROR_1c82d001',
    '"VUID-vkCmdSetBlendConstants-None-00612"' : 'VALIDATION_ERROR_1ca004c8',
    '"VUID-vkCmdSetBlendConstants-commandBuffer-parameter"' : 'VALIDATION_ERROR_1ca02401',
    '"VUID-vkCmdSetBlendConstants-commandBuffer-recording"' : 'VALIDATION_ERROR_1ca02413',
    '"VUID-vkCmdSetBlendConstants-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1ca02415',
    '"VUID-vkCmdSetDepthBias-None-00789"' : 'VALIDATION_ERROR_1cc0062a',
    '"VUID-vkCmdSetDepthBias-depthBiasClamp-00790"' : 'VALIDATION_ERROR_1cc0062c',
    '"VUID-vkCmdSetDepthBias-commandBuffer-parameter"' : 'VALIDATION_ERROR_1cc02401',
    '"VUID-vkCmdSetDepthBias-commandBuffer-recording"' : 'VALIDATION_ERROR_1cc02413',
    '"VUID-vkCmdSetDepthBias-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1cc02415',
    '"VUID-vkCmdSetDepthBounds-None-00599"' : 'VALIDATION_ERROR_1ce004ae',
    '"VUID-vkCmdSetDepthBounds-minDepthBounds-00600"' : 'VALIDATION_ERROR_1ce004b0',
    '"VUID-vkCmdSetDepthBounds-maxDepthBounds-00601"' : 'VALIDATION_ERROR_1ce004b2',
    '"VUID-vkCmdSetDepthBounds-commandBuffer-parameter"' : 'VALIDATION_ERROR_1ce02401',
    '"VUID-vkCmdSetDepthBounds-commandBuffer-recording"' : 'VALIDATION_ERROR_1ce02413',
    '"VUID-vkCmdSetDepthBounds-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1ce02415',
    '"VUID-vkCmdSetDeviceMask-deviceMask-00108"' : 'VALIDATION_ERROR_1d0000d8',
    '"VUID-vkCmdSetDeviceMask-deviceMask-00109"' : 'VALIDATION_ERROR_1d0000da',
    '"VUID-vkCmdSetDeviceMask-deviceMask-00110"' : 'VALIDATION_ERROR_1d0000dc',
    '"VUID-vkCmdSetDeviceMask-deviceMask-00111"' : 'VALIDATION_ERROR_1d0000de',
    '"VUID-vkCmdSetDeviceMask-commandBuffer-parameter"' : 'VALIDATION_ERROR_1d002401',
    '"VUID-vkCmdSetDeviceMask-commandBuffer-recording"' : 'VALIDATION_ERROR_1d002413',
    '"VUID-vkCmdSetDeviceMask-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1d002415',
    '"VUID-vkCmdSetDiscardRectangleEXT-None-00583"' : 'VALIDATION_ERROR_1d20048e',
    '"VUID-vkCmdSetDiscardRectangleEXT-firstDiscardRectangle-00585"' : 'VALIDATION_ERROR_1d200492',
    '"VUID-vkCmdSetDiscardRectangleEXT-x-00587"' : 'VALIDATION_ERROR_1d200496',
    '"VUID-vkCmdSetDiscardRectangleEXT-offset-00588"' : 'VALIDATION_ERROR_1d200498',
    '"VUID-vkCmdSetDiscardRectangleEXT-offset-00589"' : 'VALIDATION_ERROR_1d20049a',
    '"VUID-vkCmdSetDiscardRectangleEXT-commandBuffer-parameter"' : 'VALIDATION_ERROR_1d202401',
    '"VUID-vkCmdSetDiscardRectangleEXT-commandBuffer-recording"' : 'VALIDATION_ERROR_1d202413',
    '"VUID-vkCmdSetDiscardRectangleEXT-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1d202415',
    '"VUID-vkCmdSetDiscardRectangleEXT-discardRectangleCount-arraylength"' : 'VALIDATION_ERROR_1d205c1b',
    '"VUID-vkCmdSetDiscardRectangleEXT-pDiscardRectangles-parameter"' : 'VALIDATION_ERROR_1d214601',
    '"VUID-vkCmdSetEvent-commonparent"' : 'VALIDATION_ERROR_1d400009',
    '"VUID-vkCmdSetEvent-renderpass"' : 'VALIDATION_ERROR_1d400017',
    '"VUID-vkCmdSetEvent-stageMask-01149"' : 'VALIDATION_ERROR_1d4008fa',
    '"VUID-vkCmdSetEvent-stageMask-01150"' : 'VALIDATION_ERROR_1d4008fc',
    '"VUID-vkCmdSetEvent-stageMask-01151"' : 'VALIDATION_ERROR_1d4008fe',
    '"VUID-vkCmdSetEvent-commandBuffer-01152"' : 'VALIDATION_ERROR_1d400900',
    '"VUID-vkCmdSetEvent-commandBuffer-parameter"' : 'VALIDATION_ERROR_1d402401',
    '"VUID-vkCmdSetEvent-commandBuffer-recording"' : 'VALIDATION_ERROR_1d402413',
    '"VUID-vkCmdSetEvent-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1d402415',
    '"VUID-vkCmdSetEvent-event-parameter"' : 'VALIDATION_ERROR_1d407e01',
    '"VUID-vkCmdSetEvent-stageMask-parameter"' : 'VALIDATION_ERROR_1d42de01',
    '"VUID-vkCmdSetEvent-stageMask-requiredbitmask"' : 'VALIDATION_ERROR_1d42de03',
    '"VUID-vkCmdSetLineWidth-None-00787"' : 'VALIDATION_ERROR_1d600626',
    '"VUID-vkCmdSetLineWidth-lineWidth-00788"' : 'VALIDATION_ERROR_1d600628',
    '"VUID-vkCmdSetLineWidth-commandBuffer-parameter"' : 'VALIDATION_ERROR_1d602401',
    '"VUID-vkCmdSetLineWidth-commandBuffer-recording"' : 'VALIDATION_ERROR_1d602413',
    '"VUID-vkCmdSetLineWidth-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1d602415',
    '"VUID-vkCmdSetScissor-None-00590"' : 'VALIDATION_ERROR_1d80049c',
    '"VUID-vkCmdSetScissor-firstScissor-00591"' : 'VALIDATION_ERROR_1d80049e',
    '"VUID-vkCmdSetScissor-firstScissor-00592"' : 'VALIDATION_ERROR_1d8004a0',
    '"VUID-vkCmdSetScissor-firstScissor-00593"' : 'VALIDATION_ERROR_1d8004a2',
    '"VUID-vkCmdSetScissor-scissorCount-00594"' : 'VALIDATION_ERROR_1d8004a4',
    '"VUID-vkCmdSetScissor-x-00595"' : 'VALIDATION_ERROR_1d8004a6',
    '"VUID-vkCmdSetScissor-offset-00596"' : 'VALIDATION_ERROR_1d8004a8',
    '"VUID-vkCmdSetScissor-offset-00597"' : 'VALIDATION_ERROR_1d8004aa',
    '"VUID-vkCmdSetScissor-commandBuffer-parameter"' : 'VALIDATION_ERROR_1d802401',
    '"VUID-vkCmdSetScissor-commandBuffer-recording"' : 'VALIDATION_ERROR_1d802413',
    '"VUID-vkCmdSetScissor-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1d802415',
    '"VUID-vkCmdSetScissor-pScissors-parameter"' : 'VALIDATION_ERROR_1d822601',
    '"VUID-vkCmdSetScissor-scissorCount-arraylength"' : 'VALIDATION_ERROR_1d82b61b',
    '"VUID-vkCmdSetStencilCompareMask-None-00602"' : 'VALIDATION_ERROR_1da004b4',
    '"VUID-vkCmdSetStencilCompareMask-commandBuffer-parameter"' : 'VALIDATION_ERROR_1da02401',
    '"VUID-vkCmdSetStencilCompareMask-commandBuffer-recording"' : 'VALIDATION_ERROR_1da02413',
    '"VUID-vkCmdSetStencilCompareMask-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1da02415',
    '"VUID-vkCmdSetStencilCompareMask-faceMask-parameter"' : 'VALIDATION_ERROR_1da08401',
    '"VUID-vkCmdSetStencilCompareMask-faceMask-requiredbitmask"' : 'VALIDATION_ERROR_1da08403',
    '"VUID-vkCmdSetStencilReference-None-00604"' : 'VALIDATION_ERROR_1dc004b8',
    '"VUID-vkCmdSetStencilReference-commandBuffer-parameter"' : 'VALIDATION_ERROR_1dc02401',
    '"VUID-vkCmdSetStencilReference-commandBuffer-recording"' : 'VALIDATION_ERROR_1dc02413',
    '"VUID-vkCmdSetStencilReference-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1dc02415',
    '"VUID-vkCmdSetStencilReference-faceMask-parameter"' : 'VALIDATION_ERROR_1dc08401',
    '"VUID-vkCmdSetStencilReference-faceMask-requiredbitmask"' : 'VALIDATION_ERROR_1dc08403',
    '"VUID-vkCmdSetStencilWriteMask-None-00603"' : 'VALIDATION_ERROR_1de004b6',
    '"VUID-vkCmdSetStencilWriteMask-commandBuffer-parameter"' : 'VALIDATION_ERROR_1de02401',
    '"VUID-vkCmdSetStencilWriteMask-commandBuffer-recording"' : 'VALIDATION_ERROR_1de02413',
    '"VUID-vkCmdSetStencilWriteMask-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1de02415',
    '"VUID-vkCmdSetStencilWriteMask-faceMask-parameter"' : 'VALIDATION_ERROR_1de08401',
    '"VUID-vkCmdSetStencilWriteMask-faceMask-requiredbitmask"' : 'VALIDATION_ERROR_1de08403',
    '"VUID-vkCmdSetViewport-None-01221"' : 'VALIDATION_ERROR_1e00098a',
    '"VUID-vkCmdSetViewport-firstViewport-01222"' : 'VALIDATION_ERROR_1e00098c',
    '"VUID-vkCmdSetViewport-firstViewport-01223"' : 'VALIDATION_ERROR_1e00098e',
    '"VUID-vkCmdSetViewport-firstViewport-01224"' : 'VALIDATION_ERROR_1e000990',
    '"VUID-vkCmdSetViewport-viewportCount-01225"' : 'VALIDATION_ERROR_1e000992',
    '"VUID-vkCmdSetViewport-commandBuffer-parameter"' : 'VALIDATION_ERROR_1e002401',
    '"VUID-vkCmdSetViewport-commandBuffer-recording"' : 'VALIDATION_ERROR_1e002413',
    '"VUID-vkCmdSetViewport-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1e002415',
    '"VUID-vkCmdSetViewport-viewportCount-arraylength"' : 'VALIDATION_ERROR_1e030a1b',
    '"VUID-vkCmdSetViewport-pViewports-parameter"' : 'VALIDATION_ERROR_1e03fa01',
    '"VUID-vkCmdSetViewportWScalingNV-None-01322"' : 'VALIDATION_ERROR_1e200a54',
    '"VUID-vkCmdSetViewportWScalingNV-firstViewport-01323"' : 'VALIDATION_ERROR_1e200a56',
    '"VUID-vkCmdSetViewportWScalingNV-firstViewport-01324"' : 'VALIDATION_ERROR_1e200a58',
    '"VUID-vkCmdSetViewportWScalingNV-commandBuffer-parameter"' : 'VALIDATION_ERROR_1e202401',
    '"VUID-vkCmdSetViewportWScalingNV-commandBuffer-recording"' : 'VALIDATION_ERROR_1e202413',
    '"VUID-vkCmdSetViewportWScalingNV-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1e202415',
    '"VUID-vkCmdSetViewportWScalingNV-viewportCount-arraylength"' : 'VALIDATION_ERROR_1e230a1b',
    '"VUID-vkCmdSetViewportWScalingNV-pViewportWScalings-parameter"' : 'VALIDATION_ERROR_1e23fc01',
    '"VUID-vkCmdUpdateBuffer-commonparent"' : 'VALIDATION_ERROR_1e400009',
    '"VUID-vkCmdUpdateBuffer-renderpass"' : 'VALIDATION_ERROR_1e400017',
    '"VUID-vkCmdUpdateBuffer-dstOffset-00032"' : 'VALIDATION_ERROR_1e400040',
    '"VUID-vkCmdUpdateBuffer-dataSize-00033"' : 'VALIDATION_ERROR_1e400042',
    '"VUID-vkCmdUpdateBuffer-dstBuffer-00034"' : 'VALIDATION_ERROR_1e400044',
    '"VUID-vkCmdUpdateBuffer-dstBuffer-00035"' : 'VALIDATION_ERROR_1e400046',
    '"VUID-vkCmdUpdateBuffer-dstOffset-00036"' : 'VALIDATION_ERROR_1e400048',
    '"VUID-vkCmdUpdateBuffer-dataSize-00037"' : 'VALIDATION_ERROR_1e40004a',
    '"VUID-vkCmdUpdateBuffer-dataSize-00038"' : 'VALIDATION_ERROR_1e40004c',
    '"VUID-vkCmdUpdateBuffer-commandBuffer-01813"' : 'VALIDATION_ERROR_1e400e2a',
    '"VUID-vkCmdUpdateBuffer-commandBuffer-01814"' : 'VALIDATION_ERROR_1e400e2c',
    '"VUID-vkCmdUpdateBuffer-commandBuffer-parameter"' : 'VALIDATION_ERROR_1e402401',
    '"VUID-vkCmdUpdateBuffer-commandBuffer-recording"' : 'VALIDATION_ERROR_1e402413',
    '"VUID-vkCmdUpdateBuffer-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1e402415',
    '"VUID-vkCmdUpdateBuffer-dataSize-arraylength"' : 'VALIDATION_ERROR_1e403c1b',
    '"VUID-vkCmdUpdateBuffer-dstBuffer-parameter"' : 'VALIDATION_ERROR_1e406c01',
    '"VUID-vkCmdUpdateBuffer-pData-parameter"' : 'VALIDATION_ERROR_1e412201',
    '"VUID-vkCmdWaitEvents-commonparent"' : 'VALIDATION_ERROR_1e600009',
    '"VUID-vkCmdWaitEvents-srcStageMask-01158"' : 'VALIDATION_ERROR_1e60090c',
    '"VUID-vkCmdWaitEvents-srcStageMask-01159"' : 'VALIDATION_ERROR_1e60090e',
    '"VUID-vkCmdWaitEvents-dstStageMask-01160"' : 'VALIDATION_ERROR_1e600910',
    '"VUID-vkCmdWaitEvents-srcStageMask-01161"' : 'VALIDATION_ERROR_1e600912',
    '"VUID-vkCmdWaitEvents-dstStageMask-01162"' : 'VALIDATION_ERROR_1e600914',
    '"VUID-vkCmdWaitEvents-pEvents-01163"' : 'VALIDATION_ERROR_1e600916',
    '"VUID-vkCmdWaitEvents-srcStageMask-01164"' : 'VALIDATION_ERROR_1e600918',
    '"VUID-vkCmdWaitEvents-pMemoryBarriers-01165"' : 'VALIDATION_ERROR_1e60091a',
    '"VUID-vkCmdWaitEvents-pMemoryBarriers-01166"' : 'VALIDATION_ERROR_1e60091c',
    '"VUID-vkCmdWaitEvents-commandBuffer-01167"' : 'VALIDATION_ERROR_1e60091e',
    '"VUID-vkCmdWaitEvents-commandBuffer-parameter"' : 'VALIDATION_ERROR_1e602401',
    '"VUID-vkCmdWaitEvents-commandBuffer-recording"' : 'VALIDATION_ERROR_1e602413',
    '"VUID-vkCmdWaitEvents-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1e602415',
    '"VUID-vkCmdWaitEvents-dstStageMask-parameter"' : 'VALIDATION_ERROR_1e607801',
    '"VUID-vkCmdWaitEvents-dstStageMask-requiredbitmask"' : 'VALIDATION_ERROR_1e607803',
    '"VUID-vkCmdWaitEvents-eventCount-arraylength"' : 'VALIDATION_ERROR_1e60801b',
    '"VUID-vkCmdWaitEvents-pBufferMemoryBarriers-parameter"' : 'VALIDATION_ERROR_1e610401',
    '"VUID-vkCmdWaitEvents-pEvents-parameter"' : 'VALIDATION_ERROR_1e616001',
    '"VUID-vkCmdWaitEvents-pImageMemoryBarriers-parameter"' : 'VALIDATION_ERROR_1e618a01',
    '"VUID-vkCmdWaitEvents-pMemoryBarriers-parameter"' : 'VALIDATION_ERROR_1e61ac01',
    '"VUID-vkCmdWaitEvents-srcStageMask-parameter"' : 'VALIDATION_ERROR_1e62d401',
    '"VUID-vkCmdWaitEvents-srcStageMask-requiredbitmask"' : 'VALIDATION_ERROR_1e62d403',
    '"VUID-vkCmdWriteTimestamp-commonparent"' : 'VALIDATION_ERROR_1e800009',
    '"VUID-vkCmdWriteTimestamp-queryPool-00828"' : 'VALIDATION_ERROR_1e800678',
    '"VUID-vkCmdWriteTimestamp-timestampValidBits-00829"' : 'VALIDATION_ERROR_1e80067a',
    '"VUID-vkCmdWriteTimestamp-None-00830"' : 'VALIDATION_ERROR_1e80067c',
    '"VUID-vkCmdWriteTimestamp-query-00831"' : 'VALIDATION_ERROR_1e80067e',
    '"VUID-vkCmdWriteTimestamp-queryPool-01416"' : 'VALIDATION_ERROR_1e800b10',
    '"VUID-vkCmdWriteTimestamp-commandBuffer-parameter"' : 'VALIDATION_ERROR_1e802401',
    '"VUID-vkCmdWriteTimestamp-commandBuffer-recording"' : 'VALIDATION_ERROR_1e802413',
    '"VUID-vkCmdWriteTimestamp-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_1e802415',
    '"VUID-vkCmdWriteTimestamp-pipelineStage-parameter"' : 'VALIDATION_ERROR_1e828401',
    '"VUID-vkCmdWriteTimestamp-queryPool-parameter"' : 'VALIDATION_ERROR_1e829801',
    '"VUID-vkCreateAndroidSurfaceKHR-instance-parameter"' : 'VALIDATION_ERROR_1ea0bc01',
    '"VUID-vkCreateAndroidSurfaceKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_1ea0ec01',
    '"VUID-vkCreateAndroidSurfaceKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1ea11e01',
    '"VUID-vkCreateAndroidSurfaceKHR-pSurface-parameter"' : 'VALIDATION_ERROR_1ea24801',
    '"VUID-vkCreateBuffer-flags-00911"' : 'VALIDATION_ERROR_1ec0071e',
    '"VUID-vkCreateBuffer-device-parameter"' : 'VALIDATION_ERROR_1ec05601',
    '"VUID-vkCreateBuffer-pAllocator-parameter"' : 'VALIDATION_ERROR_1ec0ec01',
    '"VUID-vkCreateBuffer-pBuffer-parameter"' : 'VALIDATION_ERROR_1ec10001',
    '"VUID-vkCreateBuffer-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1ec11e01',
    '"VUID-vkCreateBufferView-device-parameter"' : 'VALIDATION_ERROR_1ee05601',
    '"VUID-vkCreateBufferView-pAllocator-parameter"' : 'VALIDATION_ERROR_1ee0ec01',
    '"VUID-vkCreateBufferView-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1ee11e01',
    '"VUID-vkCreateBufferView-pView-parameter"' : 'VALIDATION_ERROR_1ee26a01',
    '"VUID-vkCreateCommandPool-device-parameter"' : 'VALIDATION_ERROR_1f005601',
    '"VUID-vkCreateCommandPool-pAllocator-parameter"' : 'VALIDATION_ERROR_1f00ec01',
    '"VUID-vkCreateCommandPool-pCommandPool-parameter"' : 'VALIDATION_ERROR_1f011601',
    '"VUID-vkCreateCommandPool-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1f011e01',
    '"VUID-vkCreateComputePipelines-flags-00695"' : 'VALIDATION_ERROR_1f20056e',
    '"VUID-vkCreateComputePipelines-flags-00696"' : 'VALIDATION_ERROR_1f200570',
    '"VUID-vkCreateComputePipelines-createInfoCount-arraylength"' : 'VALIDATION_ERROR_1f20381b',
    '"VUID-vkCreateComputePipelines-device-parameter"' : 'VALIDATION_ERROR_1f205601',
    '"VUID-vkCreateComputePipelines-pAllocator-parameter"' : 'VALIDATION_ERROR_1f20ec01',
    '"VUID-vkCreateComputePipelines-pCreateInfos-parameter"' : 'VALIDATION_ERROR_1f212001',
    '"VUID-vkCreateComputePipelines-pPipelines-parameter"' : 'VALIDATION_ERROR_1f21e201',
    '"VUID-vkCreateComputePipelines-pipelineCache-parameter"' : 'VALIDATION_ERROR_1f228001',
    '"VUID-vkCreateComputePipelines-pipelineCache-parent"' : 'VALIDATION_ERROR_1f228007',
    '"VUID-vkCreateDebugReportCallbackEXT-instance-parameter"' : 'VALIDATION_ERROR_1f40bc01',
    '"VUID-vkCreateDebugReportCallbackEXT-pAllocator-parameter"' : 'VALIDATION_ERROR_1f40ec01',
    '"VUID-vkCreateDebugReportCallbackEXT-pCallback-parameter"' : 'VALIDATION_ERROR_1f410801',
    '"VUID-vkCreateDebugReportCallbackEXT-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1f411e01',
    '"VUID-vkCreateDescriptorPool-device-parameter"' : 'VALIDATION_ERROR_1f605601',
    '"VUID-vkCreateDescriptorPool-pAllocator-parameter"' : 'VALIDATION_ERROR_1f60ec01',
    '"VUID-vkCreateDescriptorPool-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1f611e01',
    '"VUID-vkCreateDescriptorPool-pDescriptorPool-parameter"' : 'VALIDATION_ERROR_1f612e01',
    '"VUID-vkCreateDescriptorSetLayout-device-parameter"' : 'VALIDATION_ERROR_1f805601',
    '"VUID-vkCreateDescriptorSetLayout-pAllocator-parameter"' : 'VALIDATION_ERROR_1f80ec01',
    '"VUID-vkCreateDescriptorSetLayout-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1f811e01',
    '"VUID-vkCreateDescriptorSetLayout-pSetLayout-parameter"' : 'VALIDATION_ERROR_1f822a01',
    '"VUID-vkCreateDescriptorUpdateTemplate-device-parameter"' : 'VALIDATION_ERROR_1fa05601',
    '"VUID-vkCreateDescriptorUpdateTemplate-pAllocator-parameter"' : 'VALIDATION_ERROR_1fa0ec01',
    '"VUID-vkCreateDescriptorUpdateTemplate-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1fa11e01',
    '"VUID-vkCreateDescriptorUpdateTemplate-pDescriptorUpdateTemplate-parameter"' : 'VALIDATION_ERROR_1fa13401',
    '"VUID-vkCreateDevice-ppEnabledExtensionNames-01387"' : 'VALIDATION_ERROR_1fc00ad6',
    '"VUID-vkCreateDevice-pAllocator-parameter"' : 'VALIDATION_ERROR_1fc0ec01',
    '"VUID-vkCreateDevice-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1fc11e01',
    '"VUID-vkCreateDevice-pDevice-parameter"' : 'VALIDATION_ERROR_1fc13801',
    '"VUID-vkCreateDevice-physicalDevice-parameter"' : 'VALIDATION_ERROR_1fc27a01',
    '"VUID-vkCreateDisplayModeKHR-display-parameter"' : 'VALIDATION_ERROR_1fe06001',
    '"VUID-vkCreateDisplayModeKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_1fe0ec01',
    '"VUID-vkCreateDisplayModeKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_1fe11e01',
    '"VUID-vkCreateDisplayModeKHR-pMode-parameter"' : 'VALIDATION_ERROR_1fe1bc01',
    '"VUID-vkCreateDisplayModeKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_1fe27a01',
    '"VUID-vkCreateDisplayPlaneSurfaceKHR-instance-parameter"' : 'VALIDATION_ERROR_2000bc01',
    '"VUID-vkCreateDisplayPlaneSurfaceKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_2000ec01',
    '"VUID-vkCreateDisplayPlaneSurfaceKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_20011e01',
    '"VUID-vkCreateDisplayPlaneSurfaceKHR-pSurface-parameter"' : 'VALIDATION_ERROR_20024801',
    '"VUID-vkCreateEvent-device-parameter"' : 'VALIDATION_ERROR_20205601',
    '"VUID-vkCreateEvent-pAllocator-parameter"' : 'VALIDATION_ERROR_2020ec01',
    '"VUID-vkCreateEvent-pCreateInfo-parameter"' : 'VALIDATION_ERROR_20211e01',
    '"VUID-vkCreateEvent-pEvent-parameter"' : 'VALIDATION_ERROR_20215e01',
    '"VUID-vkCreateFence-device-parameter"' : 'VALIDATION_ERROR_20405601',
    '"VUID-vkCreateFence-pAllocator-parameter"' : 'VALIDATION_ERROR_2040ec01',
    '"VUID-vkCreateFence-pCreateInfo-parameter"' : 'VALIDATION_ERROR_20411e01',
    '"VUID-vkCreateFence-pFence-parameter"' : 'VALIDATION_ERROR_20417001',
    '"VUID-vkCreateFramebuffer-device-parameter"' : 'VALIDATION_ERROR_20605601',
    '"VUID-vkCreateFramebuffer-pAllocator-parameter"' : 'VALIDATION_ERROR_2060ec01',
    '"VUID-vkCreateFramebuffer-pCreateInfo-parameter"' : 'VALIDATION_ERROR_20611e01',
    '"VUID-vkCreateFramebuffer-pFramebuffer-parameter"' : 'VALIDATION_ERROR_20617801',
    '"VUID-vkCreateGraphicsPipelines-flags-00720"' : 'VALIDATION_ERROR_208005a0',
    '"VUID-vkCreateGraphicsPipelines-flags-00721"' : 'VALIDATION_ERROR_208005a2',
    '"VUID-vkCreateGraphicsPipelines-createInfoCount-arraylength"' : 'VALIDATION_ERROR_2080381b',
    '"VUID-vkCreateGraphicsPipelines-device-parameter"' : 'VALIDATION_ERROR_20805601',
    '"VUID-vkCreateGraphicsPipelines-pAllocator-parameter"' : 'VALIDATION_ERROR_2080ec01',
    '"VUID-vkCreateGraphicsPipelines-pCreateInfos-parameter"' : 'VALIDATION_ERROR_20812001',
    '"VUID-vkCreateGraphicsPipelines-pPipelines-parameter"' : 'VALIDATION_ERROR_2081e201',
    '"VUID-vkCreateGraphicsPipelines-pipelineCache-parameter"' : 'VALIDATION_ERROR_20828001',
    '"VUID-vkCreateGraphicsPipelines-pipelineCache-parent"' : 'VALIDATION_ERROR_20828007',
    '"VUID-vkCreateIOSSurfaceMVK-instance-parameter"' : 'VALIDATION_ERROR_20a0bc01',
    '"VUID-vkCreateIOSSurfaceMVK-pAllocator-parameter"' : 'VALIDATION_ERROR_20a0ec01',
    '"VUID-vkCreateIOSSurfaceMVK-pCreateInfo-parameter"' : 'VALIDATION_ERROR_20a11e01',
    '"VUID-vkCreateIOSSurfaceMVK-pSurface-parameter"' : 'VALIDATION_ERROR_20a24801',
    '"VUID-vkCreateImage-flags-00939"' : 'VALIDATION_ERROR_20c00756',
    '"VUID-vkCreateImage-device-parameter"' : 'VALIDATION_ERROR_20c05601',
    '"VUID-vkCreateImage-pAllocator-parameter"' : 'VALIDATION_ERROR_20c0ec01',
    '"VUID-vkCreateImage-pCreateInfo-parameter"' : 'VALIDATION_ERROR_20c11e01',
    '"VUID-vkCreateImage-pImage-parameter"' : 'VALIDATION_ERROR_20c17e01',
    '"VUID-vkCreateImageView-device-parameter"' : 'VALIDATION_ERROR_20e05601',
    '"VUID-vkCreateImageView-pAllocator-parameter"' : 'VALIDATION_ERROR_20e0ec01',
    '"VUID-vkCreateImageView-pCreateInfo-parameter"' : 'VALIDATION_ERROR_20e11e01',
    '"VUID-vkCreateImageView-pView-parameter"' : 'VALIDATION_ERROR_20e26a01',
    '"VUID-vkCreateIndirectCommandsLayoutNVX-device-parameter"' : 'VALIDATION_ERROR_21005601',
    '"VUID-vkCreateIndirectCommandsLayoutNVX-pAllocator-parameter"' : 'VALIDATION_ERROR_2100ec01',
    '"VUID-vkCreateIndirectCommandsLayoutNVX-pCreateInfo-parameter"' : 'VALIDATION_ERROR_21011e01',
    '"VUID-vkCreateIndirectCommandsLayoutNVX-pIndirectCommandsLayout-parameter"' : 'VALIDATION_ERROR_21019201',
    '"VUID-vkCreateInstance-ppEnabledExtensionNames-01388"' : 'VALIDATION_ERROR_21200ad8',
    '"VUID-vkCreateInstance-pAllocator-parameter"' : 'VALIDATION_ERROR_2120ec01',
    '"VUID-vkCreateInstance-pCreateInfo-parameter"' : 'VALIDATION_ERROR_21211e01',
    '"VUID-vkCreateInstance-pInstance-parameter"' : 'VALIDATION_ERROR_21219c01',
    '"VUID-vkCreateMacOSSurfaceMVK-instance-parameter"' : 'VALIDATION_ERROR_2140bc01',
    '"VUID-vkCreateMacOSSurfaceMVK-pAllocator-parameter"' : 'VALIDATION_ERROR_2140ec01',
    '"VUID-vkCreateMacOSSurfaceMVK-pCreateInfo-parameter"' : 'VALIDATION_ERROR_21411e01',
    '"VUID-vkCreateMacOSSurfaceMVK-pSurface-parameter"' : 'VALIDATION_ERROR_21424801',
    '"VUID-vkCreateMirSurfaceKHR-instance-parameter"' : 'VALIDATION_ERROR_2160bc01',
    '"VUID-vkCreateMirSurfaceKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_2160ec01',
    '"VUID-vkCreateMirSurfaceKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_21611e01',
    '"VUID-vkCreateMirSurfaceKHR-pSurface-parameter"' : 'VALIDATION_ERROR_21624801',
    '"VUID-vkCreateObjectTableNVX-device-parameter"' : 'VALIDATION_ERROR_21805601',
    '"VUID-vkCreateObjectTableNVX-pAllocator-parameter"' : 'VALIDATION_ERROR_2180ec01',
    '"VUID-vkCreateObjectTableNVX-pCreateInfo-parameter"' : 'VALIDATION_ERROR_21811e01',
    '"VUID-vkCreateObjectTableNVX-pObjectTable-parameter"' : 'VALIDATION_ERROR_2181d001',
    '"VUID-vkCreatePipelineCache-device-parameter"' : 'VALIDATION_ERROR_21a05601',
    '"VUID-vkCreatePipelineCache-pAllocator-parameter"' : 'VALIDATION_ERROR_21a0ec01',
    '"VUID-vkCreatePipelineCache-pCreateInfo-parameter"' : 'VALIDATION_ERROR_21a11e01',
    '"VUID-vkCreatePipelineCache-pPipelineCache-parameter"' : 'VALIDATION_ERROR_21a1de01',
    '"VUID-vkCreatePipelineLayout-device-parameter"' : 'VALIDATION_ERROR_21c05601',
    '"VUID-vkCreatePipelineLayout-pAllocator-parameter"' : 'VALIDATION_ERROR_21c0ec01',
    '"VUID-vkCreatePipelineLayout-pCreateInfo-parameter"' : 'VALIDATION_ERROR_21c11e01',
    '"VUID-vkCreatePipelineLayout-pPipelineLayout-parameter"' : 'VALIDATION_ERROR_21c1e001',
    '"VUID-vkCreateQueryPool-device-parameter"' : 'VALIDATION_ERROR_21e05601',
    '"VUID-vkCreateQueryPool-pAllocator-parameter"' : 'VALIDATION_ERROR_21e0ec01',
    '"VUID-vkCreateQueryPool-pCreateInfo-parameter"' : 'VALIDATION_ERROR_21e11e01',
    '"VUID-vkCreateQueryPool-pQueryPool-parameter"' : 'VALIDATION_ERROR_21e1fa01',
    '"VUID-vkCreateRenderPass-device-parameter"' : 'VALIDATION_ERROR_22005601',
    '"VUID-vkCreateRenderPass-pAllocator-parameter"' : 'VALIDATION_ERROR_2200ec01',
    '"VUID-vkCreateRenderPass-pCreateInfo-parameter"' : 'VALIDATION_ERROR_22011e01',
    '"VUID-vkCreateRenderPass-pRenderPass-parameter"' : 'VALIDATION_ERROR_22021601',
    '"VUID-vkCreateSampler-device-parameter"' : 'VALIDATION_ERROR_22205601',
    '"VUID-vkCreateSampler-pAllocator-parameter"' : 'VALIDATION_ERROR_2220ec01',
    '"VUID-vkCreateSampler-pCreateInfo-parameter"' : 'VALIDATION_ERROR_22211e01',
    '"VUID-vkCreateSampler-pSampler-parameter"' : 'VALIDATION_ERROR_22222401',
    '"VUID-vkCreateSemaphore-device-parameter"' : 'VALIDATION_ERROR_22405601',
    '"VUID-vkCreateSemaphore-pAllocator-parameter"' : 'VALIDATION_ERROR_2240ec01',
    '"VUID-vkCreateSemaphore-pCreateInfo-parameter"' : 'VALIDATION_ERROR_22411e01',
    '"VUID-vkCreateSemaphore-pSemaphore-parameter"' : 'VALIDATION_ERROR_22422801',
    '"VUID-vkCreateShaderModule-device-parameter"' : 'VALIDATION_ERROR_22605601',
    '"VUID-vkCreateShaderModule-pAllocator-parameter"' : 'VALIDATION_ERROR_2260ec01',
    '"VUID-vkCreateShaderModule-pCreateInfo-parameter"' : 'VALIDATION_ERROR_22611e01',
    '"VUID-vkCreateShaderModule-pShaderModule-parameter"' : 'VALIDATION_ERROR_22622e01',
    '"VUID-vkCreateSharedSwapchainsKHR-device-parameter"' : 'VALIDATION_ERROR_22805601',
    '"VUID-vkCreateSharedSwapchainsKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_2280ec01',
    '"VUID-vkCreateSharedSwapchainsKHR-pCreateInfos-parameter"' : 'VALIDATION_ERROR_22812001',
    '"VUID-vkCreateSharedSwapchainsKHR-pSwapchains-parameter"' : 'VALIDATION_ERROR_22825801',
    '"VUID-vkCreateSharedSwapchainsKHR-swapchainCount-arraylength"' : 'VALIDATION_ERROR_2282f21b',
    '"VUID-vkCreateSwapchainKHR-device-parameter"' : 'VALIDATION_ERROR_22a05601',
    '"VUID-vkCreateSwapchainKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_22a0ec01',
    '"VUID-vkCreateSwapchainKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_22a11e01',
    '"VUID-vkCreateSwapchainKHR-pSwapchain-parameter"' : 'VALIDATION_ERROR_22a25201',
    '"VUID-vkCreateViSurfaceNN-instance-parameter"' : 'VALIDATION_ERROR_22c0bc01',
    '"VUID-vkCreateViSurfaceNN-pAllocator-parameter"' : 'VALIDATION_ERROR_22c0ec01',
    '"VUID-vkCreateViSurfaceNN-pCreateInfo-parameter"' : 'VALIDATION_ERROR_22c11e01',
    '"VUID-vkCreateViSurfaceNN-pSurface-parameter"' : 'VALIDATION_ERROR_22c24801',
    '"VUID-vkCreateWaylandSurfaceKHR-instance-parameter"' : 'VALIDATION_ERROR_22e0bc01',
    '"VUID-vkCreateWaylandSurfaceKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_22e0ec01',
    '"VUID-vkCreateWaylandSurfaceKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_22e11e01',
    '"VUID-vkCreateWaylandSurfaceKHR-pSurface-parameter"' : 'VALIDATION_ERROR_22e24801',
    '"VUID-vkCreateWin32SurfaceKHR-instance-parameter"' : 'VALIDATION_ERROR_2300bc01',
    '"VUID-vkCreateWin32SurfaceKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_2300ec01',
    '"VUID-vkCreateWin32SurfaceKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_23011e01',
    '"VUID-vkCreateWin32SurfaceKHR-pSurface-parameter"' : 'VALIDATION_ERROR_23024801',
    '"VUID-vkCreateXcbSurfaceKHR-instance-parameter"' : 'VALIDATION_ERROR_2320bc01',
    '"VUID-vkCreateXcbSurfaceKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_2320ec01',
    '"VUID-vkCreateXcbSurfaceKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_23211e01',
    '"VUID-vkCreateXcbSurfaceKHR-pSurface-parameter"' : 'VALIDATION_ERROR_23224801',
    '"VUID-vkCreateXlibSurfaceKHR-instance-parameter"' : 'VALIDATION_ERROR_2340bc01',
    '"VUID-vkCreateXlibSurfaceKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_2340ec01',
    '"VUID-vkCreateXlibSurfaceKHR-pCreateInfo-parameter"' : 'VALIDATION_ERROR_23411e01',
    '"VUID-vkCreateXlibSurfaceKHR-pSurface-parameter"' : 'VALIDATION_ERROR_23424801',
    '"VUID-vkDebugMarkerSetObjectNameEXT-device-parameter"' : 'VALIDATION_ERROR_23605601',
    '"VUID-vkDebugMarkerSetObjectNameEXT-pNameInfo-parameter"' : 'VALIDATION_ERROR_2361c201',
    '"VUID-vkDebugMarkerSetObjectTagEXT-device-parameter"' : 'VALIDATION_ERROR_23805601',
    '"VUID-vkDebugMarkerSetObjectTagEXT-pTagInfo-parameter"' : 'VALIDATION_ERROR_23825c01',
    '"VUID-vkDebugReportMessageEXT-object-01241"' : 'VALIDATION_ERROR_23a009b2',
    '"VUID-vkDebugReportMessageEXT-objectType-01498"' : 'VALIDATION_ERROR_23a00bb4',
    '"VUID-vkDebugReportMessageEXT-flags-parameter"' : 'VALIDATION_ERROR_23a09001',
    '"VUID-vkDebugReportMessageEXT-flags-requiredbitmask"' : 'VALIDATION_ERROR_23a09003',
    '"VUID-vkDebugReportMessageEXT-instance-parameter"' : 'VALIDATION_ERROR_23a0bc01',
    '"VUID-vkDebugReportMessageEXT-objectType-parameter"' : 'VALIDATION_ERROR_23a0da01',
    '"VUID-vkDebugReportMessageEXT-pLayerPrefix-parameter"' : 'VALIDATION_ERROR_23a1a001',
    '"VUID-vkDebugReportMessageEXT-pMessage-parameter"' : 'VALIDATION_ERROR_23a1b801',
    '"VUID-vkDestroyBuffer-buffer-00922"' : 'VALIDATION_ERROR_23c00734',
    '"VUID-vkDestroyBuffer-buffer-00923"' : 'VALIDATION_ERROR_23c00736',
    '"VUID-vkDestroyBuffer-buffer-00924"' : 'VALIDATION_ERROR_23c00738',
    '"VUID-vkDestroyBuffer-buffer-parameter"' : 'VALIDATION_ERROR_23c01a01',
    '"VUID-vkDestroyBuffer-buffer-parent"' : 'VALIDATION_ERROR_23c01a07',
    '"VUID-vkDestroyBuffer-device-parameter"' : 'VALIDATION_ERROR_23c05601',
    '"VUID-vkDestroyBuffer-pAllocator-parameter"' : 'VALIDATION_ERROR_23c0ec01',
    '"VUID-vkDestroyBufferView-bufferView-00936"' : 'VALIDATION_ERROR_23e00750',
    '"VUID-vkDestroyBufferView-bufferView-00937"' : 'VALIDATION_ERROR_23e00752',
    '"VUID-vkDestroyBufferView-bufferView-00938"' : 'VALIDATION_ERROR_23e00754',
    '"VUID-vkDestroyBufferView-bufferView-parameter"' : 'VALIDATION_ERROR_23e01c01',
    '"VUID-vkDestroyBufferView-bufferView-parent"' : 'VALIDATION_ERROR_23e01c07',
    '"VUID-vkDestroyBufferView-device-parameter"' : 'VALIDATION_ERROR_23e05601',
    '"VUID-vkDestroyBufferView-pAllocator-parameter"' : 'VALIDATION_ERROR_23e0ec01',
    '"VUID-vkDestroyCommandPool-commandPool-00041"' : 'VALIDATION_ERROR_24000052',
    '"VUID-vkDestroyCommandPool-commandPool-00042"' : 'VALIDATION_ERROR_24000054',
    '"VUID-vkDestroyCommandPool-commandPool-00043"' : 'VALIDATION_ERROR_24000056',
    '"VUID-vkDestroyCommandPool-commandPool-parameter"' : 'VALIDATION_ERROR_24002801',
    '"VUID-vkDestroyCommandPool-commandPool-parent"' : 'VALIDATION_ERROR_24002807',
    '"VUID-vkDestroyCommandPool-device-parameter"' : 'VALIDATION_ERROR_24005601',
    '"VUID-vkDestroyCommandPool-pAllocator-parameter"' : 'VALIDATION_ERROR_2400ec01',
    '"VUID-vkDestroyDebugReportCallbackEXT-instance-01242"' : 'VALIDATION_ERROR_242009b4',
    '"VUID-vkDestroyDebugReportCallbackEXT-instance-01243"' : 'VALIDATION_ERROR_242009b6',
    '"VUID-vkDestroyDebugReportCallbackEXT-callback-parameter"' : 'VALIDATION_ERROR_24201e01',
    '"VUID-vkDestroyDebugReportCallbackEXT-callback-parent"' : 'VALIDATION_ERROR_24201e07',
    '"VUID-vkDestroyDebugReportCallbackEXT-instance-parameter"' : 'VALIDATION_ERROR_2420bc01',
    '"VUID-vkDestroyDebugReportCallbackEXT-pAllocator-parameter"' : 'VALIDATION_ERROR_2420ec01',
    '"VUID-vkDestroyDescriptorPool-descriptorPool-00303"' : 'VALIDATION_ERROR_2440025e',
    '"VUID-vkDestroyDescriptorPool-descriptorPool-00304"' : 'VALIDATION_ERROR_24400260',
    '"VUID-vkDestroyDescriptorPool-descriptorPool-00305"' : 'VALIDATION_ERROR_24400262',
    '"VUID-vkDestroyDescriptorPool-descriptorPool-parameter"' : 'VALIDATION_ERROR_24404601',
    '"VUID-vkDestroyDescriptorPool-descriptorPool-parent"' : 'VALIDATION_ERROR_24404607',
    '"VUID-vkDestroyDescriptorPool-device-parameter"' : 'VALIDATION_ERROR_24405601',
    '"VUID-vkDestroyDescriptorPool-pAllocator-parameter"' : 'VALIDATION_ERROR_2440ec01',
    '"VUID-vkDestroyDescriptorSetLayout-descriptorSetLayout-00284"' : 'VALIDATION_ERROR_24600238',
    '"VUID-vkDestroyDescriptorSetLayout-descriptorSetLayout-00285"' : 'VALIDATION_ERROR_2460023a',
    '"VUID-vkDestroyDescriptorSetLayout-descriptorSetLayout-parameter"' : 'VALIDATION_ERROR_24604c01',
    '"VUID-vkDestroyDescriptorSetLayout-descriptorSetLayout-parent"' : 'VALIDATION_ERROR_24604c07',
    '"VUID-vkDestroyDescriptorSetLayout-device-parameter"' : 'VALIDATION_ERROR_24605601',
    '"VUID-vkDestroyDescriptorSetLayout-pAllocator-parameter"' : 'VALIDATION_ERROR_2460ec01',
    '"VUID-vkDestroyDescriptorUpdateTemplate-descriptorSetLayout-00356"' : 'VALIDATION_ERROR_248002c8',
    '"VUID-vkDestroyDescriptorUpdateTemplate-descriptorSetLayout-00357"' : 'VALIDATION_ERROR_248002ca',
    '"VUID-vkDestroyDescriptorUpdateTemplate-descriptorUpdateTemplate-parameter"' : 'VALIDATION_ERROR_24805201',
    '"VUID-vkDestroyDescriptorUpdateTemplate-descriptorUpdateTemplate-parent"' : 'VALIDATION_ERROR_24805207',
    '"VUID-vkDestroyDescriptorUpdateTemplate-device-parameter"' : 'VALIDATION_ERROR_24805601',
    '"VUID-vkDestroyDescriptorUpdateTemplate-pAllocator-parameter"' : 'VALIDATION_ERROR_2480ec01',
    '"VUID-vkDestroyDevice-device-00378"' : 'VALIDATION_ERROR_24a002f4',
    '"VUID-vkDestroyDevice-device-00379"' : 'VALIDATION_ERROR_24a002f6',
    '"VUID-vkDestroyDevice-device-00380"' : 'VALIDATION_ERROR_24a002f8',
    '"VUID-vkDestroyDevice-device-parameter"' : 'VALIDATION_ERROR_24a05601',
    '"VUID-vkDestroyDevice-pAllocator-parameter"' : 'VALIDATION_ERROR_24a0ec01',
    '"VUID-vkDestroyEvent-event-01145"' : 'VALIDATION_ERROR_24c008f2',
    '"VUID-vkDestroyEvent-event-01146"' : 'VALIDATION_ERROR_24c008f4',
    '"VUID-vkDestroyEvent-event-01147"' : 'VALIDATION_ERROR_24c008f6',
    '"VUID-vkDestroyEvent-device-parameter"' : 'VALIDATION_ERROR_24c05601',
    '"VUID-vkDestroyEvent-event-parameter"' : 'VALIDATION_ERROR_24c07e01',
    '"VUID-vkDestroyEvent-event-parent"' : 'VALIDATION_ERROR_24c07e07',
    '"VUID-vkDestroyEvent-pAllocator-parameter"' : 'VALIDATION_ERROR_24c0ec01',
    '"VUID-vkDestroyFence-fence-01120"' : 'VALIDATION_ERROR_24e008c0',
    '"VUID-vkDestroyFence-fence-01121"' : 'VALIDATION_ERROR_24e008c2',
    '"VUID-vkDestroyFence-fence-01122"' : 'VALIDATION_ERROR_24e008c4',
    '"VUID-vkDestroyFence-device-parameter"' : 'VALIDATION_ERROR_24e05601',
    '"VUID-vkDestroyFence-fence-parameter"' : 'VALIDATION_ERROR_24e08801',
    '"VUID-vkDestroyFence-fence-parent"' : 'VALIDATION_ERROR_24e08807',
    '"VUID-vkDestroyFence-pAllocator-parameter"' : 'VALIDATION_ERROR_24e0ec01',
    '"VUID-vkDestroyFramebuffer-framebuffer-00892"' : 'VALIDATION_ERROR_250006f8',
    '"VUID-vkDestroyFramebuffer-framebuffer-00893"' : 'VALIDATION_ERROR_250006fa',
    '"VUID-vkDestroyFramebuffer-framebuffer-00894"' : 'VALIDATION_ERROR_250006fc',
    '"VUID-vkDestroyFramebuffer-device-parameter"' : 'VALIDATION_ERROR_25005601',
    '"VUID-vkDestroyFramebuffer-framebuffer-parameter"' : 'VALIDATION_ERROR_25009401',
    '"VUID-vkDestroyFramebuffer-framebuffer-parent"' : 'VALIDATION_ERROR_25009407',
    '"VUID-vkDestroyFramebuffer-pAllocator-parameter"' : 'VALIDATION_ERROR_2500ec01',
    '"VUID-vkDestroyImage-image-01000"' : 'VALIDATION_ERROR_252007d0',
    '"VUID-vkDestroyImage-image-01001"' : 'VALIDATION_ERROR_252007d2',
    '"VUID-vkDestroyImage-image-01002"' : 'VALIDATION_ERROR_252007d4',
    '"VUID-vkDestroyImage-device-parameter"' : 'VALIDATION_ERROR_25205601',
    '"VUID-vkDestroyImage-image-parameter"' : 'VALIDATION_ERROR_2520a001',
    '"VUID-vkDestroyImage-image-parent"' : 'VALIDATION_ERROR_2520a007',
    '"VUID-vkDestroyImage-pAllocator-parameter"' : 'VALIDATION_ERROR_2520ec01',
    '"VUID-vkDestroyImageView-imageView-01026"' : 'VALIDATION_ERROR_25400804',
    '"VUID-vkDestroyImageView-imageView-01027"' : 'VALIDATION_ERROR_25400806',
    '"VUID-vkDestroyImageView-imageView-01028"' : 'VALIDATION_ERROR_25400808',
    '"VUID-vkDestroyImageView-device-parameter"' : 'VALIDATION_ERROR_25405601',
    '"VUID-vkDestroyImageView-imageView-parameter"' : 'VALIDATION_ERROR_2540b001',
    '"VUID-vkDestroyImageView-imageView-parent"' : 'VALIDATION_ERROR_2540b007',
    '"VUID-vkDestroyImageView-pAllocator-parameter"' : 'VALIDATION_ERROR_2540ec01',
    '"VUID-vkDestroyIndirectCommandsLayoutNVX-indirectCommandsLayout-01352"' : 'VALIDATION_ERROR_25600a90',
    '"VUID-vkDestroyIndirectCommandsLayoutNVX-objectTable-01353"' : 'VALIDATION_ERROR_25600a92',
    '"VUID-vkDestroyIndirectCommandsLayoutNVX-objectTable-01354"' : 'VALIDATION_ERROR_25600a94',
    '"VUID-vkDestroyIndirectCommandsLayoutNVX-device-parameter"' : 'VALIDATION_ERROR_25605601',
    '"VUID-vkDestroyIndirectCommandsLayoutNVX-indirectCommandsLayout-parameter"' : 'VALIDATION_ERROR_2560b401',
    '"VUID-vkDestroyIndirectCommandsLayoutNVX-indirectCommandsLayout-parent"' : 'VALIDATION_ERROR_2560b407',
    '"VUID-vkDestroyIndirectCommandsLayoutNVX-pAllocator-parameter"' : 'VALIDATION_ERROR_2560ec01',
    '"VUID-vkDestroyInstance-instance-00629"' : 'VALIDATION_ERROR_258004ea',
    '"VUID-vkDestroyInstance-instance-00630"' : 'VALIDATION_ERROR_258004ec',
    '"VUID-vkDestroyInstance-instance-00631"' : 'VALIDATION_ERROR_258004ee',
    '"VUID-vkDestroyInstance-instance-parameter"' : 'VALIDATION_ERROR_2580bc01',
    '"VUID-vkDestroyInstance-pAllocator-parameter"' : 'VALIDATION_ERROR_2580ec01',
    '"VUID-vkDestroyObjectTableNVX-objectTable-01361"' : 'VALIDATION_ERROR_25a00aa2',
    '"VUID-vkDestroyObjectTableNVX-objectTable-01362"' : 'VALIDATION_ERROR_25a00aa4',
    '"VUID-vkDestroyObjectTableNVX-objectTable-01363"' : 'VALIDATION_ERROR_25a00aa6',
    '"VUID-vkDestroyObjectTableNVX-device-parameter"' : 'VALIDATION_ERROR_25a05601',
    '"VUID-vkDestroyObjectTableNVX-objectTable-parameter"' : 'VALIDATION_ERROR_25a0d801',
    '"VUID-vkDestroyObjectTableNVX-objectTable-parent"' : 'VALIDATION_ERROR_25a0d807',
    '"VUID-vkDestroyObjectTableNVX-pAllocator-parameter"' : 'VALIDATION_ERROR_25a0ec01',
    '"VUID-vkDestroyPipeline-pipeline-00765"' : 'VALIDATION_ERROR_25c005fa',
    '"VUID-vkDestroyPipeline-pipeline-00766"' : 'VALIDATION_ERROR_25c005fc',
    '"VUID-vkDestroyPipeline-pipeline-00767"' : 'VALIDATION_ERROR_25c005fe',
    '"VUID-vkDestroyPipeline-device-parameter"' : 'VALIDATION_ERROR_25c05601',
    '"VUID-vkDestroyPipeline-pAllocator-parameter"' : 'VALIDATION_ERROR_25c0ec01',
    '"VUID-vkDestroyPipeline-pipeline-parameter"' : 'VALIDATION_ERROR_25c27c01',
    '"VUID-vkDestroyPipeline-pipeline-parent"' : 'VALIDATION_ERROR_25c27c07',
    '"VUID-vkDestroyPipelineCache-pipelineCache-00771"' : 'VALIDATION_ERROR_25e00606',
    '"VUID-vkDestroyPipelineCache-pipelineCache-00772"' : 'VALIDATION_ERROR_25e00608',
    '"VUID-vkDestroyPipelineCache-device-parameter"' : 'VALIDATION_ERROR_25e05601',
    '"VUID-vkDestroyPipelineCache-pAllocator-parameter"' : 'VALIDATION_ERROR_25e0ec01',
    '"VUID-vkDestroyPipelineCache-pipelineCache-parameter"' : 'VALIDATION_ERROR_25e28001',
    '"VUID-vkDestroyPipelineCache-pipelineCache-parent"' : 'VALIDATION_ERROR_25e28007',
    '"VUID-vkDestroyPipelineLayout-pipelineLayout-00299"' : 'VALIDATION_ERROR_26000256',
    '"VUID-vkDestroyPipelineLayout-pipelineLayout-00300"' : 'VALIDATION_ERROR_26000258',
    '"VUID-vkDestroyPipelineLayout-device-parameter"' : 'VALIDATION_ERROR_26005601',
    '"VUID-vkDestroyPipelineLayout-pAllocator-parameter"' : 'VALIDATION_ERROR_2600ec01',
    '"VUID-vkDestroyPipelineLayout-pipelineLayout-parameter"' : 'VALIDATION_ERROR_26028201',
    '"VUID-vkDestroyPipelineLayout-pipelineLayout-parent"' : 'VALIDATION_ERROR_26028207',
    '"VUID-vkDestroyQueryPool-queryPool-00793"' : 'VALIDATION_ERROR_26200632',
    '"VUID-vkDestroyQueryPool-queryPool-00794"' : 'VALIDATION_ERROR_26200634',
    '"VUID-vkDestroyQueryPool-queryPool-00795"' : 'VALIDATION_ERROR_26200636',
    '"VUID-vkDestroyQueryPool-device-parameter"' : 'VALIDATION_ERROR_26205601',
    '"VUID-vkDestroyQueryPool-pAllocator-parameter"' : 'VALIDATION_ERROR_2620ec01',
    '"VUID-vkDestroyQueryPool-queryPool-parameter"' : 'VALIDATION_ERROR_26229801',
    '"VUID-vkDestroyQueryPool-queryPool-parent"' : 'VALIDATION_ERROR_26229807',
    '"VUID-vkDestroyRenderPass-renderPass-00873"' : 'VALIDATION_ERROR_264006d2',
    '"VUID-vkDestroyRenderPass-renderPass-00874"' : 'VALIDATION_ERROR_264006d4',
    '"VUID-vkDestroyRenderPass-renderPass-00875"' : 'VALIDATION_ERROR_264006d6',
    '"VUID-vkDestroyRenderPass-device-parameter"' : 'VALIDATION_ERROR_26405601',
    '"VUID-vkDestroyRenderPass-pAllocator-parameter"' : 'VALIDATION_ERROR_2640ec01',
    '"VUID-vkDestroyRenderPass-renderPass-parameter"' : 'VALIDATION_ERROR_2642ae01',
    '"VUID-vkDestroyRenderPass-renderPass-parent"' : 'VALIDATION_ERROR_2642ae07',
    '"VUID-vkDestroySampler-sampler-01082"' : 'VALIDATION_ERROR_26600874',
    '"VUID-vkDestroySampler-sampler-01083"' : 'VALIDATION_ERROR_26600876',
    '"VUID-vkDestroySampler-sampler-01084"' : 'VALIDATION_ERROR_26600878',
    '"VUID-vkDestroySampler-device-parameter"' : 'VALIDATION_ERROR_26605601',
    '"VUID-vkDestroySampler-pAllocator-parameter"' : 'VALIDATION_ERROR_2660ec01',
    '"VUID-vkDestroySampler-sampler-parameter"' : 'VALIDATION_ERROR_2662b201',
    '"VUID-vkDestroySampler-sampler-parent"' : 'VALIDATION_ERROR_2662b207',
    '"VUID-vkDestroySemaphore-semaphore-01137"' : 'VALIDATION_ERROR_268008e2',
    '"VUID-vkDestroySemaphore-semaphore-01138"' : 'VALIDATION_ERROR_268008e4',
    '"VUID-vkDestroySemaphore-semaphore-01139"' : 'VALIDATION_ERROR_268008e6',
    '"VUID-vkDestroySemaphore-device-parameter"' : 'VALIDATION_ERROR_26805601',
    '"VUID-vkDestroySemaphore-pAllocator-parameter"' : 'VALIDATION_ERROR_2680ec01',
    '"VUID-vkDestroySemaphore-semaphore-parameter"' : 'VALIDATION_ERROR_2682b801',
    '"VUID-vkDestroySemaphore-semaphore-parent"' : 'VALIDATION_ERROR_2682b807',
    '"VUID-vkDestroyShaderModule-shaderModule-01092"' : 'VALIDATION_ERROR_26a00888',
    '"VUID-vkDestroyShaderModule-shaderModule-01093"' : 'VALIDATION_ERROR_26a0088a',
    '"VUID-vkDestroyShaderModule-device-parameter"' : 'VALIDATION_ERROR_26a05601',
    '"VUID-vkDestroyShaderModule-pAllocator-parameter"' : 'VALIDATION_ERROR_26a0ec01',
    '"VUID-vkDestroyShaderModule-shaderModule-parameter"' : 'VALIDATION_ERROR_26a2be01',
    '"VUID-vkDestroyShaderModule-shaderModule-parent"' : 'VALIDATION_ERROR_26a2be07',
    '"VUID-vkDestroySurfaceKHR-surface-01266"' : 'VALIDATION_ERROR_26c009e4',
    '"VUID-vkDestroySurfaceKHR-surface-01267"' : 'VALIDATION_ERROR_26c009e6',
    '"VUID-vkDestroySurfaceKHR-surface-01268"' : 'VALIDATION_ERROR_26c009e8',
    '"VUID-vkDestroySurfaceKHR-instance-parameter"' : 'VALIDATION_ERROR_26c0bc01',
    '"VUID-vkDestroySurfaceKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_26c0ec01',
    '"VUID-vkDestroySurfaceKHR-surface-parameter"' : 'VALIDATION_ERROR_26c2ec01',
    '"VUID-vkDestroySurfaceKHR-surface-parent"' : 'VALIDATION_ERROR_26c2ec07',
    '"VUID-vkDestroySwapchainKHR-commonparent"' : 'VALIDATION_ERROR_26e00009',
    '"VUID-vkDestroySwapchainKHR-swapchain-01282"' : 'VALIDATION_ERROR_26e00a04',
    '"VUID-vkDestroySwapchainKHR-swapchain-01283"' : 'VALIDATION_ERROR_26e00a06',
    '"VUID-vkDestroySwapchainKHR-swapchain-01284"' : 'VALIDATION_ERROR_26e00a08',
    '"VUID-vkDestroySwapchainKHR-device-parameter"' : 'VALIDATION_ERROR_26e05601',
    '"VUID-vkDestroySwapchainKHR-pAllocator-parameter"' : 'VALIDATION_ERROR_26e0ec01',
    '"VUID-vkDestroySwapchainKHR-swapchain-parameter"' : 'VALIDATION_ERROR_26e2f001',
    '"VUID-vkDeviceWaitIdle-device-parameter"' : 'VALIDATION_ERROR_27005601',
    '"VUID-vkDisplayPowerControlEXT-device-parameter"' : 'VALIDATION_ERROR_27205601',
    '"VUID-vkDisplayPowerControlEXT-display-parameter"' : 'VALIDATION_ERROR_27206001',
    '"VUID-vkDisplayPowerControlEXT-pDisplayPowerInfo-parameter"' : 'VALIDATION_ERROR_27214e01',
    '"VUID-vkEndCommandBuffer-commandBuffer-00059"' : 'VALIDATION_ERROR_27400076',
    '"VUID-vkEndCommandBuffer-commandBuffer-00060"' : 'VALIDATION_ERROR_27400078',
    '"VUID-vkEndCommandBuffer-commandBuffer-00061"' : 'VALIDATION_ERROR_2740007a',
    '"VUID-vkEndCommandBuffer-commandBuffer-00062"' : 'VALIDATION_ERROR_2740007c',
    '"VUID-vkEndCommandBuffer-commandBuffer-01815"' : 'VALIDATION_ERROR_27400e2e',
    '"VUID-vkEndCommandBuffer-commandBuffer-parameter"' : 'VALIDATION_ERROR_27402401',
    '"VUID-vkEnumerateDeviceExtensionProperties-pLayerName-parameter"' : 'VALIDATION_ERROR_27619e01',
    '"VUID-vkEnumerateDeviceExtensionProperties-pProperties-parameter"' : 'VALIDATION_ERROR_2761f401',
    '"VUID-vkEnumerateDeviceExtensionProperties-pPropertyCount-parameter"' : 'VALIDATION_ERROR_2761f601',
    '"VUID-vkEnumerateDeviceExtensionProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_27627a01',
    '"VUID-vkEnumerateDeviceLayerProperties-pProperties-parameter"' : 'VALIDATION_ERROR_2781f401',
    '"VUID-vkEnumerateDeviceLayerProperties-pPropertyCount-parameter"' : 'VALIDATION_ERROR_2781f601',
    '"VUID-vkEnumerateDeviceLayerProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_27827a01',
    '"VUID-vkEnumerateInstanceExtensionProperties-pLayerName-parameter"' : 'VALIDATION_ERROR_27a19e01',
    '"VUID-vkEnumerateInstanceExtensionProperties-pProperties-parameter"' : 'VALIDATION_ERROR_27a1f401',
    '"VUID-vkEnumerateInstanceExtensionProperties-pPropertyCount-parameter"' : 'VALIDATION_ERROR_27a1f601',
    '"VUID-vkEnumerateInstanceLayerProperties-pProperties-parameter"' : 'VALIDATION_ERROR_27c1f401',
    '"VUID-vkEnumerateInstanceLayerProperties-pPropertyCount-parameter"' : 'VALIDATION_ERROR_27c1f601',
    '"VUID-vkEnumeratePhysicalDeviceGroups-instance-parameter"' : 'VALIDATION_ERROR_27e0bc01',
    '"VUID-vkEnumeratePhysicalDeviceGroups-pPhysicalDeviceGroupCount-parameter"' : 'VALIDATION_ERROR_27e1d801',
    '"VUID-vkEnumeratePhysicalDeviceGroups-pPhysicalDeviceGroupProperties-parameter"' : 'VALIDATION_ERROR_27e1da01',
    '"VUID-vkEnumeratePhysicalDevices-instance-parameter"' : 'VALIDATION_ERROR_2800bc01',
    '"VUID-vkEnumeratePhysicalDevices-pPhysicalDeviceCount-parameter"' : 'VALIDATION_ERROR_2801d601',
    '"VUID-vkEnumeratePhysicalDevices-pPhysicalDevices-parameter"' : 'VALIDATION_ERROR_2801dc01',
    '"VUID-vkFlushMappedMemoryRanges-device-parameter"' : 'VALIDATION_ERROR_28205601',
    '"VUID-vkFlushMappedMemoryRanges-memoryRangeCount-arraylength"' : 'VALIDATION_ERROR_2820c81b',
    '"VUID-vkFlushMappedMemoryRanges-pMemoryRanges-parameter"' : 'VALIDATION_ERROR_2821b201',
    '"VUID-vkFreeCommandBuffers-pCommandBuffers-00047"' : 'VALIDATION_ERROR_2840005e',
    '"VUID-vkFreeCommandBuffers-pCommandBuffers-00048"' : 'VALIDATION_ERROR_28400060',
    '"VUID-vkFreeCommandBuffers-commandBufferCount-arraylength"' : 'VALIDATION_ERROR_2840261b',
    '"VUID-vkFreeCommandBuffers-commandPool-parameter"' : 'VALIDATION_ERROR_28402801',
    '"VUID-vkFreeCommandBuffers-commandPool-parent"' : 'VALIDATION_ERROR_28402807',
    '"VUID-vkFreeCommandBuffers-device-parameter"' : 'VALIDATION_ERROR_28405601',
    '"VUID-vkFreeCommandBuffers-pCommandBuffers-parent"' : 'VALIDATION_ERROR_28411407',
    '"VUID-vkFreeDescriptorSets-pDescriptorSets-00309"' : 'VALIDATION_ERROR_2860026a',
    '"VUID-vkFreeDescriptorSets-pDescriptorSets-00310"' : 'VALIDATION_ERROR_2860026c',
    '"VUID-vkFreeDescriptorSets-pDescriptorSets-00311"' : 'VALIDATION_ERROR_2860026e',
    '"VUID-vkFreeDescriptorSets-descriptorPool-00312"' : 'VALIDATION_ERROR_28600270',
    '"VUID-vkFreeDescriptorSets-descriptorPool-parameter"' : 'VALIDATION_ERROR_28604601',
    '"VUID-vkFreeDescriptorSets-descriptorPool-parent"' : 'VALIDATION_ERROR_28604607',
    '"VUID-vkFreeDescriptorSets-descriptorSetCount-arraylength"' : 'VALIDATION_ERROR_28604a1b',
    '"VUID-vkFreeDescriptorSets-device-parameter"' : 'VALIDATION_ERROR_28605601',
    '"VUID-vkFreeDescriptorSets-pDescriptorSets-parent"' : 'VALIDATION_ERROR_28613007',
    '"VUID-vkFreeMemory-memory-00677"' : 'VALIDATION_ERROR_2880054a',
    '"VUID-vkFreeMemory-device-parameter"' : 'VALIDATION_ERROR_28805601',
    '"VUID-vkFreeMemory-memory-parameter"' : 'VALIDATION_ERROR_2880c601',
    '"VUID-vkFreeMemory-memory-parent"' : 'VALIDATION_ERROR_2880c607',
    '"VUID-vkFreeMemory-pAllocator-parameter"' : 'VALIDATION_ERROR_2880ec01',
    '"VUID-vkGetBufferMemoryRequirements-buffer-parameter"' : 'VALIDATION_ERROR_28a01a01',
    '"VUID-vkGetBufferMemoryRequirements-buffer-parent"' : 'VALIDATION_ERROR_28a01a07',
    '"VUID-vkGetBufferMemoryRequirements-device-parameter"' : 'VALIDATION_ERROR_28a05601',
    '"VUID-vkGetBufferMemoryRequirements-pMemoryRequirements-parameter"' : 'VALIDATION_ERROR_28a1b401',
    '"VUID-vkGetDeviceGroupPeerMemoryFeatures-heapIndex-00691"' : 'VALIDATION_ERROR_28c00566',
    '"VUID-vkGetDeviceGroupPeerMemoryFeatures-localDeviceIndex-00692"' : 'VALIDATION_ERROR_28c00568',
    '"VUID-vkGetDeviceGroupPeerMemoryFeatures-remoteDeviceIndex-00693"' : 'VALIDATION_ERROR_28c0056a',
    '"VUID-vkGetDeviceGroupPeerMemoryFeatures-localDeviceIndex-00694"' : 'VALIDATION_ERROR_28c0056c',
    '"VUID-vkGetDeviceGroupPeerMemoryFeatures-device-parameter"' : 'VALIDATION_ERROR_28c05601',
    '"VUID-vkGetDeviceGroupPeerMemoryFeatures-pPeerMemoryFeatures-parameter"' : 'VALIDATION_ERROR_28c1d401',
    '"VUID-vkGetDeviceGroupPeerMemoryFeatures-pPeerMemoryFeatures-requiredbitmask"' : 'VALIDATION_ERROR_28c1d403',
    '"VUID-vkGetDeviceGroupPresentCapabilitiesKHR-device-parameter"' : 'VALIDATION_ERROR_28e05601',
    '"VUID-vkGetDeviceGroupPresentCapabilitiesKHR-pDeviceGroupPresentCapabilities-parameter"' : 'VALIDATION_ERROR_28e13c01',
    '"VUID-vkGetDeviceGroupSurfacePresentModesKHR-commonparent"' : 'VALIDATION_ERROR_29000009',
    '"VUID-vkGetDeviceGroupSurfacePresentModesKHR-device-parameter"' : 'VALIDATION_ERROR_29005601',
    '"VUID-vkGetDeviceGroupSurfacePresentModesKHR-pModes-parameter"' : 'VALIDATION_ERROR_2901be01',
    '"VUID-vkGetDeviceGroupSurfacePresentModesKHR-surface-parameter"' : 'VALIDATION_ERROR_2902ec01',
    '"VUID-vkGetDeviceMemoryCommitment-memory-00690"' : 'VALIDATION_ERROR_29200564',
    '"VUID-vkGetDeviceMemoryCommitment-device-parameter"' : 'VALIDATION_ERROR_29205601',
    '"VUID-vkGetDeviceMemoryCommitment-memory-parameter"' : 'VALIDATION_ERROR_2920c601',
    '"VUID-vkGetDeviceMemoryCommitment-memory-parent"' : 'VALIDATION_ERROR_2920c607',
    '"VUID-vkGetDeviceMemoryCommitment-pCommittedMemoryInBytes-parameter"' : 'VALIDATION_ERROR_29211801',
    '"VUID-vkGetDeviceProcAddr-device-parameter"' : 'VALIDATION_ERROR_29405601',
    '"VUID-vkGetDeviceProcAddr-pName-parameter"' : 'VALIDATION_ERROR_2941c001',
    '"VUID-vkGetDeviceQueue-queueFamilyIndex-00384"' : 'VALIDATION_ERROR_29600300',
    '"VUID-vkGetDeviceQueue-queueIndex-00385"' : 'VALIDATION_ERROR_29600302',
    '"VUID-vkGetDeviceQueue-flags-01841"' : 'VALIDATION_ERROR_29600e62',
    '"VUID-vkGetDeviceQueue-device-parameter"' : 'VALIDATION_ERROR_29605601',
    '"VUID-vkGetDeviceQueue-pQueue-parameter"' : 'VALIDATION_ERROR_2961fc01',
    '"VUID-vkGetDisplayModePropertiesKHR-display-parameter"' : 'VALIDATION_ERROR_29806001',
    '"VUID-vkGetDisplayModePropertiesKHR-pProperties-parameter"' : 'VALIDATION_ERROR_2981f401',
    '"VUID-vkGetDisplayModePropertiesKHR-pPropertyCount-parameter"' : 'VALIDATION_ERROR_2981f601',
    '"VUID-vkGetDisplayModePropertiesKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_29827a01',
    '"VUID-vkGetDisplayPlaneCapabilitiesKHR-mode-parameter"' : 'VALIDATION_ERROR_29a0ce01',
    '"VUID-vkGetDisplayPlaneCapabilitiesKHR-pCapabilities-parameter"' : 'VALIDATION_ERROR_29a10a01',
    '"VUID-vkGetDisplayPlaneCapabilitiesKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_29a27a01',
    '"VUID-vkGetDisplayPlaneSupportedDisplaysKHR-planeIndex-01249"' : 'VALIDATION_ERROR_29c009c2',
    '"VUID-vkGetDisplayPlaneSupportedDisplaysKHR-pDisplayCount-parameter"' : 'VALIDATION_ERROR_29c14a01',
    '"VUID-vkGetDisplayPlaneSupportedDisplaysKHR-pDisplays-parameter"' : 'VALIDATION_ERROR_29c15201',
    '"VUID-vkGetDisplayPlaneSupportedDisplaysKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_29c27a01',
    '"VUID-vkGetEventStatus-device-parameter"' : 'VALIDATION_ERROR_29e05601',
    '"VUID-vkGetEventStatus-event-parameter"' : 'VALIDATION_ERROR_29e07e01',
    '"VUID-vkGetEventStatus-event-parent"' : 'VALIDATION_ERROR_29e07e07',
    '"VUID-vkGetFenceStatus-device-parameter"' : 'VALIDATION_ERROR_2a005601',
    '"VUID-vkGetFenceStatus-fence-parameter"' : 'VALIDATION_ERROR_2a008801',
    '"VUID-vkGetFenceStatus-fence-parent"' : 'VALIDATION_ERROR_2a008807',
    '"VUID-vkGetImageMemoryRequirements-image-01588"' : 'VALIDATION_ERROR_2a200c68',
    '"VUID-vkGetImageMemoryRequirements-device-parameter"' : 'VALIDATION_ERROR_2a205601',
    '"VUID-vkGetImageMemoryRequirements-image-parameter"' : 'VALIDATION_ERROR_2a20a001',
    '"VUID-vkGetImageMemoryRequirements-image-parent"' : 'VALIDATION_ERROR_2a20a007',
    '"VUID-vkGetImageMemoryRequirements-pMemoryRequirements-parameter"' : 'VALIDATION_ERROR_2a21b401',
    '"VUID-vkGetImageSparseMemoryRequirements-device-parameter"' : 'VALIDATION_ERROR_2a405601',
    '"VUID-vkGetImageSparseMemoryRequirements-image-parameter"' : 'VALIDATION_ERROR_2a40a001',
    '"VUID-vkGetImageSparseMemoryRequirements-image-parent"' : 'VALIDATION_ERROR_2a40a007',
    '"VUID-vkGetImageSparseMemoryRequirements-pSparseMemoryRequirementCount-parameter"' : 'VALIDATION_ERROR_2a423601',
    '"VUID-vkGetImageSparseMemoryRequirements-pSparseMemoryRequirements-parameter"' : 'VALIDATION_ERROR_2a423801',
    '"VUID-vkGetImageSubresourceLayout-image-00996"' : 'VALIDATION_ERROR_2a6007c8',
    '"VUID-vkGetImageSubresourceLayout-aspectMask-00997"' : 'VALIDATION_ERROR_2a6007ca',
    '"VUID-vkGetImageSubresourceLayout-format-01581"' : 'VALIDATION_ERROR_2a600c5a',
    '"VUID-vkGetImageSubresourceLayout-format-01582"' : 'VALIDATION_ERROR_2a600c5c',
    '"VUID-vkGetImageSubresourceLayout-mipLevel-01716"' : 'VALIDATION_ERROR_2a600d68',
    '"VUID-vkGetImageSubresourceLayout-arrayLayer-01717"' : 'VALIDATION_ERROR_2a600d6a',
    '"VUID-vkGetImageSubresourceLayout-image-01895"' : 'VALIDATION_ERROR_2a600ece',
    '"VUID-vkGetImageSubresourceLayout-device-parameter"' : 'VALIDATION_ERROR_2a605601',
    '"VUID-vkGetImageSubresourceLayout-image-parameter"' : 'VALIDATION_ERROR_2a60a001',
    '"VUID-vkGetImageSubresourceLayout-image-parent"' : 'VALIDATION_ERROR_2a60a007',
    '"VUID-vkGetImageSubresourceLayout-pLayout-parameter"' : 'VALIDATION_ERROR_2a61a201',
    '"VUID-vkGetImageSubresourceLayout-pSubresource-parameter"' : 'VALIDATION_ERROR_2a624401',
    '"VUID-vkGetInstanceProcAddr-instance-parameter"' : 'VALIDATION_ERROR_2a80bc01',
    '"VUID-vkGetInstanceProcAddr-pName-parameter"' : 'VALIDATION_ERROR_2a81c001',
    '"VUID-vkGetMemoryFdKHR-device-parameter"' : 'VALIDATION_ERROR_2aa05601',
    '"VUID-vkGetMemoryFdKHR-pFd-parameter"' : 'VALIDATION_ERROR_2aa16c01',
    '"VUID-vkGetMemoryFdKHR-pGetFdInfo-parameter"' : 'VALIDATION_ERROR_2aa39e01',
    '"VUID-vkGetMemoryFdPropertiesKHR-fd-00673"' : 'VALIDATION_ERROR_2ac00542',
    '"VUID-vkGetMemoryFdPropertiesKHR-handleType-00674"' : 'VALIDATION_ERROR_2ac00544',
    '"VUID-vkGetMemoryFdPropertiesKHR-device-parameter"' : 'VALIDATION_ERROR_2ac05601',
    '"VUID-vkGetMemoryFdPropertiesKHR-handleType-parameter"' : 'VALIDATION_ERROR_2ac09c01',
    '"VUID-vkGetMemoryFdPropertiesKHR-pMemoryFdProperties-parameter"' : 'VALIDATION_ERROR_2ac1ae01',
    '"VUID-vkGetMemoryWin32HandleKHR-device-parameter"' : 'VALIDATION_ERROR_2ae05601',
    '"VUID-vkGetMemoryWin32HandleKHR-pHandle-parameter"' : 'VALIDATION_ERROR_2ae17c01',
    '"VUID-vkGetMemoryWin32HandleKHR-pGetWin32HandleInfo-parameter"' : 'VALIDATION_ERROR_2ae3a001',
    '"VUID-vkGetMemoryWin32HandleNV-handleType-01326"' : 'VALIDATION_ERROR_2b000a5c',
    '"VUID-vkGetMemoryWin32HandleNV-device-parameter"' : 'VALIDATION_ERROR_2b005601',
    '"VUID-vkGetMemoryWin32HandleNV-handleType-parameter"' : 'VALIDATION_ERROR_2b009c01',
    '"VUID-vkGetMemoryWin32HandleNV-handleType-requiredbitmask"' : 'VALIDATION_ERROR_2b009c03',
    '"VUID-vkGetMemoryWin32HandleNV-memory-parameter"' : 'VALIDATION_ERROR_2b00c601',
    '"VUID-vkGetMemoryWin32HandleNV-memory-parent"' : 'VALIDATION_ERROR_2b00c607',
    '"VUID-vkGetMemoryWin32HandleNV-pHandle-parameter"' : 'VALIDATION_ERROR_2b017c01',
    '"VUID-vkGetMemoryWin32HandlePropertiesKHR-handle-00665"' : 'VALIDATION_ERROR_2b200532',
    '"VUID-vkGetMemoryWin32HandlePropertiesKHR-handleType-00666"' : 'VALIDATION_ERROR_2b200534',
    '"VUID-vkGetMemoryWin32HandlePropertiesKHR-device-parameter"' : 'VALIDATION_ERROR_2b205601',
    '"VUID-vkGetMemoryWin32HandlePropertiesKHR-handleType-parameter"' : 'VALIDATION_ERROR_2b209c01',
    '"VUID-vkGetMemoryWin32HandlePropertiesKHR-pMemoryWin32HandleProperties-parameter"' : 'VALIDATION_ERROR_2b21b601',
    '"VUID-vkGetPastPresentationTimingGOOGLE-commonparent"' : 'VALIDATION_ERROR_2b400009',
    '"VUID-vkGetPastPresentationTimingGOOGLE-device-parameter"' : 'VALIDATION_ERROR_2b405601',
    '"VUID-vkGetPastPresentationTimingGOOGLE-pPresentationTimingCount-parameter"' : 'VALIDATION_ERROR_2b41ec01',
    '"VUID-vkGetPastPresentationTimingGOOGLE-pPresentationTimings-parameter"' : 'VALIDATION_ERROR_2b41ee01',
    '"VUID-vkGetPastPresentationTimingGOOGLE-swapchain-parameter"' : 'VALIDATION_ERROR_2b42f001',
    '"VUID-vkGetPhysicalDeviceDisplayPlanePropertiesKHR-pProperties-parameter"' : 'VALIDATION_ERROR_2b61f401',
    '"VUID-vkGetPhysicalDeviceDisplayPlanePropertiesKHR-pPropertyCount-parameter"' : 'VALIDATION_ERROR_2b61f601',
    '"VUID-vkGetPhysicalDeviceDisplayPlanePropertiesKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2b627a01',
    '"VUID-vkGetPhysicalDeviceDisplayPropertiesKHR-pProperties-parameter"' : 'VALIDATION_ERROR_2b81f401',
    '"VUID-vkGetPhysicalDeviceDisplayPropertiesKHR-pPropertyCount-parameter"' : 'VALIDATION_ERROR_2b81f601',
    '"VUID-vkGetPhysicalDeviceDisplayPropertiesKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2b827a01',
    '"VUID-vkGetPhysicalDeviceExternalBufferProperties-pExternalBufferInfo-parameter"' : 'VALIDATION_ERROR_2ba16201',
    '"VUID-vkGetPhysicalDeviceExternalBufferProperties-pExternalBufferProperties-parameter"' : 'VALIDATION_ERROR_2ba16401',
    '"VUID-vkGetPhysicalDeviceExternalBufferProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_2ba27a01',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-externalHandleType-parameter"' : 'VALIDATION_ERROR_2bc08201',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-flags-parameter"' : 'VALIDATION_ERROR_2bc09001',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-format-parameter"' : 'VALIDATION_ERROR_2bc09201',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-pExternalImageFormatProperties-parameter"' : 'VALIDATION_ERROR_2bc16601',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-physicalDevice-parameter"' : 'VALIDATION_ERROR_2bc27a01',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-tiling-parameter"' : 'VALIDATION_ERROR_2bc2fa01',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-type-parameter"' : 'VALIDATION_ERROR_2bc30401',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-usage-parameter"' : 'VALIDATION_ERROR_2bc30601',
    '"VUID-vkGetPhysicalDeviceExternalImageFormatPropertiesNV-usage-requiredbitmask"' : 'VALIDATION_ERROR_2bc30603',
    '"VUID-vkGetPhysicalDeviceExternalSemaphoreProperties-pExternalSemaphoreInfo-parameter"' : 'VALIDATION_ERROR_2be16801',
    '"VUID-vkGetPhysicalDeviceExternalSemaphoreProperties-pExternalSemaphoreProperties-parameter"' : 'VALIDATION_ERROR_2be16a01',
    '"VUID-vkGetPhysicalDeviceExternalSemaphoreProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_2be27a01',
    '"VUID-vkGetPhysicalDeviceFeatures-pFeatures-parameter"' : 'VALIDATION_ERROR_2c016e01',
    '"VUID-vkGetPhysicalDeviceFeatures-physicalDevice-parameter"' : 'VALIDATION_ERROR_2c027a01',
    '"VUID-vkGetPhysicalDeviceFeatures2-pFeatures-parameter"' : 'VALIDATION_ERROR_2c216e01',
    '"VUID-vkGetPhysicalDeviceFeatures2-physicalDevice-parameter"' : 'VALIDATION_ERROR_2c227a01',
    '"VUID-vkGetPhysicalDeviceFormatProperties-format-parameter"' : 'VALIDATION_ERROR_2c409201',
    '"VUID-vkGetPhysicalDeviceFormatProperties-pFormatProperties-parameter"' : 'VALIDATION_ERROR_2c417601',
    '"VUID-vkGetPhysicalDeviceFormatProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_2c427a01',
    '"VUID-vkGetPhysicalDeviceFormatProperties2-format-parameter"' : 'VALIDATION_ERROR_2c609201',
    '"VUID-vkGetPhysicalDeviceFormatProperties2-pFormatProperties-parameter"' : 'VALIDATION_ERROR_2c617601',
    '"VUID-vkGetPhysicalDeviceFormatProperties2-physicalDevice-parameter"' : 'VALIDATION_ERROR_2c627a01',
    '"VUID-vkGetPhysicalDeviceGeneratedCommandsPropertiesNVX-pFeatures-parameter"' : 'VALIDATION_ERROR_2c816e01',
    '"VUID-vkGetPhysicalDeviceGeneratedCommandsPropertiesNVX-pLimits-parameter"' : 'VALIDATION_ERROR_2c81a401',
    '"VUID-vkGetPhysicalDeviceGeneratedCommandsPropertiesNVX-physicalDevice-parameter"' : 'VALIDATION_ERROR_2c827a01',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties-flags-parameter"' : 'VALIDATION_ERROR_2ca09001',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties-format-parameter"' : 'VALIDATION_ERROR_2ca09201',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties-pImageFormatProperties-parameter"' : 'VALIDATION_ERROR_2ca18401',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_2ca27a01',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties-tiling-parameter"' : 'VALIDATION_ERROR_2ca2fa01',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties-type-parameter"' : 'VALIDATION_ERROR_2ca30401',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties-usage-parameter"' : 'VALIDATION_ERROR_2ca30601',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties-usage-requiredbitmask"' : 'VALIDATION_ERROR_2ca30603',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties2-pNext-01868"' : 'VALIDATION_ERROR_2cc00e98',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties2-pImageFormatInfo-parameter"' : 'VALIDATION_ERROR_2cc18201',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties2-pImageFormatProperties-parameter"' : 'VALIDATION_ERROR_2cc18401',
    '"VUID-vkGetPhysicalDeviceImageFormatProperties2-physicalDevice-parameter"' : 'VALIDATION_ERROR_2cc27a01',
    '"VUID-vkGetPhysicalDeviceMemoryProperties-pMemoryProperties-parameter"' : 'VALIDATION_ERROR_2ce1b001',
    '"VUID-vkGetPhysicalDeviceMemoryProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_2ce27a01',
    '"VUID-vkGetPhysicalDeviceMemoryProperties2-pMemoryProperties-parameter"' : 'VALIDATION_ERROR_2d01b001',
    '"VUID-vkGetPhysicalDeviceMemoryProperties2-physicalDevice-parameter"' : 'VALIDATION_ERROR_2d027a01',
    '"VUID-vkGetPhysicalDeviceMirPresentationSupportKHR-queueFamilyIndex-01265"' : 'VALIDATION_ERROR_2d2009e2',
    '"VUID-vkGetPhysicalDeviceMirPresentationSupportKHR-connection-parameter"' : 'VALIDATION_ERROR_2d203001',
    '"VUID-vkGetPhysicalDeviceMirPresentationSupportKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2d227a01',
    '"VUID-vkGetPhysicalDevicePresentRectanglesKHR-commonparent"' : 'VALIDATION_ERROR_2d400009',
    '"VUID-vkGetPhysicalDevicePresentRectanglesKHR-pRectCount-parameter"' : 'VALIDATION_ERROR_2d420a01',
    '"VUID-vkGetPhysicalDevicePresentRectanglesKHR-pRects-parameter"' : 'VALIDATION_ERROR_2d420e01',
    '"VUID-vkGetPhysicalDevicePresentRectanglesKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2d427a01',
    '"VUID-vkGetPhysicalDevicePresentRectanglesKHR-surface-parameter"' : 'VALIDATION_ERROR_2d42ec01',
    '"VUID-vkGetPhysicalDeviceProperties-pProperties-parameter"' : 'VALIDATION_ERROR_2d61f401',
    '"VUID-vkGetPhysicalDeviceProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_2d627a01',
    '"VUID-vkGetPhysicalDeviceProperties2-pProperties-parameter"' : 'VALIDATION_ERROR_2d81f401',
    '"VUID-vkGetPhysicalDeviceProperties2-physicalDevice-parameter"' : 'VALIDATION_ERROR_2d827a01',
    '"VUID-vkGetPhysicalDeviceQueueFamilyProperties-pQueueFamilyProperties-parameter"' : 'VALIDATION_ERROR_2da20001',
    '"VUID-vkGetPhysicalDeviceQueueFamilyProperties-pQueueFamilyPropertyCount-parameter"' : 'VALIDATION_ERROR_2da20201',
    '"VUID-vkGetPhysicalDeviceQueueFamilyProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_2da27a01',
    '"VUID-vkGetPhysicalDeviceQueueFamilyProperties2-pQueueFamilyProperties-parameter"' : 'VALIDATION_ERROR_2dc20001',
    '"VUID-vkGetPhysicalDeviceQueueFamilyProperties2-pQueueFamilyPropertyCount-parameter"' : 'VALIDATION_ERROR_2dc20201',
    '"VUID-vkGetPhysicalDeviceQueueFamilyProperties2-physicalDevice-parameter"' : 'VALIDATION_ERROR_2dc27a01',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-samples-01094"' : 'VALIDATION_ERROR_2de0088c',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-format-parameter"' : 'VALIDATION_ERROR_2de09201',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-pProperties-parameter"' : 'VALIDATION_ERROR_2de1f401',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-pPropertyCount-parameter"' : 'VALIDATION_ERROR_2de1f601',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_2de27a01',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-samples-parameter"' : 'VALIDATION_ERROR_2de2b401',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-tiling-parameter"' : 'VALIDATION_ERROR_2de2fa01',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-type-parameter"' : 'VALIDATION_ERROR_2de30401',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-usage-parameter"' : 'VALIDATION_ERROR_2de30601',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties-usage-requiredbitmask"' : 'VALIDATION_ERROR_2de30603',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties2-pFormatInfo-parameter"' : 'VALIDATION_ERROR_2e017401',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties2-pProperties-parameter"' : 'VALIDATION_ERROR_2e01f401',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties2-pPropertyCount-parameter"' : 'VALIDATION_ERROR_2e01f601',
    '"VUID-vkGetPhysicalDeviceSparseImageFormatProperties2-physicalDevice-parameter"' : 'VALIDATION_ERROR_2e027a01',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilities2EXT-commonparent"' : 'VALIDATION_ERROR_2e200009',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilities2EXT-pSurfaceCapabilities-parameter"' : 'VALIDATION_ERROR_2e224a01',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilities2EXT-physicalDevice-parameter"' : 'VALIDATION_ERROR_2e227a01',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilities2EXT-surface-parameter"' : 'VALIDATION_ERROR_2e22ec01',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilities2KHR-pSurfaceCapabilities-parameter"' : 'VALIDATION_ERROR_2e424a01',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilities2KHR-pSurfaceInfo-parameter"' : 'VALIDATION_ERROR_2e425001',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilities2KHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2e427a01',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilitiesKHR-commonparent"' : 'VALIDATION_ERROR_2e600009',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilitiesKHR-pSurfaceCapabilities-parameter"' : 'VALIDATION_ERROR_2e624a01',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilitiesKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2e627a01',
    '"VUID-vkGetPhysicalDeviceSurfaceCapabilitiesKHR-surface-parameter"' : 'VALIDATION_ERROR_2e62ec01',
    '"VUID-vkGetPhysicalDeviceSurfaceFormats2KHR-pSurfaceFormatCount-parameter"' : 'VALIDATION_ERROR_2e824c01',
    '"VUID-vkGetPhysicalDeviceSurfaceFormats2KHR-pSurfaceFormats-parameter"' : 'VALIDATION_ERROR_2e824e01',
    '"VUID-vkGetPhysicalDeviceSurfaceFormats2KHR-pSurfaceInfo-parameter"' : 'VALIDATION_ERROR_2e825001',
    '"VUID-vkGetPhysicalDeviceSurfaceFormats2KHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2e827a01',
    '"VUID-vkGetPhysicalDeviceSurfaceFormatsKHR-commonparent"' : 'VALIDATION_ERROR_2ea00009',
    '"VUID-vkGetPhysicalDeviceSurfaceFormatsKHR-pSurfaceFormatCount-parameter"' : 'VALIDATION_ERROR_2ea24c01',
    '"VUID-vkGetPhysicalDeviceSurfaceFormatsKHR-pSurfaceFormats-parameter"' : 'VALIDATION_ERROR_2ea24e01',
    '"VUID-vkGetPhysicalDeviceSurfaceFormatsKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2ea27a01',
    '"VUID-vkGetPhysicalDeviceSurfaceFormatsKHR-surface-parameter"' : 'VALIDATION_ERROR_2ea2ec01',
    '"VUID-vkGetPhysicalDeviceSurfacePresentModesKHR-commonparent"' : 'VALIDATION_ERROR_2ec00009',
    '"VUID-vkGetPhysicalDeviceSurfacePresentModesKHR-pPresentModeCount-parameter"' : 'VALIDATION_ERROR_2ec1e801',
    '"VUID-vkGetPhysicalDeviceSurfacePresentModesKHR-pPresentModes-parameter"' : 'VALIDATION_ERROR_2ec1ea01',
    '"VUID-vkGetPhysicalDeviceSurfacePresentModesKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2ec27a01',
    '"VUID-vkGetPhysicalDeviceSurfacePresentModesKHR-surface-parameter"' : 'VALIDATION_ERROR_2ec2ec01',
    '"VUID-vkGetPhysicalDeviceSurfaceSupportKHR-commonparent"' : 'VALIDATION_ERROR_2ee00009',
    '"VUID-vkGetPhysicalDeviceSurfaceSupportKHR-queueFamilyIndex-01269"' : 'VALIDATION_ERROR_2ee009ea',
    '"VUID-vkGetPhysicalDeviceSurfaceSupportKHR-pSupported-parameter"' : 'VALIDATION_ERROR_2ee24601',
    '"VUID-vkGetPhysicalDeviceSurfaceSupportKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2ee27a01',
    '"VUID-vkGetPhysicalDeviceSurfaceSupportKHR-surface-parameter"' : 'VALIDATION_ERROR_2ee2ec01',
    '"VUID-vkGetPhysicalDeviceWaylandPresentationSupportKHR-queueFamilyIndex-01306"' : 'VALIDATION_ERROR_2f000a34',
    '"VUID-vkGetPhysicalDeviceWaylandPresentationSupportKHR-display-parameter"' : 'VALIDATION_ERROR_2f006001',
    '"VUID-vkGetPhysicalDeviceWaylandPresentationSupportKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2f027a01',
    '"VUID-vkGetPhysicalDeviceWin32PresentationSupportKHR-queueFamilyIndex-01309"' : 'VALIDATION_ERROR_2f200a3a',
    '"VUID-vkGetPhysicalDeviceWin32PresentationSupportKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2f227a01',
    '"VUID-vkGetPhysicalDeviceXcbPresentationSupportKHR-queueFamilyIndex-01312"' : 'VALIDATION_ERROR_2f400a40',
    '"VUID-vkGetPhysicalDeviceXcbPresentationSupportKHR-connection-parameter"' : 'VALIDATION_ERROR_2f403001',
    '"VUID-vkGetPhysicalDeviceXcbPresentationSupportKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2f427a01',
    '"VUID-vkGetPhysicalDeviceXlibPresentationSupportKHR-queueFamilyIndex-01315"' : 'VALIDATION_ERROR_2f600a46',
    '"VUID-vkGetPhysicalDeviceXlibPresentationSupportKHR-dpy-parameter"' : 'VALIDATION_ERROR_2f606601',
    '"VUID-vkGetPhysicalDeviceXlibPresentationSupportKHR-physicalDevice-parameter"' : 'VALIDATION_ERROR_2f627a01',
    '"VUID-vkGetPipelineCacheData-device-parameter"' : 'VALIDATION_ERROR_2f805601',
    '"VUID-vkGetPipelineCacheData-pData-parameter"' : 'VALIDATION_ERROR_2f812201',
    '"VUID-vkGetPipelineCacheData-pDataSize-parameter"' : 'VALIDATION_ERROR_2f812401',
    '"VUID-vkGetPipelineCacheData-pipelineCache-parameter"' : 'VALIDATION_ERROR_2f828001',
    '"VUID-vkGetPipelineCacheData-pipelineCache-parent"' : 'VALIDATION_ERROR_2f828007',
    '"VUID-vkGetQueryPoolResults-firstQuery-00813"' : 'VALIDATION_ERROR_2fa0065a',
    '"VUID-vkGetQueryPoolResults-flags-00814"' : 'VALIDATION_ERROR_2fa0065c',
    '"VUID-vkGetQueryPoolResults-flags-00815"' : 'VALIDATION_ERROR_2fa0065e',
    '"VUID-vkGetQueryPoolResults-firstQuery-00816"' : 'VALIDATION_ERROR_2fa00660',
    '"VUID-vkGetQueryPoolResults-dataSize-00817"' : 'VALIDATION_ERROR_2fa00662',
    '"VUID-vkGetQueryPoolResults-queryType-00818"' : 'VALIDATION_ERROR_2fa00664',
    '"VUID-vkGetQueryPoolResults-dataSize-arraylength"' : 'VALIDATION_ERROR_2fa03c1b',
    '"VUID-vkGetQueryPoolResults-device-parameter"' : 'VALIDATION_ERROR_2fa05601',
    '"VUID-vkGetQueryPoolResults-flags-parameter"' : 'VALIDATION_ERROR_2fa09001',
    '"VUID-vkGetQueryPoolResults-pData-parameter"' : 'VALIDATION_ERROR_2fa12201',
    '"VUID-vkGetQueryPoolResults-queryPool-parameter"' : 'VALIDATION_ERROR_2fa29801',
    '"VUID-vkGetQueryPoolResults-queryPool-parent"' : 'VALIDATION_ERROR_2fa29807',
    '"VUID-vkGetRandROutputDisplayEXT-dpy-parameter"' : 'VALIDATION_ERROR_2fc06601',
    '"VUID-vkGetRandROutputDisplayEXT-pDisplay-parameter"' : 'VALIDATION_ERROR_2fc14801',
    '"VUID-vkGetRandROutputDisplayEXT-physicalDevice-parameter"' : 'VALIDATION_ERROR_2fc27a01',
    '"VUID-vkGetRefreshCycleDurationGOOGLE-commonparent"' : 'VALIDATION_ERROR_2fe00009',
    '"VUID-vkGetRefreshCycleDurationGOOGLE-device-parameter"' : 'VALIDATION_ERROR_2fe05601',
    '"VUID-vkGetRefreshCycleDurationGOOGLE-pDisplayTimingProperties-parameter"' : 'VALIDATION_ERROR_2fe15001',
    '"VUID-vkGetRefreshCycleDurationGOOGLE-swapchain-parameter"' : 'VALIDATION_ERROR_2fe2f001',
    '"VUID-vkGetRenderAreaGranularity-device-parameter"' : 'VALIDATION_ERROR_30005601',
    '"VUID-vkGetRenderAreaGranularity-pGranularity-parameter"' : 'VALIDATION_ERROR_30017a01',
    '"VUID-vkGetRenderAreaGranularity-renderPass-parameter"' : 'VALIDATION_ERROR_3002ae01',
    '"VUID-vkGetRenderAreaGranularity-renderPass-parent"' : 'VALIDATION_ERROR_3002ae07',
    '"VUID-vkGetSemaphoreFdKHR-device-parameter"' : 'VALIDATION_ERROR_30205601',
    '"VUID-vkGetSemaphoreFdKHR-pFd-parameter"' : 'VALIDATION_ERROR_30216c01',
    '"VUID-vkGetSemaphoreFdKHR-pGetFdInfo-parameter"' : 'VALIDATION_ERROR_30239e01',
    '"VUID-vkGetSemaphoreWin32HandleKHR-device-parameter"' : 'VALIDATION_ERROR_30405601',
    '"VUID-vkGetSemaphoreWin32HandleKHR-pHandle-parameter"' : 'VALIDATION_ERROR_30417c01',
    '"VUID-vkGetSemaphoreWin32HandleKHR-pGetWin32HandleInfo-parameter"' : 'VALIDATION_ERROR_3043a001',
    '"VUID-vkGetSwapchainCounterEXT-commonparent"' : 'VALIDATION_ERROR_30600009',
    '"VUID-vkGetSwapchainCounterEXT-swapchain-01245"' : 'VALIDATION_ERROR_306009ba',
    '"VUID-vkGetSwapchainCounterEXT-counter-parameter"' : 'VALIDATION_ERROR_30603601',
    '"VUID-vkGetSwapchainCounterEXT-device-parameter"' : 'VALIDATION_ERROR_30605601',
    '"VUID-vkGetSwapchainCounterEXT-pCounterValue-parameter"' : 'VALIDATION_ERROR_30611c01',
    '"VUID-vkGetSwapchainCounterEXT-swapchain-parameter"' : 'VALIDATION_ERROR_3062f001',
    '"VUID-vkGetSwapchainImagesKHR-commonparent"' : 'VALIDATION_ERROR_30800009',
    '"VUID-vkGetSwapchainImagesKHR-device-parameter"' : 'VALIDATION_ERROR_30805601',
    '"VUID-vkGetSwapchainImagesKHR-pSwapchainImageCount-parameter"' : 'VALIDATION_ERROR_30825401',
    '"VUID-vkGetSwapchainImagesKHR-pSwapchainImages-parameter"' : 'VALIDATION_ERROR_30825601',
    '"VUID-vkGetSwapchainImagesKHR-swapchain-parameter"' : 'VALIDATION_ERROR_3082f001',
    '"VUID-vkGetSwapchainStatusKHR-commonparent"' : 'VALIDATION_ERROR_30a00009',
    '"VUID-vkGetSwapchainStatusKHR-device-parameter"' : 'VALIDATION_ERROR_30a05601',
    '"VUID-vkGetSwapchainStatusKHR-swapchain-parameter"' : 'VALIDATION_ERROR_30a2f001',
    '"VUID-vkImportSemaphoreFdKHR-semaphore-01142"' : 'VALIDATION_ERROR_30c008ec',
    '"VUID-vkImportSemaphoreFdKHR-device-parameter"' : 'VALIDATION_ERROR_30c05601',
    '"VUID-vkImportSemaphoreFdKHR-pImportSemaphoreFdInfo-parameter"' : 'VALIDATION_ERROR_30c18e01',
    '"VUID-vkImportSemaphoreWin32HandleKHR-device-parameter"' : 'VALIDATION_ERROR_30e05601',
    '"VUID-vkImportSemaphoreWin32HandleKHR-pImportSemaphoreWin32HandleInfo-parameter"' : 'VALIDATION_ERROR_30e19001',
    '"VUID-vkInvalidateMappedMemoryRanges-device-parameter"' : 'VALIDATION_ERROR_31005601',
    '"VUID-vkInvalidateMappedMemoryRanges-memoryRangeCount-arraylength"' : 'VALIDATION_ERROR_3100c81b',
    '"VUID-vkInvalidateMappedMemoryRanges-pMemoryRanges-parameter"' : 'VALIDATION_ERROR_3101b201',
    '"VUID-vkMapMemory-memory-00678"' : 'VALIDATION_ERROR_3120054c',
    '"VUID-vkMapMemory-offset-00679"' : 'VALIDATION_ERROR_3120054e',
    '"VUID-vkMapMemory-size-00680"' : 'VALIDATION_ERROR_31200550',
    '"VUID-vkMapMemory-size-00681"' : 'VALIDATION_ERROR_31200552',
    '"VUID-vkMapMemory-memory-00682"' : 'VALIDATION_ERROR_31200554',
    '"VUID-vkMapMemory-memory-00683"' : 'VALIDATION_ERROR_31200556',
    '"VUID-vkMapMemory-device-parameter"' : 'VALIDATION_ERROR_31205601',
    '"VUID-vkMapMemory-flags-zerobitmask"' : 'VALIDATION_ERROR_31209005',
    '"VUID-vkMapMemory-memory-parameter"' : 'VALIDATION_ERROR_3120c601',
    '"VUID-vkMapMemory-memory-parent"' : 'VALIDATION_ERROR_3120c607',
    '"VUID-vkMapMemory-ppData-parameter"' : 'VALIDATION_ERROR_31228c01',
    '"VUID-vkMergePipelineCaches-dstCache-00770"' : 'VALIDATION_ERROR_31400604',
    '"VUID-vkMergePipelineCaches-device-parameter"' : 'VALIDATION_ERROR_31405601',
    '"VUID-vkMergePipelineCaches-dstCache-parameter"' : 'VALIDATION_ERROR_31406e01',
    '"VUID-vkMergePipelineCaches-dstCache-parent"' : 'VALIDATION_ERROR_31406e07',
    '"VUID-vkMergePipelineCaches-pSrcCaches-parameter"' : 'VALIDATION_ERROR_31423c01',
    '"VUID-vkMergePipelineCaches-pSrcCaches-parent"' : 'VALIDATION_ERROR_31423c07',
    '"VUID-vkMergePipelineCaches-srcCacheCount-arraylength"' : 'VALIDATION_ERROR_3142ca1b',
    '"VUID-vkQueueBindSparse-commonparent"' : 'VALIDATION_ERROR_31600009',
    '"VUID-vkQueueBindSparse-queuetype"' : 'VALIDATION_ERROR_31600011',
    '"VUID-vkQueueBindSparse-fence-01113"' : 'VALIDATION_ERROR_316008b2',
    '"VUID-vkQueueBindSparse-fence-01114"' : 'VALIDATION_ERROR_316008b4',
    '"VUID-vkQueueBindSparse-pSignalSemaphores-01115"' : 'VALIDATION_ERROR_316008b6',
    '"VUID-vkQueueBindSparse-pWaitSemaphores-01116"' : 'VALIDATION_ERROR_316008b8',
    '"VUID-vkQueueBindSparse-pWaitSemaphores-01117"' : 'VALIDATION_ERROR_316008ba',
    '"VUID-vkQueueBindSparse-fence-parameter"' : 'VALIDATION_ERROR_31608801',
    '"VUID-vkQueueBindSparse-pBindInfo-parameter"' : 'VALIDATION_ERROR_3160f801',
    '"VUID-vkQueueBindSparse-queue-parameter"' : 'VALIDATION_ERROR_31629c01',
    '"VUID-vkQueuePresentKHR-pSwapchains-01292"' : 'VALIDATION_ERROR_31800a18',
    '"VUID-vkQueuePresentKHR-pSwapchains-01293"' : 'VALIDATION_ERROR_31800a1a',
    '"VUID-vkQueuePresentKHR-pWaitSemaphores-01294"' : 'VALIDATION_ERROR_31800a1c',
    '"VUID-vkQueuePresentKHR-pWaitSemaphores-01295"' : 'VALIDATION_ERROR_31800a1e',
    '"VUID-vkQueuePresentKHR-pPresentInfo-parameter"' : 'VALIDATION_ERROR_3181e601',
    '"VUID-vkQueuePresentKHR-queue-parameter"' : 'VALIDATION_ERROR_31829c01',
    '"VUID-vkQueueSubmit-commonparent"' : 'VALIDATION_ERROR_31a00009',
    '"VUID-vkQueueSubmit-fence-00063"' : 'VALIDATION_ERROR_31a0007e',
    '"VUID-vkQueueSubmit-fence-00064"' : 'VALIDATION_ERROR_31a00080',
    '"VUID-vkQueueSubmit-pCommandBuffers-00065"' : 'VALIDATION_ERROR_31a00082',
    '"VUID-vkQueueSubmit-pWaitDstStageMask-00066"' : 'VALIDATION_ERROR_31a00084',
    '"VUID-vkQueueSubmit-pSignalSemaphores-00067"' : 'VALIDATION_ERROR_31a00086',
    '"VUID-vkQueueSubmit-pWaitSemaphores-00068"' : 'VALIDATION_ERROR_31a00088',
    '"VUID-vkQueueSubmit-pWaitSemaphores-00069"' : 'VALIDATION_ERROR_31a0008a',
    '"VUID-vkQueueSubmit-pCommandBuffers-00070"' : 'VALIDATION_ERROR_31a0008c',
    '"VUID-vkQueueSubmit-pCommandBuffers-00071"' : 'VALIDATION_ERROR_31a0008e',
    '"VUID-vkQueueSubmit-pCommandBuffers-00072"' : 'VALIDATION_ERROR_31a00090',
    '"VUID-vkQueueSubmit-pCommandBuffers-00073"' : 'VALIDATION_ERROR_31a00092',
    '"VUID-vkQueueSubmit-pCommandBuffers-00074"' : 'VALIDATION_ERROR_31a00094',
    '"VUID-vkQueueSubmit-fence-parameter"' : 'VALIDATION_ERROR_31a08801',
    '"VUID-vkQueueSubmit-pSubmits-parameter"' : 'VALIDATION_ERROR_31a24001',
    '"VUID-vkQueueSubmit-queue-parameter"' : 'VALIDATION_ERROR_31a29c01',
    '"VUID-vkQueueWaitIdle-queue-parameter"' : 'VALIDATION_ERROR_31c29c01',
    '"VUID-vkRegisterDeviceEventEXT-device-parameter"' : 'VALIDATION_ERROR_31e05601',
    '"VUID-vkRegisterDeviceEventEXT-pAllocator-parameter"' : 'VALIDATION_ERROR_31e0ec01',
    '"VUID-vkRegisterDeviceEventEXT-pDeviceEventInfo-parameter"' : 'VALIDATION_ERROR_31e13a01',
    '"VUID-vkRegisterDeviceEventEXT-pFence-parameter"' : 'VALIDATION_ERROR_31e17001',
    '"VUID-vkRegisterDisplayEventEXT-device-parameter"' : 'VALIDATION_ERROR_32005601',
    '"VUID-vkRegisterDisplayEventEXT-display-parameter"' : 'VALIDATION_ERROR_32006001',
    '"VUID-vkRegisterDisplayEventEXT-pAllocator-parameter"' : 'VALIDATION_ERROR_3200ec01',
    '"VUID-vkRegisterDisplayEventEXT-pDisplayEventInfo-parameter"' : 'VALIDATION_ERROR_32014c01',
    '"VUID-vkRegisterDisplayEventEXT-pFence-parameter"' : 'VALIDATION_ERROR_32017001',
    '"VUID-vkRegisterObjectsNVX-pObjectTableEntry-01364"' : 'VALIDATION_ERROR_32200aa8',
    '"VUID-vkRegisterObjectsNVX-pObjectIndices-01365"' : 'VALIDATION_ERROR_32200aaa',
    '"VUID-vkRegisterObjectsNVX-pObjectIndices-01366"' : 'VALIDATION_ERROR_32200aac',
    '"VUID-vkRegisterObjectsNVX-device-parameter"' : 'VALIDATION_ERROR_32205601',
    '"VUID-vkRegisterObjectsNVX-objectCount-arraylength"' : 'VALIDATION_ERROR_3220d61b',
    '"VUID-vkRegisterObjectsNVX-objectTable-parameter"' : 'VALIDATION_ERROR_3220d801',
    '"VUID-vkRegisterObjectsNVX-objectTable-parent"' : 'VALIDATION_ERROR_3220d807',
    '"VUID-vkRegisterObjectsNVX-pObjectIndices-parameter"' : 'VALIDATION_ERROR_3221cc01',
    '"VUID-vkRegisterObjectsNVX-ppObjectTableEntries-parameter"' : 'VALIDATION_ERROR_32229201',
    '"VUID-vkReleaseDisplayEXT-display-parameter"' : 'VALIDATION_ERROR_32406001',
    '"VUID-vkReleaseDisplayEXT-physicalDevice-parameter"' : 'VALIDATION_ERROR_32427a01',
    '"VUID-vkResetCommandBuffer-commandBuffer-00045"' : 'VALIDATION_ERROR_3260005a',
    '"VUID-vkResetCommandBuffer-commandBuffer-00046"' : 'VALIDATION_ERROR_3260005c',
    '"VUID-vkResetCommandBuffer-commandBuffer-parameter"' : 'VALIDATION_ERROR_32602401',
    '"VUID-vkResetCommandBuffer-flags-parameter"' : 'VALIDATION_ERROR_32609001',
    '"VUID-vkResetCommandPool-commandPool-00040"' : 'VALIDATION_ERROR_32800050',
    '"VUID-vkResetCommandPool-commandPool-parameter"' : 'VALIDATION_ERROR_32802801',
    '"VUID-vkResetCommandPool-commandPool-parent"' : 'VALIDATION_ERROR_32802807',
    '"VUID-vkResetCommandPool-device-parameter"' : 'VALIDATION_ERROR_32805601',
    '"VUID-vkResetCommandPool-flags-parameter"' : 'VALIDATION_ERROR_32809001',
    '"VUID-vkResetDescriptorPool-descriptorPool-00313"' : 'VALIDATION_ERROR_32a00272',
    '"VUID-vkResetDescriptorPool-descriptorPool-parameter"' : 'VALIDATION_ERROR_32a04601',
    '"VUID-vkResetDescriptorPool-descriptorPool-parent"' : 'VALIDATION_ERROR_32a04607',
    '"VUID-vkResetDescriptorPool-device-parameter"' : 'VALIDATION_ERROR_32a05601',
    '"VUID-vkResetDescriptorPool-flags-zerobitmask"' : 'VALIDATION_ERROR_32a09005',
    '"VUID-vkResetEvent-event-01148"' : 'VALIDATION_ERROR_32c008f8',
    '"VUID-vkResetEvent-device-parameter"' : 'VALIDATION_ERROR_32c05601',
    '"VUID-vkResetEvent-event-parameter"' : 'VALIDATION_ERROR_32c07e01',
    '"VUID-vkResetEvent-event-parent"' : 'VALIDATION_ERROR_32c07e07',
    '"VUID-vkResetFences-pFences-01123"' : 'VALIDATION_ERROR_32e008c6',
    '"VUID-vkResetFences-device-parameter"' : 'VALIDATION_ERROR_32e05601',
    '"VUID-vkResetFences-fenceCount-arraylength"' : 'VALIDATION_ERROR_32e08a1b',
    '"VUID-vkResetFences-pFences-parameter"' : 'VALIDATION_ERROR_32e17201',
    '"VUID-vkResetFences-pFences-parent"' : 'VALIDATION_ERROR_32e17207',
    '"VUID-vkSetEvent-device-parameter"' : 'VALIDATION_ERROR_33005601',
    '"VUID-vkSetEvent-event-parameter"' : 'VALIDATION_ERROR_33007e01',
    '"VUID-vkSetEvent-event-parent"' : 'VALIDATION_ERROR_33007e07',
    '"VUID-vkSetHdrMetadataEXT-commonparent"' : 'VALIDATION_ERROR_33200009',
    '"VUID-vkSetHdrMetadataEXT-device-parameter"' : 'VALIDATION_ERROR_33205601',
    '"VUID-vkSetHdrMetadataEXT-pMetadata-parameter"' : 'VALIDATION_ERROR_3321ba01',
    '"VUID-vkSetHdrMetadataEXT-pSwapchains-parameter"' : 'VALIDATION_ERROR_33225801',
    '"VUID-vkSetHdrMetadataEXT-swapchainCount-arraylength"' : 'VALIDATION_ERROR_3322f21b',
    '"VUID-vkTrimCommandPool-commandPool-parameter"' : 'VALIDATION_ERROR_33402801',
    '"VUID-vkTrimCommandPool-commandPool-parent"' : 'VALIDATION_ERROR_33402807',
    '"VUID-vkTrimCommandPool-device-parameter"' : 'VALIDATION_ERROR_33405601',
    '"VUID-vkTrimCommandPool-flags-zerobitmask"' : 'VALIDATION_ERROR_33409005',
    '"VUID-vkUnmapMemory-memory-00689"' : 'VALIDATION_ERROR_33600562',
    '"VUID-vkUnmapMemory-device-parameter"' : 'VALIDATION_ERROR_33605601',
    '"VUID-vkUnmapMemory-memory-parameter"' : 'VALIDATION_ERROR_3360c601',
    '"VUID-vkUnmapMemory-memory-parent"' : 'VALIDATION_ERROR_3360c607',
    '"VUID-vkUnregisterObjectsNVX-pObjectIndices-01373"' : 'VALIDATION_ERROR_33800aba',
    '"VUID-vkUnregisterObjectsNVX-pObjectEntryTypes-01374"' : 'VALIDATION_ERROR_33800abc',
    '"VUID-vkUnregisterObjectsNVX-None-01375"' : 'VALIDATION_ERROR_33800abe',
    '"VUID-vkUnregisterObjectsNVX-device-parameter"' : 'VALIDATION_ERROR_33805601',
    '"VUID-vkUnregisterObjectsNVX-objectCount-arraylength"' : 'VALIDATION_ERROR_3380d61b',
    '"VUID-vkUnregisterObjectsNVX-objectTable-parameter"' : 'VALIDATION_ERROR_3380d801',
    '"VUID-vkUnregisterObjectsNVX-objectTable-parent"' : 'VALIDATION_ERROR_3380d807',
    '"VUID-vkUnregisterObjectsNVX-pObjectEntryTypes-parameter"' : 'VALIDATION_ERROR_3381c801',
    '"VUID-vkUnregisterObjectsNVX-pObjectIndices-parameter"' : 'VALIDATION_ERROR_3381cc01',
    '"VUID-vkUpdateDescriptorSetWithTemplate-pData-01685"' : 'VALIDATION_ERROR_33a00d2a',
    '"VUID-vkUpdateDescriptorSetWithTemplate-descriptorSet-parameter"' : 'VALIDATION_ERROR_33a04801',
    '"VUID-vkUpdateDescriptorSetWithTemplate-descriptorUpdateTemplate-parameter"' : 'VALIDATION_ERROR_33a05201',
    '"VUID-vkUpdateDescriptorSetWithTemplate-descriptorUpdateTemplate-parent"' : 'VALIDATION_ERROR_33a05207',
    '"VUID-vkUpdateDescriptorSetWithTemplate-device-parameter"' : 'VALIDATION_ERROR_33a05601',
    '"VUID-vkUpdateDescriptorSets-dstSet-00314"' : 'VALIDATION_ERROR_33c00274',
    '"VUID-vkUpdateDescriptorSets-None-03047"' : 'VALIDATION_ERROR_33c017ce',
    '"VUID-vkUpdateDescriptorSets-device-parameter"' : 'VALIDATION_ERROR_33c05601',
    '"VUID-vkUpdateDescriptorSets-pDescriptorCopies-parameter"' : 'VALIDATION_ERROR_33c12c01',
    '"VUID-vkUpdateDescriptorSets-pDescriptorWrites-parameter"' : 'VALIDATION_ERROR_33c13601',
    '"VUID-vkWaitForFences-device-parameter"' : 'VALIDATION_ERROR_33e05601',
    '"VUID-vkWaitForFences-fenceCount-arraylength"' : 'VALIDATION_ERROR_33e08a1b',
    '"VUID-vkWaitForFences-pFences-parameter"' : 'VALIDATION_ERROR_33e17201',
    '"VUID-vkWaitForFences-pFences-parent"' : 'VALIDATION_ERROR_33e17207',
    '"VUID-VkPhysicalDeviceProperties2-pNext-pNext"' : 'VALIDATION_ERROR_3401c40d',
    '"VUID-VkPhysicalDeviceProperties2-sType-sType"' : 'VALIDATION_ERROR_3402b00b',
    '"VUID-VkPhysicalDeviceProperties2-sType-unique"' : 'VALIDATION_ERROR_3402b00f',
    '"VUID-VkFormatProperties2-pNext-pNext"' : 'VALIDATION_ERROR_3421c40d',
    '"VUID-VkFormatProperties2-sType-sType"' : 'VALIDATION_ERROR_3422b00b',
    '"VUID-VkImageFormatProperties2-pNext-pNext"' : 'VALIDATION_ERROR_3441c40d',
    '"VUID-VkImageFormatProperties2-sType-sType"' : 'VALIDATION_ERROR_3442b00b',
    '"VUID-VkImageFormatProperties2-sType-unique"' : 'VALIDATION_ERROR_3442b00f',
    '"VUID-VkPhysicalDeviceMemoryProperties2-pNext-pNext"' : 'VALIDATION_ERROR_3461c40d',
    '"VUID-VkPhysicalDeviceMemoryProperties2-sType-sType"' : 'VALIDATION_ERROR_3462b00b',
    '"VUID-VkSurfaceCapabilities2KHR-pNext-pNext"' : 'VALIDATION_ERROR_3481c40d',
    '"VUID-VkSurfaceCapabilities2KHR-sType-sType"' : 'VALIDATION_ERROR_3482b00b',
    '"VUID-VkDeviceGroupPresentCapabilitiesKHR-pNext-pNext"' : 'VALIDATION_ERROR_34a1c40d',
    '"VUID-VkDeviceGroupPresentCapabilitiesKHR-sType-sType"' : 'VALIDATION_ERROR_34a2b00b',
    '"VUID-VkExternalBufferProperties-pNext-pNext"' : 'VALIDATION_ERROR_34c1c40d',
    '"VUID-VkExternalBufferProperties-sType-sType"' : 'VALIDATION_ERROR_34c2b00b',
    '"VUID-VkExternalSemaphoreProperties-pNext-pNext"' : 'VALIDATION_ERROR_3521c40d',
    '"VUID-VkExternalSemaphoreProperties-sType-sType"' : 'VALIDATION_ERROR_3522b00b',
    '"VUID-VkQueueFamilyProperties2-pNext-pNext"' : 'VALIDATION_ERROR_3541c40d',
    '"VUID-VkQueueFamilyProperties2-sType-sType"' : 'VALIDATION_ERROR_3542b00b',
    '"VUID-VkSparseImageFormatProperties2-pNext-pNext"' : 'VALIDATION_ERROR_3561c40d',
    '"VUID-VkSparseImageFormatProperties2-sType-sType"' : 'VALIDATION_ERROR_3562b00b',
    '"VUID-VkSurfaceFormat2KHR-pNext-pNext"' : 'VALIDATION_ERROR_3581c40d',
    '"VUID-VkSurfaceFormat2KHR-sType-sType"' : 'VALIDATION_ERROR_3582b00b',
    '"VUID-VkPhysicalDeviceMultiviewProperties-sType-sType"' : 'VALIDATION_ERROR_35c2b00b',
    '"VUID-VkExternalImageFormatProperties-sType-sType"' : 'VALIDATION_ERROR_3602b00b',
    '"VUID-VkPhysicalDeviceIDProperties-sType-sType"' : 'VALIDATION_ERROR_3622b00b',
    '"VUID-VkPhysicalDeviceMultiviewPerViewAttributesPropertiesNVX-sType-sType"' : 'VALIDATION_ERROR_3642b00b',
    '"VUID-VkSharedPresentSurfaceCapabilitiesKHR-sType-sType"' : 'VALIDATION_ERROR_37e2b00b',
    '"VUID-VkPhysicalDeviceBlendOperationAdvancedFeaturesEXT-sType-sType"' : 'VALIDATION_ERROR_3822b00b',
    '"VUID-VkPhysicalDeviceBlendOperationAdvancedPropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_3842b00b',
    '"VUID-VkPhysicalDeviceSamplerFilterMinmaxPropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_3862b00b',
    '"VUID-VkPipelineColorBlendAdvancedStateCreateInfoEXT-srcPremultiplied-01424"' : 'VALIDATION_ERROR_38800b20',
    '"VUID-VkPipelineColorBlendAdvancedStateCreateInfoEXT-dstPremultiplied-01425"' : 'VALIDATION_ERROR_38800b22',
    '"VUID-VkPipelineColorBlendAdvancedStateCreateInfoEXT-blendOverlap-01426"' : 'VALIDATION_ERROR_38800b24',
    '"VUID-VkPipelineColorBlendAdvancedStateCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_3882b00b',
    '"VUID-VkPipelineColorBlendAdvancedStateCreateInfoEXT-blendOverlap-parameter"' : 'VALIDATION_ERROR_38834a01',
    '"VUID-VkPipelineCoverageModulationStateCreateInfoNV-coverageModulationTableEnable-01405"' : 'VALIDATION_ERROR_38a00afa',
    '"VUID-VkPipelineCoverageModulationStateCreateInfoNV-flags-zerobitmask"' : 'VALIDATION_ERROR_38a09005',
    '"VUID-VkPipelineCoverageModulationStateCreateInfoNV-sType-sType"' : 'VALIDATION_ERROR_38a2b00b',
    '"VUID-VkPipelineCoverageModulationStateCreateInfoNV-coverageModulationMode-parameter"' : 'VALIDATION_ERROR_38a34c01',
    '"VUID-VkPipelineCoverageModulationStateCreateInfoNV-coverageModulationTableCount-arraylength"' : 'VALIDATION_ERROR_38a34e1b',
    '"VUID-VkPipelineCoverageToColorStateCreateInfoNV-coverageToColorEnable-01404"' : 'VALIDATION_ERROR_38c00af8',
    '"VUID-VkPipelineCoverageToColorStateCreateInfoNV-flags-zerobitmask"' : 'VALIDATION_ERROR_38c09005',
    '"VUID-VkPipelineCoverageToColorStateCreateInfoNV-sType-sType"' : 'VALIDATION_ERROR_38c2b00b',
    '"VUID-VkSamplerReductionModeCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_38e2b00b',
    '"VUID-VkSamplerReductionModeCreateInfoEXT-reductionMode-parameter"' : 'VALIDATION_ERROR_38e35001',
    '"VUID-VkExportFenceCreateInfo-handleTypes-01446"' : 'VALIDATION_ERROR_39400b4c',
    '"VUID-VkExportFenceCreateInfo-handleTypes-parameter"' : 'VALIDATION_ERROR_39409e01',
    '"VUID-VkExportFenceCreateInfo-sType-sType"' : 'VALIDATION_ERROR_3942b00b',
    '"VUID-VkPhysicalDeviceExternalFenceInfo-handleType-parameter"' : 'VALIDATION_ERROR_39609c01',
    '"VUID-VkPhysicalDeviceExternalFenceInfo-pNext-pNext"' : 'VALIDATION_ERROR_3961c40d',
    '"VUID-VkPhysicalDeviceExternalFenceInfo-sType-sType"' : 'VALIDATION_ERROR_3962b00b',
    '"VUID-VkExternalFenceProperties-pNext-pNext"' : 'VALIDATION_ERROR_3981c40d',
    '"VUID-VkExternalFenceProperties-sType-sType"' : 'VALIDATION_ERROR_3982b00b',
    '"VUID-vkGetPhysicalDeviceExternalFenceProperties-physicalDevice-parameter"' : 'VALIDATION_ERROR_39a27a01',
    '"VUID-vkGetPhysicalDeviceExternalFenceProperties-pExternalFenceInfo-parameter"' : 'VALIDATION_ERROR_39a3a201',
    '"VUID-vkGetPhysicalDeviceExternalFenceProperties-pExternalFenceProperties-parameter"' : 'VALIDATION_ERROR_39a3a401',
    '"VUID-VkImportFenceFdInfoKHR-handleType-01464"' : 'VALIDATION_ERROR_39c00b70',
    '"VUID-VkImportFenceFdInfoKHR-fd-01541"' : 'VALIDATION_ERROR_39c00c0a',
    '"VUID-VkImportFenceFdInfoKHR-fence-parameter"' : 'VALIDATION_ERROR_39c08801',
    '"VUID-VkImportFenceFdInfoKHR-flags-parameter"' : 'VALIDATION_ERROR_39c09001',
    '"VUID-VkImportFenceFdInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_39c09c01',
    '"VUID-VkImportFenceFdInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_39c1c40d',
    '"VUID-VkImportFenceFdInfoKHR-sType-sType"' : 'VALIDATION_ERROR_39c2b00b',
    '"VUID-VkFenceGetFdInfoKHR-handleType-01453"' : 'VALIDATION_ERROR_39e00b5a',
    '"VUID-VkFenceGetFdInfoKHR-handleType-01454"' : 'VALIDATION_ERROR_39e00b5c',
    '"VUID-VkFenceGetFdInfoKHR-fence-01455"' : 'VALIDATION_ERROR_39e00b5e',
    '"VUID-VkFenceGetFdInfoKHR-handleType-01456"' : 'VALIDATION_ERROR_39e00b60',
    '"VUID-VkFenceGetFdInfoKHR-fence-parameter"' : 'VALIDATION_ERROR_39e08801',
    '"VUID-VkFenceGetFdInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_39e09c01',
    '"VUID-VkFenceGetFdInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_39e1c40d',
    '"VUID-VkFenceGetFdInfoKHR-sType-sType"' : 'VALIDATION_ERROR_39e2b00b',
    '"VUID-vkImportFenceFdKHR-fence-01463"' : 'VALIDATION_ERROR_3a000b6e',
    '"VUID-vkImportFenceFdKHR-device-parameter"' : 'VALIDATION_ERROR_3a005601',
    '"VUID-vkImportFenceFdKHR-pImportFenceFdInfo-parameter"' : 'VALIDATION_ERROR_3a03a801',
    '"VUID-vkGetFenceFdKHR-device-parameter"' : 'VALIDATION_ERROR_3a205601',
    '"VUID-vkGetFenceFdKHR-pFd-parameter"' : 'VALIDATION_ERROR_3a216c01',
    '"VUID-vkGetFenceFdKHR-pGetFdInfo-parameter"' : 'VALIDATION_ERROR_3a239e01',
    '"VUID-VkImportFenceWin32HandleInfoKHR-handleType-01457"' : 'VALIDATION_ERROR_3a400b62',
    '"VUID-VkImportFenceWin32HandleInfoKHR-handleType-01459"' : 'VALIDATION_ERROR_3a400b66',
    '"VUID-VkImportFenceWin32HandleInfoKHR-handleType-01460"' : 'VALIDATION_ERROR_3a400b68',
    '"VUID-VkImportFenceWin32HandleInfoKHR-handleType-01461"' : 'VALIDATION_ERROR_3a400b6a',
    '"VUID-VkImportFenceWin32HandleInfoKHR-handle-01462"' : 'VALIDATION_ERROR_3a400b6c',
    '"VUID-VkImportFenceWin32HandleInfoKHR-handle-01539"' : 'VALIDATION_ERROR_3a400c06',
    '"VUID-VkImportFenceWin32HandleInfoKHR-name-01540"' : 'VALIDATION_ERROR_3a400c08',
    '"VUID-VkImportFenceWin32HandleInfoKHR-fence-parameter"' : 'VALIDATION_ERROR_3a408801',
    '"VUID-VkImportFenceWin32HandleInfoKHR-flags-parameter"' : 'VALIDATION_ERROR_3a409001',
    '"VUID-VkImportFenceWin32HandleInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_3a409c01',
    '"VUID-VkImportFenceWin32HandleInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_3a41c40d',
    '"VUID-VkImportFenceWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_3a42b00b',
    '"VUID-VkExportFenceWin32HandleInfoKHR-handleTypes-01447"' : 'VALIDATION_ERROR_3a600b4e',
    '"VUID-VkExportFenceWin32HandleInfoKHR-pAttributes-parameter"' : 'VALIDATION_ERROR_3a60f401',
    '"VUID-VkExportFenceWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_3a62b00b',
    '"VUID-VkFenceGetWin32HandleInfoKHR-handleType-01448"' : 'VALIDATION_ERROR_3a800b50',
    '"VUID-VkFenceGetWin32HandleInfoKHR-handleType-01449"' : 'VALIDATION_ERROR_3a800b52',
    '"VUID-VkFenceGetWin32HandleInfoKHR-fence-01450"' : 'VALIDATION_ERROR_3a800b54',
    '"VUID-VkFenceGetWin32HandleInfoKHR-handleType-01451"' : 'VALIDATION_ERROR_3a800b56',
    '"VUID-VkFenceGetWin32HandleInfoKHR-handleType-01452"' : 'VALIDATION_ERROR_3a800b58',
    '"VUID-VkFenceGetWin32HandleInfoKHR-fence-parameter"' : 'VALIDATION_ERROR_3a808801',
    '"VUID-VkFenceGetWin32HandleInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_3a809c01',
    '"VUID-VkFenceGetWin32HandleInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_3a81c40d',
    '"VUID-VkFenceGetWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_3a82b00b',
    '"VUID-vkImportFenceWin32HandleKHR-device-parameter"' : 'VALIDATION_ERROR_3aa05601',
    '"VUID-vkImportFenceWin32HandleKHR-pImportFenceWin32HandleInfo-parameter"' : 'VALIDATION_ERROR_3aa3aa01',
    '"VUID-vkGetFenceWin32HandleKHR-device-parameter"' : 'VALIDATION_ERROR_3ac05601',
    '"VUID-vkGetFenceWin32HandleKHR-pHandle-parameter"' : 'VALIDATION_ERROR_3ac17c01',
    '"VUID-vkGetFenceWin32HandleKHR-pGetWin32HandleInfo-parameter"' : 'VALIDATION_ERROR_3ac3a001',
    '"VUID-VkSemaphoreGetFdInfoKHR-handleType-01132"' : 'VALIDATION_ERROR_3ae008d8',
    '"VUID-VkSemaphoreGetFdInfoKHR-semaphore-01133"' : 'VALIDATION_ERROR_3ae008da',
    '"VUID-VkSemaphoreGetFdInfoKHR-handleType-01134"' : 'VALIDATION_ERROR_3ae008dc',
    '"VUID-VkSemaphoreGetFdInfoKHR-handleType-01135"' : 'VALIDATION_ERROR_3ae008de',
    '"VUID-VkSemaphoreGetFdInfoKHR-handleType-01136"' : 'VALIDATION_ERROR_3ae008e0',
    '"VUID-VkSemaphoreGetFdInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_3ae09c01',
    '"VUID-VkSemaphoreGetFdInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_3ae1c40d',
    '"VUID-VkSemaphoreGetFdInfoKHR-sType-sType"' : 'VALIDATION_ERROR_3ae2b00b',
    '"VUID-VkSemaphoreGetFdInfoKHR-semaphore-parameter"' : 'VALIDATION_ERROR_3ae2b801',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-handleType-01126"' : 'VALIDATION_ERROR_3b0008cc',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-handleType-01127"' : 'VALIDATION_ERROR_3b0008ce',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-semaphore-01128"' : 'VALIDATION_ERROR_3b0008d0',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-handleType-01129"' : 'VALIDATION_ERROR_3b0008d2',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-handleType-01130"' : 'VALIDATION_ERROR_3b0008d4',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-handleType-01131"' : 'VALIDATION_ERROR_3b0008d6',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_3b009c01',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_3b01c40d',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_3b02b00b',
    '"VUID-VkSemaphoreGetWin32HandleInfoKHR-semaphore-parameter"' : 'VALIDATION_ERROR_3b02b801',
    '"VUID-VkMemoryGetFdInfoKHR-handleType-00671"' : 'VALIDATION_ERROR_3b20053e',
    '"VUID-VkMemoryGetFdInfoKHR-handleType-00672"' : 'VALIDATION_ERROR_3b200540',
    '"VUID-VkMemoryGetFdInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_3b209c01',
    '"VUID-VkMemoryGetFdInfoKHR-memory-parameter"' : 'VALIDATION_ERROR_3b20c601',
    '"VUID-VkMemoryGetFdInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_3b21c40d',
    '"VUID-VkMemoryGetFdInfoKHR-sType-sType"' : 'VALIDATION_ERROR_3b22b00b',
    '"VUID-VkMemoryGetWin32HandleInfoKHR-handleType-00662"' : 'VALIDATION_ERROR_3b40052c',
    '"VUID-VkMemoryGetWin32HandleInfoKHR-handleType-00663"' : 'VALIDATION_ERROR_3b40052e',
    '"VUID-VkMemoryGetWin32HandleInfoKHR-handleType-00664"' : 'VALIDATION_ERROR_3b400530',
    '"VUID-VkMemoryGetWin32HandleInfoKHR-handleType-parameter"' : 'VALIDATION_ERROR_3b409c01',
    '"VUID-VkMemoryGetWin32HandleInfoKHR-memory-parameter"' : 'VALIDATION_ERROR_3b40c601',
    '"VUID-VkMemoryGetWin32HandleInfoKHR-pNext-pNext"' : 'VALIDATION_ERROR_3b41c40d',
    '"VUID-VkMemoryGetWin32HandleInfoKHR-sType-sType"' : 'VALIDATION_ERROR_3b42b00b',
    '"VUID-VkMemoryDedicatedRequirements-sType-sType"' : 'VALIDATION_ERROR_3b62b00b',
    '"VUID-VkMemoryDedicatedAllocateInfo-commonparent"' : 'VALIDATION_ERROR_3b800009',
    '"VUID-VkMemoryDedicatedAllocateInfo-image-01432"' : 'VALIDATION_ERROR_3b800b30',
    '"VUID-VkMemoryDedicatedAllocateInfo-image-01433"' : 'VALIDATION_ERROR_3b800b32',
    '"VUID-VkMemoryDedicatedAllocateInfo-image-01434"' : 'VALIDATION_ERROR_3b800b34',
    '"VUID-VkMemoryDedicatedAllocateInfo-buffer-01435"' : 'VALIDATION_ERROR_3b800b36',
    '"VUID-VkMemoryDedicatedAllocateInfo-buffer-01436"' : 'VALIDATION_ERROR_3b800b38',
    '"VUID-VkMemoryDedicatedAllocateInfo-image-01797"' : 'VALIDATION_ERROR_3b800e0a',
    '"VUID-VkMemoryDedicatedAllocateInfo-image-01876"' : 'VALIDATION_ERROR_3b800ea8',
    '"VUID-VkMemoryDedicatedAllocateInfo-buffer-01877"' : 'VALIDATION_ERROR_3b800eaa',
    '"VUID-VkMemoryDedicatedAllocateInfo-image-01878"' : 'VALIDATION_ERROR_3b800eac',
    '"VUID-VkMemoryDedicatedAllocateInfo-buffer-01879"' : 'VALIDATION_ERROR_3b800eae',
    '"VUID-VkMemoryDedicatedAllocateInfo-buffer-parameter"' : 'VALIDATION_ERROR_3b801a01',
    '"VUID-VkMemoryDedicatedAllocateInfo-image-parameter"' : 'VALIDATION_ERROR_3b80a001',
    '"VUID-VkMemoryDedicatedAllocateInfo-sType-sType"' : 'VALIDATION_ERROR_3b82b00b',
    '"VUID-VkBufferMemoryRequirementsInfo2-buffer-parameter"' : 'VALIDATION_ERROR_3ba01a01',
    '"VUID-VkBufferMemoryRequirementsInfo2-pNext-pNext"' : 'VALIDATION_ERROR_3ba1c40d',
    '"VUID-VkBufferMemoryRequirementsInfo2-sType-sType"' : 'VALIDATION_ERROR_3ba2b00b',
    '"VUID-VkImageMemoryRequirementsInfo2-image-01589"' : 'VALIDATION_ERROR_3bc00c6a',
    '"VUID-VkImageMemoryRequirementsInfo2-image-01590"' : 'VALIDATION_ERROR_3bc00c6c',
    '"VUID-VkImageMemoryRequirementsInfo2-image-01591"' : 'VALIDATION_ERROR_3bc00c6e',
    '"VUID-VkImageMemoryRequirementsInfo2-image-01897"' : 'VALIDATION_ERROR_3bc00ed2',
    '"VUID-VkImageMemoryRequirementsInfo2-image-parameter"' : 'VALIDATION_ERROR_3bc0a001',
    '"VUID-VkImageMemoryRequirementsInfo2-pNext-pNext"' : 'VALIDATION_ERROR_3bc1c40d',
    '"VUID-VkImageMemoryRequirementsInfo2-sType-sType"' : 'VALIDATION_ERROR_3bc2b00b',
    '"VUID-VkImageSparseMemoryRequirementsInfo2-image-parameter"' : 'VALIDATION_ERROR_3be0a001',
    '"VUID-VkImageSparseMemoryRequirementsInfo2-pNext-pNext"' : 'VALIDATION_ERROR_3be1c40d',
    '"VUID-VkImageSparseMemoryRequirementsInfo2-sType-sType"' : 'VALIDATION_ERROR_3be2b00b',
    '"VUID-VkMemoryRequirements2-pNext-pNext"' : 'VALIDATION_ERROR_3c01c40d',
    '"VUID-VkMemoryRequirements2-sType-sType"' : 'VALIDATION_ERROR_3c02b00b',
    '"VUID-VkSparseImageMemoryRequirements2-pNext-pNext"' : 'VALIDATION_ERROR_3c21c40d',
    '"VUID-VkSparseImageMemoryRequirements2-sType-sType"' : 'VALIDATION_ERROR_3c22b00b',
    '"VUID-vkGetImageMemoryRequirements2-device-parameter"' : 'VALIDATION_ERROR_3c405601',
    '"VUID-vkGetImageMemoryRequirements2-pMemoryRequirements-parameter"' : 'VALIDATION_ERROR_3c41b401',
    '"VUID-vkGetImageMemoryRequirements2-pInfo-parameter"' : 'VALIDATION_ERROR_3c439c01',
    '"VUID-vkGetBufferMemoryRequirements2-device-parameter"' : 'VALIDATION_ERROR_3c605601',
    '"VUID-vkGetBufferMemoryRequirements2-pMemoryRequirements-parameter"' : 'VALIDATION_ERROR_3c61b401',
    '"VUID-vkGetBufferMemoryRequirements2-pInfo-parameter"' : 'VALIDATION_ERROR_3c639c01',
    '"VUID-vkGetImageSparseMemoryRequirements2-device-parameter"' : 'VALIDATION_ERROR_3c805601',
    '"VUID-vkGetImageSparseMemoryRequirements2-pSparseMemoryRequirementCount-parameter"' : 'VALIDATION_ERROR_3c823601',
    '"VUID-vkGetImageSparseMemoryRequirements2-pSparseMemoryRequirements-parameter"' : 'VALIDATION_ERROR_3c823801',
    '"VUID-vkGetImageSparseMemoryRequirements2-pInfo-parameter"' : 'VALIDATION_ERROR_3c839c01',
    '"VUID-VkPhysicalDevice16BitStorageFeatures-sType-sType"' : 'VALIDATION_ERROR_3ca2b00b',
    '"VUID-VkPhysicalDeviceVariablePointerFeatures-variablePointers-01431"' : 'VALIDATION_ERROR_3cc00b2e',
    '"VUID-VkPhysicalDeviceVariablePointerFeatures-sType-sType"' : 'VALIDATION_ERROR_3cc2b00b',
    '"VUID-VkSampleLocationsInfoEXT-sampleLocationsPerPixel-01526"' : 'VALIDATION_ERROR_3ce00bec',
    '"VUID-VkSampleLocationsInfoEXT-sampleLocationsCount-01527"' : 'VALIDATION_ERROR_3ce00bee',
    '"VUID-VkSampleLocationsInfoEXT-sType-sType"' : 'VALIDATION_ERROR_3ce2b00b',
    '"VUID-VkSampleLocationsInfoEXT-sampleLocationsPerPixel-parameter"' : 'VALIDATION_ERROR_3ce3b201',
    '"VUID-VkSampleLocationsInfoEXT-sampleLocationsCount-arraylength"' : 'VALIDATION_ERROR_3ce3b41b',
    '"VUID-VkSampleLocationsInfoEXT-pSampleLocations-parameter"' : 'VALIDATION_ERROR_3ce3b601',
    '"VUID-VkRenderPassSampleLocationsBeginInfoEXT-sType-sType"' : 'VALIDATION_ERROR_3d02b00b',
    '"VUID-VkRenderPassSampleLocationsBeginInfoEXT-pAttachmentInitialSampleLocations-parameter"' : 'VALIDATION_ERROR_3d03ba01',
    '"VUID-VkRenderPassSampleLocationsBeginInfoEXT-pPostSubpassSampleLocations-parameter"' : 'VALIDATION_ERROR_3d03e801',
    '"VUID-VkPipelineSampleLocationsStateCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_3d22b00b',
    '"VUID-VkPipelineSampleLocationsStateCreateInfoEXT-sampleLocationsInfo-parameter"' : 'VALIDATION_ERROR_3d23c601',
    '"VUID-VkPhysicalDeviceSampleLocationsPropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_3d42b00b',
    '"VUID-VkMultisamplePropertiesEXT-pNext-pNext"' : 'VALIDATION_ERROR_3d61c40d',
    '"VUID-VkMultisamplePropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_3d62b00b',
    '"VUID-vkGetPhysicalDeviceMultisamplePropertiesEXT-physicalDevice-parameter"' : 'VALIDATION_ERROR_3d827a01',
    '"VUID-vkGetPhysicalDeviceMultisamplePropertiesEXT-samples-parameter"' : 'VALIDATION_ERROR_3d82b401',
    '"VUID-vkGetPhysicalDeviceMultisamplePropertiesEXT-pMultisampleProperties-parameter"' : 'VALIDATION_ERROR_3d83ca01',
    '"VUID-VkValidationCacheCreateInfoEXT-initialDataSize-01534"' : 'VALIDATION_ERROR_3da00bfc',
    '"VUID-VkValidationCacheCreateInfoEXT-initialDataSize-01535"' : 'VALIDATION_ERROR_3da00bfe',
    '"VUID-VkValidationCacheCreateInfoEXT-flags-zerobitmask"' : 'VALIDATION_ERROR_3da09005',
    '"VUID-VkValidationCacheCreateInfoEXT-pInitialData-parameter"' : 'VALIDATION_ERROR_3da19601',
    '"VUID-VkValidationCacheCreateInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_3da1c40d',
    '"VUID-VkValidationCacheCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_3da2b00b',
    '"VUID-VkShaderModuleValidationCacheCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_3dc2b00b',
    '"VUID-VkShaderModuleValidationCacheCreateInfoEXT-validationCache-parameter"' : 'VALIDATION_ERROR_3dc3c401',
    '"VUID-vkCreateValidationCacheEXT-device-parameter"' : 'VALIDATION_ERROR_3de05601',
    '"VUID-vkCreateValidationCacheEXT-pAllocator-parameter"' : 'VALIDATION_ERROR_3de0ec01',
    '"VUID-vkCreateValidationCacheEXT-pCreateInfo-parameter"' : 'VALIDATION_ERROR_3de11e01',
    '"VUID-vkCreateValidationCacheEXT-pValidationCache-parameter"' : 'VALIDATION_ERROR_3de3c201',
    '"VUID-vkGetValidationCacheDataEXT-device-parameter"' : 'VALIDATION_ERROR_3e005601',
    '"VUID-vkGetValidationCacheDataEXT-pData-parameter"' : 'VALIDATION_ERROR_3e012201',
    '"VUID-vkGetValidationCacheDataEXT-pDataSize-parameter"' : 'VALIDATION_ERROR_3e012401',
    '"VUID-vkGetValidationCacheDataEXT-validationCache-parameter"' : 'VALIDATION_ERROR_3e03c401',
    '"VUID-vkGetValidationCacheDataEXT-validationCache-parent"' : 'VALIDATION_ERROR_3e03c407',
    '"VUID-vkCmdSetSampleLocationsEXT-None-01528"' : 'VALIDATION_ERROR_3e200bf0',
    '"VUID-vkCmdSetSampleLocationsEXT-sampleLocationsPerPixel-01529"' : 'VALIDATION_ERROR_3e200bf2',
    '"VUID-vkCmdSetSampleLocationsEXT-variableSampleLocations-01530"' : 'VALIDATION_ERROR_3e200bf4',
    '"VUID-vkCmdSetSampleLocationsEXT-commandBuffer-parameter"' : 'VALIDATION_ERROR_3e202401',
    '"VUID-vkCmdSetSampleLocationsEXT-commandBuffer-recording"' : 'VALIDATION_ERROR_3e202413',
    '"VUID-vkCmdSetSampleLocationsEXT-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_3e202415',
    '"VUID-vkCmdSetSampleLocationsEXT-pSampleLocationsInfo-parameter"' : 'VALIDATION_ERROR_3e23c801',
    '"VUID-vkDestroyValidationCacheEXT-validationCache-01537"' : 'VALIDATION_ERROR_3e400c02',
    '"VUID-vkDestroyValidationCacheEXT-validationCache-01538"' : 'VALIDATION_ERROR_3e400c04',
    '"VUID-vkDestroyValidationCacheEXT-device-parameter"' : 'VALIDATION_ERROR_3e405601',
    '"VUID-vkDestroyValidationCacheEXT-pAllocator-parameter"' : 'VALIDATION_ERROR_3e40ec01',
    '"VUID-vkDestroyValidationCacheEXT-validationCache-parameter"' : 'VALIDATION_ERROR_3e43c401',
    '"VUID-vkDestroyValidationCacheEXT-validationCache-parent"' : 'VALIDATION_ERROR_3e43c407',
    '"VUID-vkMergeValidationCachesEXT-dstCache-01536"' : 'VALIDATION_ERROR_3e600c00',
    '"VUID-vkMergeValidationCachesEXT-device-parameter"' : 'VALIDATION_ERROR_3e605601',
    '"VUID-vkMergeValidationCachesEXT-dstCache-parameter"' : 'VALIDATION_ERROR_3e606e01',
    '"VUID-vkMergeValidationCachesEXT-dstCache-parent"' : 'VALIDATION_ERROR_3e606e07',
    '"VUID-vkMergeValidationCachesEXT-pSrcCaches-parameter"' : 'VALIDATION_ERROR_3e623c01',
    '"VUID-vkMergeValidationCachesEXT-pSrcCaches-parent"' : 'VALIDATION_ERROR_3e623c07',
    '"VUID-vkMergeValidationCachesEXT-srcCacheCount-arraylength"' : 'VALIDATION_ERROR_3e62ca1b',
    '"VUID-VkAttachmentSampleLocationsEXT-attachmentIndex-01531"' : 'VALIDATION_ERROR_3e800bf6',
    '"VUID-VkAttachmentSampleLocationsEXT-sampleLocationsInfo-parameter"' : 'VALIDATION_ERROR_3e83c601',
    '"VUID-VkSubpassSampleLocationsEXT-subpassIndex-01532"' : 'VALIDATION_ERROR_3ea00bf8',
    '"VUID-VkSubpassSampleLocationsEXT-sampleLocationsInfo-parameter"' : 'VALIDATION_ERROR_3ea3c601',
    '"VUID-VkPhysicalDevicePointClippingProperties-sType-sType"' : 'VALIDATION_ERROR_3ec2b00b',
    '"VUID-VkInputAttachmentAspectReference-aspectMask-parameter"' : 'VALIDATION_ERROR_3ee00c01',
    '"VUID-VkInputAttachmentAspectReference-aspectMask-requiredbitmask"' : 'VALIDATION_ERROR_3ee00c03',
    '"VUID-VkInputAttachmentAspectReference-pCreateInfo-01568"' : 'VALIDATION_ERROR_3ee00c40',
    '"VUID-VkInputAttachmentAspectReference-None-01569"' : 'VALIDATION_ERROR_3ee00c42',
    '"VUID-VkInputAttachmentAspectReference-aspectMask-01570"' : 'VALIDATION_ERROR_3ee00c44',
    '"VUID-VkRenderPassInputAttachmentAspectCreateInfo-sType-sType"' : 'VALIDATION_ERROR_3f02b00b',
    '"VUID-VkRenderPassInputAttachmentAspectCreateInfo-aspectReferenceCount-arraylength"' : 'VALIDATION_ERROR_3f03ce1b',
    '"VUID-VkRenderPassInputAttachmentAspectCreateInfo-pAspectReferences-parameter"' : 'VALIDATION_ERROR_3f03d001',
    '"VUID-VkImageViewUsageCreateInfo-usage-01587"' : 'VALIDATION_ERROR_3f200c66',
    '"VUID-VkImageViewUsageCreateInfo-sType-sType"' : 'VALIDATION_ERROR_3f22b00b',
    '"VUID-VkImageViewUsageCreateInfo-usage-parameter"' : 'VALIDATION_ERROR_3f230601',
    '"VUID-VkImageViewUsageCreateInfo-usage-requiredbitmask"' : 'VALIDATION_ERROR_3f230603',
    '"VUID-VkPipelineTessellationDomainOriginStateCreateInfo-sType-sType"' : 'VALIDATION_ERROR_3f42b00b',
    '"VUID-VkPipelineTessellationDomainOriginStateCreateInfo-domainOrigin-parameter"' : 'VALIDATION_ERROR_3f43d201',
    '"VUID-VkImageFormatListCreateInfoKHR-viewFormatCount-01578"' : 'VALIDATION_ERROR_3f600c54',
    '"VUID-VkImageFormatListCreateInfoKHR-flags-01579"' : 'VALIDATION_ERROR_3f600c56',
    '"VUID-VkImageFormatListCreateInfoKHR-viewFormatCount-01580"' : 'VALIDATION_ERROR_3f600c58',
    '"VUID-VkImageFormatListCreateInfoKHR-sType-sType"' : 'VALIDATION_ERROR_3f62b00b',
    '"VUID-VkImageFormatListCreateInfoKHR-pViewFormats-parameter"' : 'VALIDATION_ERROR_3f63e401',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-format-01649"' : 'VALIDATION_ERROR_3f800ce2',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-format-01650"' : 'VALIDATION_ERROR_3f800ce4',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-xChromaOffset-01651"' : 'VALIDATION_ERROR_3f800ce6',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-xChromaOffset-01652"' : 'VALIDATION_ERROR_3f800ce8',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-format-01653"' : 'VALIDATION_ERROR_3f800cea',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-None-01654"' : 'VALIDATION_ERROR_3f800cec',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-ycbcrModel-01655"' : 'VALIDATION_ERROR_3f800cee',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-forceExplicitReconstruction-01656"' : 'VALIDATION_ERROR_3f800cf0',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-chromaFilter-01657"' : 'VALIDATION_ERROR_3f800cf2',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-format-01904"' : 'VALIDATION_ERROR_3f800ee0',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-components-parameter"' : 'VALIDATION_ERROR_3f802c01',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-format-parameter"' : 'VALIDATION_ERROR_3f809201',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-pNext-pNext"' : 'VALIDATION_ERROR_3f81c40d',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-sType-sType"' : 'VALIDATION_ERROR_3f82b00b',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-ycbcrModel-parameter"' : 'VALIDATION_ERROR_3f83d401',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-ycbcrRange-parameter"' : 'VALIDATION_ERROR_3f83d601',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-xChromaOffset-parameter"' : 'VALIDATION_ERROR_3f83d801',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-yChromaOffset-parameter"' : 'VALIDATION_ERROR_3f83da01',
    '"VUID-VkSamplerYcbcrConversionCreateInfo-chromaFilter-parameter"' : 'VALIDATION_ERROR_3f83dc01',
    '"VUID-VkBindImagePlaneMemoryInfo-planeAspect-01642"' : 'VALIDATION_ERROR_3fa00cd4',
    '"VUID-VkBindImagePlaneMemoryInfo-None-01643"' : 'VALIDATION_ERROR_3fa00cd6',
    '"VUID-VkBindImagePlaneMemoryInfo-sType-sType"' : 'VALIDATION_ERROR_3fa2b00b',
    '"VUID-VkBindImagePlaneMemoryInfo-planeAspect-parameter"' : 'VALIDATION_ERROR_3fa3de01',
    '"VUID-VkImagePlaneMemoryRequirementsInfo-planeAspect-01592"' : 'VALIDATION_ERROR_3fc00c70',
    '"VUID-VkImagePlaneMemoryRequirementsInfo-sType-sType"' : 'VALIDATION_ERROR_3fc2b00b',
    '"VUID-VkImagePlaneMemoryRequirementsInfo-planeAspect-parameter"' : 'VALIDATION_ERROR_3fc3de01',
    '"VUID-vkCreateSamplerYcbcrConversion-None-01648"' : 'VALIDATION_ERROR_3fe00ce0',
    '"VUID-vkCreateSamplerYcbcrConversion-device-parameter"' : 'VALIDATION_ERROR_3fe05601',
    '"VUID-vkCreateSamplerYcbcrConversion-pAllocator-parameter"' : 'VALIDATION_ERROR_3fe0ec01',
    '"VUID-vkCreateSamplerYcbcrConversion-pCreateInfo-parameter"' : 'VALIDATION_ERROR_3fe11e01',
    '"VUID-vkCreateSamplerYcbcrConversion-pYcbcrConversion-parameter"' : 'VALIDATION_ERROR_3fe3e001',
    '"VUID-VkBindBufferMemoryDeviceGroupInfo-deviceIndexCount-01606"' : 'VALIDATION_ERROR_40000c8c',
    '"VUID-VkBindBufferMemoryDeviceGroupInfo-pDeviceIndices-01607"' : 'VALIDATION_ERROR_40000c8e',
    '"VUID-VkBindBufferMemoryDeviceGroupInfo-pDeviceIndices-parameter"' : 'VALIDATION_ERROR_40013e01',
    '"VUID-VkBindBufferMemoryDeviceGroupInfo-sType-sType"' : 'VALIDATION_ERROR_4002b00b',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-deviceIndexCount-01633"' : 'VALIDATION_ERROR_40200cc2',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-deviceIndexCount-01634"' : 'VALIDATION_ERROR_40200cc4',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-pDeviceIndices-01635"' : 'VALIDATION_ERROR_40200cc6',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-splitInstanceBindRegionCount-01636"' : 'VALIDATION_ERROR_40200cc8',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-pSplitInstanceBindRegions-01637"' : 'VALIDATION_ERROR_40200cca',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-offset-01638"' : 'VALIDATION_ERROR_40200ccc',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-offset-01639"' : 'VALIDATION_ERROR_40200cce',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-extent-01640"' : 'VALIDATION_ERROR_40200cd0',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-extent-01641"' : 'VALIDATION_ERROR_40200cd2',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-pDeviceIndices-parameter"' : 'VALIDATION_ERROR_40213e01',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-sType-sType"' : 'VALIDATION_ERROR_4022b00b',
    '"VUID-VkBindImageMemoryDeviceGroupInfo-pSplitInstanceBindRegions-parameter"' : 'VALIDATION_ERROR_4023fe01',
    '"VUID-vkDestroySamplerYcbcrConversion-device-parameter"' : 'VALIDATION_ERROR_40405601',
    '"VUID-vkDestroySamplerYcbcrConversion-pAllocator-parameter"' : 'VALIDATION_ERROR_4040ec01',
    '"VUID-vkDestroySamplerYcbcrConversion-ycbcrConversion-parameter"' : 'VALIDATION_ERROR_4043e201',
    '"VUID-vkDestroySamplerYcbcrConversion-ycbcrConversion-parent"' : 'VALIDATION_ERROR_4043e207',
    '"VUID-VkPhysicalDeviceSamplerYcbcrConversionFeatures-sType-sType"' : 'VALIDATION_ERROR_4062b00b',
    '"VUID-VkSamplerYcbcrConversionImageFormatProperties-sType-sType"' : 'VALIDATION_ERROR_4082b00b',
    '"VUID-VkSamplerYcbcrConversionInfo-sType-sType"' : 'VALIDATION_ERROR_40a2b00b',
    '"VUID-VkSamplerYcbcrConversionInfo-conversion-parameter"' : 'VALIDATION_ERROR_40a3e601',
    '"VUID-VkDeviceQueueGlobalPriorityCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_40c2b00b',
    '"VUID-VkDeviceQueueGlobalPriorityCreateInfoEXT-globalPriority-parameter"' : 'VALIDATION_ERROR_40c3ea01',
    '"VUID-vkGetShaderInfoAMD-device-parameter"' : 'VALIDATION_ERROR_40e05601',
    '"VUID-vkGetShaderInfoAMD-pipeline-parameter"' : 'VALIDATION_ERROR_40e27c01',
    '"VUID-vkGetShaderInfoAMD-pipeline-parent"' : 'VALIDATION_ERROR_40e27c07',
    '"VUID-vkGetShaderInfoAMD-pInfo-parameter"' : 'VALIDATION_ERROR_40e39c01',
    '"VUID-vkGetShaderInfoAMD-shaderStage-parameter"' : 'VALIDATION_ERROR_40e3ec01',
    '"VUID-vkGetShaderInfoAMD-infoType-parameter"' : 'VALIDATION_ERROR_40e3ee01',
    '"VUID-vkGetShaderInfoAMD-pInfoSize-parameter"' : 'VALIDATION_ERROR_40e3f001',
    '"VUID-VkImportMemoryHostPointerInfoEXT-handleType-01747"' : 'VALIDATION_ERROR_41200da6',
    '"VUID-VkImportMemoryHostPointerInfoEXT-handleType-01748"' : 'VALIDATION_ERROR_41200da8',
    '"VUID-VkImportMemoryHostPointerInfoEXT-pHostPointer-01749"' : 'VALIDATION_ERROR_41200daa',
    '"VUID-VkImportMemoryHostPointerInfoEXT-handleType-01750"' : 'VALIDATION_ERROR_41200dac',
    '"VUID-VkImportMemoryHostPointerInfoEXT-handleType-01751"' : 'VALIDATION_ERROR_41200dae',
    '"VUID-VkImportMemoryHostPointerInfoEXT-handleType-parameter"' : 'VALIDATION_ERROR_41209c01',
    '"VUID-VkImportMemoryHostPointerInfoEXT-sType-sType"' : 'VALIDATION_ERROR_4122b00b',
    '"VUID-VkMemoryHostPointerPropertiesEXT-pNext-pNext"' : 'VALIDATION_ERROR_4141c40d',
    '"VUID-VkMemoryHostPointerPropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_4142b00b',
    '"VUID-VkPhysicalDeviceExternalMemoryHostPropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_4162b00b',
    '"VUID-vkGetMemoryHostPointerPropertiesEXT-handleType-01752"' : 'VALIDATION_ERROR_41800db0',
    '"VUID-vkGetMemoryHostPointerPropertiesEXT-pHostPointer-01753"' : 'VALIDATION_ERROR_41800db2',
    '"VUID-vkGetMemoryHostPointerPropertiesEXT-handleType-01754"' : 'VALIDATION_ERROR_41800db4',
    '"VUID-vkGetMemoryHostPointerPropertiesEXT-handleType-01755"' : 'VALIDATION_ERROR_41800db6',
    '"VUID-vkGetMemoryHostPointerPropertiesEXT-device-parameter"' : 'VALIDATION_ERROR_41805601',
    '"VUID-vkGetMemoryHostPointerPropertiesEXT-handleType-parameter"' : 'VALIDATION_ERROR_41809c01',
    '"VUID-vkGetMemoryHostPointerPropertiesEXT-pMemoryHostPointerProperties-parameter"' : 'VALIDATION_ERROR_4183f401',
    '"VUID-VkPhysicalDeviceConservativeRasterizationPropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_41a2b00b',
    '"VUID-VkPipelineRasterizationConservativeStateCreateInfoEXT-extraPrimitiveOverestimationSize-01769"' : 'VALIDATION_ERROR_41c00dd2',
    '"VUID-VkPipelineRasterizationConservativeStateCreateInfoEXT-flags-zerobitmask"' : 'VALIDATION_ERROR_41c09005',
    '"VUID-VkPipelineRasterizationConservativeStateCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_41c2b00b',
    '"VUID-VkPipelineRasterizationConservativeStateCreateInfoEXT-conservativeRasterizationMode-parameter"' : 'VALIDATION_ERROR_41c3f801',
    '"VUID-vkCmdWriteBufferMarkerAMD-commonparent"' : 'VALIDATION_ERROR_41e00009',
    '"VUID-vkCmdWriteBufferMarkerAMD-dstOffset-01798"' : 'VALIDATION_ERROR_41e00e0c',
    '"VUID-vkCmdWriteBufferMarkerAMD-dstBuffer-01799"' : 'VALIDATION_ERROR_41e00e0e',
    '"VUID-vkCmdWriteBufferMarkerAMD-dstBuffer-01800"' : 'VALIDATION_ERROR_41e00e10',
    '"VUID-vkCmdWriteBufferMarkerAMD-dstOffset-01801"' : 'VALIDATION_ERROR_41e00e12',
    '"VUID-vkCmdWriteBufferMarkerAMD-commandBuffer-parameter"' : 'VALIDATION_ERROR_41e02401',
    '"VUID-vkCmdWriteBufferMarkerAMD-commandBuffer-recording"' : 'VALIDATION_ERROR_41e02413',
    '"VUID-vkCmdWriteBufferMarkerAMD-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_41e02415',
    '"VUID-vkCmdWriteBufferMarkerAMD-dstBuffer-parameter"' : 'VALIDATION_ERROR_41e06c01',
    '"VUID-vkCmdWriteBufferMarkerAMD-pipelineStage-parameter"' : 'VALIDATION_ERROR_41e28401',
    '"VUID-VkDescriptorSetLayoutSupport-pNext-pNext"' : 'VALIDATION_ERROR_4201c40d',
    '"VUID-VkDescriptorSetLayoutSupport-sType-sType"' : 'VALIDATION_ERROR_4202b00b',
    '"VUID-VkDeviceQueueInfo2-queueFamilyIndex-01842"' : 'VALIDATION_ERROR_42200e64',
    '"VUID-VkDeviceQueueInfo2-queueIndex-01843"' : 'VALIDATION_ERROR_42200e66',
    '"VUID-VkDeviceQueueInfo2-flags-parameter"' : 'VALIDATION_ERROR_42209001',
    '"VUID-VkDeviceQueueInfo2-flags-requiredbitmask"' : 'VALIDATION_ERROR_42209003',
    '"VUID-VkDeviceQueueInfo2-pNext-pNext"' : 'VALIDATION_ERROR_4221c40d',
    '"VUID-VkDeviceQueueInfo2-sType-sType"' : 'VALIDATION_ERROR_4222b00b',
    '"VUID-VkPhysicalDeviceMaintenance3Properties-sType-sType"' : 'VALIDATION_ERROR_4242b00b',
    '"VUID-VkPhysicalDeviceProtectedMemoryFeatures-sType-sType"' : 'VALIDATION_ERROR_4262b00b',
    '"VUID-VkPhysicalDeviceProtectedMemoryProperties-sType-sType"' : 'VALIDATION_ERROR_4282b00b',
    '"VUID-VkPhysicalDeviceShaderDrawParameterFeatures-sType-sType"' : 'VALIDATION_ERROR_42a2b00b',
    '"VUID-VkPhysicalDeviceSubgroupProperties-sType-sType"' : 'VALIDATION_ERROR_42c2b00b',
    '"VUID-VkProtectedSubmitInfo-protectedSubmit-01816"' : 'VALIDATION_ERROR_42e00e30',
    '"VUID-VkProtectedSubmitInfo-protectedSubmit-01817"' : 'VALIDATION_ERROR_42e00e32',
    '"VUID-VkProtectedSubmitInfo-protectedSubmit-01818"' : 'VALIDATION_ERROR_42e00e34',
    '"VUID-VkProtectedSubmitInfo-pNext-01819"' : 'VALIDATION_ERROR_42e00e36',
    '"VUID-VkProtectedSubmitInfo-sType-sType"' : 'VALIDATION_ERROR_42e2b00b',
    '"VUID-vkEnumerateInstanceVersion-pApiVersion-parameter"' : 'VALIDATION_ERROR_43040001',
    '"VUID-vkGetDescriptorSetLayoutSupport-device-parameter"' : 'VALIDATION_ERROR_43205601',
    '"VUID-vkGetDescriptorSetLayoutSupport-pCreateInfo-parameter"' : 'VALIDATION_ERROR_43211e01',
    '"VUID-vkGetDescriptorSetLayoutSupport-pSupport-parameter"' : 'VALIDATION_ERROR_43240201',
    '"VUID-vkGetDeviceQueue2-device-parameter"' : 'VALIDATION_ERROR_43405601',
    '"VUID-vkGetDeviceQueue2-pQueue-parameter"' : 'VALIDATION_ERROR_4341fc01',
    '"VUID-vkGetDeviceQueue2-pQueueInfo-parameter"' : 'VALIDATION_ERROR_43440401',
    '"VUID-VkDebugUtilsObjectNameInfoEXT-objectType-01905"' : 'VALIDATION_ERROR_43600ee2',
    '"VUID-VkDebugUtilsObjectNameInfoEXT-objectHandle-01906"' : 'VALIDATION_ERROR_43600ee4',
    '"VUID-VkDebugUtilsObjectNameInfoEXT-objectHandle-01907"' : 'VALIDATION_ERROR_43600ee6',
    '"VUID-VkDebugUtilsObjectNameInfoEXT-objectType-parameter"' : 'VALIDATION_ERROR_4360da01',
    '"VUID-VkDebugUtilsObjectNameInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_4361c40d',
    '"VUID-VkDebugUtilsObjectNameInfoEXT-pObjectName-parameter"' : 'VALIDATION_ERROR_4361ce01',
    '"VUID-VkDebugUtilsObjectNameInfoEXT-sType-sType"' : 'VALIDATION_ERROR_4362b00b',
    '"VUID-VkDebugUtilsObjectTagInfoEXT-objectType-01908"' : 'VALIDATION_ERROR_43800ee8',
    '"VUID-VkDebugUtilsObjectTagInfoEXT-objectHandle-01909"' : 'VALIDATION_ERROR_43800eea',
    '"VUID-VkDebugUtilsObjectTagInfoEXT-objectHandle-01910"' : 'VALIDATION_ERROR_43800eec',
    '"VUID-VkDebugUtilsObjectTagInfoEXT-objectType-parameter"' : 'VALIDATION_ERROR_4380da01',
    '"VUID-VkDebugUtilsObjectTagInfoEXT-pNext-pNext"' : 'VALIDATION_ERROR_4381c40d',
    '"VUID-VkDebugUtilsObjectTagInfoEXT-pTag-parameter"' : 'VALIDATION_ERROR_43825a01',
    '"VUID-VkDebugUtilsObjectTagInfoEXT-sType-sType"' : 'VALIDATION_ERROR_4382b00b',
    '"VUID-VkDebugUtilsObjectTagInfoEXT-tagSize-arraylength"' : 'VALIDATION_ERROR_4382f41b',
    '"VUID-VkDebugUtilsLabelEXT-pNext-pNext"' : 'VALIDATION_ERROR_43a1c40d',
    '"VUID-VkDebugUtilsLabelEXT-sType-sType"' : 'VALIDATION_ERROR_43a2b00b',
    '"VUID-VkDebugUtilsLabelEXT-pLabelName-parameter"' : 'VALIDATION_ERROR_43a40801',
    '"VUID-VkDebugUtilsMessengerCallbackDataEXT-flags-zerobitmask"' : 'VALIDATION_ERROR_43c09005',
    '"VUID-VkDebugUtilsMessengerCallbackDataEXT-objectCount-arraylength"' : 'VALIDATION_ERROR_43c0d61b',
    '"VUID-VkDebugUtilsMessengerCallbackDataEXT-pMessage-parameter"' : 'VALIDATION_ERROR_43c1b801',
    '"VUID-VkDebugUtilsMessengerCallbackDataEXT-pNext-pNext"' : 'VALIDATION_ERROR_43c1c40d',
    '"VUID-VkDebugUtilsMessengerCallbackDataEXT-sType-sType"' : 'VALIDATION_ERROR_43c2b00b',
    '"VUID-VkDebugUtilsMessengerCallbackDataEXT-pMessageIdName-parameter"' : 'VALIDATION_ERROR_43c42201',
    '"VUID-VkDebugUtilsMessengerCreateInfoEXT-pfnUserCallback-01914"' : 'VALIDATION_ERROR_43e00ef4',
    '"VUID-VkDebugUtilsMessengerCreateInfoEXT-flags-zerobitmask"' : 'VALIDATION_ERROR_43e09005',
    '"VUID-VkDebugUtilsMessengerCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_43e2b00b',
    '"VUID-VkDebugUtilsMessengerCreateInfoEXT-messageSeverity-parameter"' : 'VALIDATION_ERROR_43e40a01',
    '"VUID-VkDebugUtilsMessengerCreateInfoEXT-messageSeverity-requiredbitmask"' : 'VALIDATION_ERROR_43e40a03',
    '"VUID-VkDebugUtilsMessengerCreateInfoEXT-messageType-parameter"' : 'VALIDATION_ERROR_43e40c01',
    '"VUID-VkDebugUtilsMessengerCreateInfoEXT-messageType-requiredbitmask"' : 'VALIDATION_ERROR_43e40c03',
    '"VUID-vkCreateDebugUtilsMessengerEXT-instance-parameter"' : 'VALIDATION_ERROR_4400bc01',
    '"VUID-vkCreateDebugUtilsMessengerEXT-pAllocator-parameter"' : 'VALIDATION_ERROR_4400ec01',
    '"VUID-vkCreateDebugUtilsMessengerEXT-pCreateInfo-parameter"' : 'VALIDATION_ERROR_44011e01',
    '"VUID-vkCreateDebugUtilsMessengerEXT-pMessenger-parameter"' : 'VALIDATION_ERROR_44041001',
    '"VUID-vkSubmitDebugUtilsMessageEXT-instance-parameter"' : 'VALIDATION_ERROR_4420bc01',
    '"VUID-vkSubmitDebugUtilsMessageEXT-messageSeverity-parameter"' : 'VALIDATION_ERROR_44240a01',
    '"VUID-vkSubmitDebugUtilsMessageEXT-messageTypes-parameter"' : 'VALIDATION_ERROR_44241201',
    '"VUID-vkSubmitDebugUtilsMessageEXT-messageTypes-requiredbitmask"' : 'VALIDATION_ERROR_44241203',
    '"VUID-vkSubmitDebugUtilsMessageEXT-pCallbackData-parameter"' : 'VALIDATION_ERROR_44242801',
    '"VUID-VkPhysicalDeviceVertexAttributeDivisorPropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_4442b00b',
    '"VUID-VkPipelineVertexInputDivisorStateCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_4462b00b',
    '"VUID-VkPipelineVertexInputDivisorStateCreateInfoEXT-vertexBindingDivisorCount-arraylength"' : 'VALIDATION_ERROR_4464141b',
    '"VUID-VkPipelineVertexInputDivisorStateCreateInfoEXT-pVertexBindingDivisors-parameter"' : 'VALIDATION_ERROR_44641601',
    '"VUID-VkExternalFormatANDROID-externalFormat-01894"' : 'VALIDATION_ERROR_44800ecc',
    '"VUID-VkExternalFormatANDROID-sType-sType"' : 'VALIDATION_ERROR_4482b00b',
    '"VUID-VkImportAndroidHardwareBufferInfoANDROID-buffer-01880"' : 'VALIDATION_ERROR_44a00eb0',
    '"VUID-VkImportAndroidHardwareBufferInfoANDROID-buffer-01881"' : 'VALIDATION_ERROR_44a00eb2',
    '"VUID-VkImportAndroidHardwareBufferInfoANDROID-buffer-parameter"' : 'VALIDATION_ERROR_44a01a01',
    '"VUID-VkImportAndroidHardwareBufferInfoANDROID-sType-sType"' : 'VALIDATION_ERROR_44a2b00b',
    '"VUID-VkMemoryGetAndroidHardwareBufferInfoANDROID-handleTypes-01882"' : 'VALIDATION_ERROR_44c00eb4',
    '"VUID-VkMemoryGetAndroidHardwareBufferInfoANDROID-pNext-01883"' : 'VALIDATION_ERROR_44c00eb6',
    '"VUID-vkCmdEndDebugUtilsLabelEXT-commandBuffer-01912"' : 'VALIDATION_ERROR_44e00ef0',
    '"VUID-vkCmdEndDebugUtilsLabelEXT-commandBuffer-01913"' : 'VALIDATION_ERROR_44e00ef2',
    '"VUID-vkCmdEndDebugUtilsLabelEXT-commandBuffer-parameter"' : 'VALIDATION_ERROR_44e02401',
    '"VUID-vkCmdEndDebugUtilsLabelEXT-commandBuffer-recording"' : 'VALIDATION_ERROR_44e02413',
    '"VUID-vkCmdEndDebugUtilsLabelEXT-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_44e02415',
    '"VUID-vkDestroyDebugUtilsMessengerEXT-messenger-01915"' : 'VALIDATION_ERROR_45000ef6',
    '"VUID-vkDestroyDebugUtilsMessengerEXT-messenger-01916"' : 'VALIDATION_ERROR_45000ef8',
    '"VUID-vkDestroyDebugUtilsMessengerEXT-instance-parameter"' : 'VALIDATION_ERROR_4500bc01',
    '"VUID-vkDestroyDebugUtilsMessengerEXT-pAllocator-parameter"' : 'VALIDATION_ERROR_4500ec01',
    '"VUID-vkDestroyDebugUtilsMessengerEXT-messenger-parameter"' : 'VALIDATION_ERROR_45042601',
    '"VUID-vkDestroyDebugUtilsMessengerEXT-messenger-parent"' : 'VALIDATION_ERROR_45042607',
    '"VUID-vkGetAndroidHardwareBufferPropertiesANDROID-buffer-01884"' : 'VALIDATION_ERROR_45200eb8',
    '"VUID-vkGetAndroidHardwareBufferPropertiesANDROID-buffer-parameter"' : 'VALIDATION_ERROR_45201a01',
    '"VUID-vkGetAndroidHardwareBufferPropertiesANDROID-device-parameter"' : 'VALIDATION_ERROR_45205601',
    '"VUID-vkGetAndroidHardwareBufferPropertiesANDROID-pProperties-parameter"' : 'VALIDATION_ERROR_4521f401',
    '"VUID-vkQueueEndDebugUtilsLabelEXT-None-01911"' : 'VALIDATION_ERROR_45400eee',
    '"VUID-vkQueueEndDebugUtilsLabelEXT-queue-parameter"' : 'VALIDATION_ERROR_45429c01',
    '"VUID-VkAndroidHardwareBufferUsageANDROID-sType-sType"' : 'VALIDATION_ERROR_4562b00b',
    '"VUID-vkGetMemoryAndroidHardwareBufferANDROID-device-parameter"' : 'VALIDATION_ERROR_45a05601',
    '"VUID-vkGetMemoryAndroidHardwareBufferANDROID-pBuffer-parameter"' : 'VALIDATION_ERROR_45a10001',
    '"VUID-vkGetMemoryAndroidHardwareBufferANDROID-pInfo-parameter"' : 'VALIDATION_ERROR_45a39c01',
    '"VUID-VkAndroidHardwareBufferFormatPropertiesANDROID-sType-sType"' : 'VALIDATION_ERROR_45c2b00b',
    '"VUID-vkCmdBeginDebugUtilsLabelEXT-commandBuffer-parameter"' : 'VALIDATION_ERROR_45e02401',
    '"VUID-vkCmdBeginDebugUtilsLabelEXT-commandBuffer-recording"' : 'VALIDATION_ERROR_45e02413',
    '"VUID-vkCmdBeginDebugUtilsLabelEXT-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_45e02415',
    '"VUID-vkCmdBeginDebugUtilsLabelEXT-pLabelInfo-parameter"' : 'VALIDATION_ERROR_45e42401',
    '"VUID-vkCmdInsertDebugUtilsLabelEXT-commandBuffer-parameter"' : 'VALIDATION_ERROR_46002401',
    '"VUID-vkCmdInsertDebugUtilsLabelEXT-commandBuffer-recording"' : 'VALIDATION_ERROR_46002413',
    '"VUID-vkCmdInsertDebugUtilsLabelEXT-commandBuffer-cmdpool"' : 'VALIDATION_ERROR_46002415',
    '"VUID-vkCmdInsertDebugUtilsLabelEXT-pLabelInfo-parameter"' : 'VALIDATION_ERROR_46042401',
    '"VUID-vkQueueBeginDebugUtilsLabelEXT-queue-parameter"' : 'VALIDATION_ERROR_46229c01',
    '"VUID-vkQueueBeginDebugUtilsLabelEXT-pLabelInfo-parameter"' : 'VALIDATION_ERROR_46242401',
    '"VUID-vkQueueInsertDebugUtilsLabelEXT-queue-parameter"' : 'VALIDATION_ERROR_46429c01',
    '"VUID-vkQueueInsertDebugUtilsLabelEXT-pLabelInfo-parameter"' : 'VALIDATION_ERROR_46442401',
    '"VUID-vkSetDebugUtilsObjectNameEXT-device-parameter"' : 'VALIDATION_ERROR_46605601',
    '"VUID-vkSetDebugUtilsObjectNameEXT-pNameInfo-parameter"' : 'VALIDATION_ERROR_4661c201',
    '"VUID-vkSetDebugUtilsObjectTagEXT-device-parameter"' : 'VALIDATION_ERROR_46805601',
    '"VUID-vkSetDebugUtilsObjectTagEXT-pTagInfo-parameter"' : 'VALIDATION_ERROR_46825c01',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-bindingCount-03002"' : 'VALIDATION_ERROR_46a01774',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-flags-03003"' : 'VALIDATION_ERROR_46a01776',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-pBindingFlags-03004"' : 'VALIDATION_ERROR_46a01778',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingUniformBufferUpdateAfterBind-03005"' : 'VALIDATION_ERROR_46a0177a',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingSampledImageUpdateAfterBind-03006"' : 'VALIDATION_ERROR_46a0177c',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingStorageImageUpdateAfterBind-03007"' : 'VALIDATION_ERROR_46a0177e',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingStorageBufferUpdateAfterBind-03008"' : 'VALIDATION_ERROR_46a01780',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingUniformTexelBufferUpdateAfterBind-03009"' : 'VALIDATION_ERROR_46a01782',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingStorageTexelBufferUpdateAfterBind-03010"' : 'VALIDATION_ERROR_46a01784',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-None-03011"' : 'VALIDATION_ERROR_46a01786',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingUpdateUnusedWhilePending-03012"' : 'VALIDATION_ERROR_46a01788',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingPartiallyBound-03013"' : 'VALIDATION_ERROR_46a0178a',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-descriptorBindingVariableDescriptorCount-03014"' : 'VALIDATION_ERROR_46a0178c',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-pBindingFlags-03015"' : 'VALIDATION_ERROR_46a0178e',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_46a2b00b',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-pBindingFlags-parameter"' : 'VALIDATION_ERROR_46a42a01',
    '"VUID-VkDescriptorSetLayoutBindingFlagsCreateInfoEXT-pBindingFlags-requiredbitmask"' : 'VALIDATION_ERROR_46a42a03',
    '"VUID-VkDescriptorSetVariableDescriptorCountAllocateInfoEXT-descriptorSetCount-03045"' : 'VALIDATION_ERROR_46c017ca',
    '"VUID-VkDescriptorSetVariableDescriptorCountAllocateInfoEXT-pSetLayouts-03046"' : 'VALIDATION_ERROR_46c017cc',
    '"VUID-VkDescriptorSetVariableDescriptorCountAllocateInfoEXT-sType-sType"' : 'VALIDATION_ERROR_46c2b00b',
    '"VUID-VkDescriptorSetVariableDescriptorCountAllocateInfoEXT-pDescriptorCounts-parameter"' : 'VALIDATION_ERROR_46c42c01',
    '"VUID-VkDescriptorSetVariableDescriptorCountLayoutSupportEXT-sType-sType"' : 'VALIDATION_ERROR_46e2b00b',
    '"VUID-VkPhysicalDeviceDescriptorIndexingFeaturesEXT-sType-sType"' : 'VALIDATION_ERROR_4702b00b',
    '"VUID-VkPhysicalDeviceDescriptorIndexingPropertiesEXT-sType-sType"' : 'VALIDATION_ERROR_4722b00b',
    '"VUID-VkPhysicalDeviceShaderCorePropertiesAMD-sType-sType"' : 'VALIDATION_ERROR_4742b00b',
    '"VUID-VkVertexInputBindingDivisorDescriptionEXT-binding-01869"' : 'VALIDATION_ERROR_47600e9a',
    '"VUID-VkVertexInputBindingDivisorDescriptionEXT-divisor-01870"' : 'VALIDATION_ERROR_47600e9c',
    '"VUID-VkVertexInputBindingDivisorDescriptionEXT-inputRate-01871"' : 'VALIDATION_ERROR_47600e9e'}

# invert the dictionary
idict = {value: key for key, value in vuid_dict.items()}

# construct regex using inverted dictionary
regex = re.compile('|'.join(map(re.escape, idict)))
def subst(match):
    return idict[match.group(0)]

# process files in place, with backup (.bak)
numfiles = len(sys.argv) - 1
filenum = 1
while (numfiles >= filenum):
    file_name = sys.argv[filenum]
    bak_name = file_name + ".bak"
    ifile = open(file_name, "r")
    in_text = ifile.read()
    ifile.close()
    os.rename(file_name, bak_name)
    out_text = regex.sub(subst, in_text)
    ofile = open(file_name, "w")
    ofile.write(out_text)
    ofile.close()
    print("Processed ", file_name)
    filenum = filenum + 1

